@@ -1,20 +1,18 @@
 #include "BehaviorBase.h"
 #include "Events/EventRouter.h"
 
-std::set<BehaviorBase*> BehaviorBase::registry;
-
 BehaviorBase::BehaviorBase(const std::string& name)
 	: ReferenceCounter(), EventListener(), started(false),
 	  instanceName(name), className(name)
 {
-	registry.insert(this);
+	getRegistryInstance().insert(this);
 }
 
 BehaviorBase::BehaviorBase(const std::string& classname, const std::string& instancename)
 	: ReferenceCounter(), EventListener(), started(false),
 	  instanceName(instancename), className(classname)
 {
-	registry.insert(this);
+	getRegistryInstance().insert(this);
 }
 
 
@@ -22,7 +20,7 @@ BehaviorBase::BehaviorBase(const BehaviorBase& b)
 	: ReferenceCounter(b), EventListener(b), started(b.started),
 	  instanceName(b.instanceName), className(b.className)
 {
-	registry.insert(this);
+	getRegistryInstance().insert(this);
 }
 
 BehaviorBase&
@@ -39,7 +37,7 @@ BehaviorBase::~BehaviorBase() {
 	if(started)
 		std::cerr << "Behavior " << getName() << " deleted while running: use 'RemoveReference', not 'delete'" << std::endl;
 	erouter->removeListener(this);
-	registry.erase(this);
+	getRegistryInstance().erase(this);
 }
 
 void
@@ -56,20 +54,24 @@ BehaviorBase::DoStop() {
 	//std::cout << getName() << " stopped " << this << std::endl;
 	if(started) {
 		started=false;
-		erouter->removeListener(this);
-		erouter->removeTimer(this);
+		erouter->remove(this);
 		RemoveReference();
 	}
 }
 
+std::set<BehaviorBase*>& BehaviorBase::getRegistryInstance() {
+	static std::set<BehaviorBase*> registry;
+	return registry;
+}
+
 /*! @file
  * @brief Implements BehaviorBase from which all Behaviors should inherit
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2005/07/07 22:33:51 $
+ * $Date: 2006/09/27 21:15:52 $
  */
 
