@@ -8,19 +8,24 @@
 #include <set>
 
 //! The basis from which all other Behaviors should inherit
-/*! Makes use of ReferenceCounter so that behaviors can automatically delete themselves if
- *  wanted.
+/*! 
+ *  For complex behaviors, it may be helpful to break aspects of the behaviors into independent 'states', and
+ *  use a state machine formalism to control them.  See StateNode and Transition for more information.
  *
- *  Make sure your own DoStart and DoStop call BehaviorBase::DoStart (or Stop) to allow
- *  the auto-deletion from reference counting... otherwise you'll get memory leaks if you
- *  rely on the reference counting.
- *
- *  For an empty behavior boilerplate file to help you get started quickly, try
- *  <a href="http://cvs.tekkotsu.org/cgi-bin/viewcvs.cgi/Tekkotsu/project/templates/behavior.h?rev=HEAD&content-type=text/vnd.viewcvs-markup"><i>project</i><tt>/templates/behavior.h</tt></a>:
+ *  Quick-start boilerplate is included in the distribution: <a href="http://cvs.tekkotsu.org/cgi/viewcvs.cgi/Tekkotsu/project/templates/behavior.h?rev=HEAD&content-type=text/vnd.viewcvs-markup"><i>project</i><tt>/templates/behavior.h</tt></a>:
  * 
- *  But it would probably still be a good idea to go through the "<a
- *  href="../FirstBehavior.html">First Behavior</a>" tutorial to get a better idea of
- *  what's going on.
+ *  Tutorials:
+ *  - <a href="../FirstBehavior.html">Tekkotsu's "First Behavior" Tutorial</a>
+ *  - <a href="http://www.cs.cmu.edu/~dst/Tekkotsu/Tutorial/behaviors.shtml">David Touretzky's "Behaviors" Chapter</a>
+ *  - <a href="http://www.cs.cmu.edu/afs/cs/academic/class/15494-s06/www/lectures/behaviors.pdf">CMU's Cognitive Robotics course slides</a>
+ *  
+ *  REMEMBER: If/when you override DoStart() / DoStop(), make sure that your own implementation calls BehaviorBase's implementation to allow
+ *  proper reference counting... otherwise you'll get memory leaks and other odd issues. (see boilerplate link above for example usage)
+ *
+ *  Also, if you instantiate a behavior on the stack instead of the heap (this is very rarely done), remember to call 
+ *  SetAutoDelete(false) (provided from the ReferenceCounter base class) -- don't want it to try to free memory
+ *  on the stack when the behavior is stopped!  (The stack limits the allocation of the behavior
+ *  to the current scope, which overrides the reference counting.)
  */
 class BehaviorBase : public ReferenceCounter, public EventListener {
 public:
@@ -74,9 +79,9 @@ public:
 	//! Returns true if the behavior is currently running
 	virtual bool isActive() const { return started; }
 	
-	//! Allows read-only access to the set of currently instantiated behaviors
+	//! This read-only set allows us list all the currently instantiated behaviors
 	/*! Not all of these behaviors are necessarily active, this is everything that has been allocated and not yet deallocated */
-	static const std::set<BehaviorBase*>& getRegistry() { return registry; }
+	static const std::set<BehaviorBase*>& getRegistry() { return getRegistryInstance(); }
 
 	// Just some debugging stuff in stasis
 	/*	virtual void AddReference() {
@@ -91,6 +96,9 @@ public:
 	*/
 	
 protected:
+	//! static function to provide well-defined initialization order
+	static std::set<BehaviorBase*>& getRegistryInstance();
+
 	//! constructor, @a name is used as both instance name and class name
 	explicit BehaviorBase(const std::string& name);
 	//! constructor, allows different initial values for class name and instance name
@@ -103,7 +111,6 @@ protected:
 	bool started; //!< true when the behavior is active
 	std::string instanceName; //!< holds the name of this instance of behavior
 	const std::string className; //!< holds the type of the subclass of this behavior as a string
-	static std::set<BehaviorBase*> registry; //!< allows us to keep track of all the current behaviors
 };
 
 /*! @file
@@ -111,10 +118,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.21 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.28 $
  * $State: Exp $
- * $Date: 2005/04/23 18:32:59 $
+ * $Date: 2006/10/03 22:09:40 $
  */
 
 #endif
