@@ -11,6 +11,9 @@
 #include "Shared/ERS220Info.h"
 #include "Shared/ERS7Info.h"
 #include "Shared/string_util.h"
+#ifndef PLATFORM_APERIOS
+#  include "local/sim/Simulator.h"
+#endif
 #include <sstream>
 
 Controller * Controller::theOneController=NULL;
@@ -28,11 +31,11 @@ using namespace string_util;
 
 void Controller::DoStart() {
 	BehaviorBase::DoStart();
-	sndman->LoadFile(config->controller.select_snd);
-	sndman->LoadFile(config->controller.next_snd);
-	sndman->LoadFile(config->controller.prev_snd);
-	sndman->LoadFile(config->controller.read_snd);
-	sndman->LoadFile(config->controller.cancel_snd);
+	sndman->loadFile(config->controller.select_snd);
+	sndman->loadFile(config->controller.next_snd);
+	sndman->loadFile(config->controller.prev_snd);
+	sndman->loadFile(config->controller.read_snd);
+	sndman->loadFile(config->controller.cancel_snd);
 	erouter->addListener(this,EventBase::estopEGID);
 	// Turn on wireless
 	gui_comm=wireless->socket(SocketNS::SOCK_STREAM, 2048, 32000);
@@ -48,11 +51,11 @@ void Controller::DoStart() {
 }
 
 void Controller::DoStop() {
-	sndman->ReleaseFile(config->controller.select_snd);
-	sndman->ReleaseFile(config->controller.next_snd);
-	sndman->ReleaseFile(config->controller.prev_snd);
-	sndman->ReleaseFile(config->controller.read_snd);
-	sndman->ReleaseFile(config->controller.cancel_snd);
+	sndman->releaseFile(config->controller.select_snd);
+	sndman->releaseFile(config->controller.next_snd);
+	sndman->releaseFile(config->controller.prev_snd);
+	sndman->releaseFile(config->controller.read_snd);
+	sndman->releaseFile(config->controller.cancel_snd);
 	erouter->removeListener(this);
 	reset();
 	motman->removeMotion(display);
@@ -216,7 +219,7 @@ int Controller::gui_comm_callback(char *buf, int bytes) {
 
 	//pass a line at a time to the controller
 	while(s.size()>0) {
-		unsigned int endline=s.find('\n');
+		std::string::size_type endline=s.find('\n');
 		if(endline==std::string::npos) {
 			incomplete+=s;
 			return 0;
@@ -247,7 +250,7 @@ int Controller::console_callback(char *buf, int bytes) {
 
 	//pass a line at a time to the controller
 	while(s.size()>0) {
-		unsigned int endline=s.find('\n');
+		std::string::size_type endline=s.find('\n');
 		if(endline==std::string::npos) {
 			incomplete+=s;
 			return 0;
@@ -260,10 +263,18 @@ int Controller::console_callback(char *buf, int bytes) {
 			incomplete+=s.substr(0,endline);
 		
 		//is now complete
-		if(wireless->isConnected(theOneController->gui_comm->sock))
-			erouter->postEvent(new TextMsgEvent(incomplete));
-		else
-			theOneController->takeLine(incomplete); 
+		switch(config->main.consoleMode) {
+			case Config::main_config::CONTROLLER:
+				theOneController->takeLine(incomplete); break;
+			case Config::main_config::TEXTMSG:
+				erouter->postEvent(TextMsgEvent(incomplete,0)); break;
+			case Config::main_config::AUTO:
+				if(wireless->isConnected(theOneController->gui_comm->sock)) 	 
+					erouter->postEvent(TextMsgEvent(incomplete,0)); 	 
+				else
+					theOneController->takeLine(incomplete); 
+				break;
+		}
 		incomplete.erase();
 		s=s.substr(endline+1);
 	}
@@ -365,7 +376,7 @@ void Controller::takeLine(const std::string& s) {
 			setNext(cmdstack.top()->doCancel());
 		} else if(args[0]=="!select") {
 		  if (args.size() == 1)
-			setNext(cmdstack.top()->doSelect());
+				setNext(cmdstack.top()->doSelect());
 		  else {
 		    select(root, args[1].c_str());
 		    refresh();
@@ -387,11 +398,66 @@ void Controller::takeLine(const std::string& s) {
 				cmdstack.push(tmpstack.top());
 				tmpstack.pop();
 			}
+		} else if(args[0]=="!post") {
+			if(args.size()<4) {
+				serr->printf("Bad post command, need at least 3 arguments: generator source type [duration]\n");
+				return;
+			}
+			//parse generator id -- could be a generator name or a numeric value
+			int egid=0;
+			for(;egid<EventBase::numEGIDs && args[1]!=EventBase::EventGeneratorNames[egid];egid++) {}
+			if(egid==EventBase::numEGIDs) {
+				egid=atoi(args[1].c_str());
+				if(egid==0 && args[1]!="0") {
+					serr->printf("Bad event generator '%s'\n",args[1].c_str());
+					return;
+				}
+			}
+			//parse source id -- numeric value, unless egid is buttonEGID, in which case we can look up a button name
+			//(if you want to add support for other symbolic source types, this is where to do it)
+			unsigned int source;
+			if(egid==EventBase::buttonEGID) {
+				source=0;
+				for(;source<NumButtons && args[2]!=buttonNames[source];source++) {}
+				if(source==NumButtons) {
+					source=atoi(args[2].c_str());
+					if(source==0 && args[2]!="0") {
+						serr->printf("Invalid button name or index '%s'\n",args[2].c_str());
+						return;
+					}
+				}
+			} else {
+				source=atoi(args[2].c_str());
+			}
+			//parse type id -- numeric, name, or abbreviated name
+			int etid=0;
+			for(;etid<EventBase::numETIDs && args[3]!=EventBase::EventTypeNames[etid];etid++) {}
+			if(etid==EventBase::numETIDs) {
+				etid=0;
+				for(;etid<EventBase::numETIDs && args[3]!=EventBase::EventTypeAbbr[etid];etid++) {}
+				if(etid==EventBase::numETIDs) {
+					etid=atoi(args[3].c_str());
+					if(etid==0 && args[3]!="0") {
+						serr->printf("Bad event type '%s'\n",args[3].c_str());
+						return;
+					}
+				}
+			}
+			//duration field (optional, have to check args.size())
+			int dur=0;
+			if(args.size()>4)
+				dur=atoi(args[4].c_str());
+			//send event!
+			if(egid==EventBase::buttonEGID && isControlling)
+				erouter->removeTrapper(this);
+			erouter->postEvent((EventBase::EventGeneratorID_t)egid,source,(EventBase::EventTypeID_t)etid,dur);
+			if(egid==EventBase::buttonEGID && isControlling)
+				erouter->addTrapper(this,EventBase::buttonEGID);
 		} else if(args[0]=="!msg") {
 			if(offsets.size()>1)
-				erouter->postEvent(new TextMsgEvent(s.substr(offsets[1])));
+				erouter->postEvent(TextMsgEvent(s.substr(offsets[1]),0));
 			else
-				erouter->postEvent(new TextMsgEvent(""));
+				erouter->postEvent(TextMsgEvent("",0));
 		} else if(args[0]=="!hello") {
 			static unsigned int count=0;
 			count++;
@@ -417,8 +483,14 @@ void Controller::takeLine(const std::string& s) {
 				}
 			refresh();
 		} else if(args[0]=="!set") {
-      setConfig(s.substr(offsets[1]).c_str());
-    } else
+			setConfig(s.substr(offsets[1]).c_str());
+		} else if(args[0]=="!sim") {
+#ifdef PLATFORM_APERIOS
+			serr->printf("!sim command invalid -- not running in simulator!\n");
+#else
+			Simulator::sendCommand(s.substr(offsets[1]));
+#endif
+		} else
 			setNext(cmdstack.top()->takeInput(s));
 	}
 }
@@ -492,8 +564,8 @@ bool Controller::chkCmdStack() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.45 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.55 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:44 $
+ * $Date: 2006/09/18 18:08:05 $
  */
