@@ -22,8 +22,9 @@
  *	- '<tt>!next</tt>' - calls ControlBase::doNextItem() of the current control
  *	- '<tt>!prev</tt>' - calls ControlBase::doPrevItem() of the current control
  *	- '<tt>!select</tt> [<i>item</i>]' - calls ControlBase::doSelect() of the current control, unless <i>item</i> is specified, in which case it is searched for, starting at the root.
- *	- '<tt>!cancel</tt>' - calls ControlBase::doCancel() of the current control
+ *	- '<tt>!cancel</tt>' - calls current ControlBase::doCancel(), indicates control should cease activity and return to parent (e.g. "Back" button)
  *	- '<tt>!dump_stack</tt>' - requests a dump of the current stack of submenus (useful if the GUI (re)connects and thus current robot state is unknown)
+ *  - '<tt>!post </tt><i>generator source type</i> [<i>duration</i>]' - posts an event of your choosing; <i>Generator</i> should be an entry in EventBase::EventGeneratorNames (e.g. timerEGID) or numeric value; <i>source</i> should be a numeric value (unless generator is buttonEGID, in which case it could be an entry from #buttonNames); <i>type</i> can be a numeric value, EventBase::EventTypeNames (e.g. <tt>activate</tt>), or EventBase::EventTypeAbbr (e.g. <tt>A</tt>); <i>duration</i>, if specified, gives the value for EventBase::duration
  *	- '<tt>!msg </tt><i>text</i>' - sends <i>text</i> out as a TextMsgEvent; also note that any text entered on the console port while a GUI is also connected will also be sent as a TextMsgEvent, without needing the !input.
  *  - '<tt>!root </tt><i>text</i>' - calls ControlBase::takeInput(<i>text</i>) on the root control
  *  - '<tt>!hello</tt>' - responds with '<tt>hello\\n</tt><i>count</i>\\n' where <i>count</i> is the number of times '<tt>!hello</tt>' has been sent.  Good for detecting first connection after boot vs. a reconnect.
@@ -220,10 +221,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.35 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.37 $
  * $State: Exp $
- * $Date: 2005/08/04 04:37:55 $
+ * $Date: 2005/09/01 18:53:06 $
  */
 
 #endif
