@@ -9,7 +9,11 @@
 class BehaviorSwitchActivatorControl : public ControlBase {
 public:
 	//! lets you tell it what action to perform
-	enum Mode_t { start, stop, toggle };
+	enum Mode_t {
+		start, //!< Passed to constructor, indicates this control should start the behavior when activated
+		stop,  //!< Passed to constructor, indicates this control should stop the behavior when activated
+		toggle //!< Passed to constructor, indicates this control should toggle the behavior when activated
+	};
 
 	//!constructor
 	BehaviorSwitchActivatorControl(const std::string& n, BehaviorSwitchControlBase* bscb, Mode_t m=toggle) : ControlBase(n), behswitch(bscb), mode(m) {}
@@ -54,10 +58,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.3 $
- * $State: Rel $
- * $Date: 2003/09/25 15:26:10 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.4 $
+ * $State: Exp $
+ * $Date: 2006/09/16 06:28:06 $
  */
 
 #endif
