@@ -7,6 +7,7 @@
 #include "Shared/ReferenceCounter.h"
 #include "Shared/Factory.h"
 #include "Shared/debuget.h"
+#include "Events/TextMsgEvent.h"
 
 //! Holds some utility classes and functions for BehaviorSwitchControl which shouldn't be stored in a templated class
 class BehaviorSwitchControlBase : public ControlBase {
@@ -20,9 +21,10 @@ public:
 	 *  Pass NULL instead of one of these to get checkbox-style. */
 	class BehaviorGroup : public ReferenceCounter {
 	public:
-		BehaviorGroup() : curBehavior(NULL) { } //!< contructor
+		BehaviorGroup() : curBehavior(NULL), members() { } //!< contructor
 		~BehaviorGroup() { if(curBehavior!=NULL) curBehavior->DoStop(); } //!< destructor, will stop the current behavior if it was a one-shot
 		BehaviorBase * curBehavior; //!< pointer to current behavior
+		std::set<BehaviorSwitchControlBase*> members; //!< set of members of the group
 	private:
 		BehaviorGroup(const BehaviorGroup&); //!< shouldn't be called
 		BehaviorGroup operator=(const BehaviorGroup&); //!< shouldn't be called
@@ -31,17 +33,41 @@ public:
 	//! constructor
 	BehaviorSwitchControlBase(const std::string& n, BehaviorBase* beh, BehaviorGroup* bg=NULL)
 		: ControlBase(n), behgrp(bg), mybeh(beh) {
-		if(behgrp!=NULL)
-			behgrp->AddReference();
-		if(mybeh!=NULL)
+		if(mybeh!=NULL) {
 			mybeh->AddReference();
-	}
-	//! constructor
-	BehaviorSwitchControlBase(BehaviorBase* beh, BehaviorGroup* bg=NULL)
-		: ControlBase(), behgrp(bg), mybeh(beh) {
-		if(behgrp!=NULL)
+			mybeh->setName(n);
+			if(mybeh->isActive())
+				mybeh->AddReference();
+		}
+		if(behgrp!=NULL) {
 			behgrp->AddReference();
+			behgrp->members.insert(this);
+			if(mybeh!=NULL && mybeh->isActive()) {
+				if(behgrp->curBehavior!=NULL) {
+					behgrp->curBehavior->DoStop();
+					notifyGroupMembers();
+				}
+				behgrp->curBehavior=mybeh;
+			}
+		}
+	}
+	//! constructor, behavior must not be NULL
+	BehaviorSwitchControlBase(BehaviorBase* beh, BehaviorGroup* bg=NULL)
+		: ControlBase(beh->getName()), behgrp(bg), mybeh(beh) {
 		mybeh->AddReference();
+		if(mybeh->isActive())
+			mybeh->AddReference();
+		if(behgrp!=NULL) {
+			behgrp->AddReference();
+			behgrp->members.insert(this);
+			if(mybeh!=NULL && mybeh->isActive()) {
+				if(behgrp->curBehavior!=NULL) {
+					behgrp->curBehavior->DoStop();
+					notifyGroupMembers();
+				}
+				behgrp->curBehavior=mybeh;
+			}
+		}
 	}
 
 	//! destructor
@@ -50,6 +76,7 @@ public:
 		if(mybeh!=NULL)
 			stop();
 		if(behgrp!=NULL) {
+			behgrp->members.erase(this);
 			behgrp->RemoveReference();
 			behgrp=NULL;
 		}
@@ -67,6 +94,15 @@ public:
 	//! toggles the behavior
 	virtual BehaviorSwitchControlBase* toggle() { if(isRunning()) stopother(); else { stopother(); startmine(); } return this; }
 
+	virtual ControlBase * takeInput(const std::string& msg) {
+		if(options.size()>0)
+			return ControlBase::takeInput(msg);
+		if(!isRunning())
+			startmine();
+		mybeh->processEvent(TextMsgEvent(msg,1));
+		return NULL;
+	}
+	
 	//! tells the current behavior (if there is one) to stop then loads its own
 	/*! @return NULL unless there are submenus */
 	virtual ControlBase * activate(MotionManager::MC_ID display, Socket * gui) {
@@ -89,35 +125,46 @@ public:
 		return "Class "+mybeh->getClassName()+": "+mybeh->getDescription();
 	}
 	
+	//! Returns true if the associated behavior is running
+	virtual bool isRunning() const {
+		if(mybeh==NULL) //not created or has been destroyed, definitely not running
+			return false;
+		// so, beh has been created (but may have been stopped by another in the group)
+		return mybeh->isActive(); //just check active flag (is valid object, we would have set it to NULL if we stopped it ourselves)
+	}
+	
 protected:
 	//! Stops the "other" guy's behavior - if ::behgrp is NULL, stops ourselves
 	virtual void stopother() {
 		if(behgrp==NULL) {
-			if(mybeh->isActive())
+			if(mybeh!=NULL && mybeh->isActive()) {
 				mybeh->DoStop();
+				behaviorStopped();
+			}
 		} else if(behgrp->curBehavior!=NULL) {
-			behgrp->curBehavior->DoStop();
+			if(behgrp->curBehavior->isActive()) {
+				behgrp->curBehavior->DoStop();
+				notifyGroupMembers();
+			}
 			behgrp->curBehavior=NULL;
 		}
 	}
-
+	
 	//! Starts our behavior
 	virtual void startmine() {
 		if(behgrp!=NULL)
 			behgrp->curBehavior=mybeh;
 		mybeh->DoStart();
 	}
-
-	//! Returns true if the associated behavior is running
-	virtual bool isRunning() const {
-		if(mybeh==NULL) //not created or has been destroyed, definitely not running
-			return false;
-		// so, beh has been created (but may have been stopped by another in the group)
-		if(behgrp==NULL) //no group
-			return mybeh->isActive(); //just check active flag (is valid object, we would have set it to NULL if we stopped it ourselves)
-		// so, we're in a group, someone else could have stopped us
-		return (behgrp->curBehavior==mybeh); //all we can see is if the current behavior is ours.  If it is, it'll be active
+	
+	//! updates other members in the group that the current behavior stopped -- do not call if behgrp is NULL
+	virtual void notifyGroupMembers() {
+		for(std::set<BehaviorSwitchControlBase*>::iterator it=behgrp->members.begin(); it!=behgrp->members.end(); ++it)
+			if((*it)->mybeh==behgrp->curBehavior)
+				(*it)->behaviorStopped();
 	}
+	//! called by notifyGroupMembers if #mybeh was destructed when stopped
+	virtual void behaviorStopped() {}
 
 	BehaviorGroup * behgrp; //!< the behavior group this belongs to.  Uses this to track the "current" behavior
 	BehaviorBase* mybeh; //!< used to store the behavior.  If retained and non-NULL, will be valid.  However, if not retained, only valid if equals behgrp->curBehavior
@@ -136,49 +183,34 @@ class BehaviorSwitchControl : public BehaviorSwitchControlBase {
 public:
 	//! constructor, can use this to toggle a single behavior on and off
 	BehaviorSwitchControl(const std::string& n, bool retain=false)
-		: BehaviorSwitchControlBase(n,NULL,NULL), retained(retain)
+		: BehaviorSwitchControlBase(n,NULL,NULL), retained(retain), startref(NULL)
 	{}
 	//! constructor, if you want to use an already constructed behavior
 	BehaviorSwitchControl(B* beh, BehaviorGroup* bg=NULL)
-		: BehaviorSwitchControlBase(beh,bg), retained(true)
+		: BehaviorSwitchControlBase(beh,bg), retained(true), startref(NULL)
 	{}
 	//! constructor, if you want to use an already constructed behavior, but unretain it if it's stopped (if not retaining, will start @a beh if it's not already started)
 	BehaviorSwitchControl(const std::string& n, B* beh, BehaviorGroup* bg=NULL, bool retain=false)
-		: BehaviorSwitchControlBase(n,beh,bg), retained(retain)
+		: BehaviorSwitchControlBase(n,beh,bg), retained(retain), startref(NULL)
 	{
 		if(!retained) {
 			// have to make sure behavior is started to maintain invariants
 			if(!mybeh->isActive()) {
-				//keep reference from superclass's constructor in case mybeh stops itself right away
-				mybeh->DoStart();
-				bool stopped=!mybeh->isActive();
-				mybeh->RemoveReference(); //cancels reference from BehaviorSwitchControlBase's constructor
-				if(stopped)
-					mybeh=NULL;
-			} else
-				mybeh->RemoveReference(); //cancels reference from BehaviorSwitchControlBase's constructor
-		}
-		if(behgrp!=NULL) {
-			if(mybeh->isActive()) {
-				if(behgrp->curBehavior!=NULL)
-					behgrp->curBehavior->DoStop();
-				behgrp->curBehavior=mybeh;
-			} else if(!retained) {
-				if(behgrp->curBehavior!=NULL)
-					behgrp->curBehavior->DoStop();
-				behgrp->curBehavior=NULL;
+				startmine();
 			}
+			mybeh->RemoveReference(); //cancels reference from BehaviorSwitchControlBase's constructor
 		}
 	}
 	//! constructor, needs to know what group its in and whether to retain its behavior
 	BehaviorSwitchControl(const std::string& n, BehaviorGroup* bg, bool retain=false)
-		: BehaviorSwitchControlBase(n,NULL,bg), retained(retain)
+		: BehaviorSwitchControlBase(n,NULL,bg), retained(retain), startref(NULL)
 	{}
 	
 	//! destructor
 	virtual ~BehaviorSwitchControl() {
 		stop();
 		if(behgrp!=NULL) {
+			behgrp->members.erase(this);
 			behgrp->RemoveReference();
 			behgrp=NULL;
 		}
@@ -200,27 +232,8 @@ public:
 			return BehaviorSwitchControlBase::getDescription();
 	}
 	
-
 protected:
 
-	virtual void stopother() {
-		if(behgrp==NULL) {
-			if(mybeh!=NULL) {
-				if(mybeh->isActive()) {
-					mybeh->DoStop();
-					if(!retained)
-						mybeh=NULL;
-				} else
-					ASSERT(retained,"null group, non-null not retained beh, not active, did you call inherited DoStart/DoStop in your Behavior?");
-			}
-		} else if(behgrp->curBehavior!=NULL) {
-			behgrp->curBehavior->DoStop();
-			if(behgrp->curBehavior==mybeh)
-				mybeh=NULL;
-			behgrp->curBehavior=NULL;
-		}
-	}
-
 	virtual void startmine() {
 		if(!retained) {
 			Al allocator;
@@ -238,17 +251,20 @@ protected:
 			if(behgrp!=NULL)
 				behgrp->curBehavior=mybeh;
 		}
-		mybeh->AddReference(); //temporary reference in case mybeh stops itself right away
+		startref=mybeh;
+		startref->AddReference();
 		mybeh->DoStart();
-		bool stopped=(!mybeh->isActive() && !retained);
-		mybeh->RemoveReference();
-		if(stopped) {
-			if(behgrp!=NULL && behgrp->curBehavior==mybeh)
-				behgrp->curBehavior=NULL;
-			mybeh=NULL;
-		}
 	}
 
+	//! adds a check to see if behavior has stopped itself -- if so, remove startref
+	virtual bool isRunning() const {
+		if(BehaviorSwitchControlBase::isRunning())
+			return true;
+		else if(startref!=NULL)
+			const_cast<BehaviorSwitchControl<B,Al>*>(this)->stopother();
+		return false;
+	}		
+	
 	//! Returns true if mybeh is pointing to a valid object
 	virtual bool isValid() const {
 		if(isRunning())
@@ -256,8 +272,19 @@ protected:
 		return retained;
 	}
 
-private:
+	virtual void behaviorStopped() {
+		if(!retained)
+			mybeh=NULL;
+		if(startref!=NULL) {
+			startref->RemoveReference();
+			startref=NULL;
+		}
+	}
+	
 	bool retained; //!< true if the behavior should be generated once and retained after DoStop.  Otherwise, a new one is generated each time it is started
+	BehaviorBase * startref; //!< true if a reference was added (and still current) from calling DoStart
+	
+private:
 	BehaviorSwitchControl(const BehaviorSwitchControl&); //!< shouldn't call this
 	BehaviorSwitchControl operator=(const BehaviorSwitchControl&); //!<shouldn't call this
 };
@@ -267,10 +294,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.23 $
  * $State: Exp $
- * $Date: 2005/06/29 22:02:58 $
+ * $Date: 2006/09/01 18:21:20 $
  */
 
 #endif
