@@ -37,7 +37,8 @@ void FreeMemReportControl::refresh() {
 //! reports size of free memory - if this is below low_mem, also generates a warning
 void FreeMemReportControl::report() {
 	size_t freemem=freeMem();
-	sout->printf("%lu bytes free\n",(unsigned long)freemem);
+	sout->printf("%lu bytes free (%+ld)\n",(unsigned long)freemem,(long)(freemem-lastReport));
+	lastReport=freemem;
 	if(freemem<low_mem)
 		if(isWarning)
 			serr->printf("WARNING: Low memory: %lu\n",(unsigned long)freemem);
@@ -69,9 +70,9 @@ void FreeMemReportControl::resetTimerFreq() {
  * @author ejt (object), alokl (core function)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2005/02/05 07:27:26 $
+ * $Date: 2006/09/25 23:26:56 $
  */
 
