@@ -23,6 +23,7 @@ class LoadPostureControl : public FileBrowserControl, public EventListener {
 		setFilter("*.pos");
 	}
 	
+	//! destructor
 	virtual ~LoadPostureControl() {
 		erouter->removeListener(this);
 		motman->removeMotion(ledid);
@@ -53,7 +54,7 @@ protected:
 			runFile();
 		} else {
 			//we have to wait for the estop to be turned off
-			sndman->PlayFile("donkey.wav");
+			sndman->playFile("donkey.wav");
 			SharedObject<LedMC> led;
 			led->cset(FaceLEDMask,0);
 			led->cycle(BotLLEDMask,1000,3,0,0);
@@ -74,10 +75,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.16 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.18 $
  * $State: Exp $
- * $Date: 2005/06/06 23:05:51 $
+ * $Date: 2006/09/18 18:07:54 $
  */
 
 #endif
