@@ -37,8 +37,9 @@ protected:
 		if(walk==NULL)
 			serr->printf("Invalid walk for loading\n");
 		else {
-			walk->LoadFile(f.c_str());
-			motman->checkinMotion(id);
+			walk->loadFile(f.c_str());
+			if(id!=MotionManager::invalid_MC_ID)
+				motman->checkinMotion(id);
 		}
 		return NULL;
 	}
@@ -56,10 +57,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2005/06/06 23:05:51 $
+ * $Date: 2006/09/09 04:32:17 $
  */
 
 #endif
