@@ -20,9 +20,9 @@ class PlaySoundControl : public FileBrowserControl {
 protected:
 	//!does the actual loading of the MotionSequence
 	virtual ControlBase* selectedFile(const std::string& f) {
-		sndman->StopPlay();
+		sndman->stopPlay();
 		if(sndman)
-			sndman->PlayFile(f.c_str());
+			sndman->playFile(f.c_str());
 		return this;
 	}
 };
@@ -32,10 +32,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2005/06/06 23:05:51 $
+ * $Date: 2006/09/18 18:07:54 $
  */
 
 #endif
