@@ -64,13 +64,14 @@ void
 PostureEditor::refresh() {
 	//cout << "refresh" << endl;
 	if(isEStopped()) {
+		processEvent(EventBase(EventBase::timerEGID,1,EventBase::statusETID,0));
 		erouter->addTimer(this,0,500);
 		options[0]=disabledLoadPose;
 	} else {
 		options[0]=loadPose;
 	}
 	if(loadPose->getLastInput().size()>0) {
-		pose.LoadFile(loadPose->getLastInput().c_str());
+		pose.loadFile(loadPose->getLastInput().c_str());
 		updatePose(moveTime);
 		loadPose->clearLastInput();
 	} else if(savePose->getLastInput().size()>0) {
@@ -78,7 +79,7 @@ PostureEditor::refresh() {
 		std::string filename=savePose->getLastInput();
 		if(filename.find(".")==std::string::npos)
 			filename+=".pos";
-		pose.SaveFile(config->motion.makePath(filename).c_str());
+		pose.saveFile(config->motion.makePath(filename).c_str());
 		savePose->takeInput("");
 	} else {
 		updatePose(moveTime/2);
@@ -128,7 +129,8 @@ PostureEditor::processEvent(const EventBase& e) {
 			pose(i).value=state->outputs[i];
 		for(unsigned int i=LEDOffset+NumLEDs; i<NumOutputs; i++)
 			pose(i).value=state->outputs[i];
-		refresh();
+		if(e.getSourceID()==0) // source==1 indicates it's a forged event sent from refresh -- don't inf. recurse
+			refresh();
 	} else {
 		serr->printf("WARNING: PostureEditor unexpected event: %s\n",e.getName().c_str());
 	}
@@ -168,8 +170,8 @@ PostureEditor::updatePose(unsigned int delay) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.18 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.20 $
  * $State: Exp $
- * $Date: 2005/08/02 22:24:20 $
+ * $Date: 2006/09/09 04:32:18 $
  */
