@@ -3,7 +3,7 @@
 #define INCLUDED_ProfilerCheckControl_h_
 
 #include "ControlBase.h"
-#include "Shared/WorldState.h"
+#include "Shared/Profiler.h"
 
 //! causes the WorldState::mainProfile and WorldState::motionProfile to display reports to #sout
 class ProfilerCheckControl : public ControlBase {
@@ -13,8 +13,9 @@ public:
 
 	//! Prints a report to sout
 	virtual ControlBase * activate(MotionManager::MC_ID, Socket *) {
-		sout->printf("~~~ Main: ~~~\n%s",state->mainProfile.report().c_str());
-		sout->printf("~~~ Motion: ~~~\n%s",state->motionProfile.report().c_str());
+		sout->printf("~~~ Main: ~~~\n%s\n",mainProfiler==NULL?"Main profile unavailable":mainProfiler->report().c_str());
+		sout->printf("~~~ Motion: ~~~\n%s\n",motionProfiler==NULL?"Motion profile unavailable":motionProfiler->report().c_str());
+		sout->printf("~~~ Sound: ~~~\n%s\n",soundProfiler==NULL?"Sound profile unavailable":soundProfiler->report().c_str());
 		return NULL;
 	}
 };
@@ -24,10 +25,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/11/11 20:34:59 $
+ * $Date: 2006/07/13 17:25:50 $
  */
 
 #endif
