@@ -22,7 +22,7 @@ class SavePostureControl : public StringInputControl {
 			PostureEngine post;
 			post.takeSnapshot();
 			post.setWeights(1);
-			post.SaveFile(filename.c_str());
+			post.saveFile(filename.c_str());
 		}
 		return StringInputControl::takeInput(msg);
 	}
@@ -33,10 +33,10 @@ class SavePostureControl : public StringInputControl {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:45 $
+ * $Date: 2006/09/09 04:32:18 $
  */
 
 #endif
