@@ -28,8 +28,9 @@ class SaveWalkControl : public StringInputControl {
 			if(walk==NULL)
 				serr->printf("Invalid walk for saving\n");
 			else {
-				walk->SaveFile(filename.c_str());
-				motman->checkinMotion(id);
+				walk->saveFile(filename.c_str());
+				if(id!=MotionManager::invalid_MC_ID)
+					motman->checkinMotion(id);
 			}
 		}
 		return StringInputControl::takeInput(msg);
@@ -49,9 +50,9 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:45 $
+ * $Date: 2006/09/09 04:32:18 $
  */
 #endif
