@@ -1,12 +1,17 @@
 #include "ShutdownControl.h"
 #ifdef PLATFORM_APERIOS
 #  include <OPENR/OPENRAPI.h>
+#else
+#  include "local/sim/SharedGlobals.h"
 #endif
 
 ControlBase * ShutdownControl::doSelect()    {
 #ifdef PLATFORM_APERIOS
 	OBootCondition bc(0);
 	OPENR::Shutdown(bc);
+#else
+	if(globals!=NULL)
+		globals->signalShutdown();
 #endif
 	return NULL;
 }
@@ -16,9 +21,9 @@ ControlBase * ShutdownControl::doSelect()    {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2005/02/02 18:20:27 $
+ * $Date: 2005/08/31 21:55:12 $
  */
 
