@@ -6,7 +6,7 @@
 #ifdef PLATFORM_APERIOS
 #  warning SimulatorAdvanceFrameControl is only useful when running in simulation!
 #else
-#  include "local/sim/Main.h"
+#  include "local/sim/Simulator.h"
 #endif
 
 //! Requests the next camera frame and sensor data, for use when running in simulation
@@ -32,23 +32,25 @@ public:
 #ifndef PLATFORM_APERIOS
 
 	virtual ControlBase * activate(MotionManager::MC_ID disp_id, Socket * gui) {
-		Main::advanceVision();
-		Main::advanceSensor();
+		Simulator::sendCommand("advance");
 		return NullControl::activate(disp_id,gui);
 	}
 
 	virtual std::string getName() const {
-		if(Main::canManuallyAdvance())
+		if(canManuallyAdvance())
 			return NullControl::getName();
 		return "[Auto-Advancing]";
 	}
 
 	virtual std::string getDescription() const {
-		if(Main::canManuallyAdvance())
+		if(canManuallyAdvance())
 			return NullControl::getDescription();
 		return "Cannot manually advance when in realtime mode, or when AdvanceOnAccess is enabled";
 	}
 	
+protected:
+	bool canManuallyAdvance() const { return true; }
+	
 #endif
 
 };
@@ -58,9 +60,9 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.1 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.2 $
  * $State: Exp $
- * $Date: 2005/06/23 22:37:28 $
+ * $Date: 2006/08/30 14:26:44 $
  */
 #endif
