@@ -220,12 +220,12 @@ ControlBase* WalkCalibration::doSelect() {
 		if(hilights.size()==0)
 			return this;
 		if(options[hilights.front()]==measure) {
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			setupChoose();
 			refresh();
 			return this;
 		} else if(options[hilights.front()]==clear) {
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			setupClear();
 			refresh();
 			return this;
@@ -235,10 +235,10 @@ ControlBase* WalkCalibration::doSelect() {
 	} else if(st==CLEAR) {
 		if(hilights.size()==0)
 			return this;
-		sndman->PlayFile(config->controller.select_snd);
+		sndman->playFile(config->controller.select_snd);
 		if(hilights.front()!=0) {
 			sout->printf("Clearing data...\n");
-			sndman->PlayFile(config->controller.cancel_snd);
+			sndman->playFile(config->controller.cancel_snd);
 			for(int i=0; i<NUM_SRC; i++) {
 				clearData(data[i]);
 				cnts[i]=0;
@@ -252,18 +252,18 @@ ControlBase* WalkCalibration::doSelect() {
 			return this;
 		if(hilights.front()-2<NUM_SRC) {
 			curType=static_cast<dataSource>(hilights.front()-2);
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			setupReady();
 			refresh();
 			return this;
 		}
-		sndman->PlayFile(config->controller.cancel_snd);
+		sndman->playFile(config->controller.cancel_snd);
 		setupRoot();
 		refresh();
 		return this;
 	} else if(st==READY) {
 		if(hilights.size()==0 || options[hilights.front()]->getName()=="Go!") {
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			setupMoving();
 			refresh();
 			return this;
@@ -271,12 +271,12 @@ ControlBase* WalkCalibration::doSelect() {
 		if(options[hilights.front()]==polar || options[hilights.front()]==rect) {
 			return ControlBase::doSelect();
 		}
-		sndman->PlayFile(config->controller.cancel_snd);
+		sndman->playFile(config->controller.cancel_snd);
 		setupChoose();
 		refresh();
 		return this;
 	} else {
-		sndman->PlayFile(config->controller.cancel_snd);
+		sndman->playFile(config->controller.cancel_snd);
 		setupChoose();
 		refresh();
 		return this;
@@ -287,7 +287,7 @@ void WalkCalibration::processEvent(const EventBase& e) {
 	if(st==MOVING) {
 		stopTime=e.getTimeStamp();
 		sout->printf("Ran for %g seconds\n",(stopTime-startTime)/1000.f);
-		sndman->PlayFile(config->controller.select_snd);
+		sndman->playFile(config->controller.select_snd);
 		setupReading1();
 		refresh();
 		if(curType!=5)
@@ -310,7 +310,7 @@ ControlBase * WalkCalibration::takeInput(const std::string& msg) {
 				err("Invalid input: "+msg);
 				return doReadStdIn(std::string("Enter ")+getFirstMeasure(curType));
 			}
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			setupReading2();
 			refresh();
 			if(*end!='\0')
@@ -325,7 +325,7 @@ ControlBase * WalkCalibration::takeInput(const std::string& msg) {
 				return doReadStdIn(std::string("Enter ")+getSecondMeasure(curType));
 			}
 			addSample();
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			setupReady();
 			refresh();
 			return this;
@@ -873,7 +873,7 @@ void WalkCalibration::err(const std::string& str) {
 		errmsg.push_back(str);
 		serr->printf("%s\n",str.c_str());
 		Controller::loadGUI("org.tekkotsu.mon.ControllerErr","msg",0,errmsg);
-		sndman->PlayFile(config->controller.error_snd);
+		sndman->playFile(config->controller.error_snd);
 		return;
 }
 
@@ -898,9 +898,9 @@ void WalkCalibration::addSample(std::vector<float*>& dat, float x, float y, floa
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:45 $
+ * $Date: 2006/09/18 18:07:54 $
  */
 
