@@ -44,25 +44,25 @@ public:
 
 protected:
 	enum {
-		ROOT,
-		CHOOSE,
-		READY,
-		MOVING,
-		READING_1,
-		READING_2,
-		CLEAR,
+		ROOT,      //!< indicates the root menu is currently displayed (save/load data sets...)
+		CHOOSE,    //!< indicates the sample type selection is displayed
+		READY,     //!< waiting for user to indicate 0 point
+		MOVING,    //!< recording, waiting for the motion stop event
+		READING_1, //!< waiting for user to supply the first measurement coordinate
+		READING_2, //!< waiting for user to supply the second measurement coordinate
+		CLEAR,     //!< clear data confirmation menu
 	} st; //!< the currently active state
 
 	//! allows representation of the current sample type
 	enum dataSource {
-		fs,
-		fr,
-		sr,
-		br,
-		bs,
-		r,
-		NUM_SRC
-	} curType;
+		fs, //!< forward-sideways
+		fr, //!< forward-rotate
+		sr, //!< sideways-rotate
+		br, //!< backward-rotate
+		bs, //!< backward-sideways
+		r,  //!< pure rotation
+		NUM_SRC //!< number of data types
+	} curType; //!< the currently selected type of data being recorded	
 
 	static void loadData(const std::string& name, std::vector<float*>& data); //!< does the work of loading data sets
 	static void saveData(const std::string& name, const std::vector<float*>& data); //!< does the work of saving data sets
@@ -123,10 +123,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2005/02/02 18:47:23 $
+ * $Date: 2006/09/16 20:11:49 $
  */
 
 #endif
