@@ -120,23 +120,23 @@ WaypointWalkControl::doSelect() {
 				startstopCtl->setDescription("Halt locomotion");
 				MMAccessor<WaypointWalkMC>(walk_id)->go();
 			}
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			return curctl;
 		} else if(curctl==loopCtl) {
 			MMAccessor<WaypointWalkMC>(walk_id)->setIsLooping(!loopCtl->getStatus());
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			return curctl;
 		} else if(curctl==addEgoWPCtl) {
 			MMAccessor<WaypointWalkMC>(walk_id)->addEgocentricWaypoint(0,0,false,true,.1);
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			return curctl;
 		} else if(curctl==addOffWPCtl) {
 			MMAccessor<WaypointWalkMC>(walk_id)->addOffsetWaypoint(0,0,false,true,.1);
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			return curctl;
 		} else if(curctl==addAbsWPCtl) {
 			MMAccessor<WaypointWalkMC>(walk_id)->addAbsoluteWaypoint(0,0,false,true,.1);
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			return curctl;
 		}
 	}
@@ -177,20 +177,20 @@ ControlBase* WaypointWalkControl::WaypointEditControl::doSelect() {
 		if(curctl==up) {
 			WaypointWalkMC::WaypointList_t& list=MMAccessor<WaypointWalkMC>(walk_id)->getWaypointList();
 			list.swap(list.prev(waypoint_id),waypoint_id);
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			return NULL;
 		} else if(curctl==down) {
 			WaypointWalkMC::WaypointList_t& list=MMAccessor<WaypointWalkMC>(walk_id)->getWaypointList();
 			list.swap(waypoint_id,list.next(waypoint_id));
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			return NULL;
 		} else if(curctl==del) {
 			MMAccessor<WaypointWalkMC>(walk_id)->getWaypointList().erase(waypoint_id);
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			return NULL;
 		} else if(curctl==set) {
 			MMAccessor<WaypointWalkMC>(walk_id)->setTargetWaypoint(waypoint_id);
-			sndman->PlayFile(config->controller.select_snd);
+			sndman->playFile(config->controller.select_snd);
 			return NULL;
 		}
 	}
@@ -247,9 +247,9 @@ ControlBase* WaypointWalkControl::WaypointEditControl::doSelect() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.16 $
  * $State: Exp $
- * $Date: 2005/06/06 23:05:51 $
+ * $Date: 2006/09/18 18:07:54 $
  */
 
