@@ -16,6 +16,7 @@
 #include "Vision/RawCameraGenerator.h"
 #include "Vision/InterleavedYUVGenerator.h"
 #include "Vision/JPEGGenerator.h"
+#include "Vision/PNGGenerator.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -33,7 +34,7 @@ CameraBehavior::DoStart() {
 		camera_click.setSourceID(ERS7Info::HeadButOffset);
 	}
 	initIndex();
-	sndman->LoadFile("camera.wav");
+	sndman->loadFile("camera.wav");
 	ledID=motman->addPersistentMotion(SharedObject<LedMC>());
 	erouter->addListener(this,camera_click);
 	erouter->addListener(this,EventBase::textmsgEGID);
@@ -41,7 +42,7 @@ CameraBehavior::DoStart() {
 
 void CameraBehavior::DoStop() {
 	erouter->removeListener(this);
-	sndman->ReleaseFile("camera.wav");
+	sndman->releaseFile("camera.wav");
 	motman->removeMotion(ledID);
 	BehaviorBase::DoStop();
 }
@@ -49,7 +50,7 @@ void CameraBehavior::DoStop() {
 	
 /*! The format used depends on the current config settings.  If JPEG
  *  is the current choice, then a JPEG file will be written.
- *  Otherwise, RawCameraGenerator::SaveFile() will be called.
+ *  Otherwise, RawCameraGenerator::saveFile() will be called.
  */
 void
 CameraBehavior::processEvent(const EventBase& e) {
@@ -78,19 +79,19 @@ CameraBehavior::processEvent(const EventBase& e) {
 		if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_COLOR) {
 			FilterBankGenerator * gen=ProjectInterface::defInterleavedYUVGenerator; // just an alias for readability
 			gen->selectSaveImage(ProjectInterface::doubleLayer,InterleavedYUVGenerator::CHAN_YUV);
-			unsigned int len=gen->SaveFileStream(f);
+			unsigned int len=gen->saveFileStream(f);
 			if(len==0) {
 				serr->printf("Error saving file\n");
-				sndman->PlayFile(config->controller.error_snd);
+				sndman->playFile(config->controller.error_snd);
 				return;
 			}
 		} else if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_SINGLE_CHANNEL) {
 			FilterBankGenerator * gen=ProjectInterface::defRawCameraGenerator; // just an alias for readability
 			gen->selectSaveImage(ProjectInterface::doubleLayer,config->vision.rawcam_channel);
-			unsigned int len=gen->SaveFileStream(f);
+			unsigned int len=gen->saveFileStream(f);
 			if(len==0) {
 				serr->printf("Error saving file\n");
-				sndman->PlayFile(config->controller.error_snd);
+				sndman->playFile(config->controller.error_snd);
 				return;
 			}
 		}
@@ -122,7 +123,7 @@ CameraBehavior::processEvent(const EventBase& e) {
 			unsigned int writ=fwrite(imgbuf,jpeg->getImageSize(ProjectInterface::doubleLayer,chan),1,f);
 			if(writ==0) {
 				serr->printf("Error saving file\n");
-				sndman->PlayFile(config->controller.error_snd);
+				sndman->playFile(config->controller.error_snd);
 				return;
 			}
 
@@ -131,9 +132,37 @@ CameraBehavior::processEvent(const EventBase& e) {
 			
 			jpeg->setQuality(tmp_q);
 		}
+
+	} else if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_PNG) {
+		//save a JPEG image
+		PNGGenerator * png=NULL; // we'll set this to pick between the color png or a single channel grayscale png
+		unsigned int chan=0; // and this will hold the channel to use out of that png generator
+		if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_COLOR)
+			png=dynamic_cast<PNGGenerator*>(ProjectInterface::defColorPNGGenerator);
+		else if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_SINGLE_CHANNEL) {
+			png=dynamic_cast<PNGGenerator*>(ProjectInterface::defGrayscalePNGGenerator);
+			chan=config->vision.rawcam_channel;
+		}
+		if(png!=NULL) {
+			// open file
+			FILE * f=openNextFile(".png");
+			if(f==NULL) //error message already displayed in openNextFile()
+				return;
+			
+			//! write actual image data
+			unsigned char * imgbuf=png->getImage(ProjectInterface::doubleLayer,chan);
+			unsigned int writ=fwrite(imgbuf,png->getImageSize(ProjectInterface::doubleLayer,chan),1,f);
+			if(writ==0) {
+				serr->printf("Error saving file\n");
+				sndman->playFile(config->controller.error_snd);
+				return;
+			}
+			
+			// close file
+			fclose(f);
+		}
 	}
-
-
+	
 	{
 		MMAccessor<LedMC> leds(ledID);
 		leds->clear();
@@ -151,10 +180,10 @@ CameraBehavior::openNextFile(const std::string& ext) {
 	FILE * f=fopen(getNextName(ext).c_str(),"w+");
 	if(f==NULL) {
 		serr->printf("Error opening file\n");
-		sndman->PlayFile(config->controller.error_snd);
+		sndman->playFile(config->controller.error_snd);
 		return NULL;
 	}
-	sndman->PlayFile("camera.wav");
+	sndman->playFile("camera.wav");
 	return f;
 }
 
@@ -203,9 +232,9 @@ CameraBehavior::initIndex() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2005/08/05 21:55:43 $
+ * $Date: 2006/09/18 18:07:57 $
  */
 
