@@ -52,9 +52,12 @@ public:
 				chan=RawCameraGenerator::CHAN_Y;
 				color=255;
 			} else if(e.getGeneratorID()==EventBase::visSegmentEGID) {
-				layer=fbe.getNumLayers()-1-config->vision.rlecam_skip;
-				chan=config->vision.rlecam_channel;
+				layer=fbe.getNumLayers()-1-config->vision.segcam_skip;
+				chan=config->vision.segcam_channel;
 				color=7;
+			} else {
+				std::cerr << "WARNING: " << getClassName() << " received vision event from unknown generator" << std::endl;
+				return;
 			}
 
 			//do the drawing
@@ -65,7 +68,7 @@ public:
 			
 			//this is only needed until RLEGraphics is in place
 			//  in the mean time, we trigger the RLE generator to recompress the modified seg cam image
-			if(config->vision.rlecam_compression==Config::vision_config::COMPRESS_RLE)
+			if(config->vision.segcam_compression==Config::vision_config::COMPRESS_RLE)
 				ProjectInterface::defRLEGenerator->invalidateCaches();
 			
 			drawn++;
@@ -98,10 +101,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2005/08/04 21:09:26 $
+ * $Date: 2006/06/30 16:37:03 $
  */
 
 #endif
