@@ -27,9 +27,9 @@ void ExploreMachine::setup() {
 
 	WalkNode * move=NULL;
 	addNode(move=new WalkNode(getName()+"::move",150,0,0));
-	move->setWalkID(walkid);
+	move->setMC(walkid);
 	start=addNode(turn=new WalkNode(getName()+"::turn",0,0,0.5f));
-	turn->setWalkID(walkid);
+	turn->setMC(walkid);
 
 	move->addTransition(new SmoothCompareTrans<float>(turn,&state->sensors[IRDistOffset],CompareTrans<float>::LT,350,EventBase(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID),.7));
 	turn->addTransition(new TimeOutTrans(move,2000));
@@ -42,7 +42,7 @@ void ExploreMachine::DoStart() {
 	StateNode::DoStart();
 	start->DoStart();
 	//erouter->addListener(this,EventBase::sensorEGID,SensorSourceID::UpdatedSID);
-	erouter->addListener(this,EventBase::stateMachineEGID,(unsigned int)turn,EventBase::activateETID);
+	erouter->addListener(this,EventBase::stateMachineEGID,(size_t)turn,EventBase::activateETID);
 }
 
 void ExploreMachine::DoStop() {
@@ -72,8 +72,8 @@ void ExploreMachine::processEvent(const EventBase& /*e*/) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.1 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2004/12/04 00:10:38 $
+ * $Date: 2005/12/15 18:51:35 $
  */
