@@ -3,6 +3,7 @@
 #define INCLUDED_ExploreMachine_h_
 
 #include "Behaviors/StateNode.h"
+#include "Behaviors/Nodes/WalkNode.h"
 #include "Motion/MotionManager.h"
 
 //! A state machine for exploring an environment (or searching for an object)
@@ -34,7 +35,7 @@ public:
 
 protected:
 	StateNode * start; //!< the node to begin within on DoStart() (turn)
-	class WalkNode * turn; //!< walk node to use when turning
+	WalkNode * turn; //!< walk node to use when turning
 	MotionManager::MC_ID walkid; //!< we want to share a walk between turning and walking nodes
 
 private:
@@ -47,10 +48,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.23 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.24 $
  * $State: Exp $
- * $Date: 2005/01/24 22:23:46 $
+ * $Date: 2005/12/15 18:51:36 $
  */
 
 #endif
