@@ -53,7 +53,7 @@ void FollowHeadBehavior::processEvent(const EventBase& e) {
 	} else if(e==head_release) {
 		cout << "release" << endl;
 		motman->addPrunableMotion(SharedObject<PIDMC>(HeadOffset,HeadOffset+NumHeadJoints,0));
-		erouter->addListener(this,clock);
+		erouter->addTimer(this,clock);
 
 	} else if(e==head_lock) {
 		cout << "lock" << endl;
@@ -61,7 +61,7 @@ void FollowHeadBehavior::processEvent(const EventBase& e) {
 		for(unsigned int i=HeadOffset; i<HeadOffset+NumHeadJoints; i++)
 			motman->setOutput(NULL,i,state->outputs[i]); //doing this prevents the head from jerking back when you released it to where it was before you pressed the button
 		cout << state->outputs[HeadOffset+TiltOffset]/M_PI*180 << ' ' << state->outputs[HeadOffset+PanOffset]/M_PI*180 << ' ' << state->outputs[HeadOffset+RollOffset]/M_PI*180 << endl;
-		erouter->removeListener(this,clock);
+		erouter->removeTimer(this,clock.getSourceID());
 
 	} else {
 		ASSERT(false,"unprocessed event " << e.getName() << endl);
@@ -74,8 +74,8 @@ void FollowHeadBehavior::processEvent(const EventBase& e) {
  *
  * $Author: ejt $
  * $Name $
- * $Revision: 1.9 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:36 $
+ * $Date: 2006/09/05 20:30:21 $
  */
 
