@@ -61,7 +61,7 @@ public:
 
 		} else if(e==head_release) {
 			motman->addPrunableMotion(SharedObject<PIDMC>(HeadOffset,HeadOffset+NumHeadJoints,0));
-			erouter->addListener(this,clock);
+			erouter->addTimer(this,clock);
 			processEvent(clock);
 		} else if(e==head_lock) {
 			motman->addPrunableMotion(SharedObject<PIDMC>(HeadOffset,HeadOffset+NumHeadJoints,1));
@@ -85,10 +85,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/12/23 01:47:06 $
+ * $Date: 2006/03/03 23:08:39 $
  */
 
 #endif
