@@ -60,10 +60,10 @@ void PaceTargetsMachine::setup() {
 	tmptrans->setSound("barkmed.wav");
 	
 	//preload the sounds so we don't pause on tranisitions
-	sndman->LoadFile("cutey.wav");
-	sndman->LoadFile("barkmed.wav");
-	sndman->LoadFile("whimper.wav");
-	sndman->LoadFile("fart.wav");
+	sndman->loadFile("cutey.wav");
+	sndman->loadFile("barkmed.wav");
+	sndman->loadFile("whimper.wav");
+	sndman->loadFile("fart.wav");
 
 	//starts out exploring
 	start=explGrp;
@@ -76,10 +76,10 @@ void PaceTargetsMachine::DoStart() {
 
 void PaceTargetsMachine::teardown() {
 	//release the sounds
-	sndman->ReleaseFile("cutey.wav");
-	sndman->ReleaseFile("barkmed.wav");
-	sndman->ReleaseFile("whimper.wav");
-	sndman->ReleaseFile("fart.wav");
+	sndman->releaseFile("cutey.wav");
+	sndman->releaseFile("barkmed.wav");
+	sndman->releaseFile("whimper.wav");
+	sndman->releaseFile("fart.wav");
 	StateNode::teardown();
 }
 
@@ -88,9 +88,9 @@ void PaceTargetsMachine::teardown() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.18 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.20 $
  * $State: Exp $
- * $Date: 2005/08/03 19:11:58 $
+ * $Date: 2006/09/18 18:07:57 $
  */
 
