@@ -43,18 +43,18 @@ public:
 	virtual void DoStart() {
 		BehaviorBase::DoStart();
 		erouter->addListener(this,EventBase::buttonEGID);
-		sndman->LoadFile("yap.wav");
-		sndman->LoadFile("howl.wav");
-		sndman->LoadFile("whimper.wav");
+		sndman->loadFile("yap.wav");
+		sndman->loadFile("howl.wav");
+		sndman->loadFile("whimper.wav");
 	}
 
 	//! Release sounds we loaded in DoStart()
 	virtual void DoStop() {
 		BehaviorBase::DoStop();
 		erouter->removeListener(this);
-		sndman->ReleaseFile("howl.wav");
-		sndman->ReleaseFile("yap.wav");
-		sndman->ReleaseFile("whimper.wav");
+		sndman->releaseFile("howl.wav");
+		sndman->releaseFile("yap.wav");
+		sndman->releaseFile("whimper.wav");
 	}
 
 	//! Play the sound corresponding to the button
@@ -75,7 +75,7 @@ public:
 				curplay=SoundManager::invalid_Play_ID;
 				endtime=0;
 			} else if(pauseWhileChin)
-				sndman->ResumePlay(curplay);
+				sndman->resumePlay(curplay);
 	}
 
 	//! returns name to system
@@ -89,20 +89,20 @@ protected:
 
 			// Just play the sound
 			// This is probably all you need how to do unless you want to get fancy
-			sndman->PlayFile(name);
+			sndman->playFile(name);
 
 		} else {
 
 			// Enqueue the sound - mainly useful if you have a set of sounds and want to play a song with them
 			if(curplay==SoundManager::invalid_Play_ID || !pauseWhileChin && get_time()>=endtime) {
 				//start a new chain, either this is the first or we already finished playing the chain
-				curplay=sndman->PlayFile(name);
+				curplay=sndman->playFile(name);
 				if(pauseWhileChin)
-					sndman->PausePlay(curplay);
+					sndman->pausePlay(curplay);
 			} else //add to existing chain
-				sndman->ChainFile(curplay,name);
-			endtime=sndman->GetRemainTime(curplay)+get_time()-SoundBufferTime;
-			//-SoundBufferTime to guarrantee ID validity, see SoundManager::GetRemainTime() documentation
+				sndman->chainFile(curplay,name);
+			endtime=sndman->getRemainTime(curplay)+get_time()-SoundBufferTime;
+			//-SoundBufferTime to guarrantee ID validity, see SoundManager::getRemainTime() documentation
 
 		}
 	}
@@ -121,10 +121,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:45 $
+ * $Date: 2006/09/18 18:07:57 $
  */
 
 #endif
