@@ -3,6 +3,7 @@
 #include "Events/VisionObjectEvent.h"
 #include "Shared/WorldState.h"
 #include "Motion/HeadPointerMC.h"
+#include "Motion/MMAccessor.h"
 #include "Shared/ProjectInterface.h"
 
 //! Converts degrees to radians
@@ -22,33 +23,29 @@ void StareAtBallBehavior::DoStop() {
 
 //this could be cleaned up event-wise (only use a timer when out of view)
 void StareAtBallBehavior::processEvent(const EventBase& event) {
-	/*if(event.getSourceID()==ProjectInterface::visBlueBallSID) {
-		cout << "BLUE" << endl;
-		} else if(event.getSourceID()==ProjectInterface::visPinkBallSID) {
-		cout << "PINK" << endl;
-		}
-	*/
-
-	static float horiz=0,vert=0;
+	float horiz=0,vert=0;
 	if(event.getGeneratorID()==EventBase::visObjEGID && event.getTypeID()==EventBase::statusETID) {
-		horiz=static_cast<const VisionObjectEvent*>(&event)->getCenterX();
-		vert=static_cast<const VisionObjectEvent*>(&event)->getCenterY();
+		const VisionObjectEvent& objev=static_cast<const VisionObjectEvent&>(event);
+		horiz=objev.getCenterX();
+		vert=objev.getCenterY();
 	}
 
 	//cout << horiz << ' ' << vert << endl;
 
-	// Very simple visual servoing control -- move the head in the direction of the target
+	// Very simple visual servoing control -- move the head a small distance in the direction of the target
+	// This is "proportional" control, because we move the head proportionally further when the error (horiz and vert) is larger
 	double tilt=state->outputs[HeadOffset+TiltOffset]-vert*M_PI/7;
 	double pan=state->outputs[HeadOffset+PanOffset]-horiz*M_PI/6;
-	HeadPointerMC * headpointer= (HeadPointerMC*)motman->checkoutMotion(headpointer_id);
-#ifdef TGT_ERS7
-	//on an ers-7, we want to set the nod joint to look up, since tilt can only look down
-	headpointer->setJoints(tilt,pan,outputRanges[HeadOffset+NodOffset][MaxRange]);
-#else
-	//on other models (we'll just assume ers-2xx), center the roll joint
-	headpointer->setJoints(tilt,pan,0);
-#endif
-	motman->checkinMotion(headpointer_id);
+	
+	// now request access to the headpointer we added in DoStart and set the joint angles
+	MMAccessor<HeadPointerMC> headpointer(headpointer_id);
+	if(state->robotDesign & WorldState::ERS7Mask) {
+		//on an ers-7, we want to set the nod joint to look up (maximum value), since tilt can only look down
+		headpointer->setJoints(tilt,pan,outputRanges[HeadOffset+NodOffset][MaxRange]);
+	} else {
+		//on other models (we'll just assume ers-2xx), center the roll joint
+		headpointer->setJoints(tilt,pan,0);
+	}
 }
 			
 /*! @file
