@@ -9,7 +9,7 @@
 class EchoBehavior : public BehaviorBase {
 public:
 	static EchoBehavior * theOne; //!< the singleton object (only one of these objects can be active at a time or they would conflict over ports)
-	static unsigned short port; //! the port to listen on for incoming UDP and TCP connections
+	static unsigned short port; //!< the port to listen on for incoming UDP and TCP connections
 	static int server_callbackT(char *buf, int bytes); //!< called by wireless when there's new data
 	static int client_callbackT(char *buf, int bytes); //!< called by wireless when there's new data
 	static int server_callbackU(char *buf, int bytes); //!< called by wireless when there's new data
@@ -27,6 +27,7 @@ public:
 				route[i][i]=true;				
 			}
 	}
+	//! destructor
 	~EchoBehavior() { theOne=NULL; }
 
 	virtual void DoStart();
@@ -41,6 +42,7 @@ public:
 	virtual std::string getDescription() const { return getClassDescription(); }
 
 protected:
+	//! indicates one of the available data sinks: combinations of client/server and TCP/UDP
 	enum routeIndex_t {
 		STCP=0,  //!< server TCP
 		SUDP, //!< server UDP
@@ -73,10 +75,10 @@ private:
  * @author Ethan Tira-Thompson (ejt) (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2006/09/16 06:28:07 $
  */
 
 #endif
