@@ -6,18 +6,22 @@
 HeadPointControllerBehavior* HeadPointControllerBehavior::theOne = NULL;
 
 void HeadPointControllerBehavior::runCommand(unsigned char *command) {
-	// First, turn off the stop-if-no-heartbeat timer
-	erouter->removeTimer(this);
-
 	// Extract the command parameter
 	float param;
 	unsigned char *paramp = (unsigned char *) &param;
 
+#if defined(BYTE_ORDER) && BYTE_ORDER==BIG_ENDIAN
+	paramp[0] = command[4];
+	paramp[1] = command[3];
+	paramp[2] = command[2];
+	paramp[3] = command[1];
+#else
 	paramp[0] = command[1];
 	paramp[1] = command[2];
 	paramp[2] = command[3];
 	paramp[3] = command[4];
-
+#endif
+	
 	// Find out what type of command this is
 	switch(command[0]) {
 	case CMD_tilt:
@@ -118,9 +122,9 @@ int HeadPointControllerBehavior::mechacmd_callback(char *buf, int bytes) {
  * @author tss (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2005/06/10 19:18:59 $
+ * $Date: 2006/09/10 17:00:43 $
  */
 
