@@ -16,23 +16,28 @@ class MicrophoneServer : public BehaviorBase {
 		virtual void DoStop();
 		virtual void processEvent(const EventBase& event);
 		
+		//! makes Aperios-specific call to set microphone mode
 		static bool SetMicrophoneUnidirectional(bool unidirectional);
+		//! makes Aperios-specific call to set microphone mode
 		static bool SetMicrophoneAlcEnabled(bool enabled);
 		
 	private:
+		//! max transmission buffer size for #socket
 		static const unsigned int SEND_BUFFER_SIZE = 2048 + 16;
 	
 		MicrophoneServer(); //!< constructor
 		MicrophoneServer(const MicrophoneServer& rhs); //!< don't call
 		MicrophoneServer& operator=(const MicrophoneServer& rhs); //!< don't call
-		static MicrophoneServer* instance;
+		static MicrophoneServer* instance; //!< global instance of the server
 		
+		//! returns size of a "frame" at the given sampling rate and resolution
 		unsigned int GetResampledFrameSize(
 			unsigned int samplesSize,
 			unsigned int newSampleRate,
 			unsigned int newSampleBits,
 			bool newStereo);
 		
+		//! performs sampling to a specified rate and resolution, stores into @a newSamples (which you must allocate)
 		unsigned int ResampleFrame(
 			const char* samples,
 			unsigned int samplesSize,
@@ -42,8 +47,10 @@ class MicrophoneServer : public BehaviorBase {
 			void* newSamples,
 			unsigned int newSamplesSize);
 		
+		//! aperios specific identifier for microphone access
 		static const char* const MIC_LOCATOR;
 		
+		//! socket for communication
 		class Socket *socket;
 		
 		//! writes @a value to @a dst and advances @a dst
