@@ -7,35 +7,19 @@
 #include "Behaviors/Controller.h"
 #include "Shared/ProjectInterface.h"
 
+RawCamBehavior* RawCamBehavior::theOne=NULL;
+
 RawCamBehavior::RawCamBehavior()
-	: BehaviorBase("RawCamBehavior"), visRaw(NULL), packet(NULL), cur(NULL), avail(0), max_buf(0), lastProcessedTime(0)
-{}
+	: CameraStreamBehavior("RawCamBehavior",visRaw), visRaw(NULL), packet(NULL), cur(NULL), avail(0), max_buf(0), lastProcessedTime(0)
+{
+	ASSERT(theOne==NULL,"there was already a RawCamBehavior running!");
+	theOne=this;
+}
 
 void
 RawCamBehavior::DoStart() {
 	BehaviorBase::DoStart();
-	std::vector<std::string> args;
-	args.push_back("raw");
-	char port[50];
-	snprintf(port,50,"%d",config->vision.rawcam_port);
-	args.push_back(port);
-	if(config->vision.rawcam_transport==0) {
-		max_buf=UDP_WIRELESS_BUFFER_SIZE;
-		visRaw=wireless->socket(SocketNS::SOCK_DGRAM, 1024, max_buf);
-		args.push_back("udp");
-	} else if(config->vision.rawcam_transport==1) {
-		max_buf=TCP_WIRELESS_BUFFER_SIZE;
-		visRaw=wireless->socket(SocketNS::SOCK_STREAM, 1024, max_buf);
-		wireless->setDaemon(visRaw,true);
-		args.push_back("tcp");
-	} else {
-		serr->printf("ERROR: Invalid Config::vision.rawcam_transport: %d\n",config->vision.rawcam_transport);
-		return;
-	}
-	wireless->listen(visRaw,config->vision.rawcam_port);
-	
-	Controller::loadGUI("org.tekkotsu.mon.VisionGUI","RawVisionGUI",config->vision.rawcam_port,args);
-
+	setupServer();
 	erouter->addListener(this,EventBase::visRawCameraEGID,ProjectInterface::visRawCameraSID,EventBase::deactivateETID);
 	erouter->addListener(this,EventBase::visJPEGEGID,ProjectInterface::visColorJPEGSID,EventBase::deactivateETID);
 	erouter->addListener(this,EventBase::visJPEGEGID,ProjectInterface::visGrayscaleJPEGSID,EventBase::deactivateETID);
@@ -44,14 +28,7 @@ RawCamBehavior::DoStart() {
 void
 RawCamBehavior::DoStop() {
 	erouter->removeListener(this);
-	if(wireless->isConnected(visRaw->sock))
-		sendCloseConnectionPacket();
-	Controller::closeGUI("RawVisionGUI");
-
-	// this could be considered a bug in our wireless - if we don't setDaemon(...,false)
-	// it will try to listen again even though we explicitly closed the server socket...
-	wireless->setDaemon(visRaw,false);
-	wireless->close(visRaw->sock);
+	closeServer();
 	BehaviorBase::DoStop();
 }
 
@@ -59,24 +36,57 @@ void
 RawCamBehavior::processEvent(const EventBase& e) {
 	if(!wireless->isConnected(visRaw->sock))
 		return;
-	const FilterBankEvent* fbke=dynamic_cast<const FilterBankEvent*>(&e);
-	ASSERTRET(fbke!=NULL,"unexpected event");
-	if ((get_time() - lastProcessedTime) < config->vision.rawcam_interval) {// not enough time has gone by
-	  return;
-	}
-	/* // turning these off enables individual channel compression
-		if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_NONE && e.getGeneratorID()!=EventBase::visRawCameraEGID)
+	if(config->vision.rawcam_transport==0 && visRaw->getTransport()==SocketNS::SOCK_STREAM
+		 || config->vision.rawcam_transport==1 && visRaw->getTransport()==SocketNS::SOCK_DGRAM) {
+		//reset the socket
+		closeServer();
+		setupServer();
 		return;
-		if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_JPEG && e.getGeneratorID()!=EventBase::visJPEGEGID)
-		return; */
-	if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_COLOR) {
-		bool succ=writeColor(*fbke);
-		ASSERTRET(succ,"serialization failed");
-	} else if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_SINGLE_CHANNEL) {
-		bool succ=writeSingleChannel(*fbke);
-		ASSERTRET(succ,"serialization failed");
-	} else {
-		serr->printf("%s: Bad rawcam_encoding setting\n",getName().c_str());
+	}
+	try {
+		const FilterBankEvent* fbke=dynamic_cast<const FilterBankEvent*>(&e);
+		if(fbke==NULL) {
+			CameraStreamBehavior::processEvent(e);
+			return;
+		}
+		if ((get_time() - lastProcessedTime) < config->vision.rawcam_interval) {// not enough time has gone by
+			return;
+		}
+		/* // turning these off enables individual channel compression
+			if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_NONE && e.getGeneratorID()!=EventBase::visRawCameraEGID)
+			return;
+			if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_JPEG && e.getGeneratorID()!=EventBase::visJPEGEGID)
+			return; */
+		if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_COLOR) {
+			if(!writeColor(*fbke)) {
+				if(packet) { //packet was opened, need to close it
+					cur=packet; // don't send anything
+					closePacket();
+				}
+				//error message should already be printed in writeColor
+				//ASSERTRET(false,"serialization failed");
+			}
+		} else if(config->vision.rawcam_encoding==Config::vision_config::ENCODE_SINGLE_CHANNEL) {
+			if(!writeSingleChannel(*fbke)) {
+				if(packet) { //packet was opened, need to close it
+					cur=packet; // don't send anything
+					closePacket();
+				}
+				//error message should already be printed in writeSingleChannel
+				//ASSERTRET(false,"serialization failed");
+			}
+		} else {
+			serr->printf("%s: Bad rawcam_encoding setting\n",getName().c_str());
+		}
+	} catch(...) {
+		if(packet) { //packet was opened, need to close it
+			cur=packet; // don't send anything
+			closePacket();
+		}
+		// typically this is a per-frame recurring error, so let's just stop now
+		serr->printf("%s: exception generated during image serialization, stopping stream.\n",getName().c_str());
+		DoStop();
+		throw;
 	}
 }
 
@@ -115,6 +125,44 @@ unsigned int RawCamBehavior::getSourceVLayer(unsigned int numLayers) {
 	return getSourceLayer(RawCameraGenerator::CHAN_V,numLayers);
 }
 
+void
+RawCamBehavior::closeServer() {
+	if(wireless->isConnected(visRaw->sock))
+		sendCloseConnectionPacket();
+	Controller::closeGUI("RawVisionGUI");
+	
+	// this could be considered a bug in our wireless - if we don't setDaemon(...,false)
+	// it will try to listen again even though we explicitly closed the server socket...
+	wireless->setDaemon(visRaw,false);
+	wireless->close(visRaw->sock);
+}
+
+void
+RawCamBehavior::setupServer() {
+	std::vector<std::string> args;
+	args.push_back("raw");
+	char port[50];
+	snprintf(port,50,"%d",config->vision.rawcam_port);
+	args.push_back(port);
+	if(config->vision.rawcam_transport==0) {
+		max_buf=UDP_WIRELESS_BUFFER_SIZE;
+		visRaw=wireless->socket(SocketNS::SOCK_DGRAM, 1024, max_buf);
+		args.push_back("udp");
+	} else if(config->vision.rawcam_transport==1) {
+		max_buf=TCP_WIRELESS_BUFFER_SIZE;
+		visRaw=wireless->socket(SocketNS::SOCK_STREAM, 1024, max_buf);
+		args.push_back("tcp");
+	} else {
+		serr->printf("ERROR: Invalid Config::vision.rawcam_transport: %d\n",config->vision.rawcam_transport);
+		return;
+	}
+	wireless->setDaemon(visRaw,true);
+	wireless->setReceiver(visRaw,networkCallback);
+	wireless->listen(visRaw,config->vision.rawcam_port);
+	
+	Controller::loadGUI("org.tekkotsu.mon.VisionGUI","RawVisionGUI",config->vision.rawcam_port,args);
+}
+
 bool
 RawCamBehavior::openPacket(FilterBankGenerator& fbkgen, unsigned int time, unsigned int layer) {
 	if(packet!=NULL)
@@ -124,31 +172,16 @@ RawCamBehavior::openPacket(FilterBankGenerator& fbkgen, unsigned int time, unsig
 	ASSERT(cur==NULL,"cur non-NULL");
 	cur=NULL;
 	char * buf=packet=(char*)visRaw->getWriteBuffer(avail);
-	ASSERTRETVAL(packet!=NULL,"could not get buffer",false);
+	ASSERTRETVAL(packet!=NULL,"dropped frame, network bandwidth is saturated (reduce frame rate or size)",false);
 	
-	unsigned int used;
-	used=LoadSave::encode("TekkotsuImage",buf,avail);
-	ASSERTRETVAL(used!=0,"ran out of space",false);
-	avail-=used; buf+=used;
-	used=LoadSave::encode(config->vision.rawcam_encoding,buf,avail);
-	ASSERTRETVAL(used!=0,"ran out of space",false);
-	avail-=used; buf+=used;
-	used=LoadSave::encode(config->vision.rawcam_compression,buf,avail);
-	ASSERTRETVAL(used!=0,"ran out of space",false);
-	avail-=used; buf+=used;
+	if(!LoadSave::encodeInc("TekkotsuImage",buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+	if(!LoadSave::encodeInc(config->vision.rawcam_encoding,buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+	if(!LoadSave::encodeInc(config->vision.rawcam_compression,buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
 
-	used=LoadSave::encode(fbkgen.getWidth(layer),buf,avail);
-	ASSERTRETVAL(used!=0,"ran out of space",false);
-	avail-=used; buf+=used;
-	used=LoadSave::encode(fbkgen.getHeight(layer),buf,avail);
-	ASSERTRETVAL(used!=0,"ran out of space",false);
-	avail-=used; buf+=used;
-	used=LoadSave::encode(time,buf,avail);
-	ASSERTRETVAL(used!=0,"ran out of space",false);
-	avail-=used; buf+=used;
-	used=LoadSave::encode(fbkgen.getFrameNumber(),buf,avail);
-	ASSERTRETVAL(used!=0,"ran out of space",false);
-	avail-=used; buf+=used;
+	if(!LoadSave::encodeInc(fbkgen.getWidth(layer),buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+	if(!LoadSave::encodeInc(fbkgen.getHeight(layer),buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+	if(!LoadSave::encodeInc(time,buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+	if(!LoadSave::encodeInc(fbkgen.getFrameNumber(),buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
 
 	cur=buf;
 	return true;
@@ -167,38 +200,22 @@ RawCamBehavior::writeColor(const FilterBankEvent& e) {
 			if(const JPEGGenerator* jgen=dynamic_cast<const JPEGGenerator*>(&fbkgen))
 				if(jgen->getCurrentSourceFormat()==JPEGGenerator::SRC_COLOR)
 					return true;
-			unsigned int used=0;
 			openPacket(fbkgen,e.getTimeStamp(),uv_layer);
-			ASSERTRETVAL(cur!=NULL,"header failed",false);
+			if(cur==NULL) //error should have been displayed by openPacket
+				return false;
 			
-			used=LoadSave::encode("FbkImage",cur,avail);
-			ASSERTRETVAL(used!=0,"save blank image failed",false);
-			avail-=used; cur+=used;
-			used=LoadSave::encode(0,cur,avail);
-			ASSERTRETVAL(used!=0,"save blank image failed",false);
-			avail-=used; cur+=used;
-			used=LoadSave::encode(0,cur,avail);
-			ASSERTRETVAL(used!=0,"save blank image failed",false);
-			avail-=used; cur+=used;
-			used=LoadSave::encode(-1,cur,avail);
-			ASSERTRETVAL(used!=0,"save blank image failed",false);
-			avail-=used; cur+=used;
-			used=LoadSave::encode(RawCameraGenerator::CHAN_Y,cur,avail);
-			ASSERTRETVAL(used!=0,"save blank image failed",false);
-			avail-=used; cur+=used;
-			used=LoadSave::encode("blank",cur,avail);
-			ASSERTRETVAL(used!=0,"save blank image failed",false);
-			avail-=used; cur+=used;
+			if(!LoadSave::encodeInc("FbkImage",cur,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+			if(!LoadSave::encodeInc(0,cur,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+			if(!LoadSave::encodeInc(0,cur,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+			if(!LoadSave::encodeInc(-1,cur,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+			if(!LoadSave::encodeInc(RawCameraGenerator::CHAN_Y,cur,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+			if(!LoadSave::encodeInc("blank",cur,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
 
 			fbkgen.selectSaveImage(uv_layer,RawCameraGenerator::CHAN_U);
-			used=fbkgen.SaveBuffer(cur,avail);
-			ASSERTRETVAL(used!=0,"save image failed",false);
-			avail-=used; cur+=used;
+			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
 			
 			fbkgen.selectSaveImage(uv_layer,RawCameraGenerator::CHAN_V);
-			used=fbkgen.SaveBuffer(cur,avail);
-			ASSERTRETVAL(used!=0,"save image failed",false);
-			avail-=used; cur+=used;
+			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
 
 			closePacket();
 		}
@@ -215,68 +232,51 @@ RawCamBehavior::writeColor(const FilterBankEvent& e) {
 		if(config->vision.rawcam_compression!=Config::vision_config::COMPRESS_JPEG)
 			return true;
 		if(jgen->getCurrentSourceFormat()==JPEGGenerator::SRC_COLOR && big_layer-small_layer<2) {
-			unsigned int used=0;
 			openPacket(fbkgen,e.getTimeStamp(),big_layer);
-			ASSERTRETVAL(cur!=NULL,"header failed",false);
+			if(cur==NULL) //error should have been displayed by openPacket
+				return false;
 			
 			fbkgen.selectSaveImage(big_layer,0);
-			used=fbkgen.SaveBuffer(cur,avail);
-			ASSERTRETVAL(used!=0,"save image failed",false);
-			avail-=used; cur+=used;
+			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
 			
 			closePacket();
 		} else if(jgen->getCurrentSourceFormat()==JPEGGenerator::SRC_GRAYSCALE && big_layer-small_layer>=2) {
-			unsigned int used=0;
 			bool opened=openPacket(fbkgen,e.getTimeStamp(),big_layer);
-			ASSERTRETVAL(cur!=NULL,"header failed",false);
+			if(cur==NULL) //error should have been displayed by openPacket
+				return false;
 			
 			if(big_layer==y_layer) {
 				fbkgen.selectSaveImage(y_layer,RawCameraGenerator::CHAN_Y);
-				used=fbkgen.SaveBuffer(cur,avail);
-				ASSERTRETVAL(used!=0,"save image failed",false);
-				avail-=used; cur+=used;
+				if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
 			} else {
 				fbkgen.selectSaveImage(uv_layer,RawCameraGenerator::CHAN_U);
-				used=fbkgen.SaveBuffer(cur,avail);
-				ASSERTRETVAL(used!=0,"save image failed",false);
-				avail-=used; cur+=used;
-			
+				if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
 				fbkgen.selectSaveImage(uv_layer,RawCameraGenerator::CHAN_V);
-				used=fbkgen.SaveBuffer(cur,avail);
-				ASSERTRETVAL(used!=0,"save image failed",false);
-				avail-=used; cur+=used;
+				if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
 			}
 			
 			if(!opened)
 				closePacket();
 		}
 	} else {
-		unsigned int used=0;
 		bool opened=false;
 		
 		if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_NONE || big_layer-small_layer>=2 && big_layer==uv_layer) {
 			opened=openPacket(fbkgen,e.getTimeStamp(),big_layer);
-			ASSERTRETVAL(cur!=NULL,"header failed",false);
-			
+			if(cur==NULL) //error should have been displayed by openPacket
+				return false;
 			fbkgen.selectSaveImage(y_layer,RawCameraGenerator::CHAN_Y);
-			used=fbkgen.SaveBuffer(cur,avail);
-			ASSERTRETVAL(used!=0,"save image failed",false);
-			avail-=used; cur+=used;
+			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
 		}
 		
 		if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_NONE || big_layer-small_layer>=2 && big_layer==y_layer) {
 			opened=openPacket(fbkgen,e.getTimeStamp(),big_layer);
-			ASSERTRETVAL(cur!=NULL,"header failed",false);
-			
+			if(cur==NULL) //error should have been displayed by openPacket
+				return false;
 			fbkgen.selectSaveImage(uv_layer,RawCameraGenerator::CHAN_U);
-			used=fbkgen.SaveBuffer(cur,avail);
-			ASSERTRETVAL(used!=0,"save image failed",false);
-			avail-=used; cur+=used;
-			
+			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
 			fbkgen.selectSaveImage(uv_layer,RawCameraGenerator::CHAN_V);
-			used=fbkgen.SaveBuffer(cur,avail);
-			ASSERTRETVAL(used!=0,"save image failed",false);
-			avail-=used; cur+=used;
+			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
 		}
 		
 		if(config->vision.rawcam_compression==Config::vision_config::COMPRESS_NONE || !opened)
@@ -297,14 +297,12 @@ RawCamBehavior::writeSingleChannel(const FilterBankEvent& e) {
 					return true;
 			unsigned int layer=fbkgen.getNumLayers()-1-config->vision.rawcam_y_skip;
 			
-			unsigned int used=0;
 			openPacket(fbkgen,e.getTimeStamp(),layer);
-			ASSERTRETVAL(cur!=NULL,"header failed",false);
+			if(cur==NULL) //error should have been displayed by openPacket
+				return false;
 			
 			fbkgen.selectSaveImage(layer,config->vision.rawcam_channel);
-			used=fbkgen.SaveBuffer(cur,avail);
-			ASSERTRETVAL(used!=0,"save image failed",false);
-			avail-=used; cur+=used;
+			if(!LoadSave::checkInc(fbkgen.saveBuffer(cur,avail),cur,avail,"image size too large -- may need to set Config::vision.rawcam_transport to TCP and reopen raw cam")) return false;
 			
 			closePacket();
 		}
@@ -334,9 +332,13 @@ RawCamBehavior::sendCloseConnectionPacket() {
 	char msg[]="CloseConnection";
 	unsigned int len=strlen(msg)+LoadSave::stringpad;
 	char * buf = (char*)visRaw->getWriteBuffer(len);
-	ASSERTRETVAL(buf!=NULL,"Could not get buffer for closing packet",false);
+	if(buf==NULL) {
+		std::cerr << "Could not get buffer for closing packet" << std::endl;
+		return false;
+	}
 	unsigned int used=LoadSave::encode(msg,buf,len);
-	ASSERTRETVAL(used!=0,"Could not write close packet",false);
+	if(used==0)
+		std::cerr << "Could not write close packet" << std::endl;
 	visRaw->write(used);
 	return true;
 }
@@ -347,9 +349,9 @@ RawCamBehavior::sendCloseConnectionPacket() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.21 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.33 $
  * $State: Exp $
- * $Date: 2005/07/29 18:35:05 $
+ * $Date: 2006/09/14 18:57:03 $
  */
 
