@@ -15,7 +15,49 @@ RegionCamBehavior::RegionCamBehavior()
 void
 RegionCamBehavior::DoStart() {
 	BehaviorBase::DoStart();
+	setupServer();
+	erouter->addListener(this,EventBase::visRegionEGID,ProjectInterface::visRegionSID,EventBase::deactivateETID);
+}
+
+void
+RegionCamBehavior::DoStop() {
+	erouter->removeListener(this);
+	closeServer();
+	BehaviorBase::DoStop();
+}
+
+void
+RegionCamBehavior::processEvent(const EventBase& e) {
+	if(!wireless->isConnected(visRegion->sock))
+		return;
+	if(config->vision.region_transport==0 && visRegion->getTransport()==SocketNS::SOCK_STREAM
+		 || config->vision.region_transport==1 && visRegion->getTransport()==SocketNS::SOCK_DGRAM) {
+		closeServer();
+		setupServer();
+		return;
+	}
+	const FilterBankEvent* fbke=dynamic_cast<const FilterBankEvent*>(&e);
+	ASSERTRET(fbke!=NULL,"unexpected event");
+#if DEBUG
+	bool succ=writeRegions(*fbke);
+	ASSERTRET(succ,"serialization failed");
+#else
+	writeRegions(*fbke);
+#endif
+}
+
+void
+RegionCamBehavior::closeServer() {
+	Controller::closeGUI("RegionVisionGUI");
 	
+	// this could be considered a bug in our wireless - if we don't setDaemon(...,false)
+	// it will try to listen again even though we explicitly closed the server socket...
+	wireless->setDaemon(visRegion,false);
+	wireless->close(visRegion->sock);
+}
+
+void
+RegionCamBehavior::setupServer() {
 	std::vector<std::string> args;
 	args.push_back("reg"); 
 	char port[50];
@@ -36,30 +78,6 @@ RegionCamBehavior::DoStart() {
 	}
 	wireless->listen(visRegion,config->vision.region_port);
 	Controller::loadGUI("org.tekkotsu.mon.VisionGUI","RegionVisionGUI",config->vision.region_port,args);
-
-	erouter->addListener(this,EventBase::visRegionEGID,ProjectInterface::visRegionSID);
-}
-
-void
-RegionCamBehavior::DoStop() {
-	erouter->removeListener(this);
-	Controller::closeGUI("RegionVisionGUI");
-
-	// this could be considered a bug in our wireless - if we don't setDaemon(...,false)
-	// it will try to listen again even though we explicitly closed the server socket...
-	wireless->setDaemon(visRegion,false);
-	wireless->close(visRegion->sock);
-	BehaviorBase::DoStop();
-}
-
-void
-RegionCamBehavior::processEvent(const EventBase& e) {
-	if(!wireless->isConnected(visRegion->sock))
-		return;
-	const FilterBankEvent* fbke=dynamic_cast<const FilterBankEvent*>(&e);
-	ASSERTRET(fbke!=NULL,"unexpected event");
-		bool succ=writeRegions(*fbke);
-		ASSERTRET(succ,"serialization failed");
 }
 
 bool
@@ -73,29 +91,14 @@ RegionCamBehavior::openPacket(FilterBankGenerator& fbkgen, unsigned int time, un
 	char * buf=packet=(char*)visRegion->getWriteBuffer(avail);
 	ASSERTRETVAL(packet!=NULL,"could not get buffer",false);
 	
-	unsigned int used;
-	used=LoadSave::encode("TekkotsuImage",buf,avail);
-	ASSERTRETVAL(used!=0,"ran out of space",false);
-	avail-=used; buf+=used;
-	used=LoadSave::encode(Config::vision_config::ENCODE_SINGLE_CHANNEL,buf,avail);
-	ASSERTRETVAL(used!=0,"ran out of space",false);
-	avail-=used; buf+=used;
-	used=LoadSave::encode(Config::vision_config::COMPRESS_RLE,buf,avail);
-	ASSERTRETVAL(used!=0,"ran out of space",false);
-	avail-=used; buf+=used;
+	if(!LoadSave::encodeInc("TekkotsuImage",buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+	if(!LoadSave::encodeInc(Config::vision_config::ENCODE_SINGLE_CHANNEL,buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+	if(!LoadSave::encodeInc(Config::vision_config::COMPRESS_RLE,buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
 
-	used=LoadSave::encode(fbkgen.getWidth(layer),buf,avail);
-	ASSERTRETVAL(used!=0,"ran out of space",false);
-	avail-=used; buf+=used;
-	used=LoadSave::encode(fbkgen.getHeight(layer),buf,avail);
-	ASSERTRETVAL(used!=0,"ran out of space",false);
-	avail-=used; buf+=used;
-	used=LoadSave::encode(time,buf,avail);
-	ASSERTRETVAL(used!=0,"ran out of space",false);
-	avail-=used; buf+=used;
-	used=LoadSave::encode(fbkgen.getFrameNumber(),buf,avail);
-	ASSERTRETVAL(used!=0,"ran out of space",false);
-	avail-=used; buf+=used;
+	if(!LoadSave::encodeInc(fbkgen.getWidth(layer),buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+	if(!LoadSave::encodeInc(fbkgen.getHeight(layer),buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+	if(!LoadSave::encodeInc(time,buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
+	if(!LoadSave::encodeInc(fbkgen.getFrameNumber(),buf,avail,"ran out of space %s:%un",__FILE__,__LINE__)) return false;;
 
 	cur=buf;
 	return true;
@@ -106,22 +109,18 @@ RegionCamBehavior::writeRegions(const FilterBankEvent& e) {
 	FilterBankGenerator& fbkgen=*e.getSource();
 
 	unsigned int layer=fbkgen.getNumLayers()-1-config->vision.regioncam_skip;
-	unsigned int used=0;
 	openPacket(fbkgen,e.getTimeStamp(),layer);
 	ASSERTRETVAL(cur!=NULL,"header failed",false);
 	
 	RegionGenerator * regGen = dynamic_cast<RegionGenerator*>(&fbkgen);
 	ASSERTRETVAL(regGen!=NULL,"fbkgen isn't an RegionGenerator",false);
 
-	regGen->selectSaveImage(layer,config->vision.rlecam_channel);
-	used=regGen->SaveBuffer(cur,avail);
-	ASSERTRETVAL(used!=0,"save region image failed",false);
-	avail-=used; cur+=used;
+	regGen->selectSaveImage(layer,config->vision.segcam_channel);
+	if(!LoadSave::checkInc(regGen->saveBuffer(cur,avail),cur,avail,"save region image failed")) return false;
 	
 	const SegmentedColorGenerator * seg = dynamic_cast<const SegmentedColorGenerator*>((regGen->getSourceGenerator())->getSourceGenerator()); //Get the source of his source (the SegmentedColorGenerator)
 	ASSERTRETVAL(seg!=NULL,"The source of RegionGenerator's source is not a SegmentedColorGenerator - how do i know what the colors are?",false);
-	if(0==(used=seg->encodeColors(cur,avail))) return false;
-	avail-=used; cur+=used;
+	if(!seg->encodeColorsInc(cur,avail)) return false;
 
 	closePacket();
 
@@ -144,9 +143,9 @@ RegionCamBehavior::closePacket() {
  * @author harm & niels (Creators)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.1 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2005/08/05 19:44:22 $
+ * $Date: 2006/09/09 04:32:29 $
  */
 
