@@ -27,12 +27,15 @@ public:
 
 	static std::string getClassDescription() {
 		char tmp[20];
-		sprintf(tmp,"%d",config->vision.rle_port);
+		sprintf(tmp,"%d",config->vision.segcam_port);
 		return std::string("Forwards regions calculated out of images from camera over port ")+tmp;
 	}
 	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
+	void closeServer(); //!<tear down the server socket (#visRegion)
+	void setupServer(); //!<setup the server socket (#visRegion)
+	
 	//! opens a new packet, writes header info; returns true if open, false if otherwise open (check cur==NULL for error)
 	/*! see the class documentation for RegionCamBehavior for the protocol documentation */
 	bool openPacket(FilterBankGenerator& fbkgen, unsigned int time, unsigned int layer); 
@@ -55,10 +58,10 @@ private:
  * @author harm & niels (Creators)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.1 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2005/08/05 19:44:22 $
+ * $Date: 2006/09/16 17:32:38 $
  */
 
 #endif
