@@ -2,7 +2,7 @@
 #ifndef INCLUDED_SegCamBehavior_h_
 #define INCLUDED_SegCamBehavior_h_
 
-#include "Behaviors/BehaviorBase.h"
+#include "CameraStreamBehavior.h"
 #include "Shared/Config.h"
 
 class Socket;
@@ -55,11 +55,14 @@ class FilterBankEvent;
  *  in the AIBO's byte order (little endian).  Strings are encoded using
  *  the LoadSave::encode(char*,unsigned int, unsigned int) method.
  */ 
-class SegCamBehavior : public BehaviorBase {
+class SegCamBehavior : public CameraStreamBehavior {
 public:
 	//! constructor
 	SegCamBehavior();
 
+	//! destructor
+	~SegCamBehavior() { theOne=NULL; }
+
 	static const unsigned int TCP_WIRELESS_BUFFER_SIZE=85000; //!< 85000 bytes for use up to 416x320 pixels / 8 min expected runs * 5 bytes per run + some padding
 	static const unsigned int UDP_WIRELESS_BUFFER_SIZE=64*1024; //!< 64KB is the max udp packet size
 
@@ -71,12 +74,19 @@ public:
 
 	static std::string getClassDescription() {
 		char tmp[20];
-		snprintf(tmp,20,"%d",config->vision.rle_port); tmp[19]='\0';
+		snprintf(tmp,20,"%d",config->vision.segcam_port); tmp[19]='\0';
 		return std::string("Forwards segmented images from camera over port ")+tmp;
 	}
 	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
+	static SegCamBehavior* theOne; //!< global instance of SegCamBehavior acting as server
+	//! function for network data to be sent to -- forwards to #theOne's receiveData()
+	static int networkCallback(char* buf, int bytes) { return theOne->receiveData(buf,bytes); }
+	
+	void closeServer(); //!<tear down the server socket (#visRLE)
+	void setupServer(); //!<setup the server socket (#visRLE	)
+	
 	//! opens a new packet, writes header info; returns true if open, false if otherwise open (check cur==NULL for error)
 	/*! see the class documentation for SegCamBehavior for the protocol documentation */
 	bool openPacket(FilterBankGenerator& fbkgen, unsigned int time, unsigned int layer); 
@@ -104,10 +114,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2005/07/29 18:35:05 $
+ * $Date: 2006/09/16 20:11:50 $
  */
 
 #endif
