@@ -163,7 +163,7 @@ void SpiderMachineBehavior::indent(unsigned int level) {
 }
 
 const StateNode * SpiderMachineBehavior::find(const std::string& name) {
-	for(registry_t::const_iterator it=registry.begin(); it!=registry.end(); it++) {
+	for(registry_t::const_iterator it=getRegistry().begin(); it!=getRegistry().end(); it++) {
 		const StateNode * cur=dynamic_cast<const StateNode*>(*it);
 		if(cur!=NULL && cur->getName()==name)
 			return cur;
@@ -175,13 +175,13 @@ const StateNode * SpiderMachineBehavior::find(const std::string& name) {
 void SpiderMachineBehavior::runCommand(const std::string& s) {
 	if(s==std::string("list")) {
 		unsigned int numstate=0;
-		for(registry_t::const_iterator it=registry.begin(); it!=registry.end(); it++) {
+		for(registry_t::const_iterator it=getRegistry().begin(); it!=getRegistry().end(); it++) {
 			const StateNode * cur=dynamic_cast<const StateNode*>(*it);
 			if(cur!=NULL)
 				numstate++;
 		}
 		cmdsock->printf("%d\n",numstate);
-		for(registry_t::const_iterator it=registry.begin(); it!=registry.end(); it++) {
+		for(registry_t::const_iterator it=getRegistry().begin(); it!=getRegistry().end(); it++) {
 			const StateNode * cur=dynamic_cast<const StateNode*>(*it);
 			if(cur!=NULL)
 				cmdsock->printf("%s\n",cur->getName().c_str());
@@ -232,8 +232,8 @@ int SpiderMachineBehavior::callback(char *buf, int bytes) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:45 $
+ * $Date: 2006/02/21 05:27:13 $
  */
