@@ -45,19 +45,19 @@ void UPennWalkControllerBehavior::runCommand(unsigned char *command) {
 		cout << "MECHA: hey, reprogram this button!" << endl;
 		break;
 	case CMD_opt5:
-		sndman->PlayFile("howl.wav");
+		sndman->playFile("howl.wav");
 		break;
 	case CMD_opt6:
-		sndman->PlayFile("yap.wav");
+		sndman->playFile("yap.wav");
 		break;
 	case CMD_opt7:
-		sndman->PlayFile("whimper.wav");
+		sndman->playFile("whimper.wav");
 		break;
 	case CMD_opt8:
-		sndman->PlayFile("growl.wav");
+		sndman->playFile("growl.wav");
 		break;
 	case CMD_opt9:
-		sndman->PlayFile("barkmed.wav");
+		sndman->playFile("barkmed.wav");
 		break;
 		// The options button commands.
 	default:
@@ -160,9 +160,9 @@ int UPennWalkControllerBehavior::mechacmd_callback(char *buf, int bytes) {
  * @author PA Gov. School for the Sciences 2003 Team Project - Haoqian Chen, Yantian Martin, Jon Stahlman (modifications)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:46 $
+ * $Date: 2006/09/18 18:08:07 $
  */
 
