@@ -60,7 +60,7 @@ WMMonitorBehavior::registerData(const std::string& s) {
 WMitem_base*
 WMMonitorBehavior::find (std::string& s) {
   WMregistry* wmreg=&GlobalWM;
-  unsigned int pos=s.find('.');
+  std::string::size_type pos=s.find('.');
   while (pos!=std::string::npos) {
     bool changed=false;
     std::string subreg=s.substr(0, pos);
@@ -126,7 +126,7 @@ int wmmonitorcmd_callback(char *buf, int bytes) {
                                                                                 
   //pass a line at a time to the controller
   while(s.size()>0) {
-    unsigned int endline=s.find('\n');
+    std::string::size_type endline=s.find('\n');
     if(endline==std::string::npos) {
       incomplete+=s;
       return 0;
@@ -146,8 +146,8 @@ int wmmonitorcmd_callback(char *buf, int bytes) {
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2004/04/16 20:17:22 $
+ * $Date: 2005/11/08 21:36:08 $
  */
