@@ -14,10 +14,17 @@ void WalkControllerBehavior::runCommand(unsigned char *command) {
 	float param;
 	unsigned char *paramp = (unsigned char *) &param;
 
+#if defined(BYTE_ORDER) && BYTE_ORDER==BIG_ENDIAN
+	paramp[0] = command[4];
+	paramp[1] = command[3];
+	paramp[2] = command[2];
+	paramp[3] = command[1];
+#else
 	paramp[0] = command[1];
 	paramp[1] = command[2];
 	paramp[2] = command[3];
 	paramp[3] = command[4];
+#endif
 
 	// Find out what type of command this is
 	switch(command[0]) {
@@ -45,19 +52,19 @@ void WalkControllerBehavior::runCommand(unsigned char *command) {
 		cout << "MECHA: hey, reprogram this button!" << endl;
 		break;
 	case CMD_opt5:
-		sndman->PlayFile("howl.wav");
+		sndman->playFile("howl.wav");
 		break;
 	case CMD_opt6:
-		sndman->PlayFile("yap.wav");
+		sndman->playFile("yap.wav");
 		break;
 	case CMD_opt7:
-		sndman->PlayFile("whimper.wav");
+		sndman->playFile("whimper.wav");
 		break;
 	case CMD_opt8:
-		sndman->PlayFile("growl.wav");
+		sndman->playFile("growl.wav");
 		break;
 	case CMD_opt9:
-		sndman->PlayFile("barkmed.wav");
+		sndman->playFile("barkmed.wav");
 		break;
 		// The options button commands.
 	default:
@@ -160,9 +167,9 @@ int WalkControllerBehavior::mechacmd_callback(char *buf, int bytes) {
  * @author PA Gov. School for the Sciences 2003 Team Project - Haoqian Chen, Yantian Martin, Jon Stahlman (modifications)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:46 $
+ * $Date: 2006/09/18 18:08:07 $
  */
 
