@@ -13,23 +13,26 @@ class Socket;
  *  of values.
  *
  *  Protocol:
+ *  - <@c char[]: modelName> (null terminated character array)
  *  - <@c unsigned @c int: timestamp>
- *  - <@c unsigned @c int: ::NumPIDJoints>
- *  - for each <i>i</i> of ::NumPIDJoints:
- *    - <@c float: position of joint <i>i</i>>
+ *  - <@c unsigned @c int: framenumber>
+ *  - <@c unsigned @c int: ::NumOutputs>
+ *  - for each <i>i</i> of ::NumOutputs:
+ *    - <@c float: position of output <i>i</i>>
  *  - <@c unsigned @c int: ::NumSensors>
  *  - for each <i>i</i> of ::NumSensors:
  *    - <@c float: value of sensor <i>i</i>>
  *  - <@c unsigned @c int: ::NumButtons>
  *  - for each <i>i</i> of ::NumButtons:
  *    - <@c float: value of button <i>i</i>>
+ *  - <@c unsigned @c int: ::NumPIDJoints>
  *  - for each <i>i</i> of ::NumPIDJoints:
  *    - <@c float: duty cycle of joint <i>i</i>>
  * */
 class WorldStateSerializerBehavior : public BehaviorBase {
 public:
-  WorldStateSerializerBehavior(); //!< constructor
-
+	WorldStateSerializerBehavior(); //!< constructor
+	
 	virtual void DoStart(); //!< starts listening for sensor update events
 	virtual void DoStop(); //!< stops listening for events
 	virtual void processEvent(const EventBase& e); //!< core functionality - performs serialization, sends to sockets
@@ -39,31 +42,36 @@ public:
 		return tmp;
 	}
 	virtual std::string getDescription() const { return getClassDescription(); }
-
+	
+	//! returns string corresponding to the Java GUI which should be launched
+	virtual std::string getGUIType() const { return "org.tekkotsu.mon.WorldStateRecordGUI"; }
+	//! returns port number the Java GUI should connect to
+	virtual unsigned int getPort() const { return config->main.wsjoints_port; }
+	
 protected:
-	//! writes @a value to @a dst and advances @a dst
-  template<class T>
-  inline static void encode(char **dst, const T& value) {
-    memcpy(*dst, &value, sizeof(T));
-		// it'd be nice to use network byte order, but we'll save the aibo extra work
-		//hostToNetwork(*dst, (char *)&value, sizeof(T));
-    (*dst) += sizeof(T);
-  }
+	//! writes @a value to @a dst and advances @a dst by sizeof(T)
+	/*! doesn't do any byte swapping, so this is only used if LoadSave indicates no byte swapping is needed */
+	template<class T>
+	inline static void copy(char **dst, const T& value) {
+		memcpy(*dst, &value, sizeof(T));
+		(*dst) += sizeof(T);
+	}
 
-	//! writes @a length bytes from @a src to @a dst
-  template<class T>
-  inline static void encode(char **dst, const T * src, int num) {
-    memcpy(*dst, src, num*sizeof(T));
-    (*dst) += num*sizeof(T);
-  }
-
-  Socket *wsJoints; //!< socket for sending current joint data
-  Socket *wsPIDs; //!< socket for sending current PID info
-  unsigned int lastProcessedTime; //!< the time that the last event was processed
+	//! writes @a num copies of T from @a src to @a dst and advances @a dst by @a num * sizeof(T)
+	/*! doesn't do any byte swapping, so this is only used if LoadSave indicates no byte swapping is needed */
+	template<class T>
+	inline static void copy(char **dst, const T * src, int num) {
+		memcpy(*dst, src, num*sizeof(T));
+		(*dst) += num*sizeof(T);
+	}
 
+	Socket *wsJoints; //!< socket for sending current joint data
+	Socket *wsPIDs; //!< socket for sending current PID info
+	unsigned int lastProcessedTime; //!< the time that the last event was processed
+	
 private:
-  WorldStateSerializerBehavior(const WorldStateSerializerBehavior&); //!< don't call
-  WorldStateSerializerBehavior& operator= (const WorldStateSerializerBehavior&); //!< don't call
+	WorldStateSerializerBehavior(const WorldStateSerializerBehavior&); //!< don't call
+	WorldStateSerializerBehavior& operator= (const WorldStateSerializerBehavior&); //!< don't call
 };
 
 /*! @file
@@ -71,10 +79,10 @@ private:
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2005/02/21 08:05:57 $
+ * $Date: 2006/09/09 23:28:59 $
  */
 
 #endif
