@@ -9,7 +9,7 @@
 //! A simple StateNode that plays a sound upon startup and throws a status event on completion
 /*! Doesn't automatically preload the sound buffer - if you want the sound file
  *  to be preloaded, you'll have to make the
- *  SoundManager::LoadFile() / SoundManager::ReleaseFile() calls yourself.
+ *  SoundManager::loadFile() / SoundManager::releaseFile() calls yourself.
  *  
  *  By default, sound playback will continue even after this node has been deactivated.
  *  If this is not the behavior you desire, set the #autostop flag (through setAutoStop())
@@ -33,7 +33,7 @@ public:
   virtual void DoStart() {
     StateNode::DoStart();  // don't activate transitions until our listener has been added
 		if(filename.size()>0) {
-			curplay_id = sndman->PlayFile(filename);
+			curplay_id = sndman->playFile(filename);
 			erouter->addListener(this,EventBase::audioEGID,curplay_id,EventBase::deactivateETID);
 		}
   }
@@ -41,7 +41,7 @@ public:
   //! deactivate the node, doesn't stop the sound playback unless the #autostop flag has been set
   virtual void DoStop() {
 		if(autostop)
-			StopPlay();
+			stopPlay();
     erouter->removeListener(this);
     StateNode::DoStop();
   }
@@ -53,8 +53,8 @@ public:
   }
 
   //! interrupts playing of the current sound
-  void StopPlay() {
-    sndman->StopPlay(curplay_id);
+  void stopPlay() {
+    sndman->stopPlay(curplay_id);
     curplay_id = SoundManager::invalid_Play_ID;
   }
 
@@ -81,10 +81,10 @@ protected:
  * @author dst (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:46 $
+ * $Date: 2006/09/18 18:07:59 $
  */
 
 #endif
