@@ -79,15 +79,15 @@ void StateNode::teardown() {
 }
 
 void StateNode::postStartEvent() {
-	erouter->postEvent(EventBase::stateMachineEGID,reinterpret_cast<unsigned int>(this),EventBase::activateETID,0,getName(),1);
+	erouter->postEvent(EventBase::stateMachineEGID,reinterpret_cast<size_t>(this),EventBase::activateETID,0,getName(),1);
 }
 
 void StateNode::postCompletionEvent(float magnitude/*=0*/) {
-	erouter->postEvent(EventBase::stateMachineEGID,reinterpret_cast<unsigned int>(this),EventBase::statusETID,get_time()-startedTime,getName(),magnitude);
+	erouter->postEvent(EventBase::stateMachineEGID,reinterpret_cast<size_t>(this),EventBase::statusETID,get_time()-startedTime,getName(),magnitude);
 }
 
 void StateNode::postStopEvent() {
-	erouter->postEvent(EventBase::stateMachineEGID,reinterpret_cast<unsigned int>(this),EventBase::deactivateETID,get_time()-startedTime,getName(),0);
+	erouter->postEvent(EventBase::stateMachineEGID,reinterpret_cast<size_t>(this),EventBase::deactivateETID,get_time()-startedTime,getName(),0);
 }
 
 /*! @file 
@@ -95,9 +95,9 @@ void StateNode::postStopEvent() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.25 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.26 $
  * $State: Exp $
- * $Date: 2005/04/15 21:30:55 $
+ * $Date: 2005/11/08 21:36:06 $
  */
 
