@@ -34,7 +34,7 @@ void RandomTrans::addWeight(float weight) {
 void RandomTrans::fire() {
   AddReference(); // for safety
   if ( sound.size()!=0 )
-    sndman->PlayFile(sound);
+    sndman->playFile(sound);
 
   for(size_t i=0; i<srcs.size(); i++)
     if(srcs[i]->isActive())  // don't deactivate a non-active node
