@@ -21,10 +21,12 @@ public:
   //! constructor
   RandomTrans(const std::string& name, StateNode* destination, float weight=1);
 
-  //! Add a destination node with an optional weight.
+  //! Add a destination node with weight==1 (see addDestination(StateNode* dest, float weight) to specify a different weight)
   virtual void RandomTrans::addDestination(StateNode* destination) {
-    addDestination(destination,1); }
+    addDestination(destination,1);
+	}
 
+  //! Add a destination node with an specified weight (other version of addDestination() assumes weight==1)
   void addDestination(StateNode* destination, float weight);
 
   //! Firing this type of transition activates one destination node at random, 
