@@ -12,13 +12,18 @@ const char* const EventBase::EventGeneratorNames[numEGIDs] = {
 	"erouterEGID",
 	"estopEGID",
 	"locomotionEGID",
+	"lookoutEGID",
+	"mapbuilderEGID",
 	"micOSndEGID",
 	"micRawEGID",
 	"micFFTEGID",
+	"micPitchEGID",
 	"motmanEGID",
+	"pilotEGID",
 	"powerEGID",
 	"sensorEGID",
 	"stateMachineEGID",
+	"stateSignalEGID",
 	"stateTransitionEGID",
 	"textmsgEGID",
 	"timerEGID",
@@ -26,6 +31,7 @@ const char* const EventBase::EventGeneratorNames[numEGIDs] = {
 	"visRawCameraEGID",
 	"visInterleaveEGID",
 	"visJPEGEGID",
+	"visPNGEGID",
 	"visSegmentEGID",
 	"visRLEEGID",
 	"visRegionEGID",
@@ -113,71 +119,51 @@ EventBase::getBinSize() const {
 		return XMLLoadSave::getBinSize();
 	unsigned int used=0;
 	used+=creatorSize("EventBase");
-	used+=stim_id.size()+stringpad;
-	used+=sizeof(magnitude);
-	used+=sizeof(timestamp);
-	used+=sizeof(nameisgen);
-	used+=sizeof(char);
-	used+=sizeof(char);
-	used+=sizeof(sourceID);
-	used+=sizeof(duration);
+	used+=getSerializedSize(stim_id);
+	used+=getSerializedSize(magnitude);
+	used+=getSerializedSize(timestamp);
+	used+=getSerializedSize(nameisgen);
+	used+=getSerializedSize<char>(); //genID is an enum, override to char
+	used+=getSerializedSize<char>(); //typeID is an enum, override to char
+	used+=getSerializedSize(sourceID);
+	used+=getSerializedSize(duration);
 	return used;
 }
 
 unsigned int
-EventBase::LoadBinaryBuffer(const char buf[], unsigned int len) {
+EventBase::loadBinaryBuffer(const char buf[], unsigned int len) {
 	unsigned int origlen=len;
-	unsigned int used=0;
-	if(0==(used=checkCreator("EventBase",buf,len,true))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=decode(stim_id,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=decode(magnitude,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=decode(timestamp,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=decode(nameisgen,buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!checkCreatorInc("EventBase",buf,len,true)) return 0;
+	if(!decodeInc(stim_id,buf,len)) return 0;
+	if(!decodeInc(magnitude,buf,len)) return 0;
+	if(!decodeInc(timestamp,buf,len)) return 0;
+	if(!decodeInc(nameisgen,buf,len)) return 0;
 	char tmp;
-	if(0==(used=decode(tmp,buf,len))) return 0;
+	if(!decodeInc(tmp,buf,len)) return 0;
 	genID=(EventGeneratorID_t)tmp;
-	len-=used; buf+=used;
-	if(0==(used=decode(tmp,buf,len))) return 0;
+	if(!decodeInc(tmp,buf,len)) return 0;
 	typeID=(EventTypeID_t)tmp;
-	len-=used; buf+=used;
-	if(0==(used=decode(sourceID,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=decode(duration,buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!decodeInc(sourceID,buf,len)) return 0;
+	if(!decodeInc(duration,buf,len)) return 0;
 	return origlen-len;	
 }
 
 unsigned int
-EventBase::SaveBinaryBuffer(char buf[], unsigned int len) const {
+EventBase::saveBinaryBuffer(char buf[], unsigned int len) const {
 	unsigned int origlen=len;
-	unsigned int used=0;
-	if(0==(used=saveCreator("EventBase",buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode(stim_id,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode(magnitude,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode(timestamp,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode(nameisgen,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode((char)genID,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode((char)typeID,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode(sourceID,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode(duration,buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!saveCreatorInc("EventBase",buf,len)) return 0;
+	if(!encodeInc(stim_id,buf,len)) return 0;
+	if(!encodeInc(magnitude,buf,len)) return 0;
+	if(!encodeInc(timestamp,buf,len)) return 0;
+	if(!encodeInc(nameisgen,buf,len)) return 0;
+	if(!encodeInc((char)genID,buf,len)) return 0;
+	if(!encodeInc((char)typeID,buf,len)) return 0;
+	if(!encodeInc(sourceID,buf,len)) return 0;
+	if(!encodeInc(duration,buf,len)) return 0;
 	return origlen-len;
 }
 
-void EventBase::LoadXML(xmlNode* node) {
+void EventBase::loadXML(xmlNode* node) {
 	if(xmlStrcmp(node->name, (const xmlChar *)"event"))
 		throw bad_format(node,"Load of the wrong type -- expecting 'event' node");
 	unsigned int i;
@@ -232,11 +218,11 @@ void EventBase::LoadXML(xmlNode* node) {
 	} else
 		genName();
 }
-void EventBase::SaveXML(xmlNode * node) const {
+void EventBase::saveXML(xmlNode * node) const {
 	xmlNodeSetName(node,(const xmlChar*)"event");
 	xmlSetProp(node,(const xmlChar*)"egid",(const xmlChar*)EventGeneratorNames[genID]);
 	char buf[20];
-	snprintf(buf,20,"%x",sourceID);
+	snprintf(buf,20,"%lu",static_cast<unsigned long>(sourceID));
 	xmlSetProp(node,(const xmlChar*)"sid",(const xmlChar*)buf);
 	xmlSetProp(node,(const xmlChar*)"etid",(const xmlChar*)EventTypeAbbr[typeID]);
 	snprintf(buf,20,"%u",timestamp);
@@ -260,7 +246,7 @@ EventBase::genName() {
 	if(!nameisgen)
 		return;
 	char tmp[16];
-	snprintf(tmp,16,"%d",sourceID);
+	snprintf(tmp,16,"%lu",static_cast<unsigned long>(sourceID));
 	setName(tmp);
 	nameisgen=true;
 }
@@ -270,9 +256,9 @@ EventBase::genName() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.25 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.32 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:46 $
+ * $Date: 2006/09/21 21:26:07 $
  */
 
