@@ -6,43 +6,70 @@
 #include "Shared/XMLLoadSave.h"
 #include <string>
 
-//! The basis of events passed around the high level system
-/*! Contains the list of 'known' event generators in #EventGeneratorID_t
- *  and #EventGeneratorNames[].  If you want to make a new generator, all
- *  you have to do is add a new entry to the ID list (#EventGeneratorID_t)
- *  and then put its name in the #EventGeneratorNames[] array.
+//! Forms the basis of communication between modules/behaviors in the framework
+/*! 
+ *  Events are defined by a 3-tuple:
+ *  - The @b generator indicates the class of the creator of the event, and in practice also generally implies the type (i.e. subclass) of the event itself.
+ *  - The @b source indicates the instance of the creator of the event, which differentiates when more than one generator is available.
+ *  - The @b type indicates the role of the event among other events from the source.
  *
- *  The #EventGeneratorID_t list should contain links to the
- *  generators' documentation, or will directly give information about
- *  what to expect in events from that generator.
+ *  Each of these is represented by an ID, the #EventGeneratorID_t (EGID) and #EventTypeID_t (ETID) are
+ *  defined here in EventBase.  Source IDs (SID) are defined separately by each generator, so the
+ *  documentation in each entry of EventGeneratorID_t describes how to interpret the source field.
+ *
+ *  So for example, the button event which results from initially pressing the head button on an ERS-7
+ *  robot would be:
+ *  <center>(EventBase::buttonEGID, ERS7Info::HeadButOffset, EventBase::activateETID)</center>
+ *
+ *  While the button is held down, additional #statusETID events are used to report varying pressure values (if the button
+ *  is pressure sensitive), and an event with #deactivateETID is sent when the button is released.
+ *  Alternatively, an SID value from a vision detector (say #visObjEGID) refers to seeing a particular object, a completely
+ *  different domain, values of which may overlap with other generators' source IDs.
+ *  Thus, interpreting the source field requires knowing the generator as well.
+ *
+ *  When the generator doesn't have groups of activity with a 'begin' or 'end', it will use #statusETID
+ *  for all of its events.  (in other words, not all generators necessarily have to use activate or deactivate)
+ *  For example, sensor updates are continuously occuring, so you will only ever see
+ *  <center>(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID)</center>
  *  
- *  Alternatively, there is an 'unlicensed spectrum' available under
- *  the #unknownEGID.  You can send out events from that generator just
- *  like any other, but it should only be used for quick tests and hacking
- *  around...
- *
- *  The #sourceID (just an unsigned int) is generator specific.  A SID
- *  of @a i from the button generator (#buttonEGID) will refer to a
- *  particular button, whereas a SID from a vision detector (say
- *  #visObjEGID) refers to seeing a particular object.  These SIDs are
- *  usually defined in the generators themselves.
- *
- *  If more information needs to be sent along with the event, the
- *  cleanest solution is to create a subclass of EventBase to hold the
- *  additional information.  For example, you can see the existing
- *  subclasses in the inheritance diagram above.  If you want to use a
- *  quick hack however, you could assume the pointer size is the same
- *  as an unsigned int and just pass a pointer to data as the SID.
- *  Your funeral, err, I mean your call. ;)
- *
  *  The #duration field is also generator specific - some may refer to
  *  the time since the last activation event (e.g. button events)
  *  where as others refer to time since last status (e.g. sensors
  *  updates)
  *
+ *  If you want to make a new generator, all you have to do is add a new entry
+ *  to the ID list (#EventGeneratorID_t) and then put its name in the 
+ *  #EventGeneratorNames[] array.  Alternatively, there is an 'unlicensed spectrum' available under
+ *  #unknownEGID.  You can send out events from that generator just
+ *  like any other, but it should only be used for quick tests and hacking
+ *  around...
+ *
+ *  The generator ID number is only that -- an ID number.  
+ *  Events can be posted to the EventRouter anywhere, anytime,
+ *  and do not require anything of the sender.  However, there is an EventGeneratorBase which
+ *  can simplify some aspects of behaviors whose sole purpose is processing information
+ *  and generating events.
+ *
+ *  If more information needs to be sent along with the event, the
+ *  cleanest solution is to create a subclass of EventBase to hold the
+ *  additional information.  For example, you can see the existing
+ *  subclasses in the inheritance diagram above.  If you want to use a
+ *  quick hack however, you could just pass a pointer to data as the SID if you
+ *  don't need that field for something else, or use a DataEvent.
+ *
  *  @note All subclasses must override getClassTypeID() and provide
- *  a unique value to allow fast serialization for inter-process
- *  communication.
+ *  a unique value to allow fast polymorphic serialization for inter-process
+ *  communication.  Implementing the load/save functions
+ *  ({load,save}BinaryBuffer and {load,save}XML) for your addtional data fields
+ *  would also be necessary in order to allow your event to be sent between
+ *  processes, or eventually, between robots.
+ * 
+ *  @see EventRouter for discussion on sending and receiving of events
+ *  @see Tutorials:
+ *    - <a href="../FirstBehavior2.html">Steps 3, 4, & 5 of Tekkotsu's First Behavior Tutorial</a>
+ *    - <a href="http://www.cs.cmu.edu/~dst/Tekkotsu/Tutorial/events.shtml">David Touretzky's Events Chapter</a>
+ *    - <a href="http://www.cs.cmu.edu/afs/cs/academic/class/15494-s06/www/lectures/behaviors.pdf">CMU's Cognitive Robotics course slides</a>
+ *    - <a href="../media/TekkotsuQuickReference_ERS7.pdf">ERS-7 Quick Reference Sheet</a>
  */
 class EventBase : public XMLLoadSave {
  public:
@@ -58,20 +85,26 @@ class EventBase : public XMLLoadSave {
 		erouterEGID,      //!< Sends activate event on first listener, deactivate on last listener, and status on other listener changes.; SID is the generator ID affected
 		estopEGID,        //!< Sends an event when the estop is turned on or off; SID is the MotionManager::MC_ID of the EmergencyStopMC; duration is length of estop activation
 		locomotionEGID,   //!< Sends events regarding transportation in the world; you can/should assume these will all be LocomotionEvent classes; SID is MotionManager::MC_ID of posting MotionCommand; duration is the time since last velocity change of that MC. (You could generate these for things other than walking...)
+		lookoutEGID,      //!< Sends an event when Lookout request is complete; SID is the id for lookout request
+		mapbuilderEGID,  //!< Sends a status event when map is completed
 		micOSndEGID,      //!< Sends a DataEvent<OSoundVectorData> for every audio buffer received from the system; SID and duration are always 0 (This is generated by the MainObj instantiation of MMCombo)
 		micRawEGID,       //!< reserved for future use
 		micFFTEGID,       //!< reserved for future use
+		micPitchEGID,       //!< Sends a PitchEvent when a particular frequency is detected; SID is a pointer to the PitchDetector, magnitude is product of amplitude and confidence
 		motmanEGID,       //!< Sends events when a MotionCommand is added or removed, SID is is the MotionManager::MC_ID, duration is always 0; individual MotionCommands may throw status events to signal intermediary status
+		pilotEGID,        //!< Sends events when position of agent is updated or pilot request is completed
 		powerEGID,        //!< Sends events for low power warnings, temperature, etc. see PowerSourceID::PowerSourceID_t
 		sensorEGID,       //!< Sends a status event when new sensor readings are available. see SensorSourceID::SensorSourceID_t
 		stateMachineEGID, //!< Sends an event upon entering and leaving a StateNode; SID is pointer to the StateNode; duration is always 0; some state will throw a status event when they have completed their task and are now idling
+		stateSignalEGID,  //!< Sends a DataEvent that can be monitored by a SignalTrans for triggering a state transition
 		stateTransitionEGID, //!< Sends an event each time a transition is triggered; SID is a pointer to the transition; type is always status, duration is always 0; guaranteed to occur immediately *before* the transition actually occurs
-		textmsgEGID,      //!< Sends status events when a text msg is received on console; generated by the Controller, SID is always -1; durations is always 0 (see Controller for more information)
+		textmsgEGID,      //!< Sends status events when a text msg is received on console; generated by the Controller, SID is 0 if broadcast from ControllerGUI, 1 if "private" from BehaviorSwitchControl; duration is always 0 (see Controller for more information)
 		timerEGID,        //!< Sends timer events; you set timers explicitly, you don't have to listen as well. (See EventRouter::addTimer()) There's no cross-talk, only the listener which requested the timer will receive it; SID is whatever you requested it to be; duration is the time (since boot, in ms) that the timer was supposed to go off; these are always status
 		visOFbkEGID,      //!< Sends a DataEvent < OFbkImageVectorData > for every camera image received from the system; SID and duration are always 0 (This is generated by the MainObj instantiation of MMCombo)
 		visRawCameraEGID, //!< Sends a FilterBankEvent when new raw camera images are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
 		visInterleaveEGID,//!< Sends a FilterBankEvent when new interleaved images are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
 		visJPEGEGID,      //!< Sends a FilterBankEvent when JPEG compressed images are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
+		visPNGEGID,      //!< Sends a FilterBankEvent when PNG compressed images are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
 		visSegmentEGID,   //!< Sends a SegmentedColorFilterBankEvent when color segmentated images are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
 		visRLEEGID,       //!< Sends a SegmentedColorFilterBankEvent when RLE encoded color segmentated images are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
 		visRegionEGID,    //!< Sends a SegmentedColorFilterBankEvent when color regions are available; SID is whatever value you gave during setup (typically in StartupBehavior_SetupVision.cc), duration is always 0
@@ -125,6 +158,7 @@ class EventBase : public XMLLoadSave {
 	virtual EventBase& setMagnitude(float m) { magnitude=m; return *this; }//!< sets "strength" of event - you may want to override the default values (see getMagnitude())
 
 	virtual unsigned int getTimeStamp() const { return timestamp; } //!< time event was created
+	virtual void setTimeStamp(unsigned int t) { timestamp=t; } //!< resets time event was created
 
 	virtual EventGeneratorID_t getGeneratorID() const { return genID; } /*!< @brief gets the generator ID for this event @see EventGeneratorID_t */
 	virtual EventBase& setGeneratorID(EventGeneratorID_t gid) { genID=gid; genName(); return *this; } /*!< @brief sets the generator ID for this event @see EventGeneratorID_t */
@@ -133,7 +167,7 @@ class EventBase : public XMLLoadSave {
 	virtual EventBase& setSourceID(unsigned int sid) { sourceID=sid; genName(); return *this; } /*!< @brief sets the source ID for this event @see sourceID */
 	
 	virtual EventTypeID_t getTypeID() const { return typeID; } /*!< @brief gets the type ID @see EventTypeID_t */
-	virtual EventBase& setTypeID(EventTypeID_t tid) { typeID=tid; genName(); return *this; } /*!< @brief sets the type ID @see EventTypeID_t */
+	virtual EventBase& setTypeID(EventTypeID_t tid) { typeID=tid; unsigned int n=strlen(EventTypeAbbr[typeID]); stim_id.replace(stim_id.size()-n-1,n,EventTypeAbbr[typeID]); return *this; } /*!< @brief sets the type ID @see EventTypeID_t */
 
 	virtual unsigned int getDuration() const { return duration; } /*!< @brief gets the time since the beginning of this sequence (the timestamp of the activate event) @see duration */
 	virtual EventBase& setDuration(unsigned int d) { duration = d; return *this; }/*!< @brief sets the time since the beginning of this sequence (the timestamp of the activate event) @see duration */
@@ -178,30 +212,38 @@ class EventBase : public XMLLoadSave {
 	 *  identification of the class type by the receiver. */
 	virtual unsigned int getClassTypeID() const { return makeClassTypeID("BASE"); }
 
-	virtual unsigned int getBinSize() const;
-	virtual unsigned int LoadBinaryBuffer(const char buf[], unsigned int len);
-	virtual unsigned int SaveBinaryBuffer(char buf[], unsigned int len) const;
-	virtual void LoadXML(xmlNode* node);
-	virtual void SaveXML(xmlNode * node) const;
-
-	virtual unsigned int LoadBuffer(const char buf[], unsigned int len)  {
-		unsigned int test = saveFormat!=BINARY ? XMLLoadSave::LoadBuffer(buf,len) : LoadBinaryBuffer(buf,len);
-		if(test!=0) //if the default didn't work, try the other format too...
-			return test;
-		return saveFormat!=BINARY ? LoadBinaryBuffer(buf,len) : XMLLoadSave::LoadBuffer(buf,len);
-	}
-	virtual unsigned int SaveBuffer(char buf[], unsigned int len) const { return saveFormat!=BINARY ? XMLLoadSave::SaveBuffer(buf,len) : SaveBinaryBuffer(buf,len); }
-
-	virtual	unsigned int LoadFile(const char* filename) {
-		unsigned int test = saveFormat!=BINARY ? XMLLoadSave::LoadFile(filename) : LoadSave::LoadFile(filename);
-		if(test!=0) //if the default didn't work, try the other format too...
-			return test;
-		return saveFormat!=BINARY ? LoadSave::LoadFile(filename) : XMLLoadSave::LoadFile(filename);
-	}
-	virtual unsigned int SaveFile(const char* filename) const { return saveFormat!=BINARY ? XMLLoadSave::SaveFile(filename) : LoadSave::SaveFile(filename); }
+	virtual unsigned int getBinSize() const; //!< should return the minimum size needed if using binary format (i.e. not XML)
+	virtual unsigned int loadBinaryBuffer(const char buf[], unsigned int len); //!< load from binary format
+	virtual unsigned int saveBinaryBuffer(char buf[], unsigned int len) const; //!< save to binary format
+	virtual void loadXML(xmlNode* node); //!< load from XML format
+	virtual void saveXML(xmlNode * node) const; //!< save to XML format
 	
-	virtual unsigned int LoadFileStream(FILE* f) { return saveFormat!=BINARY ? XMLLoadSave::LoadFileStream(f) : LoadSave::LoadFileStream(f); }
-	virtual unsigned int SaveFileStream(FILE* f) const { return saveFormat!=BINARY ? XMLLoadSave::SaveFileStream(f) : LoadSave::SaveFileStream(f); }
+	//! no longer need to override this -- will automatically call either loadXML() or loadBinaryBuffer() based on #saveFormat
+	/*! tries to be smart so if the load based on the current #saveFormat fails, retries with the alternative format */
+	virtual unsigned int loadBuffer(const char buf[], unsigned int len)  {
+		unsigned int test = saveFormat!=BINARY ? XMLLoadSave::loadBuffer(buf,len) : loadBinaryBuffer(buf,len);
+		if(test!=0) //if the default didn't work, try the other format too...
+			return test;
+		return saveFormat!=BINARY ? loadBinaryBuffer(buf,len) : XMLLoadSave::loadBuffer(buf,len);
+	}
+	//! no longer need to override this -- will automatically call either saveXML() or saveBinaryBuffer() based on #saveFormat
+	virtual unsigned int saveBuffer(char buf[], unsigned int len) const { return saveFormat!=BINARY ? XMLLoadSave::saveBuffer(buf,len) : saveBinaryBuffer(buf,len); }
+
+	//! automatically calls either XMLLoadSave::loadFile or LoadSave::loadFile based on #saveFormat
+	/*! tries to be smart so if the load based on the current #saveFormat fails, retries with the alternative format */
+	virtual unsigned int loadFile(const char* filename) {
+		unsigned int test = saveFormat!=BINARY ? XMLLoadSave::loadFile(filename) : LoadSave::loadFile(filename);
+		if(test!=0) //if the default didn't work, try the other format too...
+			return test;
+		return saveFormat!=BINARY ? LoadSave::loadFile(filename) : XMLLoadSave::loadFile(filename);
+	}
+	//! automatically calls either XMLLoadSave::saveFile or LoadSave::saveFile based on #saveFormat
+	virtual unsigned int saveFile(const char* filename) const { return saveFormat!=BINARY ? XMLLoadSave::saveFile(filename) : LoadSave::saveFile(filename); }
+	
+	//! automatically calls either XMLLoadSave::loadFileStream or LoadSave::loadFileStream based on #saveFormat
+	virtual unsigned int loadFileStream(FILE* f) { return saveFormat!=BINARY ? XMLLoadSave::loadFileStream(f) : LoadSave::loadFileStream(f); }
+	//! automatically calls either XMLLoadSave::loadFileStream or LoadSave::loadFileStream based on #saveFormat
+	virtual unsigned int saveFileStream(FILE* f) const { return saveFormat!=BINARY ? XMLLoadSave::saveFileStream(f) : LoadSave::saveFileStream(f); }
 	
 	//! values to pass to setSaveFormat()
 	enum SaveFormat {
@@ -223,14 +265,14 @@ class EventBase : public XMLLoadSave {
 	float magnitude; //!< the current "strength" of the event/stimuli... MAKE SURE this gets set to ZERO IF event is DEACTIVATE
 	unsigned int timestamp; //!< the time the event was created - set automatically by constructor
 
-	mutable SaveFormat saveFormat; //!< controls the format used during the next call to SaveBuffer() (packed binary or XML)
+	mutable SaveFormat saveFormat; //!< controls the format used during the next call to saveBuffer() (packed binary or XML)
 
 	bool nameisgen; //!< tracks whether the current name (stim_id) was generated by genName() (true) or setName() (false)
 	virtual void genName(); //!< calls setName() with a string version of sourceID, decimal notation
 
 	EventGeneratorID_t genID; //!< generator ID, see EventGeneratorID_t
 	EventTypeID_t typeID; //!< type ID, see EventTypeID_t
-	unsigned int sourceID; /*!< @brief the source ID for this event
+	size_t sourceID;       /*!< @brief the source ID for this event
 													* Source IDs are defined by the generator that made it.  This should
 													* give authors flexibility to design their modules without having to
 													* worry about ID space collision */
@@ -245,10 +287,10 @@ class EventBase : public XMLLoadSave {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.34 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.50 $
  * $State: Exp $
- * $Date: 2005/06/29 22:03:34 $
+ * $Date: 2006/10/03 23:19:23 $
  */
 
 #endif
