@@ -3,33 +3,35 @@
 #include "Behaviors/BehaviorBase.h"
 #include "Shared/ProjectInterface.h"
 #include <algorithm>
+#include "Events/TimerEvent.h"
 
 EventRouter * erouter=NULL;
 
 EventRouter::EventRouter()
-	: timers(), events(), doSendBufferLock(false), lastBufClear(0), buffertime(0), trappers(), listeners()
+	: timers(), trappers(), listeners(), postings()
 {}
 
+void EventRouter::postEvent(EventBase* e) { processEvent(*e); delete e; }
+
 //! @todo handle recursive calls
 void EventRouter::processTimers() {
 	//		cout << "processTimers..." << flush;
 	unsigned int curtime=get_time();
-	if(curtime-lastBufClear>=buffertime || buffertime==1)
-		processEventBuffer();
-
 	TimerEntry curTimer(curtime);
 	timer_it_t last_it=upper_bound(timers.begin(),timers.end(),&curTimer,TimerEntryPtrCmp());
 	std::vector<TimerEntry*> process(timers.begin(),last_it); //copy these out for safe keeping
 	for(timer_it_t it=process.begin(); it!=process.end(); it++) //increment the timers we're processing
-		if((*it)->repeat)
-			(*it)->next+=(*it)->delay;
-		else
+		if(!(*it)->repeat)
 			(*it)->next=(unsigned int)-1;
+		else if((*it)->delay==0)
+			(*it)->next=curtime+1;
+		else while((*it)->next<=curtime)
+			(*it)->next+=(*it)->delay;
 	sort(timers.begin(),last_it,TimerEntryPtrCmp()); //re-sort the timers we're processing (at the beginning of timers)
 	inplace_merge(timers.begin(),last_it,timers.end(),TimerEntryPtrCmp()); //now do a merge of the sorted processed stuff and the rest of the list (which is still sorted)
 	//	if(process.size()>0) chkTimers();
 	for(timer_it_t it=process.begin(); it!=process.end(); it++) { // process the timers we say we're going to, can no longer assume anything about the state of the world
-		EventBase e(EventBase::timerEGID,(*it)->sid,EventBase::statusETID,(*it)->next);
+		TimerEvent e((*it)->el,EventBase::timerEGID,(*it)->sid,EventBase::statusETID,(*it)->next-(*it)->delay);
 		try {
 			(*it)->el->processEvent(e);
 		} catch(const std::exception& ex) {
@@ -49,6 +51,7 @@ void EventRouter::processTimers() {
 			if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,msg.c_str(),NULL))
 				throw;
 		}
+		postEvent(e);
 	}
 	//	if(process.size()>0) chkTimers();
 	static const TimerEntry deadTimer((unsigned int)-1); // matches all the dead ones as set in the incrementation phase
@@ -64,10 +67,6 @@ void EventRouter::processTimers() {
  *  a delay of 0 with repeating will cause an event to be sent at every opportunity, use sparingly\n
  *  a delay of -1U will call removeTimer() if it already exists, otherwise is ignored\n
  *
- *  To add a timer, you can also call addListener() with EventBase::timerEGID and the sid
- *  and delay (in the EventBase::duration field) - this method will simply cause this
- *  function to be called internally.
- *
  *  @param el the EventListener to send the timer event to
  *  @param sid the source ID to use on that event (if you need to send more info, send a pointer to a struct of your devising, typecasted as int)
  *  @param delay the delay between the first (and future) calls
@@ -99,7 +98,7 @@ void EventRouter::removeTimer(EventListener* el) {
 			delete *it;
 			*it=NULL;
 		}
-	timers.erase(remove(timers.begin(),timers.end(),(const TimerEntry*)NULL),timers.end());
+	timers.erase(std::remove(timers.begin(),timers.end(),(const TimerEntry*)NULL),timers.end());
 }
 
 void EventRouter::removeTimer(EventListener* el, unsigned int sid) {
@@ -118,52 +117,37 @@ void EventRouter::removeAllTimers() {
 }
 
 void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid) {
-	if(egid==EventBase::timerEGID)
-		printf("WARNING: The use of addListener with timerEGID is deprecated,\n"
-								 "         please see http://bugs.tekkotsu.org/show_bug.cgi?id=89\n");
 	bool hadListener=hasListeners(egid);
 	listeners.addMapping(el,egid); 
 	if(!hadListener)
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
-	if(egid==EventBase::timerEGID)
-		printf("WARNING: The use of addListener with timerEGID is deprecated,\n"
-								 "         please see http://bugs.tekkotsu.org/show_bug.cgi?id=89\n");
 	bool hadListener=hasListeners(egid);
 	for(unsigned int et=0; et<EventBase::numETIDs; et++)
 		listeners.addMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
 	if(!hadListener)
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
-	if(egid==EventBase::timerEGID)
-		printf("WARNING: The use of addListener with timerEGID is deprecated,\n"
-								 "         please see http://bugs.tekkotsu.org/show_bug.cgi?id=89\n");
 	bool hadListener=hasListeners(egid);
 	listeners.addMapping(el,egid,sid,etid);
 	if(!hadListener)
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 void EventRouter::addListener(EventListener* el, const EventBase& e) {
-	if(e.getGeneratorID()==EventBase::timerEGID) {
-		printf("WARNING: The use of addListener with timerEGID is deprecated,\n"
-								 "         please see http://bugs.tekkotsu.org/show_bug.cgi?id=89\n");
-		addTimer(el,e.getSourceID(),e.getDuration());
-	} else {
-		bool hadListener=hasListeners(e.getGeneratorID());
-		listeners.addMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID());
-		if(!hadListener)
-			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::activateETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
-		else
-			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
-	}
+	bool hadListener=hasListeners(e.getGeneratorID());
+	listeners.addMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID());
+	if(!hadListener)
+		postEvent(EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::activateETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
+	else
+		postEvent(EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
 }
 
 void EventRouter::removeListener(EventListener* el) {
@@ -173,93 +157,67 @@ void EventRouter::removeListener(EventListener* el) {
 			continue; //nothing was removed, don't want to clean up or throw an event
 		listeners.clean(egid);
 		if(!hasListeners(egid))
-			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
+			postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
 		else
-			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
+			postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 	}
-	removeTimer(el); //this should go away when we implement bug 89
 }
 void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_t egid) {
-	if(egid==EventBase::timerEGID) {
-		printf("WARNING: The use of removeListener with timerEGID is deprecated,\n"
-		       "         please see http://bugs.tekkotsu.org/show_bug.cgi?id=89\n");
-		removeTimer(el);
-	} else {
-		if(!listeners.removeMapping(el,egid))
-			return; //nothing was removed, don't want to clean up or throw an event
-		listeners.clean(egid);
-		if(!hasListeners(egid))
-			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
-		else
-			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
-	}
+	if(!listeners.removeMapping(el,egid))
+		return; //nothing was removed, don't want to clean up or throw an event
+	listeners.clean(egid);
+	if(!hasListeners(egid))
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
+	else
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
-	if(egid==EventBase::timerEGID) {
-		printf("WARNING: The use of removeListener with timerEGID is deprecated,\n"
-		       "         please see http://bugs.tekkotsu.org/show_bug.cgi?id=89\n");
-		removeTimer(el,sid);
-	} else {
-		unsigned int removed=0;
-		for(unsigned int et=0; et<EventBase::numETIDs; et++)
-			removed+=listeners.removeMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
-		if(!removed)
-			return; //nothing was removed, don't want to clean up or throw an event
-		listeners.clean(egid);
-		if(!hasListeners(egid))
-			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
-		else
-			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
-	}
+	unsigned int removed=0;
+	for(unsigned int et=0; et<EventBase::numETIDs; et++)
+		removed+=listeners.removeMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
+	if(!removed)
+		return; //nothing was removed, don't want to clean up or throw an event
+	listeners.clean(egid);
+	if(!hasListeners(egid))
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
+	else
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
-	if(egid==EventBase::timerEGID) {
-		printf("WARNING: The use of removeListener with timerEGID is deprecated,\n"
-		       "         please see http://bugs.tekkotsu.org/show_bug.cgi?id=89\n");
-		if(etid==EventBase::statusETID)
-			removeTimer(el,sid);
-	} else {
-		if(!listeners.removeMapping(el,egid,sid,etid))
-			return; //nothing was removed, don't want to clean up or throw an event
-		listeners.clean(egid);
-		if(!hasListeners(egid))
-			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
-		else
-			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
-	}
+	if(!listeners.removeMapping(el,egid,sid,etid))
+		return; //nothing was removed, don't want to clean up or throw an event
+	listeners.clean(egid);
+	if(!hasListeners(egid))
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
+	else
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 void EventRouter::removeListener(EventListener* el, const EventBase& e) {
-	if(e.getGeneratorID()==EventBase::timerEGID) {
-		printf("WARNING: The use of removeListener with timerEGID is deprecated,\n"
-		       "         please see http://bugs.tekkotsu.org/show_bug.cgi?id=89\n");
-		removeTimer(el,e.getSourceID());
-	} else {
-		if(!listeners.removeMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID()))
-			return; //nothing was removed, don't want to clean up or throw an event
-		listeners.clean(e.getGeneratorID());
-		if(!hasListeners(e.getGeneratorID()))
-			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::deactivateETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],0));
-		else
-			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
-	}
+	if(!listeners.removeMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID()))
+		return; //nothing was removed, don't want to clean up or throw an event
+	listeners.clean(e.getGeneratorID());
+	if(!hasListeners(e.getGeneratorID()))
+		postEvent(EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::deactivateETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],0));
+	else
+		postEvent(EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
 }
 
 void EventRouter::addTrapper(EventTrapper* el, const EventBase& e) {
 	bool hadListener=hasListeners(e.getGeneratorID());
 	trappers.addMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID());
 	if(!hadListener)
-		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::activateETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
+		postEvent(EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::activateETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
+		postEvent(EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
 }
 /*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
 void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid) {
 	bool hadListener=hasListeners(egid);
 	trappers.addMapping(el,egid);
 	if(!hadListener)
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 /*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
 void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
@@ -267,18 +225,18 @@ void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egi
 	for(unsigned int et=0; et<EventBase::numETIDs; et++)
 		trappers.addMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
 	if(!hadListener)
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 /*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
 void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
 	bool hadListener=hasListeners(egid);
 	trappers.addMapping(el,egid,sid,etid);
 	if(!hadListener)
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 
 /*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
@@ -293,18 +251,18 @@ void EventRouter::removeTrapper(EventTrapper* el, const EventBase& e) {
 		return; //nothing was removed, don't want to clean up or throw an event
 	trappers.clean(e.getGeneratorID());
 	if(!hasListeners(e.getGeneratorID()))
-		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::deactivateETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],0));
+		postEvent(EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::deactivateETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],0));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
+		postEvent(EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
 }
 void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid) {
 	if(!trappers.removeMapping(el,egid))
 		return; //nothing was removed, don't want to clean up or throw an event
 	trappers.clean(egid);
 	if(!hasListeners(egid))
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
 	int removed=0;
@@ -314,18 +272,18 @@ void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t
 		return; //nothing was removed, don't want to clean up or throw an event
 	trappers.clean(egid);
 	if(!hasListeners(egid))
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
 	if(!trappers.removeMapping(el,egid,sid,etid))
 		return; //nothing was removed, don't want to clean up or throw an event
 	trappers.clean(egid);
 	if(!hasListeners(egid))
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
+		postEvent(EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 
 void EventRouter::removeTrapper(EventTrapper* el) {
@@ -333,87 +291,74 @@ void EventRouter::removeTrapper(EventTrapper* el) {
 		removeTrapper(el,(EventBase::EventGeneratorID_t)eg);
 }
 
-void EventRouter::processEventBuffer() { //clears buffered events
-	if(events.size()>0)
-		doSendBuffer();
-}
-void EventRouter::doSendBuffer() {
-	if(doSendBufferLock) {
-		std::cout << "*** WARNING recursive call to doSendBuffer()" << std::endl;
-		return;
+void EventRouter::processEvent(const EventBase& e) {
+	PostingStatus ps(trappers,listeners,e);
+	postings.push(&ps);
+	while(postings.size()>0) {
+#ifdef DEBUG
+		unsigned int presize=postings.size();
+		postings.front()->process();
+		ASSERT(postings.size()==0 || postings.size()==presize,"partial queue completion?");
+#else
+		postings.front()->process();
+#endif
+		if(postings.size()>0) // in case a sub-post took over and finished off the queue
+			postings.pop();
 	}
-	doSendBufferLock=true;
-	unsigned int start=get_time();
-	//	doSendEvent(EventBase(EventBase::eventRouterEGID,0,EventBase::activateETID,0));
-	//important to use indexes instead of iterators in case the event listeners decide to post more events during processing
-	for(unsigned int i=0; i<events.size(); i++) {
-		doSendEvent(*events[i]);
-		delete events[i];
-	}
-	events.erase(events.begin(),events.end());
-	doSendBufferLock=false;
-	lastBufClear=start;
-	//	doSendEvent(EventBase(EventBase::eventRouterEGID,0,EventBase::deactivateETID,get_time()-start));
 }
 
-void EventRouter::processEvent(const EventBase& e) {
-	// want to make sure we don't send events out of order...
-	if(events.size()>0)
-		doSendBuffer();
-	doSendEvent(e);
-}
-void EventRouter::doSendEvent(const EventBase& e) {
-	//	cout << "doSendEvent("<<e.getName()<<")..." << flush;
-	std::vector<EventTrapper*> t;
-	trappers.getMapping(e,t);
-	for(std::vector<EventTrapper*>::iterator it=t.begin(); it!=t.end(); it++)
-		if(trappers.verifyMapping(*it,e)) {
-			try {
-				if((*it)->trapEvent(e))
-					return;
-			} catch(const std::exception& ex) {
-				std::string msg="Occurred while processing event "+e.getName()+" by ";
-				if(BehaviorBase * beh=dynamic_cast<BehaviorBase*>(*it))
-					msg+="trapper "+beh->getName();
-				else
-					msg+="unnamed EventTrapper";
-				if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,msg.c_str(),&ex))
-					throw;
-			} catch(...) {
-				std::string msg="Occurred while processing event "+e.getName()+" by ";
-				if(BehaviorBase * beh=dynamic_cast<BehaviorBase*>(*it))
-					msg+="trapper "+beh->getName();
-				else
-					msg+="unnamed EventTrapper";
-				if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,msg.c_str(),NULL))
-					throw;
-			}
+void EventRouter::PostingStatus::process() {
+	while(tit!=t.end()) {
+		// increment before processing so if a new post is done during the processing, we pick up on the *next* entry
+		EventTrapper * et=*tit++;
+		if(!trappers.verifyMapping(et,e))
+			continue;
+		try {
+			if(et->trapEvent(e))
+				return;
+		} catch(const std::exception& ex) {
+			std::string msg="Occurred while processing event "+e.getName()+" by ";
+			if(BehaviorBase * beh=dynamic_cast<BehaviorBase*>(et))
+				msg+="trapper "+beh->getName();
+			else
+				msg+="unnamed EventTrapper";
+			if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,msg.c_str(),&ex))
+				throw;
+		} catch(...) {
+			std::string msg="Occurred while processing event "+e.getName()+" by ";
+			if(BehaviorBase * beh=dynamic_cast<BehaviorBase*>(et))
+				msg+="trapper "+beh->getName();
+			else
+				msg+="unnamed EventTrapper";
+			if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,msg.c_str(),NULL))
+				throw;
 		}
-	std::vector<EventListener*> l;
-	listeners.getMapping(e,l);
-	for(std::vector<EventListener*>::iterator it=l.begin(); it!=l.end(); it++)
-		if(listeners.verifyMapping(*it,e)) {
-			try {
-				(*it)->processEvent(e);
-			} catch(const std::exception& ex) {
-				std::string msg="Occurred while processing event "+e.getName()+" by ";
-				if(BehaviorBase * beh=dynamic_cast<BehaviorBase*>(*it))
-					msg+="listener "+beh->getName();
-				else
-					msg+="unnamed EventListener";
-				if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,msg.c_str(),&ex))
-					throw;
-			} catch(...) {
-				std::string msg="Occurred while processing event "+e.getName()+" by ";
-				if(BehaviorBase * beh=dynamic_cast<BehaviorBase*>(*it))
-					msg+="listener "+beh->getName();
-				else
-					msg+="unnamed EventListener";
-				if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,msg.c_str(),NULL))
-					throw;
-			}
+	}
+	while(lit!=l.end()) {
+		// increment before processing so if a new post is done during the processing, we pick up on the *next* entry
+		EventListener * el=*lit++;
+		if(!listeners.verifyMapping(el,e))
+			continue;
+		try {
+			el->processEvent(e);
+		} catch(const std::exception& ex) {
+			std::string msg="Occurred while processing event "+e.getName()+" by ";
+			if(BehaviorBase * beh=dynamic_cast<BehaviorBase*>(el))
+				msg+="listener "+beh->getName();
+			else
+				msg+="unnamed EventListener";
+			if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,msg.c_str(),&ex))
+				throw;
+		} catch(...) {
+			std::string msg="Occurred while processing event "+e.getName()+" by ";
+			if(BehaviorBase * beh=dynamic_cast<BehaviorBase*>(el))
+				msg+="listener "+beh->getName();
+			else
+				msg+="unnamed EventListener";
+			if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,msg.c_str(),NULL))
+				throw;
 		}
-	//	cout << "done." << flush;
+	}
 }
 
 EventRouter::EventMapper::EventMapper() {
@@ -441,7 +386,7 @@ void EventRouter::EventMapper::addMapping(void* el, EventBase::EventGeneratorID_
 bool EventRouter::EventMapper::removeMapping(void* el, EventBase::EventGeneratorID_t egid) {
 	// remove listener from allevents
 	unsigned int numlist=allevents[egid].size();
-	allevents[egid].erase(remove(allevents[egid].begin(),allevents[egid].end(),el),allevents[egid].end());
+	allevents[egid].erase(std::remove(allevents[egid].begin(),allevents[egid].end(),el),allevents[egid].end());
 	bool hadListener=allevents[egid].size()!=numlist;
 	
 	// now remove listener from all of the filtered events
@@ -451,7 +396,7 @@ bool EventRouter::EventMapper::removeMapping(void* el, EventBase::EventGenerator
 			SIDtoListenerVectorMap_t::iterator mapit=mapping->begin();
 			for(mapit=mapping->begin(); mapit!=mapping->end(); mapit++) {// go through each sourceID, delete EL
 				std::vector<void*> * v=&(*mapit).second;
-				std::vector<void*>::iterator last=remove(v->begin(),v->end(),el);
+				std::vector<void*>::iterator last=std::remove(v->begin(),v->end(),el);
 				if(last!=v->end()) {
 					hadListener=true;
 					v->erase(last,v->end());
@@ -469,7 +414,7 @@ bool EventRouter::EventMapper::removeMapping(void* el, EventBase::EventGenerator
 		SIDtoListenerVectorMap_t::iterator mapit=mapping->find(sid);
 		if(mapit!=mapping->end()) {
 			std::vector<void*> * v=&(*mapit).second;
-			std::vector<void*>::iterator last=remove(v->begin(),v->end(),el);
+			std::vector<void*>::iterator last=std::remove(v->begin(),v->end(),el);
 			if(last!=v->end()) {
 				hadListener=true;
 				v->erase(last,v->end());
@@ -527,13 +472,13 @@ void EventRouter::EventMapper::clear() {
 	}
 }
 
-bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid) {
+bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid) const {
 	if(allevents[egid].size()>0)
 		return true;
 	for(unsigned int et=0; et<EventBase::numETIDs; et++) {
-		SIDtoListenerVectorMap_t* mapping=filteredevents[egid][et];
+		const SIDtoListenerVectorMap_t* mapping=filteredevents[egid][et];
 		if(mapping!=NULL) {
-			SIDtoListenerVectorMap_t::iterator mapit=mapping->begin();
+			SIDtoListenerVectorMap_t::const_iterator mapit=mapping->begin();
 			for(mapit=mapping->begin(); mapit!=mapping->end(); mapit++)
 				if((*mapit).second.size()>0)
 					return true;
@@ -542,13 +487,13 @@ bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid) {
 	return false;
 }
 
-bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid, unsigned int sid) {
+bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid, unsigned int sid) const {
 	if(allevents[egid].size()>0)
 		return true;
 	for(unsigned int et=0; et<EventBase::numETIDs; et++) {
-		SIDtoListenerVectorMap_t* mapping=filteredevents[egid][et];
+		const SIDtoListenerVectorMap_t* mapping=filteredevents[egid][et];
 		if(mapping!=NULL) {
-			SIDtoListenerVectorMap_t::iterator mapit=mapping->find(sid);
+			SIDtoListenerVectorMap_t::const_iterator mapit=mapping->find(sid);
 			if(mapit!=mapping->end() && (*mapit).second.size()>0)
 				return true;
 		}
@@ -556,12 +501,12 @@ bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid, un
 	return false;
 }
 
-bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) const {
 	if(allevents[egid].size()>0)
 		return true;
-	SIDtoListenerVectorMap_t* mapping=filteredevents[egid][etid];
+	const SIDtoListenerVectorMap_t* mapping=filteredevents[egid][etid];
 	if(mapping!=NULL) {
-		SIDtoListenerVectorMap_t::iterator mapit=mapping->find(sid);
+		SIDtoListenerVectorMap_t::const_iterator mapit=mapping->find(sid);
 		if(mapit!=mapping->end())
 			return ((*mapit).second.size()>0);
 	}
@@ -569,38 +514,38 @@ bool EventRouter::EventMapper::hasMapping(EventBase::EventGeneratorID_t egid, un
 }
 
 template<class T>
-void EventRouter::EventMapper::getMapping(const EventBase& e, std::vector<T*>& ls) {
+void EventRouter::EventMapper::getMapping(const EventBase& e, std::vector<T*>& ls) const {
 	// first get all the filtered subscribers (tricky!)
-	std::vector<void*>* elv=NULL;
-	SIDtoListenerVectorMap_t* sidtovm=filteredevents[e.getGeneratorID()][e.getTypeID()];
+	const std::vector<void*>* elv=NULL;
+	const SIDtoListenerVectorMap_t* sidtovm=filteredevents[e.getGeneratorID()][e.getTypeID()];
 	if(sidtovm!=NULL) { // if there's a map (at least one EL is filtering on this EGID and ETID)
-		SIDtoListenerVectorMap_t::iterator mapit=sidtovm->find(e.getSourceID()); // find listening for this source id
+		SIDtoListenerVectorMap_t::const_iterator mapit=sidtovm->find(e.getSourceID()); // find listening for this source id
 		if(mapit!=sidtovm->end()) { // if there's at least one is filtering on this sourceID as well
 			elv=&(*mapit).second; // now go through them all
-			for(std::vector<void*>::iterator elit=elv->begin(); elit!=elv->end(); elit++)
+			for(std::vector<void*>::const_iterator elit=elv->begin(); elit!=elv->end(); elit++)
 				ls.push_back(static_cast<T*>(*elit));
 		}
 	}
 	// now get the 'all events' subscribers
 	elv=&allevents[e.getGeneratorID()];
-	for(std::vector<void*>::iterator elit=elv->begin(); elit!=elv->end(); elit++)
+	for(std::vector<void*>::const_iterator elit=elv->begin(); elit!=elv->end(); elit++)
 		ls.push_back(static_cast<T*>(*elit));
 }
 
-bool EventRouter::EventMapper::verifyMapping(void * listener, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
+bool EventRouter::EventMapper::verifyMapping(void * listener, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) const {
 	// first check the 'all events' subscribers
-	std::vector<void*>* elv=&allevents[egid];
-	for(std::vector<void*>::iterator elit=elv->begin(); elit!=elv->end(); elit++)
+	const std::vector<void*>* elv=&allevents[egid];
+	for(std::vector<void*>::const_iterator elit=elv->begin(); elit!=elv->end(); elit++)
 		if(*elit==listener)
 			return true;
 	
 	// then check all the filtered subscribers (tricky!)
-	SIDtoListenerVectorMap_t* sidtovm=filteredevents[egid][etid];
+	const SIDtoListenerVectorMap_t* sidtovm=filteredevents[egid][etid];
 	if(sidtovm!=NULL) { // if there's a map (at least one EL is filtering on this EGID and ETID)
-		SIDtoListenerVectorMap_t::iterator mapit=sidtovm->find(sid); // find listening for this source id
+		const SIDtoListenerVectorMap_t::const_iterator mapit=sidtovm->find(sid); // find listening for this source id
 		if(mapit!=sidtovm->end()) { // if there's at least one is filtering on this sourceID as well
 			elv=&(*mapit).second; // now go through them all
-			for(std::vector<void*>::iterator elit=elv->begin(); elit!=elv->end(); elit++)
+			for(std::vector<void*>::const_iterator elit=elv->begin(); elit!=elv->end(); elit++)
 				if(*elit==listener)
 					return true;
 		}
@@ -610,30 +555,30 @@ bool EventRouter::EventMapper::verifyMapping(void * listener, EventBase::EventGe
 	return false;
 }
 
-bool EventRouter::EventMapper::verifyMappingAll(void* listener, EventBase::EventGeneratorID_t egid) {
-	std::vector<void*>* elv=&allevents[egid];
-	for(std::vector<void*>::iterator elit=elv->begin(); elit!=elv->end(); elit++)
+bool EventRouter::EventMapper::verifyMappingAll(void* listener, EventBase::EventGeneratorID_t egid) const {
+	const std::vector<void*>* elv=&allevents[egid];
+	for(std::vector<void*>::const_iterator elit=elv->begin(); elit!=elv->end(); elit++)
 		if(*elit==listener)
 			return true;
 	// if not in the all listeners, can't be listening for *every* source id
 	return false;
 }
 
-bool EventRouter::EventMapper::verifyMappingAny(void* listener, EventBase::EventGeneratorID_t egid) {
+bool EventRouter::EventMapper::verifyMappingAny(void* listener, EventBase::EventGeneratorID_t egid) const {
 	// first check the 'all events' subscribers
-	std::vector<void*>* elv=&allevents[egid];
-	for(std::vector<void*>::iterator elit=elv->begin(); elit!=elv->end(); elit++)
+	const std::vector<void*>* elv=&allevents[egid];
+	for(std::vector<void*>::const_iterator elit=elv->begin(); elit!=elv->end(); elit++)
 		if(*elit==listener)
 			return true;
 	
 	// then check all the filtered subscribers (tricky!)
 	for(unsigned int et=0; et<EventBase::numETIDs; et++) {
-		SIDtoListenerVectorMap_t* sidtovm=filteredevents[egid][et];
+		const SIDtoListenerVectorMap_t* sidtovm=filteredevents[egid][et];
 		if(sidtovm!=NULL) { // if there's a map (at least one EL is filtering on this EGID and ETID)
-			SIDtoListenerVectorMap_t::iterator mapit=sidtovm->begin(); // for each of the source ids
+			SIDtoListenerVectorMap_t::const_iterator mapit=sidtovm->begin(); // for each of the source ids
 			for(;mapit!=sidtovm->end();mapit++) {
 				elv=&(*mapit).second; // now go through them all
-				for(std::vector<void*>::iterator elit=elv->begin(); elit!=elv->end(); elit++)
+				for(std::vector<void*>::const_iterator elit=elv->begin(); elit!=elv->end(); elit++)
 					if(*elit==listener)
 						return true;
 			}
@@ -644,26 +589,26 @@ bool EventRouter::EventMapper::verifyMappingAny(void* listener, EventBase::Event
 	return false;
 }
 
-bool EventRouter::EventMapper::verifyMappingAll(void* listener, EventBase::EventGeneratorID_t egid, unsigned int sid) {
+bool EventRouter::EventMapper::verifyMappingAll(void* listener, EventBase::EventGeneratorID_t egid, unsigned int sid) const {
 	// first check the 'all events' subscribers
-	std::vector<void*>* elv=&allevents[egid];
-	for(std::vector<void*>::iterator elit=elv->begin(); elit!=elv->end(); elit++)
+	const std::vector<void*>* elv=&allevents[egid];
+	for(std::vector<void*>::const_iterator elit=elv->begin(); elit!=elv->end(); elit++)
 		if(*elit==listener)
 			return true;
 	
 	// then check all the filtered subscribers (tricky!)
 	// must be found in ALL etids
 	for(unsigned int et=0; et<EventBase::numETIDs; et++) {
-		SIDtoListenerVectorMap_t* sidtovm=filteredevents[egid][et];
+		const SIDtoListenerVectorMap_t* sidtovm=filteredevents[egid][et];
 		if(sidtovm==NULL)
 			return false;
 		// there's a map (at least one EL is filtering on this EGID and ETID)
-		SIDtoListenerVectorMap_t::iterator mapit=sidtovm->find(sid); // find listening for this source id
+		const SIDtoListenerVectorMap_t::const_iterator mapit=sidtovm->find(sid); // find listening for this source id
 		if(mapit==sidtovm->end())
 			return false;
 		// there's at least one is filtering on this sourceID as well
 		elv=&(*mapit).second; // now go through them all
-		std::vector<void*>::iterator elit=elv->begin();
+		std::vector<void*>::const_iterator elit=elv->begin();
 		while(elit!=elv->end() && *elit!=listener)
 			elit++;
 		if(elit==elv->end())
@@ -675,21 +620,21 @@ bool EventRouter::EventMapper::verifyMappingAll(void* listener, EventBase::Event
 	return true;
 }
 
-bool EventRouter::EventMapper::verifyMappingAny(void* listener, EventBase::EventGeneratorID_t egid, unsigned int sid) {
+bool EventRouter::EventMapper::verifyMappingAny(void* listener, EventBase::EventGeneratorID_t egid, unsigned int sid) const {
 	// first check the 'all events' subscribers
-	std::vector<void*>* elv=&allevents[egid];
-	for(std::vector<void*>::iterator elit=elv->begin(); elit!=elv->end(); elit++)
+	const std::vector<void*>* elv=&allevents[egid];
+	for(std::vector<void*>::const_iterator elit=elv->begin(); elit!=elv->end(); elit++)
 		if(*elit==listener)
 			return true;
 	
 	// then check all the filtered subscribers (tricky!)
 	for(unsigned int et=0; et<EventBase::numETIDs; et++) {
-		SIDtoListenerVectorMap_t* sidtovm=filteredevents[egid][et];
+		const SIDtoListenerVectorMap_t* sidtovm=filteredevents[egid][et];
 		if(sidtovm!=NULL) { // if there's a map (at least one EL is filtering on this EGID and ETID)
-			SIDtoListenerVectorMap_t::iterator mapit=sidtovm->find(sid); // find listening for this source id
+			SIDtoListenerVectorMap_t::const_iterator mapit=sidtovm->find(sid); // find listening for this source id
 			if(mapit!=sidtovm->end()) { // if there's at least one is filtering on this sourceID as well
 				elv=&(*mapit).second; // now go through them all
-				for(std::vector<void*>::iterator elit=elv->begin(); elit!=elv->end(); elit++)
+				for(std::vector<void*>::const_iterator elit=elv->begin(); elit!=elv->end(); elit++)
 					if(*elit==listener)
 						return true;
 			}
@@ -705,10 +650,10 @@ bool EventRouter::EventMapper::verifyMappingAny(void* listener, EventBase::Event
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.20 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.28 $
  * $State: Exp $
- * $Date: 2005/08/16 18:43:04 $
+ * $Date: 2006/09/27 21:15:51 $
  */
 
 
