@@ -3,47 +3,50 @@
 #define INCLUDED_EventRouter_h
 
 #include <vector>
-#include <list>
+#include <queue>
 #include <map>
 #include <algorithm>
 #include "EventListener.h"
 #include "EventTrapper.h"
 #include "Shared/get_time.h"
 #include "Shared/debuget.h"
+#include "Shared/attributes.h"
 #include <iostream>
 
 //! This class will handle distribution of events as well as management of timers
 /*! Classes must inherit from EventListener and/or EventTrapper in order to
  *  receive events.
  *
- *  Use the global @c ::erouter EventRouter to post and subscribe to
- *  events, except if you are posting from within a MotionCommand, in
- *  which case you should use MotionCommand::postEvent() so that it
- *  will automatically be sent from the Motion process to the Main
- *  process.
+ *  Use the global ::erouter instance of EventRouter to both send (post) and receive (subscribe/listen) to
+ *  events.  (except if you are posting from within a MotionCommand, in
+ *  which case you should use MotionCommand::postEvent() so that it can correctly
+ *  handle inter-process communication issues under Aperios (the Aibo's OS) -- under a
+ *  Unix-based OS, this wouldn't be necessary.)
+ *
+ *  The events available for processing are listed in EventBase::EventGeneratorID_t.
+ *  Each generator ID's documentation specifies how to interpret the source ID field, and whether
+ *  you can expect events with that generator ID to be of a subclass of EventBase,
+ *  such as TextMsgEvent or LocomotionEvent.  Many generators send plain
+ *  EventBase instances.
  *
  *  When multiple listeners are subscribed, the order in which an event is
- *  distributed among them looks like this:
+ *  distributed among them is:
  *  -# "Specific" listeners: any listener which specifies a particular source id.
- *     (It doesn't matter if they specify a type id or not.)
- *    - older listeners get events before younger listeners
+ *     (doesn't matter if they specified type id as well)
+ *    - older listeners get events before more recently added listeners ("FIFO")
  *  -# "General" listeners: those that subscribe to an entire generator
- *    - older listeners get events before younger listeners
+ *    - older listeners get events before more recently added listeners ("FIFO")
  *
- *  ...but if you're relying on that ordering, there should be a cleaner
+ *  ...but if you're relying on that ordering, there probably should be a cleaner
  *  way to do whatever you're doing.
  *
- *  If one behaviors unsubscribes another one during a processEvent(),
- *  that behavior may still get the "current" event before the
- *  unsubscription takes place.  This is not a prescribed behavior,
- *  and also should not be relied on one way or the other.
- *
- *  Timer events are only sent to the generator which requested them.  So if 
- *  EventListener @e A requests a timer with ID 0 at two second intervals,
- *  and EventListener @e B requests a timer with ID 0 at three second intervals,
+ *  TimerEvents are generally only sent to the generator which requested them.  So if 
+ *  EventListener @e A requests a timer (see addTimer()) with ID 0 at two second intervals,
+ *  and @e B requests a timer with ID 0 at three second intervals,
  *  each will still only receive the timers they requested - no cross talk.
  *  The timer generator is unique in this regard, which is why it is built in
- *  as an integral component of the EventRouter.  All other events are broadcast.
+ *  as an integral component of the EventRouter.  However, EventListener @e A
+ *  <b>can</b> receive @e B's timers if it specifically wants to, via addListener().  See "Timers" below.
  *
  *  If an EventListener/EventTrapper subscribes to the same event source multiple
  *  times, it will receive multiple copies of the event.  However, the first call
@@ -57,36 +60,128 @@
  *    - If removeListener(&A,buttonEGID,0) is called, both of (buttonEGID,0,*)
  *      are removed, but (buttonEGID,*,*) would be untouched.
  *
- *  The buffered event distribution has not been tested thoroughly,
- *  and should be considered deprecated.
+ *  <h3>Timers</h3>
+ *  addTimer() allows you to request an TimerEvent to be sent at some later point in time,
+ *  possibly on a repeating basis.  Timers are specific to the behavior which requests
+ *  them, and you @e do @e not (and usually should not) call addListener() in order to receive a timer
+ *  event.
+ *
+ *  There is an important different between addTimer() and #addListener(timerEGID,...)!
+ *  addTimer will "create" the timer, and will send the timer to the listener
+ *  which created it when the timer expires.  This means that as long as the listener in
+ *  question does @e not call addListener(timerEGID), it will @e only receive its own timers.
+ *  In other words, with this usage there is no confusion with timer cross-talk between
+ *  listeners, because each listener is only receiving its own timers.
+ *
+ *  However, if a listener calls addListener(timerEGID), it will begin receiving @e all timer events
+ *  from throughout the system.  This allows you to have one behavior "eavesdrop" on
+ *  another's timers.  In order to determine which listener requested/created the timer,
+ *  you can use the TimerEvent::getTarget() value.
+ *
+ *  So beware that if you call both addTimer() and addListener(foo,timerEGID), 'foo' will get
+ *  two calls to processEvent() for its own timers, and one call for all other timers, and will
+ *  have to know to call TimerEvent::getTarget() to distinguish its timers from other
+ *  listener's timers (if it cares about the difference...)
+ *
+ *  Timers are sent to the requesting listener before being broadcast -- EventTrappers cannot
+ *  filter a listener's own timers, but can prevent the timer from being broadcast to other listeners.
+ *
+ *  <h3>Event processing examples:</h3>
+ *
+ *  Posting events:
+ *  @code
+ *  //method A: basic event posting (EventBase instance is sent)
+ *  erouter->postEvent(EventBase::aiEGID, 1234, EventBase::statusETID);
+ *
+ *  //method B: specific event instance is posted (have to use this style to post a subclass)
+ *  TextMsgEvent txt("hello world");
+ *  erouter->postEvent(txt);
+ *  // or can be done in one line:
+ *  erouter->postEvent(TextMsgEvent("hello world"))
+ *  @endcode
+ *
+ *  Receiving events:
+ *  @code
+ *  //given an EventListener subclass:
+ *  class YourListener : public EventListener {
+ *  public:
+ *    virtual void processEvent(const EventBase& e) {
+ *      std::cout << "Got: " << e.getName() << std::endl;
+ *    }
+ *  };
+ *
+ *  YourListener yourList;
+ *
+ *  // subscribes it to all EventBase::aiEGID events:
+ *  erouter->addListener(&yourList, EventBase::aiEGID);
+ *
+ *  // subscribes only to button activity from the head, but not other buttons:
+ *  erouter->addListener(&yourList, EventBase::buttonEGID, ERS7Info::HeadButOffset);
+ *  @endcode
+ *  Typically in a BehaviorBase subclass, you would just specify 'this' instead of '&yourList'.
+ *
+ *  <h3>Timer processing examples:</h3>
+ *
+ *  Requesting/Creating timers:
+ *  @code
+ *  YourListener yourList; // (any EventListener subclass)
+ *
+ *  // sends a timer with source ID 123 every 5 seconds to yourList:
+ *  erouter->addTimer(&yourList, 123, 5000);
+ *
+ *  // sends a timer with ID 456 after 1 second, *no repeat, one time only*
+ *  erouter->addTimer(&yourList, 456, 1000, false);
+ *
+ *  // cancels the first timer
+ *  erouter->removeTimer(&yourList, 123);
+ *
+ *  // postpone/update the second timer's settings (*doesn't* create two timers with the same ID)
+ *  erouter->addTimer(&yourList, 456, 2500, false);
+ *
+ *  @endcode
+ *  Again, typically in a BehaviorBase subclass, you would just specify 'this' instead of '&yourList'.
  *
  *  @see EventBase::EventGeneratorID_t for a complete listing of all generators,
  *  as well as instructions on how to add new generators.
+ *  @see Tutorials:
+ *    - <a href="../FirstBehavior2.html">Steps 3, 4, & 5 of Tekkotsu's First Behavior Tutorial</a>
+ *    - <a href="http://www.cs.cmu.edu/~dst/Tekkotsu/Tutorial/events.shtml">David Touretzky's Events Chapter</a>
+ *    - <a href="http://www.cs.cmu.edu/afs/cs/academic/class/15494-s06/www/lectures/behaviors.pdf">CMU's Cognitive Robotics course slides</a>
  */
 class EventRouter : public EventListener {
  public:
-	EventRouter(); //!< Constructs the router, #buffertime defaults to 1
+	EventRouter(); //!< Constructs the router
 	virtual ~EventRouter() { reset(); removeAllTimers(); } //!< just calls reset and removeAllTimers()
+	
 	void reset() { listeners.clear(); trappers.clear(); removeAllTimers(); } //!< erases all listeners, trappers and timers, resets EventRouter
 	
-	void setBufferTime(unsigned int t) { buffertime=t; } /*!< @brief sets the time to wait between buffer clears, see EventRouter::buffertime. @param t time to wait between buffer clears @see buffertime */
-	unsigned int getBufferTime() { return buffertime; } /*!< @brief returns the time to wait between buffer clears, see EventRouter::buffertime. @return time to wait between buffer clears @see buffertime */
-
+	
 	//!@name Posting/Processing Events
+	
 	/*!@brief recommended to create and post an event using current buffer setting */
-	void postEvent(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid, unsigned int dur) { if(buffertime>0) events.push_back(new EventBase(egid,sid,etid,dur)); else processEvent(EventBase(egid,sid,etid,dur)); }
-	void postEvent(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid, unsigned int dur, const std::string& n, float m) { if(buffertime>0) events.push_back(new EventBase(egid,sid,etid,dur,n,m)); else processEvent(EventBase(egid,sid,etid,dur,n,m)); }
-	void postEvent(EventBase* e) { if(buffertime>0) events.push_back(e); else { processEvent(*e); delete e; } }
+	void postEvent(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid, unsigned int dur=0) { processEvent(EventBase(egid,sid,etid,dur)); }
+	void postEvent(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid, unsigned int dur, const std::string& n, float m) { processEvent(EventBase(egid,sid,etid,dur,n,m)); }
+	//! deprecated -- pass by reference instead;  this version posts the specified event and then deletes it after processing is complete
+	/*! moving to pass by reference instead of pass by pointer to avoid questions about who deletes the event and the event's scope,
+	 *  also keeping the event on the stack is faster by avoiding unnecessary heap operations. */
+	void postEvent(EventBase* e) ATTR_deprecated;
+	//! posts the specified event, but doesn't delete it at the end -- equivalent to processEvent(e)
+	void postEvent(const EventBase& e) { processEvent(e); }
 
 	//! determines if timers need to be posted, and posts them if so.
-	/*! Call this often to ensure accurate timers.  Also, will clear event buffer before sending
-			timer events in order to ensure correct ordering of event reception */
+	/*! Call this often to ensure accurate timers. */
 	void processTimers();
-	void processEventBuffer(); //!< clears the event buffer, deletes events as it does so.
-	void processEvent(const EventBase& e); //!< forces unbuffered - sends event *now*.  Will clear the buffer first if needed to ensure proper event ordering
+	//! sends event to its trappers & listeners, but doesn't delete the event at the end (see also postEvent())
+	/*! this posting method is supplied to allow an EventRouter to behave as a listener as 
+	 *  well -- the 'routers' really can form a sort of network, if desired.  postEvent() is
+	 *  probably a more memnomic interface to use in direct function calls however,
+	 *  so that is the one you should call. */
+	void processEvent(const EventBase& e);
 	//@}
 
+	
 	//!@name Listener/Trapper Recall
+	
 	//! returns true if the specified listener/trapper would receive any events that match the specified criteria
 	bool isListeningAny(EventListener* el, EventBase::EventGeneratorID_t egid) { return listeners.verifyMappingAny(el,egid); }
 	bool isListeningAny(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid) { return listeners.verifyMappingAny(el,egid,sid); }
@@ -102,7 +197,9 @@ class EventRouter : public EventListener {
 	bool isTrapping(EventTrapper* el, const EventBase& e) { return trappers.verifyMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID()); }
 	//@}
 	
+	
 	//!@name Listener/Trapper Detection
+	
 	/*!@brief <b>counts both listeners and trappers</b>, so generators can tell if it even needs to bother generating an event...*/
 	/* Generators can also subscribe to the EventBase::erouterEGID event stream if
 	 * they wish to be notified when they gain or lose listeners (particularly the
@@ -111,42 +208,52 @@ class EventRouter : public EventListener {
 	 * it make a sound?\n
 	 * ... if Vision sees a ball in an image, and there's no listeners, does it
 	 * make an event? ;) */
-	bool hasListeners(EventBase::EventGeneratorID_t egid) { return (egid==EventBase::timerEGID) ? timers.size()>0 : trappers.hasMapping(egid) || listeners.hasMapping(egid); }
-	bool hasListeners(EventBase::EventGeneratorID_t egid, unsigned int sid) { return (egid==EventBase::timerEGID) ? timers.size()>0 : trappers.hasMapping(egid,sid) || listeners.hasMapping(egid,sid); }
-	bool hasListeners(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) { return (egid==EventBase::timerEGID) ? timers.size()>0 : trappers.hasMapping(egid,sid,etid) || listeners.hasMapping(egid,sid,etid); }
-	bool hasListeners(const EventBase& e) { return (e.getGeneratorID()==EventBase::timerEGID) ? timers.size()>0 : hasListeners(e.getGeneratorID(),e.getSourceID(),e.getTypeID()); }
+	bool hasListeners(EventBase::EventGeneratorID_t egid) { return trappers.hasMapping(egid) || listeners.hasMapping(egid); }
+	bool hasListeners(EventBase::EventGeneratorID_t egid, unsigned int sid) { return trappers.hasMapping(egid,sid) || listeners.hasMapping(egid,sid); }
+	bool hasListeners(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) { return trappers.hasMapping(egid,sid,etid) || listeners.hasMapping(egid,sid,etid); }
+	bool hasListeners(const EventBase& e) { return hasListeners(e.getGeneratorID(),e.getSourceID(),e.getTypeID()); }
 	//@}
 
+	
 	//!@name Timer Management
-	void addTimer(EventListener* el, unsigned int sid, unsigned int delay, bool repeat=true); //!< adds a timer if it doesn't exist, or resets the timer if it already exists.
+	
+	//! adds a timer if it doesn't exist, or resets the timer if it already exists.
+	void addTimer(EventListener* el, unsigned int sid, unsigned int delay, bool repeat=true);
 	void addTimer(EventListener* el, const EventBase& e, bool repeat=true) { addTimer(el,e.getSourceID(),e.getDuration(),repeat); } //!< calls the other addTimer() with the event's source id and duration, doesn't check to see if the generator is timerEGID
-	void removeTimer(EventListener* el); //!< clears all pending timers for listener @a el
+	
+	//! clears all pending timers for listener @a el; see remove()
+	void removeTimer(EventListener* el);
 	void removeTimer(EventListener* el, unsigned int sid); //!< clears any pending timers with source id @a sid for listener @a el
 	void removeAllTimers(); //!< clears all timers for all listeners
+	unsigned int getNextTimer() { return (timers.size()==0 ? -1U : timers.front()->next); } //!< returns time of next timer activation
 	//@}
 
+	
 	//!@name Listener Management
+	
 	//! Adds a listener for all events from a given event generator
 	void addListener(EventListener* el, EventBase::EventGeneratorID_t egid);
 	void addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid); //!< Adds a listener for all types from a specific source and generator
 	void addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid); //!< Adds a listener for a specific source id and type from a given event generator
-	//! Adds a listener for a specific source id and type from a given event generator, adding a Timer event will invoke addTimer(@a el, @a e.getSourceID(), @a e.getDuration(), @c true)
-	void addListener(EventListener* el, const EventBase& e); 
+	void addListener(EventListener* el, const EventBase& e); //!< Uses the generator, source, and type fields of @a e to add a listener for that specific tuple
 
-	//! stops sending ALL events to the listener, including timers
+	//! stops sending ALL events to the listener -- does not remove pending timers however (may need to call removeTimer(el) as well); see remove()
 	void removeListener(EventListener* el); 
 	//! stops sending specified events from the generator to the listener.
 	void removeListener(EventListener* el, EventBase::EventGeneratorID_t egid);
 	void removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid); //!< stops sending specified events from the generator to the listener.
 	void removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid); //!< stops sending specified events from the generator to the listener.
-	//! stops sending specified events from the generator to the listener.  If a timer is passed it will invoke removeTimer(@a el, @a e.getSourceID())
-	void removeListener(EventListener* el, const EventBase& e);
+	void removeListener(EventListener* el, const EventBase& e); //!< Uses the generator, source, and type fields of @a e to remove a listener for that specific tuple
+	
+	//! stops all events and timers, shorthand for removeListener(el) and removeTimer(el); Note that trappers are separate, removeTrapper() is @e not called
+	void remove(EventListener* el) { removeListener(el); removeTimer(el); }
 
 	//@}
 
 	//!@name Trapper Management
+	
 	//! Adds a trapper for a specific source id and type from a given event generator
-	/*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
+	/*! Note that only the broadcasted timers can be trapped.  The EventListener which requested the timer will receive that timer before any trapping is done. */
 	void addTrapper(EventTrapper* el, const EventBase& e);
 	void addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid); //!< Adds a trapper for all events from a given event generator
 	void addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid);  //!< Adds a trapper for all types from a specific source and generator
@@ -164,18 +271,9 @@ class EventRouter : public EventListener {
 	//@}
 
  protected:
-	void doSendBuffer(); //!< does the work of clearing the buffer (calls doSendEvent() )
-	
-	//! does the work of sending an event
-	/*! Be aware this is an O(n^2) where n is the number of listeners for a particular event.
-	 *  This is because after each call to processEvent, the list of listeners could have changed
-	 *  so each listener much be verified before it is sent an event.  New listeners won't get the
-	 *  current event, but neither should listeners which have just be removed */
-	void doSendEvent(const EventBase& e); 
-
 	//! Contains all the information needed to maintain a timer by the EventRouter
 	struct TimerEntry {
-		//! constructors an entry using the given value for next - useful for with TimerEntryPtrCmp
+		//! constructs an entry using the given value for next - useful for with TimerEntryPtrCmp
 		explicit TimerEntry(unsigned int nxt) : el(NULL), sid(0), delay(0), next(nxt), repeat(false) {}
 		//! constructs with the given values, sets next field automatically; see next
 		TimerEntry(EventListener* e, unsigned int s, unsigned int d, bool r) : el(e), sid(s), delay(d), next(get_time()+delay), repeat(r) {}
@@ -227,14 +325,6 @@ class EventRouter : public EventListener {
 		}
 		std::cout << std::endl;
 	}
-
-	std::vector<EventBase*> events;     //!< used to store buffered events
-	bool doSendBufferLock;              //!< in case of recursive calls to processEventBuffer()/doSendBuffer()
-	unsigned int lastBufClear;          //!< time of last event buffer clear
-	unsigned int buffertime;            //!< The time between clearings of the buffer
-																			/*!< - 0 will not use the buffer, events are routed upon posting
-																			 *   - 1 will clear the buffer at next call to processTimers() or processEventBuffer()
-																			 *   - a larger value will cause a delay of that number of milliseconds since the last clearing */
 	
 	//! Does the actual storage of the mapping between EventBase's and the EventListeners/EventTrappers who should receive them
 	/*! Actually only stores void*'s, so it's more general than just Listeners or Trappers */
@@ -263,9 +353,9 @@ class EventRouter : public EventListener {
 		/*! ... if a tree falls in a forest, and there's no one around to see it, does it make a sound?\n
 			  ... if Vision sees a ball in an image, and there's no listeners, does it make an event? ;) \n
 			  @return true if it has any listeners, false otherwise */
-		bool hasMapping(EventBase::EventGeneratorID_t egid);
-		bool hasMapping(EventBase::EventGeneratorID_t egid, unsigned int sid);
-		bool hasMapping(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid);
+		bool hasMapping(EventBase::EventGeneratorID_t egid) const;
+		bool hasMapping(EventBase::EventGeneratorID_t egid, unsigned int sid) const;
+		bool hasMapping(EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) const;
 		//@}
 
 		//! builds a list of all listeners which should receive the event, templated to typecast the pointers for you
@@ -274,34 +364,34 @@ class EventRouter : public EventListener {
 		 *  @a listeners is not cleared prior to building, new listeners are pushed on end\n
 		 *  Results are in the order: all specific matches first, all generator listeners second, in order they were added to the EventMapper.*/
 		template<class T>
-		void getMapping(const EventBase& e, std::vector<T*>& listeners);
+		void getMapping(const EventBase& e, std::vector<T*>& listeners) const;
 
 		//! Used to make sure that the specified listener exists for the given event
 		/*! This is needed because after we call processEvent on a lister, we can't assume
 		 *  that no other listeners have been modified - one listener could cause another
 		 *  to turn off.  If that has happened, we shouldn't send the event, even if it
 		 *  was in the queue originally. */
-		bool verifyMapping(void * listener, const EventBase& e) { return verifyMapping(listener,e.getGeneratorID(),e.getSourceID(),e.getTypeID()); }
+		bool verifyMapping(void * listener, const EventBase& e) const { return verifyMapping(listener,e.getGeneratorID(),e.getSourceID(),e.getTypeID()); }
 		//! Used to make sure that the specified listener exists for the given event
 		/*! This is needed because after we call processEvent on a lister, we can't assume
 		 *  that no other listeners have been modified - one listener could cause another
 		 *  to turn off.  If that has happened, we shouldn't send the event, even if it
 		 *  was in the queue originally. */
-		bool verifyMapping(void * listener, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid);
+		bool verifyMapping(void * listener, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) const;
 
 		//! Needed to complete EventRouter::isListening suite
 		/*! Only checks #allevents */
-		bool verifyMappingAll(void * listener, EventBase::EventGeneratorID_t egid);
+		bool verifyMappingAll(void * listener, EventBase::EventGeneratorID_t egid) const;
 		//! Needed to complete EventRouter::isListening suite
 		/*! Checks both #allevents and #filteredevents */
-		bool verifyMappingAny(void * listener, EventBase::EventGeneratorID_t egid);
+		bool verifyMappingAny(void * listener, EventBase::EventGeneratorID_t egid) const;
 
 		//! Needed to complete EventRouter::isListening suite
 		/*! Checks both #allevents and #filteredevents, must be found in all */
-		bool verifyMappingAll(void * listener, EventBase::EventGeneratorID_t egid, unsigned int sid);
+		bool verifyMappingAll(void * listener, EventBase::EventGeneratorID_t egid, unsigned int sid) const;
 		//! Needed to complete EventRouter::isListening suite
 		/*! Checks both #allevents and #filteredevents, can be found in either */
-		bool verifyMappingAny(void * listener, EventBase::EventGeneratorID_t egid, unsigned int sid);
+		bool verifyMappingAny(void * listener, EventBase::EventGeneratorID_t egid, unsigned int sid) const;
 
 	protected:
 		//! a mapping from source IDs (unsigned ints), each to a vector of pointers to listeners
@@ -315,12 +405,32 @@ class EventRouter : public EventListener {
 
 	private:
 		EventMapper(const EventMapper&);           //!< this shouldn't be called...
-		EventMapper operator=(const EventMapper&); //!< this shouldn't be called...
+		EventMapper& operator=(const EventMapper&); //!< this shouldn't be called...
 	};
 
 	EventMapper trappers;  //!< A mapping of which EventTrapper's should get a chance to trap the event
 	EventMapper listeners; //!< A mapping of which EventListener's should receive events
 
+	//! contains information regarding the progress of posting an event
+	/*! This allows us to resume and complete the posting of the "current" event before processing a new incoming event */
+	class PostingStatus {
+	public:
+		//! constructor
+		PostingStatus(const EventMapper& eventTrappers, const EventMapper& eventListeners, const EventBase& event)
+			: trappers(eventTrappers), listeners(eventListeners), t(), tit(), l(), lit(), e(event)
+		{ trappers.getMapping(e,t); tit=t.begin(); listeners.getMapping(e,l); lit=l.begin(); }
+		//! begins or resumes sending the event #e to trappers and listeners in #t and #l
+		void process();
+	protected:
+		const EventMapper& trappers; //!< the current trapper mapping, used to verify each entry in #t is still valid before processing it
+		const EventMapper& listeners; //!< the current listener mapping, used to verify each entry in #l is still valid before processing it
+		std::vector<EventTrapper*> t; //!< list of trappers which were subscribed when the PostingStatus instance was constructed
+		std::vector<EventTrapper*>::const_iterator tit; //!< current position within #t
+		std::vector<EventListener*> l; //!< list of listeners which were subscribed when the PostingStatus instance was constructed
+		std::vector<EventListener*>::const_iterator lit; //!< current position within #l
+		const EventBase& e; //!< the event being processed
+	};
+	std::queue<PostingStatus*> postings; //!< stores calls to post() currently in progress -- may grow if one postEvent() triggers another; this allows us to finish processing of the original postEvent() before starting the second.
 };
 
 //! a global router for cross communication, probably the most common usage, although perhaps there may be times you'd rather have multiple event routers for smaller sections
@@ -331,10 +441,10 @@ extern EventRouter * erouter;
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.21 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.35 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2006/10/03 21:09:04 $
  */
 
 #endif
