@@ -4,6 +4,7 @@
 #include "Events/TextMsgEvent.h"
 #include "Events/EventRouter.h"
 #include "Shared/debuget.h"
+#include "Shared/ProjectInterface.h"
 #include <iostream>
 
 #ifdef PLATFORM_APERIOS
@@ -24,7 +25,7 @@ EventTranslator::~EventTranslator() {
 }
 
 void
-EventTranslator::encodeEvent(const EventBase& event) {
+EventTranslator::encodeEvent(const EventBase& event, bool onlyReady/*=false*/) {
 	event.setSaveFormat(EventBase::BINARY);
 	const unsigned int headerlen=sizeof(event.getClassTypeID());
 	const unsigned int bufsize=headerlen+event.getBinSize();
@@ -35,13 +36,13 @@ EventTranslator::encodeEvent(const EventBase& event) {
 	}
 	unsigned int header=event.getClassTypeID();
 	memcpy(buf,&header,headerlen);
-	unsigned int used=event.SaveBuffer(buf+headerlen,bufsize-headerlen);
+	unsigned int used=event.saveBuffer(buf+headerlen,bufsize-headerlen);
 	if(used==0) {
-		cerr << "ERROR: EventTranslator unable to transmit event because EventBase::SaveBuffer failed (buffer==" << (void*)(buf+headerlen) << ", size==" << bufsize-headerlen << ")" << endl;
-		post(buf,0);
+		cerr << "ERROR: EventTranslator unable to transmit event because EventBase::saveBuffer failed (buffer==" << (void*)(buf+headerlen) << ", size==" << bufsize-headerlen << ")" << endl;
+		post(buf,0,onlyReady);
 		return;
 	}
-	post(buf,used);
+	post(buf,used,onlyReady);
 	return;
 }
 
@@ -50,6 +51,7 @@ EventTranslator::decodeEvent(const char * entry, unsigned int size) {
 	const unsigned int headerlen=sizeof(unsigned int);
 	unsigned int header=0;
 	memcpy(&header,entry,headerlen);
+	//cout << "decodeEvent(" << (void*)entry << ","<< size << ") header is " << header << " (" << entry[0] << entry[1] << entry[2] << entry[3] << ")" << endl;
 	eventLookup_t::iterator it=eventLookup.find(header);
 	if(it==eventLookup.end()) {
 		cerr << "ERROR: EventTranslator unable to translate buffer because header does not match a previously registered class type id" << endl;
@@ -57,42 +59,66 @@ EventTranslator::decodeEvent(const char * entry, unsigned int size) {
 	}
 	EventBase* evt=static_cast<EventBase*>((*it).second->constructTemplate());
 	evt->setSaveFormat(EventBase::BINARY);
-	if(evt->LoadBuffer(entry+headerlen,size-headerlen)==0) {
-		cerr << "ERROR: EventTranlator unable to translate buffer because data is malformed (EventBase::LoadBuffer failed)" << endl;
+	if(evt->loadBuffer(entry+headerlen,size-headerlen)==0) {
+		cerr << "ERROR: EventTranlator unable to translate buffer because data is malformed (EventBase::loadBuffer failed)" << endl;
 		return NULL;
 	}
+	//cout << "decodes to " << evt->getDescription() << endl;
 	return evt;
 }
 
 void
-NoOpEventTranslator::encodeEvent(const EventBase& event) {
-	evtRouter.postEvent(event.clone());
+NoOpEventTranslator::encodeEvent(const EventBase& event, bool /*onlyReady=false*/) {
+	evtRouter.postEvent(event);
 }
 
 char*
 IPCEventTranslator::bufferRequest(unsigned int size) {
 	ASSERT(curRegion==NULL,"WARNING: IPCEventTranslator::bufferRequest() curRegion was not NULL");
-	curRegion = new RCRegion(size);
-	return curRegion->Base();
+	try {
+		curRegion = new RCRegion(size);
+		return curRegion->Base();
+	} catch(...) {
+		curRegion=NULL;
+		throw;
+	}
 }
 
-//#include "Shared/TimeET.h"
-
 void
-IPCEventTranslator::post(const char* buf, unsigned int /*size*/) {
+IPCEventTranslator::post(const char* buf, unsigned int /*size*/, bool onlyReady) {
 	ASSERTRET(curRegion!=NULL,"ERROR: IPCEventTranslator::post(buf,size) was NULL");
 	if(buf!=curRegion->Base()) {
 		cerr << "ERROR: IPCEventTranslator::post(buf,size) buf does not match value given from previous bufferRequest()" << endl;
 		return;
 	}
-	//cout << TimeET() << endl;
 #ifdef PLATFORM_APERIOS
-	subject.SetData(curRegion);
-	subject.NotifyObservers();
+	if(!onlyReady) {
+		subject.SetData(curRegion);
+		subject.NotifyObservers();
+	} else {
+		for(ObserverConstIterator it=subject.begin(); it!=subject.end(); ++it) {
+			if(subject.IsReady(*it)) {
+				subject.SetData(*it,curRegion);
+				subject.NotifyObserver(*it);
+			}
+		}
+	}
 #else
-	subject.sendMessage(curRegion);
-	curRegion->RemoveReference();
+	if(!onlyReady || subject.getMessageSN(subject.newest())==subject.getMessagesRead()) {
+		try {
+			subject.sendMessage(curRegion);
+		} catch(const std::exception& ex) {
+			static char errmsg[256];
+			strncpy(errmsg,("Occurred during IPCEventTranslator::post(), dropping interprocess event "+curName).c_str(),256);
+			ProjectInterface::uncaughtException(__FILE__,__LINE__,errmsg,&ex);
+		} catch(...) {
+			static char errmsg[256];
+			strncpy(errmsg,("Occurred during IPCEventTranslator::post(), dropping interprocess event "+curName).c_str(),256);
+			ProjectInterface::uncaughtException(__FILE__,__LINE__,errmsg,NULL);
+		}
+	}
 #endif
+	curRegion->RemoveReference();
 	curRegion=NULL;
 }
 	
@@ -102,9 +128,9 @@ IPCEventTranslator::post(const char* buf, unsigned int /*size*/) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.22 $
  * $State: Exp $
- * $Date: 2005/07/26 03:11:23 $
+ * $Date: 2006/09/28 21:00:27 $
  */
 
