@@ -17,7 +17,9 @@ public:
 	virtual ~EventTranslator();
 
 	//! Call this with events which should be forwarded to other processes
-	virtual void encodeEvent(const EventBase& event);
+	/*! @param event the event to serialize and send
+	 *  @param onlyReady if true, only send the event to observers which do not have any message backlog (if supported by transfer mechanism) */
+	virtual void encodeEvent(const EventBase& event, bool onlyReady=false);
 
 	//! Call this with events which should be forwarded to other processes (redirects to encodeEvent())
 	/*! By providing an EventTrapper interface, you can directly
@@ -67,11 +69,12 @@ protected:
 	//! Called by encodeEvent() after serialization is complete for communication to other processes
 	/*! @param buf the data to be sent, will be a buffer previously requested from #bufferRequest
 	 *  @param size the number of bytes to send
+	 *  @param onlyReady if true, only send the event to observers which do not have any message backlog (if supported by transfer mechanism)
 	 *
 	 *  You will always get this callback after each call to bufferRequest(), even
 	 *  in the event of an error during saving.  If an error occured, the callback
 	 *  will receive 0 for size.*/
-	virtual void post(const char* buf, unsigned int size)=0;
+	virtual void post(const char* buf, unsigned int size, bool onlyReady)=0;
 
 	//! The value which trapEvent() should return
 	bool trapRet;
@@ -98,13 +101,13 @@ public:
 	//! constructor
 	explicit NoOpEventTranslator(EventRouter& er) : EventTranslator(), evtRouter(er) {}
 
-	virtual void encodeEvent(const EventBase& event);
+	virtual void encodeEvent(const EventBase& event, bool onlyReady=false);
 
 protected:
 	//! should never be called, only included to satisfy interface
 	virtual char* bufferRequest(unsigned int /*size*/) { return NULL; }
 	//! should never be called, only included to satisfy interface
-	virtual void post(const char* /*buf*/, unsigned int /*size*/) { }
+	virtual void post(const char* /*buf*/, unsigned int /*size*/, bool /*onlyReady*/) { }
 	
 	EventRouter& evtRouter; //!< the EventRouter to send events to
 };
@@ -132,14 +135,21 @@ public:
 #endif
 
 	//! constructor
-	explicit IPCEventTranslator(IPCSender_t& subj) : EventTranslator(), subject(subj), curRegion(NULL) {}
+	explicit IPCEventTranslator(IPCSender_t& subj) : EventTranslator(), subject(subj), curRegion(NULL), curName() {}
+	
+	//! extends base class's implementation to store @a event.getName() into #curName 
+	virtual void encodeEvent(const EventBase& event, bool onlyReady=false) {
+		curName=event.getName();
+		EventTranslator::encodeEvent(event,onlyReady);
+	}
 
 protected:
 	virtual char* bufferRequest(unsigned int size);
-	virtual void post(const char* buf, unsigned int size);
+	virtual void post(const char* buf, unsigned int size, bool onlyReady);
 	
 	IPCSender_t& subject; //!< where to post messages upon serialization, set by constructor
 	RCRegion* curRegion; //!< the region currently being serialized into, only valid between call to bufferRequest() and following post()
+	std::string curName; //!< name of current event being posted (for error messages)
 
 private:
 	IPCEventTranslator(const IPCEventTranslator&); //!< don't call
@@ -151,10 +161,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2006/09/25 23:28:12 $
  */
 
 #endif
