@@ -21,51 +21,40 @@ LocomotionEvent::getBinSize() const {
 		return used; //if using XML, the XMLLoadSave::getBinSize (called by EventBase::getBinSize) is all we need
 	//otherwise need to add our own fields
 	used+=creatorSize("EventBase::LocomotionEvent");
-	used+=sizeof(x);
-	used+=sizeof(y);
-	used+=sizeof(a);
+	used+=getSerializedSize(x);
+	used+=getSerializedSize(y);
+	used+=getSerializedSize(a);
 	return used;
 }
 
 unsigned int
-LocomotionEvent::LoadBinaryBuffer(const char buf[], unsigned int len) {
+LocomotionEvent::loadBinaryBuffer(const char buf[], unsigned int len) {
 	unsigned int origlen=len;
-	unsigned int used;
-	if(0==(used=EventBase::LoadBinaryBuffer(buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=checkCreator("EventBase::LocomotionEvent",buf,len,true))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=decode(x,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=decode(y,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=decode(a,buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!checkInc(EventBase::loadBinaryBuffer(buf,len),buf,len)) return 0;
+	if(!checkCreatorInc("EventBase::LocomotionEvent",buf,len,true)) return 0;
+	if(!decodeInc(x,buf,len)) return 0;
+	if(!decodeInc(y,buf,len)) return 0;
+	if(!decodeInc(a,buf,len)) return 0;
 	return origlen-len;	
 }
 
 unsigned int
-LocomotionEvent::SaveBinaryBuffer(char buf[], unsigned int len) const {
+LocomotionEvent::saveBinaryBuffer(char buf[], unsigned int len) const {
 	unsigned int origlen=len;
-	unsigned int used;
-	if(0==(used=EventBase::SaveBinaryBuffer(buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=saveCreator("EventBase::LocomotionEvent",buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode(x,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode(y,buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode(a,buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!checkInc(EventBase::saveBinaryBuffer(buf,len),buf,len)) return 0;
+	if(!saveCreatorInc("EventBase::LocomotionEvent",buf,len)) return 0;
+	if(!encodeInc(x,buf,len)) return 0;
+	if(!encodeInc(y,buf,len)) return 0;
+	if(!encodeInc(a,buf,len)) return 0;
 	return origlen-len;
 }
 
-void LocomotionEvent::LoadXML(xmlNode* node) {
+void
+LocomotionEvent::loadXML(xmlNode* node) {
 	if(node==NULL)
 		return;
 	
-	EventBase::LoadXML(node);
+	EventBase::loadXML(node);
 	
 	for(xmlNode* cur = skipToElement(node->children); cur!=NULL; cur = skipToElement(cur->next)) {
 		if(xmlStrcmp(cur->name, (const xmlChar *)"param"))
@@ -79,7 +68,7 @@ void LocomotionEvent::LoadXML(xmlNode* node) {
 		if(val==NULL)
 			throw bad_format(cur,"property missing value");
 		
-		cout << "LoadXML: " << name << "=" << val << endl;
+		//cout << "loadXML: " << name << "=" << val << endl;
 		
 		if(xmlStrcmp(name, (const xmlChar *)"x")==0)
 			x=atof((const char*)val);
@@ -103,10 +92,11 @@ char valbuf[20]; \
 snprintf(valbuf,20,"%g",name); \
 xmlSetProp(cur,(const xmlChar*)"value",(const xmlChar*)valbuf); }
 
-void LocomotionEvent::SaveXML(xmlNode * node) const {
+void
+LocomotionEvent::saveXML(xmlNode * node) const {
 	if(node==NULL)
 		return;
-	EventBase::SaveXML(node);
+	EventBase::saveXML(node);
 	
 	//clear old params first
 	for(xmlNode* cur = skipToElement(node->children); cur!=NULL; ) {
@@ -118,7 +108,7 @@ void LocomotionEvent::SaveXML(xmlNode * node) const {
 			cur = skipToElement(cur->next);
 	}
 	
-	cout << "SaveXML: " << x << ' ' << y << ' ' << a << endl;
+	//cout << "saveXML: " << x << ' ' << y << ' ' << a << endl;
 
 	SAVE_PARAM(x);
 	SAVE_PARAM(y);
@@ -130,8 +120,8 @@ void LocomotionEvent::SaveXML(xmlNode * node) const {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2005/06/29 22:03:35 $
+ * $Date: 2006/09/21 21:14:47 $
  */
