@@ -18,46 +18,37 @@ TextMsgEvent::getBinSize() const {
 		return used; //if using XML, the XMLLoadSave::getBinSize (called by EventBase::getBinSize) is all we need
 	//otherwise need to add our own fields
 	used+=creatorSize("EventBase::TextMsgEvent");
-	used+=_text.size()+stringpad;
+	used+=getSerializedSize(_text);
 	//used+=sizeof(_token);
 	return used;
 }
 
 unsigned int
-TextMsgEvent::LoadBinaryBuffer(const char buf[], unsigned int len) {
+TextMsgEvent::loadBinaryBuffer(const char buf[], unsigned int len) {
 	unsigned int origlen=len;
-	unsigned int used;
-	if(0==(used=EventBase::LoadBinaryBuffer(buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=checkCreator("EventBase::TextMsgEvent",buf,len,true))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=decode(_text,buf,len))) return 0;
-	len-=used; buf+=used;
-	//if(0==(used=decode(_token,buf,len))) return 0;
+	if(!checkInc(EventBase::loadBinaryBuffer(buf,len),buf,len)) return 0;
+	if(!checkCreatorInc("EventBase::TextMsgEvent",buf,len,true)) return 0;
+	if(!decodeInc(_text,buf,len)) return 0;
+	//if(!decodeInc(_token,buf,len)) return 0;
 	//len-=used; buf+=used;
 	return origlen-len;	
 }
 
 unsigned int
-TextMsgEvent::SaveBinaryBuffer(char buf[], unsigned int len) const {
+TextMsgEvent::saveBinaryBuffer(char buf[], unsigned int len) const {
 	unsigned int origlen=len;
-	unsigned int used;
-	if(0==(used=EventBase::SaveBinaryBuffer(buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=saveCreator("EventBase::TextMsgEvent",buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode(_text,buf,len))) return 0;
-	len-=used; buf+=used;
-	//if(0==(used=encode(_token,buf,len))) return 0;
-	//len-=used; buf+=used;
+	if(!checkInc(EventBase::saveBinaryBuffer(buf,len),buf,len)) return 0;
+	if(!saveCreatorInc("EventBase::TextMsgEvent",buf,len)) return 0;
+	if(!encodeInc(_text,buf,len)) return 0;
+	//if(!encodeInc(_token,buf,len)) return 0;
 	return origlen-len;
 }
 
-void TextMsgEvent::LoadXML(xmlNode* node) {
+void TextMsgEvent::loadXML(xmlNode* node) {
 	if(node==NULL)
 		return;
 	
-	EventBase::LoadXML(node);
+	EventBase::loadXML(node);
 	
 	for(xmlNode* cur = skipToElement(node->children); cur!=NULL; cur = skipToElement(cur->next)) {
 		if(xmlStrcmp(cur->name, (const xmlChar *)"param"))
@@ -79,10 +70,10 @@ void TextMsgEvent::LoadXML(xmlNode* node) {
 	}
 }
 
-void TextMsgEvent::SaveXML(xmlNode * node) const {
+void TextMsgEvent::saveXML(xmlNode * node) const {
 	if(node==NULL)
 		return;
-	EventBase::SaveXML(node);
+	EventBase::saveXML(node);
 	
 	//clear old params first
 	for(xmlNode* cur = skipToElement(node->children); cur!=NULL; ) {
@@ -106,8 +97,8 @@ void TextMsgEvent::SaveXML(xmlNode * node) const {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2005/06/10 17:26:30 $
+ * $Date: 2006/09/09 04:32:48 $
  */
