@@ -11,7 +11,7 @@ class TextMsgEvent : public EventBase {
   TextMsgEvent() : EventBase(EventBase::textmsgEGID,(unsigned int)-1, EventBase::statusETID,0),_text("")/*,_token(0)*/ {  }
 
   //! Constructor, pass a text msg
-  TextMsgEvent(const std::string& text) : EventBase(EventBase::textmsgEGID,(unsigned int)-1, EventBase::statusETID,0),_text(text)/*,_token(0)*/ { }
+  TextMsgEvent(const std::string& text, unsigned int srcID=-1U) : EventBase(EventBase::textmsgEGID,srcID, EventBase::statusETID,0),_text(text)/*,_token(0)*/ { }
   
 	virtual EventBase* clone() const { return new TextMsgEvent(*this); }
 
@@ -26,10 +26,10 @@ class TextMsgEvent : public EventBase {
 	std::string getDescription(bool showTypeSpecific=true, unsigned int verbosity=0) const;
 	
 	virtual unsigned int getBinSize() const;
-	virtual unsigned int LoadBinaryBuffer(const char buf[], unsigned int len);
-	virtual unsigned int SaveBinaryBuffer(char buf[], unsigned int len) const;
-	virtual void LoadXML(xmlNode* node);
-	virtual void SaveXML(xmlNode * node) const;
+	virtual unsigned int loadBinaryBuffer(const char buf[], unsigned int len);
+	virtual unsigned int saveBinaryBuffer(char buf[], unsigned int len) const;
+	virtual void loadXML(xmlNode* node);
+	virtual void saveXML(xmlNode * node) const;
 	
  protected:
   std::string _text; //!< the unmodified arguments passed to the command
@@ -41,10 +41,10 @@ class TextMsgEvent : public EventBase {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2005/06/29 22:03:35 $
+ * $Date: 2006/09/09 04:32:48 $
  */
 
 #endif
