@@ -63,61 +63,63 @@ public:
 	virtual unsigned int getClassTypeID() const { return makeClassTypeID("VISO"); }
 
 	//!@name Attribute Accessors
-  float getLeft() const { return _x1;} //!< returns the initial x (#_x1) coordinate of the Bounding Box (inclusive value)
-  VisionObjectEvent& setLeft(float x1) { _x1=x1; return *this;} //!< sets the initial x (#_x1) coordinate of the Bounding Box
-  
-  float getRight() const { return _x2;} //!< returns the final x (#_x2) coordinate of the Bounding Box (inclusive value)
-  VisionObjectEvent& setRight(float x2) { _x2=x2; return *this;} //!< sets the final x (#_x2) coordinate of the Bounding Box
-  
+	float getLeft() const { return _x1;} //!< returns the initial x (#_x1) coordinate of the Bounding Box (inclusive value)
+	VisionObjectEvent& setLeft(float x1) { _x1=x1; return *this;} //!< sets the initial x (#_x1) coordinate of the Bounding Box
+	
+	float getRight() const { return _x2;} //!< returns the final x (#_x2) coordinate of the Bounding Box (inclusive value)
+	VisionObjectEvent& setRight(float x2) { _x2=x2; return *this;} //!< sets the final x (#_x2) coordinate of the Bounding Box
+	
 	float getTop() const { return _y1;} //!< returns the initial y (#_y1) coordinate of the Bounding Box (inclusive value)
-  VisionObjectEvent& setTop(float y1) { _y1=y1; return *this;} //!< sets the initial y (#_y1) coordinate of the Bounding Box
-  
-  float getBottom() const { return _y2;} //!< returns the final y (#_y2) coordinate of the Bounding Box (inclusive value)
-  VisionObjectEvent& setBottom(float y2) { _y2=y2; return *this;} //!< sets the final y (#_y2) coordinate of the Bounding Box
-
-	float getObjectArea() const { return _area; } //!< returns the object's #_area within the camera, in squared generalized coordinates (multiply by the major camera resolution to get pixel area)
-	VisionObjectEvent& setObjectArea(float objarea) { _area=objarea; return *this; } //!< returns the object's #_area within the camera, in squared generalized coordinates (multiply by the major camera resolution to get pixel area)
+	VisionObjectEvent& setTop(float y1) { _y1=y1; return *this;} //!< sets the initial y (#_y1) coordinate of the Bounding Box
+	
+	float getBottom() const { return _y2;} //!< returns the final y (#_y2) coordinate of the Bounding Box (inclusive value)
+	VisionObjectEvent& setBottom(float y2) { _y2=y2; return *this;} //!< sets the final y (#_y2) coordinate of the Bounding Box
+	
+	float getObjectArea() const { return _area; } //!< returns the object's #_area within the camera, in squared generalized coordinates.  Multiply by the square of the major camera resolution (normally #RobotInfo::CameraResolutionX if using full resolution) and divide by 4.0 to get pixel area.
+	VisionObjectEvent& setObjectArea(float objarea) { _area=objarea; return *this; } //!< sets the object's #_area within the camera, in squared generalized coordinates (multiply by the major camera resolution to get pixel area)
 	//@}
  
 	//!@name Calculated Attributes
-  float getCenterX() const { return (_x1+_x2)/2; } //!< returns the center along x
-  float getCenterY() const { return (_y1+_y2)/2; } //!< returns the center along y
-  float getWidth() const { return _x2-_x1; } //!< return width along x
-  float getHeight() const { return _y2-_y1; } //!< return height along y
-  float getBoundaryArea() const { return (_x2-_x1)*(_y2-_y1); } //!< returns the area of the bounding box, just multiplication of width*height, (multiply by the major camera resolution to get pixel area)
-  float getXrange() const{ return  _xRange;}//!< returns the maximum x value
-  float getYrange() const{return _yRange;}//!< returns the maximum y value
-  unsigned int getFrame() const{return _frame;}//!< returns number of frame when the event was generated
+	float getDistanceEstimate(float diaMajor, float diaMinor=0) const; //!< returns an estimate of how far away the object is if its major (larger) physical dimension is @a diaMajor and the other dimension is @a diaMinor; pass 0 if to only use the major dimension
+	static float calcDistance(float visArc, float physDia); //!< returns the distance of an object, given that it takes up @a visArc of the camera's visual arc, and the physical crossection is @a physDia
+	float getCenterX() const { return (_x1+_x2)/2; } //!< returns the center along x
+	float getCenterY() const { return (_y1+_y2)/2; } //!< returns the center along y
+	float getWidth() const { return _x2-_x1; } //!< return width along x
+	float getHeight() const { return _y2-_y1; } //!< return height along y
+	float getBoundaryArea() const { return (_x2-_x1)*(_y2-_y1); } //!< returns the area of the bounding box, just multiplication of width*height, (multiply by the major camera resolution to get pixel area)
+	float getXrange() const{ return  _xRange;}//!< returns the maximum x value
+	float getYrange() const{return _yRange;}//!< returns the maximum y value
+	unsigned int getFrame() const{return _frame;}//!< returns number of frame when the event was generated
 	//@}
 
-  //!@name Object out of bounds Detection Functions
-  bool isClippedLeft() const { return _clipLeft; } //!< returns #_clipLeft
-  bool isClippedRight() const { return _clipRight; }  //!< returns #_clipRight
-  bool isClippedTop() const { return _clipTop; } //!< returns #_clipTop
-  bool isClippedBottom() const {return _clipBottom; } //!< returns #_clipBottom
+	//!@name Object out of bounds Detection Functions
+	bool isClippedLeft() const { return _clipLeft; } //!< returns #_clipLeft
+	bool isClippedRight() const { return _clipRight; }  //!< returns #_clipRight
+	bool isClippedTop() const { return _clipTop; } //!< returns #_clipTop
+	bool isClippedBottom() const {return _clipBottom; } //!< returns #_clipBottom
 	void setClipping(bool left, bool right, bool top, bool bottom) { _clipLeft=left; _clipRight=right; _clipTop=top; _clipBottom=bottom; } //!< sets clipping boundaries
 	//@}
       
 	virtual std::string getDescription(bool showTypeSpecific=true, unsigned int verbosity=0) const;
 	
 	virtual unsigned int getBinSize() const;
-	virtual unsigned int LoadBinaryBuffer(const char buf[], unsigned int len);
-	virtual unsigned int SaveBinaryBuffer(char buf[], unsigned int len) const;
-	virtual void LoadXML(xmlNode* node);
-	virtual void SaveXML(xmlNode * node) const;
+	virtual unsigned int loadBinaryBuffer(const char buf[], unsigned int len);
+	virtual unsigned int saveBinaryBuffer(char buf[], unsigned int len) const;
+	virtual void loadXML(xmlNode* node);
+	virtual void saveXML(xmlNode * node) const;
 
 protected:
 	float _x1;  //!< a value representing location in visual field - from -1 if on the left edge to 1 if it's on the right edge
 	float _x2;  //!< a value representing location in visual field - from -1 if on the left edge to 1 if it's on the right edge
 	float _y1;  //!< top boundary, in range of @f$ \pm\frac{160}{208} @f$) for ERS-7; actual values vary depending on aspect ratio to keep square coordinates
 	float _y2;  //!< bottom boundary, in approximately @f$ \pm\frac{160}{208} @f$ for ERS-7; actual values vary depending on aspect ratio to keep square coordinates
-	float _area; //!< area of the actual object within bounding box as set by generator, in same units as getBoundaryArea() (squared generalized coordinates -- multiply by the major camera resolution to get pixel area)
+	float _area; //!< area of the actual object within bounding box as set by generator, in same units as getBoundaryArea().  Multiply by the square of the major camera resolution (normally #RobotInfo::CameraResolutionX if using full resolution) and divide by 4.0 to get pixel area.
 	bool _clipLeft;   //!< flag to indicate left boundary is on or beyond the camera image's boundary
 	bool _clipRight;  //!< flag to indicate right boundary is on or beyond the camera image's boundary
 	bool _clipTop;    //!< flag to indicate top boundary is on or beyond the camera image's boundary
 	bool _clipBottom; //!< flag to indicate bottom boundary is on or beyond the camera image's boundary
-	float _xRange; //!< Max range of X dimension
-	float _yRange; //!< Max range of Y dimension
+	float _xRange; //!< Max range of X dimension (typically 1.0 for AIBO)
+	float _yRange; //!< Max range of Y dimension (typically around 0.8 for AIBO due to camera aspect ratio)
 	unsigned int _frame; //!< Number of frame when the event was generated.
 };
 
@@ -127,10 +129,10 @@ protected:
  * @author Ignacio Herrero Reder &lt; nhr at dte uma es &gt; (VisionObjectInfo Boundary Box - bug 74, frame number - bug 143)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.18 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2006/09/09 04:32:50 $
  */
 
 #endif
