@@ -5,6 +5,7 @@ unsigned int MutexLockBase::usleep_granularity=5000;
 #ifndef PLATFORM_APERIOS
 SemaphoreManager MutexLockBase::preallocated;
 SemaphoreManager* MutexLockBase::semgr=&preallocated;
+ThreadNS::Lock MutexLockBase::thdLocks[SemaphoreManager::MAX_SEM];
 #endif
 
 /*! @file 
@@ -12,8 +13,8 @@ SemaphoreManager* MutexLockBase::semgr=&preallocated;
 * @author ejt (Creator), Edward A. Lycklama, Vassos Hadzilacos (paper from which this was based)
 *
 * $Author: ejt $
-* $Name: tekkotsu-2_4_1 $
-* $Revision: 1.2 $
+* $Name: tekkotsu-3_0 $
+* $Revision: 1.3 $
 * $State: Exp $
-* $Date: 2005/06/01 05:47:46 $
+* $Date: 2006/05/08 22:07:54 $
 */
