@@ -2,12 +2,16 @@
 #ifndef __MUTEX_LOCK_ET__
 #define __MUTEX_LOCK_ET__
 
+#include "Shared/Resource.h"
+#include "ProcessID.h"
 #include <iostream>
+#include <exception>
+#include <typeinfo>
+
 #ifndef PLATFORM_APERIOS
 #  include <unistd.h>
 #  include "SemaphoreManager.h"
-#else
-#  include <exception>
+#  include "Thread.h"
 #endif
 
 // If you want to use the same software-only lock on both
@@ -25,7 +29,7 @@
  *  created via fork to handle virtual calls properly, and I don't
  *  want to put that overhead on the otherwise lightweight SoundPlay
  *  process under Aperios. */
-class MutexLockBase {
+class MutexLockBase : public Resource {
 public:
 	virtual ~MutexLockBase() {} //!< basic destructor
 	
@@ -57,6 +61,7 @@ public:
 	static void aboutToFork() {
 		preallocated.aboutToFork();
 	}
+	
 protected:
 	//! the global semaphore manager object for all locks, may point to preallocated during process initialization or destruction
 	static SemaphoreManager* semgr;
@@ -74,6 +79,9 @@ protected:
 	 *  it's the only thing that's going to need an ID before the
 	 *  manager is created.*/
 	static SemaphoreManager preallocated;
+	
+	//! need to have a thread lock available for each semaphore -- have to acquire the corresponding inter-thread lock before you can acquire the inter-process lock
+	static ThreadNS::Lock thdLocks[SemaphoreManager::MAX_SEM];
 #endif
 };
 
@@ -130,22 +138,27 @@ public:
 	
 	//! destructor, releases semaphore back to semaphore manager
 	~MutexLock() {
-		owner_index=NO_OWNER;
 		if(semgr!=NULL && !semgr->hadFault())
 			semgr->releaseSemaphore(sem);
 		else
 			std::cerr << "Warning: MutexLock leaked semaphore " << sem << " because SemaphoreManager is NULL" << std::endl;
+		if(owner_index!=NO_OWNER) {
+			owner_index=NO_OWNER;
+			while(thdLocks[sem].getLockLevel()>0)
+				thdLocks[sem].unlock();
+		}
 	}
 	
 	//! blocks until lock is achieved.  This is done efficiently using a SysV style semaphore
 	/*! You should pass some process-specific ID number as the input - just
 	 *  make sure no other process will be using the same value. */
 	void lock(int id) {
+		thdLocks[sem].lock();
 		if(owner_index!=static_cast<unsigned>(id)) {
 			//have to wait and then claim lock
-			if(semgr!=NULL && !semgr->hadFault())
+			if(semgr!=NULL && !semgr->hadFault()) {
 				semgr->testZero_add(sem,1);
-			else
+			} else
 				std::cerr << "Warning: MutexLock assuming lock of " << sem << " because SemaphoreManager is NULL" << std::endl;
 			owner_index=id;
 		} else {
@@ -161,6 +174,8 @@ public:
 	/*! You should pass some process-specific ID number as the input - just
 	 *  make sure no other process will be using the same value.*/
 	bool try_lock(int id) {
+		if(!thdLocks[sem].trylock())
+			return false;
 		if(semgr==NULL || semgr->hadFault()) {
 			std::cerr << "Warning: MutexLock assuming try_lock success of " << sem << " because SemaphoreManager is NULL" << std::endl;
 			owner_index=id;
@@ -174,8 +189,10 @@ public:
 			if(semgr->testZero_add(sem,1,false)) {
 				owner_index=id;
 				return true;
-			} else
+			} else {
+				thdLocks[sem].unlock();
 				return false;
+			}
 		}
 	}
 	
@@ -184,17 +201,20 @@ public:
 		if(semgr==NULL || semgr->hadFault()) {
 			std::cerr << "Warning: MutexLock assuming unlock of " << sem << " from " << owner_index << " because SemaphoreManager is NULL" << std::endl;
 			owner_index=NO_OWNER;
+			thdLocks[sem].unlock();
 			return;
 		}
 		if(semgr->getValue(sem)<=0) {
 			std::cerr << "Warning: MutexLock::unlock caused underflow" << std::endl;
 			owner_index=NO_OWNER;
+			thdLocks[sem].unlock();
 			return;
 		}
 		if(semgr->getValue(sem)==1)
 			owner_index=NO_OWNER;
 		if(!semgr->lower(sem,1,false))
 			std::cerr << "Warning: MutexLock::unlock caused strange underflow" << std::endl;
+		thdLocks[sem].unlock();
 	}
 	
 	//! completely unlocks, regardless of how many times a recursive lock has been obtained
@@ -205,6 +225,8 @@ public:
 			return;
 		}
 		semgr->setValue(sem,0);
+		while(thdLocks[sem].getLockLevel()>0)
+			thdLocks[sem].unlock();
 	}
 	
 	//! returns the lockcount
@@ -216,9 +238,17 @@ public:
 	}
 	
 	//! returns the current owner's id
-	inline int owner() { return owner_index; }
+	inline int owner() const { return owner_index; }
 	
 protected:
+	friend class MarkScope;
+	virtual void useResource(Resource::Data&) {
+		lock(ProcessID::getID());
+	}
+	virtual void releaseResource(Resource::Data&) {
+		unlock();
+	}
+	
 	SemaphoreManager::semid_t sem; //!< the SysV semaphore number
 	unsigned int owner_index; //!< holds the tekkotsu process id of the current lock owner
 };
@@ -229,10 +259,16 @@ protected:
 #else //SOFTWARE ONLY mutual exclusion, used on Aperios, or if MUTEX_LOCK_ET_USE_SOFTWARE_ONLY is defined
 
 
-
-
 //#define MUTEX_LOCK_ET_USE_SPINCOUNT
 
+// if DEBUG_MUTEX_LOCK is defined, we'll display information about each lock
+// access while the left front paw button is pressed
+//#define DEBUG_MUTEX_LOCK
+
+#ifdef DEBUG_MUTEX_LOCK
+#  include "Shared/WorldState.h"
+#endif
+
 //! A software only mutual exclusion lock. (does not depend on processor or OS support)
 /*! Use this to prevent more than one process from accessing a data structure
  *  at the same time (which often leads to unpredictable and unexpected results)
@@ -268,6 +304,16 @@ class MutexLock : public MutexLockBase {
 	//! constructor, just calls the init() function.
 	MutexLock() : doors_used(0), owner_index(NO_OWNER), lockcount(0) { init();	}
 
+#ifndef PLATFORM_APERIOS
+	//! destructor, re-enables thread cancelability if lock was held (non-aperios only)
+	~MutexLock() {
+		if(owner_index!=NO_OWNER) {
+			owner_index=NO_OWNER;
+			thdLock[sem].unlock();
+		}
+	}
+#endif
+
 	//! blocks (by busy looping on do_try_lock()) until a lock is achieved
 	/*! You should pass some process-specific ID number as the input - just
 	 *  make sure no other process will be using the same value.
@@ -289,7 +335,7 @@ class MutexLock : public MutexLockBase {
 	unsigned int get_lock_level() const { return lockcount;	}
 
 	//! returns the current owner's id
-	inline int owner() { return owner_index==NO_OWNER ? NO_OWNER : doors[owner_index].id; }
+	inline int owner() const { return owner_index==NO_OWNER ? NO_OWNER : doors[owner_index].id; }
 
 	//! allows you to reset one of the possible owners, so another process can take its place.  This is not tested
 	void forget(int id);
@@ -300,6 +346,14 @@ class MutexLock : public MutexLockBase {
 #endif
 	
  protected:
+	friend class MarkScope;
+	virtual void useResource(Resource::Data&) {
+		lock(ProcessID::getID());
+	}
+	virtual void releaseResource(Resource::Data&) {
+		unlock();
+	}
+	
 	//! Does the work of trying to get a lock
 	/*! Pass @c true for @a block if you want it to use FCFS blocking
 	 *  instead of just returning right away if another process has the lock */
@@ -349,11 +403,20 @@ class MutexLock : public MutexLockBase {
 template<unsigned int num_doors>
 void
 MutexLock<num_doors>::lock(int id) {
-	if(owner()!=id)
+#ifndef PLATFORM_APERIOS
+	thdLock[sem].lock();
+#endif
+	if(owner()!=id) {
 		if(!do_try_lock(lookup(id),true)) {
 			//spin(); //note the block argument above -- should never spin if that is actually working
 			std::cout << "Warning: lock() failed to achieve lock" << std::endl;
 		}
+	} else {
+#ifdef DEBUG_MUTEX_LOCK
+		if(state==NULL || state->buttons[LFrPawOffset])
+			std::cerr << id << " re-locked " << this << " level " << lockcount+1 << std::endl;
+#endif
+	}
 	lockcount++;
 }
 
@@ -361,15 +424,27 @@ MutexLock<num_doors>::lock(int id) {
 template<unsigned int num_doors>
 bool
 MutexLock<num_doors>::try_lock(int id) {
+#ifndef PLATFORM_APERIOS
+	if(!thdLock[sem].trylock())
+		return false;
+#endif
 	if(owner()==id) {
+#ifdef DEBUG_MUTEX_LOCK
+		if(state==NULL || state->buttons[LFrPawOffset])
+			std::cerr << id << " re-locked " << this << " level " << lockcount+1 << std::endl;
+#endif
 		lockcount++;
 		return true;
 	} else {
 		if(do_try_lock(lookup(id),false)) {
 			lockcount++;
 			return true;
-		} else
+		} else {
+#ifndef PLATFORM_APERIOS
+			thdLock[sem].unlock())
+#endif
 			return false;
+		}
 	}
 }
 
@@ -377,21 +452,32 @@ MutexLock<num_doors>::try_lock(int id) {
 template<unsigned int num_doors>
 void
 MutexLock<num_doors>::unlock() {
-	if(lockcount==0)
+	if(lockcount==0) {
 		std::cerr << "Warning: MutexLock::unlock caused underflow" << std::endl;
-	else if(--lockcount==0)
+		return;
+	}
+#ifdef DEBUG_MUTEX_LOCK
+	if(state==NULL || state->buttons[LFrPawOffset])
+		std::cerr << doors[owner_index].id << " unlock " << this << " level "<< lockcount << std::endl;
+#endif
+	if(--lockcount==0) {
 		if(owner_index!=NO_OWNER) {
 			unsigned int tmp = owner_index;
 			owner_index=NO_OWNER;
 			doors[tmp].BL_in_use=false;
 			doors[tmp].BL_ready=false;
 			// *** Lock has been released *** //
+#ifndef PLATFORM_APERIOS
+			if(owner_index==id) {
+				thdLock[sem].unlock();
+			}
+#endif
 		}
+	}
 }
 
 
 //! If you define this to do something more interesting, can use it to see what's going on in the locking process
-#define mutexdebugout(i,c) {}
 //#define mutexdebugout(i,c) { std::cout << ((char)(i==0?c:((i==1?'M':'a')+(c-'A')))) << std::flush; }
 
 
@@ -402,10 +488,12 @@ MutexLock<num_doors>::do_try_lock(unsigned int i, bool block) {
 		std::cerr << "WARNING: new process attempted to lock beyond num_doors ("<<num_doors<<")" << std::endl;
 		return false;
 	}
+#ifdef DEBUG_MUTEX_LOCK
+	if(state==NULL || state->buttons[LFrPawOffset])
+		std::cerr << doors[i].id << " attempting lock " << this << " held by " << owner_index << " at " << get_time() << std::endl;
+#endif	
 	unsigned char S[num_doors]; // a local copy of everyone's doors
 	// *** Entering FCFS doorway *** //
-//	pprintf(TextOutputStream,"**%d**\n",i);
-mutexdebugout(i,'A');
 	doors[i].FCFS_in_use=true;
 	for(unsigned int j=0; j<num_doors; j++)
 		S[j]=doors[j].turn;
@@ -414,20 +502,20 @@ mutexdebugout(i,'A');
 	doors[i].BL_ready=true;
 	doors[i].FCFS_in_use=false;
 	// *** Leaving FCFS doorway *** //
-mutexdebugout(i,'B');
 	for(unsigned int j=0; j<num_doors; j++) {
-mutexdebugout(i,'C');
 		while(doors[j].FCFS_in_use || (doors[j].BL_ready && S[j]==doors[j].turn))
 			if(block)
 				spin();
 			else {
 				doors[i].BL_ready=false;
+#ifdef DEBUG_MUTEX_LOCK
+				if(state==NULL || state->buttons[LFrPawOffset])
+					std::cerr << doors[i].id << " giving up on lock " << this << " held by " << owner_index << " at " << get_time() << std::endl;
+#endif	
 				return false;
 			}
-mutexdebugout(i,'D');
 	}
 	// *** Entering Burns-Lamport *** //
-mutexdebugout(i,'E');
 	do {
 		doors[i].BL_in_use=true;
 		for(unsigned int t=0; t<i; t++)
@@ -435,12 +523,14 @@ mutexdebugout(i,'E');
 				doors[i].BL_in_use=false;
 				if(!block) {
 					doors[i].BL_ready=false;
+#ifdef DEBUG_MUTEX_LOCK
+					if(state==NULL || state->buttons[LFrPawOffset])
+						std::cerr << doors[i].id << " giving up on lock " << this << " held by " << owner_index << " at " << get_time() << std::endl;
+#endif	
 					return false;
 				}
-mutexdebugout(i,'F');
 				while(doors[t].BL_in_use)
 					spin();
-mutexdebugout(i,'G');
 				break;
 			}
 	} while(!doors[i].BL_in_use);
@@ -449,8 +539,11 @@ mutexdebugout(i,'G');
 			spin();
 	// *** Leaving Burns-Lamport ***//
 	// *** Lock has been given *** //
-mutexdebugout(i,'H');
 	owner_index=i;
+#ifdef DEBUG_MUTEX_LOCK
+	if(state==NULL || state->buttons[LFrPawOffset])
+		std::cerr << doors[i].id << " received lock " << this << " at " << get_time() << std::endl;
+#endif	
 	return true;
 }
 
@@ -481,7 +574,7 @@ MutexLock<num_doors>::forget(int id) { //not tested thoroughly (or at all?)
 	do_try_lock(i,true);
 	doors[i].id=doors[--doors_used].id;
 	doors[doors_used].id=NO_OWNER;
-	release();
+	releaseAll();
 }
 
 #endif //MUTEX_LOCK_ET_USE_SOFTWARE_ONLY
@@ -491,10 +584,10 @@ MutexLock<num_doors>::forget(int id) { //not tested thoroughly (or at all?)
  * @author ejt (Creator), Edward A. Lycklama, Vassos Hadzilacos (paper from which this was based)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.16 $
  * $State: Exp $
- * $Date: 2005/07/26 03:22:02 $
+ * $Date: 2006/08/11 21:51:40 $
  */
 
 #endif
