@@ -1,7 +1,8 @@
 #ifndef PLATFORM_APERIOS
 #include "RCRegion.h"
-#include "LockScope.h"
+#include "Shared/MarkScope.h"
 #include "Shared/debuget.h"
+#include "Thread.h"
 #include <unistd.h>
 #include <sstream>
 #include <sys/stat.h>
@@ -28,11 +29,18 @@ pid_t RCRegion::rootPID(::getpid());
 
 using namespace std;
 
-typedef LockScope<ProcessID::NumProcesses> AutoLock;
+typedef MarkScope AutoLock;
 
+#if TEKKOTSU_SHM_STYLE==SYSV_SHM
 key_t RCRegion::nextKey=1024;
+#elif TEKKOTSU_SHM_STYLE==POSIX_SHM
+key_t RCRegion::nextKey=0;
+#endif
+
 RCRegion::attachedRegions_t RCRegion::attachedRegions;
 bool RCRegion::isFaultShutdown=false;
+ThreadNS::Lock* RCRegion::staticLock=NULL;
+
 
 #if TEKKOTSU_SHM_STYLE==SYSV_SHM
 //under SYSV shared memory, the keys are just numbers, and it's just as likely that the conflicted
@@ -50,6 +58,7 @@ RCRegion::ConflictResolutionStrategy RCRegion::conflictStrategy=RCRegion::REPLAC
 #endif
 
 RCRegion * RCRegion::attach(const Identifier& rid) {
+	MarkScope l(getStaticLock());
 	attachedRegions_t::iterator it=attachedRegions.find(rid.key);
 	if(it==attachedRegions.end())
 		return new RCRegion(rid); // the constructor will add entry to attachedRegions
@@ -61,7 +70,7 @@ RCRegion * RCRegion::attach(const Identifier& rid) {
 }
 
 void RCRegion::AddReference() {
-	AutoLock autolock(*lock,ProcessID::getID());
+	AutoLock autolock(*lock);
 	//cout << "AddReference " << id.shmid << ' ' << ProcessID::getID();
 	references[ProcessID::getID()]++;
 	references[ProcessID::NumProcesses]++;
@@ -73,6 +82,8 @@ void RCRegion::AddReference() {
 
 void RCRegion::RemoveReference() {
 	//cout << "RemoveReference " << id.key << ' ' << ProcessID::getID();
+	//if(MutexLockBase::getSemaphoreManager()!=NULL) //check in case this region contained the mutexman and SharedObject just destructed it
+	lock->lock(ProcessID::getID());
 	if(references[ProcessID::getID()] == 0) {
 		cerr << "Warning: RCRegion reference count underflow on " << id.key << " by " << ProcessID::getID() << "!  ";
 		for(unsigned int i=0; i<ProcessID::NumProcesses+1; i++)
@@ -80,21 +91,27 @@ void RCRegion::RemoveReference() {
 		cerr << endl;
 		return;
 	}
-	//if(MutexLockBase::getSemaphoreManager()!=NULL) //check in case this region contained the mutexman and SharedObject just destructed it
-	lock->lock(ProcessID::getID());
 	bool wasLastProcRef=(--references[ProcessID::getID()] == 0);
 	bool wasLastAnyRef=(--references[ProcessID::NumProcesses] == 0);
 	ASSERT(wasLastProcRef || !wasLastAnyRef,"global reference decremented beyond process reference");
 	//if(MutexLockBase::getSemaphoreManager()!=NULL)
-	lock->unlock();
-	if(isFaultShutdown) {
+	/*if(isFaultShutdown) {
 		cerr << "Process " << ProcessID::getID() << " dereferenced " << id.key << ".  Counts are now:";
 		for(unsigned int i=0; i<ProcessID::NumProcesses+1; i++)
 			cerr << ' ' << references[i];
 		cerr << endl;
-	}
-	if(wasLastProcRef) {
+	}*/
+	ThreadNS::Lock * old=NULL;
+	if(!wasLastProcRef) {
+		lock->unlock();
+	} else {
+		MarkScope l(getStaticLock());
 		//cout << " detach";
+		if(wasLastAnyRef)
+			lock->~MutexLock<ProcessID::NumProcesses>();
+		else
+			lock->unlock();
+		lock=NULL;
 #if TEKKOTSU_SHM_STYLE==SYSV_SHM
 		if(shmdt(base)<0)
 			perror("Warning: Region detach");
@@ -120,7 +137,7 @@ void RCRegion::RemoveReference() {
 					// so an error now is just confirmation that it worked
 					cerr << "Region " << id.key << " appears to have been successfully unlinked" << endl;
 				else {
-					cerr << "Warning: Shared memory unlink (shm_unlink) of region " << id.key << " returned " << strerror(err);
+					cerr << "Warning: Shared memory unlink of region " << id.key << " returned " << strerror(err);
 					if(err==EINVAL || err==ENOENT)
 						cerr << "\n         May have already been unlinked by a dying process.";
 					cerr << endl;
@@ -133,12 +150,18 @@ void RCRegion::RemoveReference() {
 #  error "Unknown TEKKOTSU_SHM_STYLE setting"
 #endif
 		delete this;
+		if(attachedRegions.size()==0 && !isFaultShutdown) {
+			//was last attached region, clean up lock for good measure
+			old=staticLock;
+			staticLock=NULL;
+		}
 	}
+	delete old;
 	//cout << endl;
 }
 
 void RCRegion::AddSharedReference() {
-	AutoLock autolock(*lock,ProcessID::getID());
+	AutoLock autolock(*lock);
 	//cout << "AddSharedReference " << id.shmid << ' ' << ProcessID::getID();
 	references[ProcessID::NumProcesses]++;
 	//cout << " counts are now:";
@@ -148,7 +171,7 @@ void RCRegion::AddSharedReference() {
 }
 
 void RCRegion::RemoveSharedReference() {
-	AutoLock autolock(*lock,ProcessID::getID());
+	AutoLock autolock(*lock);
 	//cout << "RemoveSharedReference " << id.shmid << ' ' << ProcessID::getID();
 	if(references[ProcessID::NumProcesses]==0) {
 		cerr << "Warning: RCRegion shared reference count underflow on " << id.key << " by " << ProcessID::getID() << "!  ";
@@ -158,6 +181,7 @@ void RCRegion::RemoveSharedReference() {
 		return;
 	}
 	references[ProcessID::NumProcesses]--;
+	ASSERT(references[ProcessID::NumProcesses]>0,"removal of shared reference was last reference -- should have local reference as well");
 	//cout << " counts are now:";
 	//for(unsigned int i=0; i<ProcessID::NumProcesses+1; i++)
 	//	cout << ' ' << references[i];
@@ -167,19 +191,27 @@ void RCRegion::RemoveSharedReference() {
 
 void RCRegion::aboutToFork(ProcessID::ProcessID_t newID) {
 	//cout << "RCRegion aboutToFork to " << newID << endl;
-	attachedRegions_t::const_iterator it=attachedRegions.begin();
-	for(; it!=attachedRegions.end(); ++it) {
-		//cout << "Duplicating attachments for " << (*it).first;
-		(*it).second->references[newID]=(*it).second->references[ProcessID::getID()];
-		(*it).second->references[ProcessID::NumProcesses]+=(*it).second->references[newID];
-		//cout << " counts are now:";
-		//for(unsigned int i=0; i<ProcessID::NumProcesses+1; i++)
-		//	cout << ' ' << (*it).second->references[i];
-		//cout << endl;
+	ThreadNS::Lock* old;
+	{
+		MarkScope l(getStaticLock());
+		attachedRegions_t::const_iterator it=attachedRegions.begin();
+		for(; it!=attachedRegions.end(); ++it) {
+			//cout << "Duplicating attachments for " << (*it).first;
+			(*it).second->references[newID]=(*it).second->references[ProcessID::getID()];
+			(*it).second->references[ProcessID::NumProcesses]+=(*it).second->references[newID];
+			//cout << " counts are now:";
+			//for(unsigned int i=0; i<ProcessID::NumProcesses+1; i++)
+			//	cout << ' ' << (*it).second->references[i];
+			//cout << endl;
+		}
+		old=staticLock;
+		staticLock=NULL;
 	}
+	delete old;
 }
 
 void RCRegion::faultShutdown() {
+	MarkScope l(getStaticLock());
 	if(isFaultShutdown) {
 		cerr << "WARNING: RCRegion::faultShutdown() called again... ignoring" << endl;
 		return;
@@ -216,7 +248,28 @@ void RCRegion::faultShutdown() {
 	}
 }
 
+RCRegion::attachedRegions_t::const_iterator RCRegion::attachedBegin(bool threadSafe) {
+	if(threadSafe) {
+		MarkScope l(getStaticLock());
+		attachedRegions.begin()->second->AddReference();
+		return attachedRegions.begin();
+	} else
+		return attachedRegions.begin();
+}
+RCRegion::attachedRegions_t::const_iterator RCRegion::attachedEnd() {
+	return attachedRegions.end();
+}
+void RCRegion::attachedAdvance(RCRegion::attachedRegions_t::const_iterator& it, int x/*=1*/) {
+	MarkScope l(getStaticLock());
+	if(it!=attachedRegions.end())
+		it->second->RemoveReference();
+	std::advance(it,x);
+	if(it!=attachedRegions.end())
+		it->second->AddReference();
+}
+
 RCRegion::~RCRegion() {
+	MarkScope l(getStaticLock());
 	attachedRegions.erase(id.key);
 	ASSERT(base==NULL,"destructed with attachment!");
 	ASSERT(references==NULL,"destructed with local references!");
@@ -231,9 +284,17 @@ unsigned int RCRegion::calcRealSize(unsigned int size) {
 	return pages*pagesize; //round up to the nearest page
 }
 
+
+ThreadNS::Lock& RCRegion::getStaticLock() {
+	if(staticLock==NULL)
+		staticLock=new ThreadNS::Lock();
+	return *staticLock;
+}
+
 #if TEKKOTSU_SHM_STYLE==SYSV_SHM
 
 void RCRegion::init(size_t sz, key_t sug_key, bool create) {
+	ThreadNS::Lock l(getStaticLock());
 	id.size=sz;
 	sz=calcRealSize(sz);
 	if(create) {
@@ -344,6 +405,7 @@ bool RCRegion::unlinkRegion() const {
 #endif
 }
 void RCRegion::init(size_t sz, const std::string& name, bool create) {
+	MarkScope l(getStaticLock());
 	id.size=sz; //size of requested region
 	sz=calcRealSize(sz); //add some additional space for region lock and reference counts
 #ifndef USE_UNBACKED_SHM
@@ -412,7 +474,7 @@ void RCRegion::init(size_t sz, const std::string& name, bool create) {
 				     << "         (may have been leftover from a previous crash)" << endl;
 #endif
 				if(!unlinkRegion())
-					perror("Warning: Shared memory unlink (shm_unlink)");
+					perror("Warning: Shared memory unlink");
 			}
 			//note fall-through from REPLACE into EXIT - only try delete once, and then recreate and exit if it fails again
 			case EXIT: {
@@ -421,7 +483,9 @@ void RCRegion::init(size_t sz, const std::string& name, bool create) {
 					cerr << "ERROR: Opening new region " << id.key << ": " << strerror(err) << " (shm_open)" << endl;
 					if(err==EEXIST)
 						cerr << "This error suggests a leaked memory region, perhaps from a bad crash on a previous run.\n"
+#ifdef USE_UNBACKED_SHM
 							<< "You may either be able to use shm_unlink to remove the region, or reboot.\n"
+#endif
 							<< "Also make sure that no other copies of the simulator are already running." << endl;
 					exit(EXIT_FAILURE);
 				}
@@ -433,7 +497,7 @@ void RCRegion::init(size_t sz, const std::string& name, bool create) {
 			if(close(fd)<0)
 				perror("Warning: Closing temporary file descriptor from shm_open");
 			if(!unlinkRegion())
-				perror("Warning: Shared memory unlink (shm_unlink)");
+				perror("Warning: Shared memory unlink");
 			exit(EXIT_FAILURE);
 		}
 	} else {
@@ -445,12 +509,12 @@ void RCRegion::init(size_t sz, const std::string& name, bool create) {
 	}
 	base=static_cast<char*>(mmap(NULL,sz,PROT_READ|PROT_WRITE,MAP_SHARED,fd,(off_t)0));	
 	int err=errno;
-	if (base == reinterpret_cast<char*>(-1)) {
+	if (base == MAP_FAILED) { /* MAP_FAILED generally defined as ((void*)-1) */
 		cerr << "ERROR: Attaching region " << id.key << " of size " << sz << ": " << strerror(err) << " (mmap)" << endl;
 		if(close(fd)<0)
 			perror("Warning: Closing temporary file descriptor from shm_open");
 		if(!unlinkRegion())
-			perror("Warning: Shared memory unlink (shm_unlink)");
+			perror("Warning: Shared memory unlink");
 		exit(EXIT_FAILURE);
 	}
 	if(close(fd)<0) {
@@ -460,7 +524,7 @@ void RCRegion::init(size_t sz, const std::string& name, bool create) {
 	references=reinterpret_cast<unsigned int*>(base+sz-extra);
 	if(create) {
 		new (lock) MutexLock<ProcessID::NumProcesses>;
-		AutoLock autolock(*lock,ProcessID::getID());
+		AutoLock autolock(*lock);
 		for(unsigned int i=0; i<ProcessID::NumProcesses+1; i++)
 			references[i]=0;
 	}
@@ -497,10 +561,10 @@ protected:
 * @author ejt (Creator)
 *
 * $Author: ejt $
-* $Name: tekkotsu-2_4_1 $
-* $Revision: 1.3 $
+* $Name: tekkotsu-3_0 $
+* $Revision: 1.10 $
 * $State: Exp $
-* $Date: 2005/06/23 20:17:54 $
+* $Date: 2006/08/15 21:45:36 $
 */
 
 #endif
