@@ -8,7 +8,7 @@
 
 #include "ListMemBuf.h"
 #include "RCRegion.h"
-#include "LockScope.h"
+#include "Shared/MarkScope.h"
 #include "ProcessID.h"
 
 //! Keeps track of currently available shared memory regions
@@ -16,7 +16,7 @@ template<unsigned int MAX_REGIONS, unsigned int NAME_LEN=0>
 class RegionRegistry {
 protected:
 	mutable MutexLock<ProcessID::NumProcesses> lock;
-	typedef LockScope<ProcessID::NumProcesses> AutoLock;
+	typedef MarkScope AutoLock;
 	
 	//! Holds information regarding a shared memory region available for listening
 	struct entry {
@@ -40,12 +40,12 @@ public:
 	RegionRegistry() : lock(), avail() {}
 	
 	~RegionRegistry() {
-		AutoLock autolock(lock,ProcessID::getID());
+		AutoLock autolock(lock);
 		avail.clear();
 	}
 	
 	index_t findRegion(const std::string& name) const {
-		AutoLock autolock(lock,ProcessID::getID());
+		AutoLock autolock(lock);
 		if(name.size()>NAME_LEN)
 			std::cerr << "WARNING: RegionRegistry::attach("<<name<<") is too long, max is " << NAME_LEN << std::endl;
 		for(index_t it=begin(); it!=end(); it=next(it))
@@ -67,7 +67,7 @@ public:
 	}
 	
 	RCRegion * registerRegion(const std::string& name, size_t size) {
-		AutoLock autolock(lock,ProcessID::getID());
+		AutoLock autolock(lock);
 		index_t it=findRegion(name);
 		if(it!=end()) {
 			//found, already registered
@@ -102,10 +102,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:46 $
+ * $Date: 2006/06/16 21:49:23 $
  */
 
 #endif //Aperios check
