@@ -6,6 +6,7 @@
 #include <errno.h>
 #include <stdio.h>
 #include <exception>
+#include <stdexcept>
 #include <iostream>
 
 //this is for linux compatability -- apparently you're *supposed* to
@@ -24,7 +25,19 @@ using namespace std;
 
 SemaphoreManager::SemaphoreManager()
 : sems(), nsem(sems_t::MAX_ENTRIES), semid(-1), mysem(sems.end()), refc(sems.end())
-{
+{init();}
+
+SemaphoreManager::SemaphoreManager(unsigned int numRequest)
+: sems(), nsem(numRequest+2), semid(-1), mysem(sems.end()), refc(sems.end())
+{init();}
+
+void SemaphoreManager::init() {
+	if(nsem>sems_t::MAX_ENTRIES) {
+		cout << "SemaphoreManager created with request for " << nsem << " semaphores, but sems_t::MAX_ENTRIES is " << sems_t::MAX_ENTRIES << endl;
+		nsem=sems_t::MAX_ENTRIES;
+	}
+	unsigned int req=nsem;
+
 	//the seminfo structure is kernel-private and I can't find a portable way to access
 	//SEMMSL without it.
 	/*semun params; 
@@ -42,6 +55,7 @@ SemaphoreManager::SemaphoreManager()
 	//So instead we'll do a binary search for the size:
 	unsigned int lowbound=0; //inclusive
 	unsigned int highbound=nsem; //inclusive
+	//note that first pass asks for highbound - if it succeeds there's no search
 	while(lowbound!=highbound) {
 		semid=semget(IPC_PRIVATE,nsem,IPC_CREAT | IPC_EXCL | 0666);
 		if(semid<0) {
@@ -61,16 +75,15 @@ SemaphoreManager::SemaphoreManager()
 		}
 		nsem=(lowbound+highbound+1)/2;
 	}
-	if(nsem!=sems_t::MAX_ENTRIES)
-		cerr << "WARNING: System can only allocate " << nsem << " semaphores per set (SEMMSL). " << sems_t::MAX_ENTRIES << " were suggested." << endl;
-	
 	//get the semaphore set
 	semid=semget(IPC_PRIVATE,nsem,IPC_CREAT | IPC_EXCL | 0666);
 	if(semid<0) {
 		perror("ERROR: SemaphoreManager construction (semget)");
 				exit(EXIT_FAILURE);
 	}
-	
+	if(nsem!=req)
+		cerr << "WARNING: System can only allocate " << nsem << " semaphores per set for id=" << semid << " (SEMMSL or SEMMNS max reached). " << req << " were requested." << endl;
+		
 	//initialize to 0 (unlocked)
 	unsigned short int semvals[sems_t::MAX_ENTRIES];
 	for(unsigned int i=0; i<nsem; i++)
@@ -146,7 +159,8 @@ SemaphoreManager& SemaphoreManager::operator=(const SemaphoreManager& mm) {
 				sems.erase(refc);
 				sems.erase(mysem);
 				for(semid_t it=sems.begin(); it!=sems.end(); it=sems.next(it))
-					cerr << "Warning: semaphore id " << it << " from set " << semid << " was still active when the set was dereferenced" << endl;
+					if(it<nsem)
+						cerr << "Warning: semaphore id " << it << " from set " << semid << " was still active when the set was dereferenced" << endl;
 				if(semctl(semid,-1,IPC_RMID)<0) {
 					perror("ERROR: SemaphoreManager deletion from operator= (semctl)");
 					exit(EXIT_FAILURE);
@@ -207,6 +221,9 @@ SemaphoreManager::semid_t SemaphoreManager::getSemaphore() {
 	lower(mysem,1);
 	semid_t id=sems.new_front();
 	raise(mysem,1);
+	if(id!=sems.end())
+		setValue(id,0);
+	intrPolicy[id]=INTR_RETRY;
 	return id;
 }
 void SemaphoreManager::releaseSemaphore(semid_t id) {
@@ -220,10 +237,30 @@ bool SemaphoreManager::lower(semid_t id, unsigned int x, bool block/*=true*/) co
 	while(semop(semid,&sb,1)<0) {
 		if(errno==EAGAIN)
 			return false;
-		perror("ERROR: SemaphoreManager unable to lower semaphore (semop)");
 		if(errno==EINTR) {
-			cerr << "       I was interrupted.  Trying again...";
+			switch(intrPolicy[id]) {
+				case INTR_CANCEL_VERBOSE:
+					perror("ERROR: SemaphoreManager unable to lower semaphore (semop)");
+					cerr << "       semop was interrupted by signal, cancelling lower()";
+				case INTR_CANCEL:
+					return false;
+				case INTR_RETRY_VERBOSE:
+					perror("ERROR: SemaphoreManager unable to lower semaphore (semop)");
+					cerr << "       semop was interrupted by signal.  Trying again...";
+				case INTR_RETRY:
+					break; //while loop will retry
+				case INTR_THROW_VERBOSE:
+					perror("ERROR: SemaphoreManager unable to lower semaphore (semop)");
+					cerr << "       semop was interrupted by signal.  Throwing exception...";
+				case INTR_THROW:
+					throw std::runtime_error("EINTR returned by lower semop");
+				case INTR_EXIT:
+					perror("ERROR: SemaphoreManager unable to lower semaphore (semop)");
+					cerr << "       semop was interrupted by signal.  Exiting...";
+					exit(EXIT_FAILURE);
+			}
 		} else {
+			perror("ERROR: SemaphoreManager unable to lower semaphore (semop)");
 			cerr << "       ";
 			if(errno==EIDRM) {
 				cerr << "Semaphore set has been removed.  " << endl;
@@ -276,7 +313,29 @@ bool SemaphoreManager::testZero(semid_t id, bool block/*=true*/) const {
 			}
 			cerr << "Goodbye" << endl;
 			exit(EXIT_FAILURE);
-		} //else cerr << "       I was interrupted.  Trying again...";
+		} else {
+			switch(intrPolicy[id]) {
+				case INTR_CANCEL_VERBOSE:
+					perror("ERROR: SemaphoreManager unable to testZero (semop)");
+					cerr << "       semop was interrupted by signal, cancelling testZero()";
+				case INTR_CANCEL:
+					return false;
+				case INTR_RETRY_VERBOSE:
+					perror("ERROR: SemaphoreManager unable to testZero (semop)");
+					cerr << "       semop was interrupted by signal.  Trying again...";
+				case INTR_RETRY:
+					break; //while loop will retry
+				case INTR_THROW_VERBOSE:
+					perror("ERROR: SemaphoreManager unable to testZero (semop)");
+					cerr << "       semop was interrupted by signal.  Throwing exception...";
+				case INTR_THROW:
+					throw std::runtime_error("EINTR returned by testZero semop");
+				case INTR_EXIT:
+					perror("ERROR: SemaphoreManager unable to testZero (semop)");
+					cerr << "       semop was interrupted by signal.  Exiting...";
+					exit(EXIT_FAILURE);
+			}
+		}
 	}
 	return true;
 }
@@ -302,7 +361,29 @@ bool SemaphoreManager::testZero_add(semid_t id, unsigned int x, bool testblock/*
 			}
 			cerr << "Goodbye" << endl;
 			exit(EXIT_FAILURE);
-		} //else cerr << "       I was interrupted.  Trying again...";
+		} else {
+			switch(intrPolicy[id]) {
+				case INTR_CANCEL_VERBOSE:
+					perror("ERROR: SemaphoreManager unable to testZero_add (semop)");
+					cerr << "       semop was interrupted by signal, cancelling testZero_add()";
+				case INTR_CANCEL:
+					return false;
+				case INTR_RETRY_VERBOSE:
+					perror("ERROR: SemaphoreManager unable to testZero_add (semop)");
+					cerr << "       semop was interrupted by signal.  Trying again...";
+				case INTR_RETRY:
+					break; //while loop will retry
+				case INTR_THROW_VERBOSE:
+					perror("ERROR: SemaphoreManager unable to testZero_add (semop)");
+					cerr << "       semop was interrupted by signal.  Throwing exception...";
+				case INTR_THROW:
+					throw std::runtime_error("EINTR returned by testZero_add semop");
+				case INTR_EXIT:
+					perror("ERROR: SemaphoreManager unable to testZero_add (semop)");
+					cerr << "       semop was interrupted by signal.  Exiting...";
+					exit(EXIT_FAILURE);
+			}
+		}
 	}
 	return true;
 }
@@ -327,7 +408,29 @@ bool SemaphoreManager::add_testZero(semid_t id, unsigned int x, bool addblock/*=
 			}
 			cerr << "Goodbye" << endl;
 			exit(EXIT_FAILURE);
-		} //else cerr << "       I was interrupted.  Trying again...";
+		} else {
+			switch(intrPolicy[id]) {
+				case INTR_CANCEL_VERBOSE:
+					perror("ERROR: SemaphoreManager unable to add_testZero (semop)");
+					cerr << "       semop was interrupted by signal, cancelling add_testZero()";
+				case INTR_CANCEL:
+					return false;
+				case INTR_RETRY_VERBOSE:
+					perror("ERROR: SemaphoreManager unable to add_testZero (semop)");
+					cerr << "       semop was interrupted by signal.  Trying again...";
+				case INTR_RETRY:
+					break; //while loop will retry
+				case INTR_THROW_VERBOSE:
+					perror("ERROR: SemaphoreManager unable to add_testZero (semop)");
+					cerr << "       semop was interrupted by signal.  Throwing exception...";
+				case INTR_THROW:
+					throw std::runtime_error("EINTR returned by add_testZero semop");
+				case INTR_EXIT:
+					perror("ERROR: SemaphoreManager unable to add_testZero (semop)");
+					cerr << "       semop was interrupted by signal.  Exiting...";
+					exit(EXIT_FAILURE);
+			}
+		}
 	}
 	return true;
 }
@@ -337,10 +440,10 @@ bool SemaphoreManager::add_testZero(semid_t id, unsigned int x, bool addblock/*=
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2005/06/23 20:18:56 $
+ * $Date: 2006/08/11 18:44:16 $
  */
 
 #endif //Aperios check
