@@ -11,6 +11,13 @@ class SharedObjectBase {
 public:
 	void* data() const { return rcr->Base(); } //!< returns a pointer to the data region
 	RCRegion * getRegion() const { return rcr; } //!< returns the OPEN-R memory region, should you need it
+	
+	virtual ~SharedObjectBase() {} //!< destructor
+	
+#ifndef PLATFORM_APERIOS
+	//! return the next region serial number -- doesn't actually increment it though, repeated calls will return the same value until the value is actually used
+	static unsigned int getNextKey() { return serialNumber+1; }
+#endif
 
 protected:
 	//! constructor, protected because you shouldn't need to create this directly, just a common interface to all templates of SharedObject
@@ -27,8 +34,6 @@ protected:
 		rcr=sob.rcr;
 		rcr->AddReference();
 	}
-	//< destructor
-	virtual ~SharedObjectBase() {} 
 
 	//!removes a reference from #rcr, and if necessary, destructs its data
 	virtual void removeRef()=0;
@@ -98,7 +103,7 @@ public:
 	}
 	//@}
 	
-	//< destructor
+	//! destructor, removes reference to shared region
 	virtual ~SharedObject() { removeRef(); }
 	
 	MC* operator->() const { return dataCasted(); } //!< smart pointer to the underlying class
@@ -128,7 +133,10 @@ protected:
 		RCRegion * r = new RCRegion(calcsize());
 #else
 		char name[RCRegion::MAX_NAME_LEN];
-		snprintf(name,RCRegion::MAX_NAME_LEN,"ShdObj.%d.%d",ProcessID::getID(),++serialNumber);
+		unsigned int suffixlen=snprintf(name,RCRegion::MAX_NAME_LEN,".%d.%d",ProcessID::getID(),++serialNumber);
+		if(suffixlen>RCRegion::MAX_NAME_LEN)
+			suffixlen=RCRegion::MAX_NAME_LEN;
+		snprintf(name,RCRegion::MAX_NAME_LEN,"Sh.%.*s.%d.%d",RCRegion::MAX_NAME_LEN-suffixlen-3,typeid(MC).name(),ProcessID::getID(),++serialNumber);
 		name[RCRegion::MAX_NAME_LEN-1]='\0';
 		RCRegion * r = new RCRegion(name,calcsize());
 #endif
@@ -176,10 +184,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2005/06/13 20:29:48 $
+ * $Date: 2006/09/16 20:11:52 $
  */
 
 #endif //INCLUDED_SharedObject_h
