@@ -1,6 +1,6 @@
 //-*-c++-*-
-#ifndef INCLUDED_DynamicMotionSequenceMC_h_
-#define INCLUDED_DynamicMotionSequenceMC_h_
+#ifndef INCLUDED_DynamicMotionSequence_h_
+#define INCLUDED_DynamicMotionSequence_h_
 
 #include "MotionSequenceEngine.h"
 #include "MotionCommand.h"
@@ -15,7 +15,7 @@ public:
 	//!constructor
 	DynamicMotionSequence() : MotionCommand(), MotionSequenceEngine(), moves(), erased() {clear();}
 	//!constructor, loads from a file and then resets the playtime to beginning and begins to play
-	explicit DynamicMotionSequence(const char* filename) : MotionCommand(), MotionSequenceEngine(), moves(), erased() {clear();LoadFile(filename);setTime(1);}
+	explicit DynamicMotionSequence(const char* filename) : MotionCommand(), MotionSequenceEngine(), moves(), erased() {clear();loadFile(filename);setTime(1);}
 	//!destructor
 	virtual ~DynamicMotionSequence() {}
 
@@ -100,18 +100,22 @@ protected:
 	//! marks keyframe @a x unused
 	virtual void eraseKeyFrame(Move_idx_t x) { erased.push_back(x); }
 	//! advances (or rewinds) @a prev and @a next so that @a t falls between them
-	void setRange(unsigned int t,Move_idx_t& prev, Move_idx_t& next) const {
+	bool setRange(unsigned int t,Move_idx_t& prev, Move_idx_t& next) const {
+		bool moved=false;
 		if(next!=invalid_move && moves[next].starttime<=t) {
+			moved=true;
 			do {
 				prev=next;
 				next=moves[prev].next;
 			} while(next!=invalid_move && moves[next].starttime<=t);
-		} else if(t<moves[prev].starttime) {
-			do {
+		} else {
+			while(moves[prev].prev!=invalid_move && t<moves[prev].starttime) {
 				next=prev;
 				prev=moves[next].prev;
-			} while(t<moves[prev].starttime);
+				moved=true;
+			}
 		}
+		return moved;
 	}
 };
 
@@ -120,10 +124,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2006/09/09 04:32:52 $
  */
 
 #endif
