@@ -12,7 +12,7 @@
 
 EmergencyStopMC::EmergencyStopMC()
 	: PostureMC(), paused(false), stilldown(false), active(true), period(2000),
-		timeoflastbtn(0), timeofthisbtn(0), timeoflastfreeze(0), duration(600),
+		timeoflastbtn(0), timeofthisbtn(0), timeoflastfreeze(0), timeoflastrelease(0), duration(600),
 		pidcutoff(0.2), ledengine()
 {
 	for(unsigned int i=0; i<NumPIDJoints; i++)
@@ -53,27 +53,41 @@ int EmergencyStopMC::updateOutputs() {
 		if((get_time()-timeoflastbtn)<duration)
 			setStopped(!paused);
 	}
-	if(!paused)
-		return 0;
-	//immediately following a pause, just hold current position at first to prevent twitching if we were in motion
-	if(get_time()-timeoflastfreeze>FrameTime*NumFrames*5) { 
-		//once joints have come to rest, respond to outside forces
-		for(unsigned int i=0; i<NumPIDJoints; i++) {
-			//exponential average of duty cycles to filter out noise
-			piddutyavgs[i]=piddutyavgs[i]*.9f+state->pidduties[i]*.1f;
-			//reset if there's something significantly out of place (perhaps we're being overridden)
-			if(fabsf(state->outputs[PIDJointOffset+i]-cmds[PIDJointOffset+i].value)>.15f) {
-				//if(PIDJointOffset+i==LFrLegOffset+RotatorOffset)
-				//cout << "resetting from " << cmds[PIDJointOffset+i].value << " to " << state->outputs[PIDJointOffset+i] << endl;
-				curPositions[PIDJointOffset+i]=cmds[PIDJointOffset+i].value=state->outputs[PIDJointOffset+i];
-				dirty=true;
-				targetReached=false;
-			}
-			//give if there's a force...
-			if(fabsf(piddutyavgs[i])>pidcutoff) {
-				cmds[PIDJointOffset+i].value-=piddutyavgs[PIDJointOffset+i]; //move in the direction of the force
-				dirty=true;
-				targetReached=false;
+	unsigned int curt=get_time();
+	dirty=dirty || (curt<timeoflastrelease);
+	if(!paused) {
+		if(!dirty)
+			return 0;
+		if(curt>=timeoflastrelease) {
+			for(unsigned int i=LEDOffset; i<LEDOffset+NumLEDs; i++)
+				motman->setOutput(this,i,0.f); //blank out LEDs to avoid residual background display
+			dirty=false;
+			return 0;
+		}
+		float w = (curt>=timeoflastrelease) ? 0 : (static_cast<float>(timeoflastrelease-curt)/FADE_OUT_TIME);
+		for(unsigned int i=0; i<NumOutputs; i++)
+			cmds[i].weight=w;
+	} else {
+		//immediately following a pause, just hold current position at first to prevent twitching if we were in motion
+		if(curt-timeoflastfreeze>FrameTime*NumFrames*5) { 
+			//once joints have come to rest, respond to outside forces
+			for(unsigned int i=0; i<NumPIDJoints; i++) {
+				//exponential average of duty cycles to filter out noise
+				piddutyavgs[i]=piddutyavgs[i]*.9f+state->pidduties[i]*.1f;
+				//reset if there's something significantly out of place (perhaps we're being overridden)
+				if(fabsf(state->outputs[PIDJointOffset+i]-cmds[PIDJointOffset+i].value)>.15f) {
+					//if(PIDJointOffset+i==LFrLegOffset+RotatorOffset)
+					//cout << "resetting from " << cmds[PIDJointOffset+i].value << " to " << state->outputs[PIDJointOffset+i] << endl;
+					curPositions[PIDJointOffset+i]=cmds[PIDJointOffset+i].value=state->outputs[PIDJointOffset+i];
+					dirty=true;
+					targetReached=false;
+				}
+				//give if there's a force...
+				if(fabsf(piddutyavgs[i])>pidcutoff) {
+					cmds[PIDJointOffset+i].value-=piddutyavgs[PIDJointOffset+i]; //move in the direction of the force
+					dirty=true;
+					targetReached=false;
+				}
 			}
 		}
 	}
@@ -81,13 +95,13 @@ int EmergencyStopMC::updateOutputs() {
 	if(state->robotDesign&WorldState::ERS7Mask) {
 		//a special Battlestar Galactica inspired effect for the ERS-7
 		static float acts[5];
-		static bool first=true;
-		if(first) {
+		static bool wasPaused=false;
+		if(!wasPaused && paused) {
 			for(int i=0; i<5; i++)
 				acts[i]=0;
-			first=false;
+			wasPaused=paused;
 		}
-		float t=get_time();
+		float t=curt;
 		t/=period;
 		t=(((int)t)&1)?(int)t+1-t:(t-(int)t);
 		t*=8;
@@ -95,18 +109,22 @@ int EmergencyStopMC::updateOutputs() {
 		const float gamma=.83;
 		const float amp=.5;
 		float imp[5];
+		// w is used to fade out LEDs when releasing estop
+		float w = (paused || curt>=timeoflastrelease) ? 1 : (static_cast<float>(timeoflastrelease-curt)/FADE_OUT_TIME);
 		for(int i=0; i<5; i++) {
-			imp[i]=exp(invsigma*(t-i-2)*(t-i-2));
+			imp[i]=exp(invsigma*(t-i-2)*(t-i-2))*w;
 			acts[i]+=amp*imp[i];
-			acts[i]*=gamma;
+			acts[i]*=gamma*w;
 		}
-		cmds[ERS7Info::FaceLEDPanelOffset+6].value=acts[0]/2+imp[0];
-		cmds[ERS7Info::FaceLEDPanelOffset+7].value=acts[4]/2+imp[4];
-		cmds[ERS7Info::FaceLEDPanelOffset+8].value=acts[1]/2+imp[1];
-		cmds[ERS7Info::FaceLEDPanelOffset+9].value=acts[3]/2+imp[3];
+		cmds[ERS7Info::FaceLEDPanelOffset+ 6].value=acts[0]/2+imp[0];
+		cmds[ERS7Info::FaceLEDPanelOffset+ 8].value=acts[1]/2+imp[1];
 		cmds[ERS7Info::FaceLEDPanelOffset+10].value=acts[2]/2+imp[2];
+		cmds[ERS7Info::FaceLEDPanelOffset+ 9].value=acts[3]/2+imp[3];
+		cmds[ERS7Info::FaceLEDPanelOffset+ 7].value=acts[4]/2+imp[4];
 	}
-	return PostureMC::updateOutputs();
+	int changed=PostureMC::updateOutputs();
+	dirty=(curt<timeoflastrelease);
+	return changed;
 }
 
 void EmergencyStopMC::setActive(bool a) {
@@ -127,12 +145,12 @@ void EmergencyStopMC::setStopped(bool p, bool sound) {
 			if(paused) {
 				freezeJoints();
 				if(sound)
-					sndman->PlayFile(config->motion.estop_on_snd);
+					sndman->playFile(config->motion.estop_on_snd);
 				cout << "*** PAUSED ***" << endl;
 			} else {
 				releaseJoints();
 				if(sound)
-					sndman->PlayFile(config->motion.estop_off_snd);
+					sndman->playFile(config->motion.estop_off_snd);
 				cout << "*** UNPAUSED ***" << endl;
 			}
 		}
@@ -142,8 +160,10 @@ void EmergencyStopMC::setStopped(bool p, bool sound) {
 void EmergencyStopMC::freezeJoints() {
 	dirty=true;
 	targetReached=false;
-	for(unsigned int i=0; i<NumOutputs; i++)
-		curPositions[i]=cmds[i].value=motman->getOutputCmd(i).value;
+	for(unsigned int i=0; i<NumOutputs; i++) {
+		OutputCmd c=motman->getOutputCmd(i);
+		curPositions[i]=cmds[i].value = (c.weight==0) ? state->outputs[i] : c.value;
+	}
 	for(unsigned int i=0; i<NumPIDJoints; i++)
 		piddutyavgs[i]=0; //or: state->pidduties[i];
 	for(unsigned int i=0; i<LEDOffset; i++)
@@ -174,34 +194,19 @@ void EmergencyStopMC::freezeJoints() {
 void EmergencyStopMC::releaseJoints() {
 	dirty=true;
 	targetReached=false;
-	for(unsigned int i=0; i<NumOutputs; i++)
-		cmds[i].unset();
-	//these lines prevent residual display
-	if(state->robotDesign&WorldState::ERS210Mask) {
-		motman->setOutput(this,ERS210Info::TlRedLEDOffset,0.f);
-		motman->setOutput(this,ERS210Info::TlBluLEDOffset,0.f);
-	} else if(state->robotDesign&WorldState::ERS220Mask) {
-		for(unsigned int i = 0; i < NumLEDs; i++)
-			if((ERS220Info::TailLEDMask|ERS220Info::BackLEDMask) & (1 << i))
-				motman->setOutput(this,LEDOffset + i,0.f);
-	} else if(state->robotDesign&WorldState::ERS7Mask) {
-		cmds[ERS7Info::MdBackColorLEDOffset].set(0,0.f);
-		for(int i=6; i<6+5; i++)
-			cmds[ERS7Info::FaceLEDPanelOffset+i].set(0,0.f);
-	} else {
-		cmds[LEDOffset+NumLEDs-1].set(0,0.f);
-		cmds[LEDOffset+NumLEDs-2].set(0,0.f);
-	}
-	postEvent(EventBase(EventBase::estopEGID,getID(),EventBase::deactivateETID,get_time()-timeoflastfreeze));
+	unsigned int curt=get_time();
+	timeoflastrelease=curt+FADE_OUT_TIME;
+	postEvent(EventBase(EventBase::estopEGID,getID(),EventBase::deactivateETID,curt-timeoflastfreeze));
 }
 
 bool EmergencyStopMC::trigger() {
-	if(state->robotDesign&WorldState::ERS210Mask)
-		return state->button_times[ERS210Info::BackButOffset];
-	if(state->robotDesign&WorldState::ERS220Mask)
-		return state->button_times[ERS220Info::BackButOffset];
-	if(state->robotDesign&WorldState::ERS7Mask)
-		return state->button_times[ERS7Info::FrontBackButOffset]+state->button_times[ERS7Info::MiddleBackButOffset]+state->button_times[ERS7Info::RearBackButOffset];
+	WorldState * st=WorldState::getCurrent(); // this is need because trigger is a static, so it doesn't access the Motion
+	if(st->robotDesign&WorldState::ERS210Mask)
+		return st->button_times[ERS210Info::BackButOffset];
+	if(st->robotDesign&WorldState::ERS220Mask)
+		return st->button_times[ERS220Info::BackButOffset];
+	if(st->robotDesign&WorldState::ERS7Mask)
+		return st->button_times[ERS7Info::FrontBackButOffset]+st->button_times[ERS7Info::MiddleBackButOffset]+st->button_times[ERS7Info::RearBackButOffset];
 	serr->printf("EmergencyStopMC: unsupported model!\n");
 	return false;
 }
@@ -211,9 +216,9 @@ bool EmergencyStopMC::trigger() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.26 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.30 $
  * $State: Exp $
- * $Date: 2005/06/06 18:30:19 $
+ * $Date: 2006/09/18 18:08:01 $
  */
 
