@@ -40,6 +40,8 @@ class EmergencyStopMC : public PostureMC {
 	void freezeJoints(); //!< code to execute when locking joints
 	void releaseJoints(); //!< code to execute when releasing joints
 	static bool trigger(); //!< true when the trigger condition is active
+	
+	static const unsigned int FADE_OUT_TIME=400; //!< number of milliseconds to fade out lock on joints
 
 	bool paused; //!< true if the joints are current locked up
 	bool stilldown; //!< true if the back button was down on last updateJointCmds
@@ -48,6 +50,7 @@ class EmergencyStopMC : public PostureMC {
 	unsigned int timeoflastbtn; //!< time of the last button press
 	unsigned int timeofthisbtn; //!< time of the current button press
 	unsigned int timeoflastfreeze; //!< the time estop was last turned on
+	unsigned int timeoflastrelease; //!< the time estop was last turned off (may be in the future if still fading out control of joints!)
 	unsigned int duration; //!<the maximum time (in milliseconds) of consecutive button-down's to count as a double tap
 	float piddutyavgs[NumPIDJoints]; //!< a running average of PID feedback ("duty"), so one bad reading doesn't cause a movement, need a consistent pressure
 	float pidcutoff; //!<abs pid duty cycle above which we just reset joint to current
@@ -59,10 +62,10 @@ class EmergencyStopMC : public PostureMC {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2005/01/07 19:36:38 $
+ * $Date: 2006/09/16 06:28:07 $
  */
 
 #endif
