@@ -1,20 +1,33 @@
+#include <math.h>
+
 #include "HeadPointerMC.h"
+#include "Kinematics.h"
 #include "Shared/debuget.h"
 #include "Shared/WorldState.h"
 #include "MotionManager.h"
-#include <math.h>
 #include "Shared/Config.h"
 #include "Wireless/Socket.h"
 
 HeadPointerMC::HeadPointerMC()
-	: MotionCommand(), dirty(true), hold(true), tolerance(.035),
-		targetReached(false), targetTimestamp(0), timeout(2000), 
+	: MotionCommand(), dirty(true), hold(true), tolerance(.05),
+		targetReached(true), targetTimestamp(0), timeout(2000), 
 	  headkin(::config->motion.makePath(::config->motion.kinematics),"Camera")
 {
 	setWeight(1);
 	defaultMaxSpeed();
+	takeSnapshot();
+}
+
+void HeadPointerMC::freezeMotion() {
+	for(unsigned int i=0; i<NumHeadJoints; i++)
+		headTargets[i]=headCmds[i].value;
+	dirty=false;
+}
+
+void HeadPointerMC::takeSnapshot() {
 	for(unsigned int i=0; i<NumHeadJoints; i++)
 		headTargets[i]=headCmds[i].value=state->outputs[HeadOffset+i];
+	dirty=true;
 }
 
 void HeadPointerMC::defaultMaxSpeed(float x/*=1*/) {
@@ -45,6 +58,8 @@ bool HeadPointerMC::lookAtPoint(float x, float y, float z) {
 
 	NEWMAT::ColumnVector poE=headkin.convertLink(0,headkin.get_dof())*Pobj;
 	poE=poE.SubMatrix(1,3,1,1);
+	//	float theta = acos(poE(3)/sqrt(poE(1)*poE(1)+poE(2)*poE(2)+poE(3)*poE(3)));
+	//	cout << "Computed:\n theta1: " << mathutils::rad2deg(theta) << " degrees\n";
 	NEWMAT::ColumnVector plE=Plink.SubMatrix(1,3,1,1);
 	float plE2=plE.SumSquare();
 	float plE_len=sqrt(plE2);
@@ -60,7 +75,11 @@ bool HeadPointerMC::lookAtPoint(float x, float y, float z) {
 
 	for(unsigned int i=0; i<NumHeadJoints; i++)
 		setJointValue(i,headkin.get_q(2+i));
-	return conv;
+
+	//	NEWMAT::ColumnVector poE2=headkin.convertLink(0,headkin.get_dof())*Pobj;
+	//	float theta2 = acos(poE2(3)/sqrt(poE2(1)*poE2(1)+poE2(2)*poE2(2)+poE2(3)*poE2(3)));
+	//	cout << " theta2: " << mathutils::rad2deg(theta2) << " degrees\n";
+	return isReachable(Pobj);
 }
 	
 bool HeadPointerMC::lookAtPoint(float x, float y, float z, float d) {
@@ -71,7 +90,8 @@ bool HeadPointerMC::lookAtPoint(float x, float y, float z, float d) {
 	NEWMAT::ColumnVector q=headkin.inv_kin_pos(Pobj,0,headkin.get_dof(),Plink,conv);
 	for(unsigned int i=0; i<NumHeadJoints; i++)
 		setJointValue(i,headkin.get_q(2+i));
-	return conv;
+	//	return conv;
+	return isReachable(Pobj);
 }
 	
 bool HeadPointerMC::lookInDirection(float x, float y, float z) {
@@ -82,9 +102,11 @@ bool HeadPointerMC::lookInDirection(float x, float y, float z) {
 	NEWMAT::ColumnVector q=headkin.inv_kin_pos(Pobj,0,headkin.get_dof(),Plink,conv);
 	for(unsigned int i=0; i<NumHeadJoints; i++)
 		setJointValue(i,headkin.get_q(2+i));
-	return conv;
+	//	return conv;
+	return isReachable(Pobj);
 }
 
+
 int HeadPointerMC::updateOutputs() {
 	int tmp=isDirty();
 	if(tmp || hold) {
@@ -125,9 +147,9 @@ int HeadPointerMC::updateOutputs() {
 int HeadPointerMC::isAlive() {
 	if(dirty || !targetReached)
 		return true;
-	if(targetReached && get_time()-targetTimestamp>timeout) { //prevents a conflicted HeadPointerMC's from fighting forever
-		if(getAutoPrune())
-			serr->printf("WARNING: HeadPointerMC timed out - possible joint conflict or out-of-range target\n");
+	if(targetReached && (!hold || get_time()-targetTimestamp>timeout)) { //prevents a conflicted HeadPointerMC's from fighting forever
+		if(get_time()-targetTimestamp>timeout && getAutoPrune())
+			serr->printf("WARNING: HeadPointerMC (mcid %d) timed out - possible joint conflict or out-of-range target\n",getID());
 		return false;
 	}
 	float maxdiff=0;
@@ -168,10 +190,10 @@ bool HeadPointerMC::ensureValidJoint(unsigned int& i) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.19 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.25 $
  * $State: Exp $
- * $Date: 2005/01/25 20:06:42 $
+ * $Date: 2006/08/31 21:42:02 $
  */
 
 
