@@ -1,16 +1,16 @@
 //-*-c++-*-
 #ifndef INCLUDED_HeadPointerMC_h
 #define INCLUDED_HeadPointerMC_h
-
 #include "MotionCommand.h"
 #include "OutputCmd.h"
 #include "Shared/RobotInfo.h"
+#include "Shared/mathutils.h"
 #include "roboop/robot.h"
 
 //! This class gives some quick and easy functions to point the head at things
 class HeadPointerMC : public MotionCommand {
 public:
-	//! Constructor, defaults to all joints to current value in ::state
+	//! Constructor, defaults to all joints to current value in ::state (i.e. calls takeSnapshot() automatically)
 	HeadPointerMC();
 	
 	//! Destructor
@@ -24,6 +24,17 @@ public:
 	virtual float getTolerance() { return tolerance; } //!< returns #tolerance
 	virtual void setTimeout(unsigned int delay) { timeout=delay; } //!< sets #timeout
 	virtual unsigned int getTimeout() { return timeout; } //!< returns #timeout
+	
+	//! sets the target to last sent commands, and dirty to false; essentially freezes motion in place
+	/*! This is very similar to takeSnapshot(), but will do the "right thing" (retain current position) when motion blending is involved.
+	 *  A status event will be generated if/when the joints reach the currently commanded position.
+	 *  Probably should use freezeMotion() if you want to stop a motion underway, but takeSnapshot() if you want to reset/intialize to the current joint positions. */
+	virtual void freezeMotion();
+	//! sets the target joint positions to current sensor values
+	/*! Similar to freezeMotion() when a motion is underway, but only if no other MotionCommands are using neck joints.
+	  *  A status event will @e not be generated unless a motion was already underway.
+	  *  Probably should use freezeMotion() if you want to stop a motion underway, but takeSnapshot() if you want to reset/intialize to the current joint positions. */
+	virtual void takeSnapshot();
 
 	//!@name Speed Control
 	
@@ -77,7 +88,7 @@ public:
 	}
 	
 	//! Centers the camera on a point in space, attempting to keep the camera as far away from the point as possible
-	/*! Point should be relative to the body reference frame (see ::BaseFrameOffset)
+	/*! Point should be relative to the body reference frame (see ::BaseFrameOffset).  Returns true if the target is reachable.
 	 *  @param x location in millimeters
 	 *  @param y location in millimeters
 	 *  @param z location in millimeters
@@ -86,7 +97,7 @@ public:
 	bool lookAtPoint(float x, float y, float z);
 	
 	//! Centers the camera on a point in space, attempting to move the camera @a d millimeters away from the point
-	/*! Point should be relative to the body reference frame (see ::BaseFrameOffset)
+	/*! Point should be relative to the body reference frame (see ::BaseFrameOffset).  Returns true if the target is reachable.
 	 *  @param x location in millimeters
 	 *  @param y location in millimeters
 	 *  @param z location in millimeters
@@ -94,15 +105,17 @@ public:
 	bool lookAtPoint(float x, float y, float z, float d);
 	
 	//! Points the camera in a given direction
-	/*! Vector should be relative to the body reference frame (see ::BaseFrameOffset)
+	/*! Vector should be relative to the body reference frame (see ::BaseFrameOffset).  Returns true if the target is reachable.
 	 *  @param x component of the direction vector
 	 *  @param y component of the direction vector
 	 *  @param z component of the direction vector */
 	bool lookInDirection(float x, float y, float z);
+
+
 	
 	//@}
 	
-	
+public:	
 	//!@name Inherited:
 	virtual int updateOutputs(); //!< Updates where the head is looking
 	virtual int isDirty() { return (dirty || !targetReached)?3:0; } //!< true if a change has been made since the last updateJointCmds() and we're active
@@ -111,6 +124,14 @@ public:
 	//@}
 
  protected:
+         //! checks if target point or direction is actually reachable
+        bool isReachable(const NEWMAT::ColumnVector& Pobj) {
+	  NEWMAT::ColumnVector poE=headkin.convertLink(0,headkin.get_dof())*Pobj;
+	  const float theta = mathutils::rad2deg(acos(poE(3)/sqrt(poE(1)*poE(1)+poE(2)*poE(2)+poE(3)*poE(3))));
+	  //	  cout << "theta: " << theta << " degrees\n";
+	  return theta < 5.0;
+	}
+
 	//! puts x in the range (-pi,pi)
 	static float normalizeAngle(float x) { return x-rint(x/(2*M_PI))*(2*M_PI); }
 	
@@ -152,10 +173,10 @@ public:
 	bool targetReached;                  //!< false if the head is still moving towards its target
 	unsigned int targetTimestamp;        //!< time at which the targetReached flag was set
 	unsigned int timeout;                //!< number of milliseconds to wait before giving up on a target that should have already been reached, a value of -1U will try forever
-  float headTargets[NumHeadJoints];    //!< stores the target value of each joint
+	float headTargets[NumHeadJoints];    //!< stores the target value of each joint
 	OutputCmd headCmds[NumHeadJoints];   //!< stores the last values we sent from updateOutputs
 	float maxSpeed[NumHeadJoints];       //!< initialized from Config::motion_config, but can be overridden by setMaxSpeed(); rad per frame
-	ROBOOP::Robot headkin;               //!< provides kinematics computations
+	ROBOOP::Robot headkin;               //!< provides kinematics computations, there's a small leak and safety issue here because ROBOOP::Robot contains pointers, and those pointers typically aren't freed because MotionCommand destructor isn't called when detaching shared region
 };
 
 /*! @file
@@ -163,10 +184,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.20 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.25 $
  * $State: Exp $
- * $Date: 2005/01/07 21:13:31 $
+ * $Date: 2006/09/26 19:29:40 $
  */
 
 #endif
