@@ -115,12 +115,26 @@ namespace ROBOOP {
 class Kinematics {
 public:
 	//!Constructor, pass the full path to the kinematics configuration file
-	Kinematics() : chains(), chainMaps() {
+	Kinematics()
+#ifdef THREADSAFE_KINEMATICS
+	: chains()
+#endif
+	{
 		init();
 	}
+	//!Copy constructor, everything is either update-before-use or static, copy is normal init
+	Kinematics(const Kinematics&)
+#ifdef THREADSAFE_KINEMATICS
+	: chains()
+#endif
+	{
+		init();
+	}
+	//!Assignment operator, everything is either update-before-use or static, assignment is no-op
+	Kinematics& operator=(const Kinematics&) { return *this; }
 
 	//!Destructor
-	virtual ~Kinematics() {}
+	virtual ~Kinematics();
 
 
 
@@ -189,21 +203,29 @@ public:
 
 
 
-	//! Find the leg which is in least contact with ground (as best we can anyway)
-	/*! This can be either based on gravity vector from accelerometer readings,
-	 *  or if that may be unreliable due to being in motion, we could do some basic
-	 *  balance modeling.
+	//! Calculate the leg heights along a given "down" vector (0 is level with base frame)
+	/*! This can be based on either the gravity vector from accelerometer readings,
+	 *  or if that may be unreliable due to being in motion, you could do some basic
+	 *  balance modeling and pass a predicted vector.  This uses the interest point database
+	 *  to find the lowest interest point for each leg
+	 *  @note on Aibo platforms, if packing accelerometer readings, don't forget to negate the "left" accelerometer! */
+	void calcLegHeights(const NEWMAT::ColumnVector& down, float heights[NumLegs]);
+	
+	//! Find the leg which is in least contact with ground
+	/*! @see calcLegHeights()
+	 *  @note on Aibo platforms, if packing accelerometer readings, don't forget to negate the "left" accelerometer!
 	 *  @return index of leg which is highest in reference to gravity vector */
 	LegOrder_t findUnusedLeg(const NEWMAT::ColumnVector& down);
 
-	//! Find the ground plane (by fitting plane to legs other the one specified by findUnusedLeg(down))
+	//! Find the ground plane by fitting a plane to the lowest 3 interest points
 	/*! This function merely calls the other version of calculateGroundPlane with the current
 	 *  gravity vector as the "down" vector.
 	 *  @return vector of the form @f$p_1x + p_2y + p_3z = p_4@f$, relative to the base frame */
 	NEWMAT::ReturnMatrix calculateGroundPlane();
 
-	//! Find the ground plane (by fitting plane to legs other the one specified by findUnusedLeg(down))
-	/*! @return vector of the form @f$p_1x + p_2y + p_3z = p_4@f$, relative to the base frame */
+	//! Find the ground plane by fitting a plane to the lowest 3 interest points
+	/*! @note on Aibo platforms, if packing accelerometer readings, don't forget to negate the "left" accelerometer!
+	 *  @return vector of the form @f$p_1x + p_2y + p_3z = p_4@f$, relative to the base frame */
 	NEWMAT::ReturnMatrix calculateGroundPlane(const NEWMAT::ColumnVector& down);
 
 	//! Find the point of intersection between a ray and a plane
@@ -256,6 +278,15 @@ protected:
 	//! Called by constructors to do basic setup - first call will read Config::motion_config::kinematics from disk, future initializes reuse static roconfig
 	void init();
 	
+	//! initializes static variables -- only call if not #staticsInited
+	static void initStatics();
+	
+	//! checks that statics have been initialized, and calls initStatics if they are missing
+	static void checkStatics() { if(!staticsInited) initStatics(); }
+	
+	//! called by init to allocate/initialize each of #chains
+	static ROBOOP::Robot* newChain(unsigned int chainIdx);
+	
 	//! Returns the location of a named point, relative to the link it is attached to
 	/*! @param[in]  name   the name of the interest point; varies by model, <a href="http://www.tekkotsu.org/Kinematics.html">see the diagrams</a> for your model.
 	 *  @param[out] c      on exit, chain index the IP is on
@@ -293,11 +324,20 @@ protected:
 		return true;
 	}
 
+	//! initially false, set to true after first Kinematics is initialized
+	static bool staticsInited;
+
+#ifdef THREADSAFE_KINEMATICS
 	//! A separate ROBOOP::Robot instantiation for each chain since ROBOOP package doesn't support branching chains (which would be rather difficult to implement well)
 	std::vector<ROBOOP::Robot*> chains;
+#else
+	//! A separate ROBOOP::Robot instantiation for each chain since ROBOOP package doesn't support branching chains (which would be rather difficult to implement well)
+	/*! static allocation solves problems with shared memory regions, but becomes thread-UNsafe... */
+	static std::vector<ROBOOP::Robot*> chains;
+#endif
 
 	//! holds mapping for each chain's links back to the tekkotsu outputs and reference frames they represent
-	std::vector< std::vector<unsigned int> > chainMaps;
+	static std::vector< std::vector<unsigned int> > chainMaps;
 	
 	//! Allows mapping from tekkotsu output index to chain and link indicies
 	struct JointMap {
@@ -319,7 +359,7 @@ protected:
 	};
 
 	//! holds mapping from tekkotsu output index to chain and link indicies
-	JointMap jointMaps[NumReferenceFrames];
+	static JointMap jointMaps[NumReferenceFrames];
 	
 	//! cache of the configuration of the robot for rapid initialization (so we don't have to re-read from disk)
 	static ROBOOP::Config * roconfig;
@@ -350,10 +390,10 @@ extern Kinematics * kine;
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.31 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.36 $
  * $State: Exp $
- * $Date: 2005/01/14 21:20:05 $
+ * $Date: 2006/09/16 17:32:39 $
  */
 
 #endif
