@@ -10,18 +10,27 @@ class MotionCommand;
 
 // LEDBitMask_t and associated constants are defined in RobotInfo.h
 
-//! Provides basic LED effects to anything that inherits from (recommended method for MotionCommands) or instantiates it (just in case you have reason to)
-/*! Provides a collection of special effects so that the code can be
+//! Provides basic LED effects via subclassing (e.g. LedMC) or embedding (e.g. EmergencyStopMC)
+/*! This implements a collection of LED special effects so that the code can be
  *  reused various places as feedback to to the user.
  *
+ * The basic effects provided are:
+ * - static brightness (set(), cset(), invert(), clear())
+ * - temporary setting (flash(), cflash())
+ * - pulsing/blinking (cycle(), ccycle())
+ * - numeric display (displayNumber(), displayPercent())
+ *
+ * The 'c' prefix on a function (cset(), cflash(), ccycle()) means it will call clear() before doing its own setting.  This is
+ * a quick way to replace whatever is currently displayed with whatever you are about to display.
+ * 
+ * A flash() will invert and override the current setting, so that it
+ * will "reset" after the flash.  Flashes change mid-range values to
+ * extremes to make the flash visible (ie not just (1-current)) Normal
+ * invert() will do simple inverses (just (1-current)), and doesn't change back automatically.
+ *
  * Cycling ("pulsing") and single-value setting are mutually exclusive;
  * one will cut off the other
  *
- * A flash will invert and override the current setting, so that it
- * will "reset" after the flash.  Flashes change mid-range values to
- * extremes to make the flash visible (ie not just (1-current)) Normal
- * invert will do simple inverses (just (1-current))
- *
  * getSetting() returns value of last set();
  * getValue() returns what's actually being returned to Motion at the moment
  *
@@ -33,6 +42,28 @@ class MotionCommand;
  * the lights" style of display instead of this pseudo-arabic display.
  * (look close to see that green bar LED at the top of the 210, which 
  * doesn't show up well in the camera image for some reason. )
+ * <img src="NumberLEDs-ERS7.jpg">
+ *
+ * The ERS-7 also has a "mode" which controls how certain face LEDs are
+ * interpreted.  By setting ERS7Info::LEDABModeOffset /
+ * ERS7Info::LEDABModeMask, you can switch between the modes -- a value
+ * of 0 is mode "A", and a value of 1 is mode "B".
+ * <img src="ERS7-LED-Modes.png">
+ *
+ * Things to note for the ERS-7:
+ * - There are many fewer LEDs than there are holes in the "grill" (the holes you see on the face are not the positions of the LEDs.
+ * - Each LED covers several holes.
+ * - Not all holes have LEDs behind them -- some areas of the face panel are always dark.
+ * - Some LEDs (12 and 13) control two symmetrical physical LEDs.
+ * - Some LEDs change color based on mode (0-1), some don't change at all (2-11), and some change position and color (12-13)
+ * - We don't have individual names for all of the LEDs on the panel.  Instead you base off of FaceLEDPanelOffset or FaceLEDPanelMask to address the LEDs, e.g., to set the <i>n</i>th led to <i>x</i>:
+ *   @code
+ *   LedEngine::set(FaceLEDPanelMask << n, x)
+ *   @endcode
+ *   or (if using other classes, e.g. PostureEngine)
+ *   @code
+ *   PostureEngine::setOutputCmd(FaceLEDPanelOffset + n, x)
+ *   @endcode
  */
 
 class LedEngine {
@@ -79,6 +110,9 @@ class LedEngine {
 	void cycle(LEDBitMask_t leds, unsigned int period, float amp, float offset=0, int phase=0);
 	//!sets all leds to 0.
 	void clear();
+	
+	//!adds @a ms to all flash times (may resurrect previously completed flashes)
+	void extendFlash(unsigned int ms);
 
 	//!returns the current setting of the LED specified by @a led_id (the value you passed in set())
 	float getSetting(LEDOffset_t led_id) { return infos[led_id-LEDOffset].value; }
@@ -177,10 +211,10 @@ class LedEngine {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.20 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.28 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2006/10/03 22:30:36 $
  */
 
 #endif
