@@ -39,11 +39,30 @@
  *  MMAccessor when it's actually a member of YourMotionCommand, this is because MMAccessor behaves as a
  *  'smart pointer', which overloads operator->() so it is fairly transparent to use.
  *
- *  See also the templated checkin(Ret_t ret) function for more examples of streamlined usage.
+ *  In some cases, you may wish to access a prunable motion, but may be unsure of whether the
+ *  motion is still alive.  If it has been pruned, the MC_ID is no longer valid, and will not provide
+ *  access to the motion.  Worse, however, is that enough new motions have been created that the
+ *  ID has been recycled and now refers to another, different, motion.
+ *
+ *  The solution to this requires two steps.  First, you must retain the SharedObject you used to
+ *  initially create the motion.  This is required because if the MotionManager prunes the motion,
+ *  it will dereference the memory region, and if there are no other references to the region, it
+ *  will be deallocated, destroying the data.  Second, you pass this SharedObject to the MMAccessor
+ *  constructor as shown:
+ *  @code
+ *  SharedObject<YourMC> yourmc;
+ *  // ... stuff ... if yourmc was added to MotionManager, it may or may not still be active
+ *  MMAccessor<YourMC> your_acc(*yourmc); // doesn't matter!
+ *  // your_acc now provides no-op access if not in MotionManager, checks it out if it is
+ *  @endcode
+ *  This guarantees safe access regardless to the current status of the motion.  (Note that you can
+ *  also just listen for the (EventBase::motmanEGID, MC_ID, EventBase::deactivateETID) event
+ *  to be notified when a motion is pruned... however, unless you still have a reference to
+ *  the SharedObject, you won't be able to access/reuse the motion after it was pruned)
  *
  *  MMAccessor is a small class, you may consider passing it around instead of a MotionManager::MC_ID
  *  if appropriate.  (Would be appropriate to avoid multiple checkin/outs in a row from different
- *  functions, but not as appropriate for storage and reuse of the same MMAccessor.
+ *  functions, but not as appropriate for storage and reuse of the same MMAccessor.)
  */
 template<class MC_t>
 class MMAccessor {
@@ -60,9 +79,14 @@ class MMAccessor {
 	}
 
 	//! constructor, allows objects to provide uniform access to MotionCommands, regardless of whether they are currently in the MotionManager
-	MMAccessor(MotionCommand * ptr) : mc_id(MotionManager::invalid_MC_ID), checkOutCnt(0), mcptr(ptr) {}
+	/*! if ckout is true (default parameter), will attempt to check out the motion if the motion reports it has a valid ID */
+	MMAccessor(MC_t & ptr, bool ckout=true) : mc_id(ptr.getID()), checkOutCnt(0), mcptr(&ptr) {
+		if(ckout && mc_id!=MotionManager::invalid_MC_ID)
+			checkout();
+	}
 
-	//! copy constructor - will reference the same mc_id - checkin/checkouts are independent between this and @a a; however, if @a a is checkout out, @c this will check itself out as well
+	//! copy constructor - will reference the same mc_id - checkin/checkouts are independent between this and @a a; however, if @a a is checked out, @c this will check itself out as well
+	/*! If the original was checked out, this will checkout as well (so #checkOutCnt will be 1) */
 	MMAccessor(const MMAccessor& a) : mc_id(a.mc_id), checkOutCnt(0), mcptr(a.mcptr) {
 		if(a.checkOutCnt>0)
 			checkout();
@@ -75,18 +99,22 @@ class MMAccessor {
 	}
 
 	//! allows assignment of MMAccessor's, similar to the copy constructor - the two MMAccessor's will control the same MotionCommand
+	/*! If the original was checked out, this will checkout as well (so #checkOutCnt will be 1) */
 	MMAccessor<MC_t> operator=(const MMAccessor<MC_t>& a) {
 		mc_id=a.mc_id;
 		mcptr=a.mcptr;
-		if(motman->isOwner(mc_id))
+		checkOutCnt=0;
+		if(a.checkOutCnt>0)
 			checkout();
 		return *this;
 	}
 	
 	//! So you can check out if not done by default (or you checked in already)
-	inline MC_t* checkout() {
-		if(mc_id!=MotionManager::invalid_MC_ID)
-			mcptr=static_cast<MC_t*>(motman->checkoutMotion(mc_id));
+	/*! @param throwOnNULL if true, indicates an exception should be thrown if the checked out motion is NULL (indicates #mc_id does not reference an active MC) */
+	inline MC_t* checkout(bool throwOnNULL=true) {
+		mcptr=static_cast<MC_t*>(motman->checkoutMotion(mc_id));
+		if(throwOnNULL && mcptr==NULL)
+			throw std::runtime_error("MMAccessor attempted to checkout an invalid MC_ID");
 		checkOutCnt++;
 		return mcptr;
 	}
@@ -98,7 +126,8 @@ class MMAccessor {
 	/*! Don't forget, you can also just limit the scope using extra { }'s */
 	inline void checkin() {
 		if(checkOutCnt>0) {
-			motman->checkinMotion(mc_id);
+			if(mc_id!=MotionManager::invalid_MC_ID)
+				motman->checkinMotion(mc_id);
 			checkOutCnt--;
 		}
 		if(checkOutCnt==0)
@@ -153,10 +182,10 @@ class MMAccessor {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.19 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2006/10/03 21:40:59 $
  */
 
 #endif
