@@ -7,7 +7,7 @@ using namespace std;
 
 void MotionCommand::postEvent(const EventBase& event) {
 	if(queue==NULL) {
-		erouter->postEvent(event.clone());
+		erouter->postEvent(event);
 	} else {
 		queue->encodeEvent(event);
 	}
@@ -20,9 +20,9 @@ void MotionCommand::postEvent(const EventBase& event) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2005/06/29 22:04:51 $
+ * $Date: 2006/09/11 23:05:11 $
  */
 
