@@ -4,6 +4,7 @@
 
 #include "Shared/RobotInfo.h"
 #include "MotionManagerMsg.h"
+#include "Shared/WorldState.h"
 #include "OutputCmd.h"
 #include <stddef.h>
 
@@ -12,13 +13,17 @@ class EventBase;
 
 //! The abstract base class for motions, provides common interface.  All motions should inherit from this
 /*! For instructions on how to create:
- * - <b>a new subclass</b> of MotionCommand, read on.  Also see the step-by-step
- *   <a href="../FirstMotionCommand.html">guide</a>
- * - <b>an instantiation</b> of a MotionCommand subclass, see MotionManager
+ * - <b>an instantiation</b> of an existing MotionCommand, see MotionManager
+ * - <b>a new subclass</b> of MotionCommand, read on.  Also see the step-by-step tutorials:
+ *   - <a href="../FirstMotionCommand.html">Tekkotsu's "First MotionCommand" Tutorial</a>
+ *   - <a href="http://www.cs.cmu.edu/~dst/Tekkotsu/Tutorial/motion.shtml">David Touretzky's Motion Commands chaper</a>
+ *   - <a href="http://www.cs.cmu.edu/afs/cs/academic/class/15494-s06/www/lectures/motion_commands.pdf">CMU's Cognitive Robotics slides</a>
  * 
  * To create a new type of motion, you'll want to subclass this.  You
  * don't need to do anything fancy, but just be sure to override the 3
- * abstract functions.
+ * abstract functions, updateOutputs(), isAlive(), and isDirty().
+ *
+ * There is a quick-start boilerplate included in the distribution: <a href="http://cvs.tekkotsu.org/cgi/viewcvs.cgi/Tekkotsu/project/templates/motioncommand.h?rev=HEAD&content-type=text/vnd.viewcvs-markup"><i>project</i><tt>/templates/motioncommand.h</tt></a>:
  *
  * When an output is set to a value, that output is held at that value
  * until it is set to a new value, even if the MotionCommand that set
@@ -41,21 +46,21 @@ class EventBase;
  *
  * Here is the cycle of calls made by MotionManager to your command:
  * -# shouldPrune() (by default, this will return !isAlive() iff #autoprune==true)
- * -# updateJointCmds() (assuming the MC wasn't pruned after the previous step)
+ * -# updateOutputs() (assuming the MC wasn't pruned after the previous step)
  * 
  * So, if you want to hold a joint at a value, each time your
- * updateJointCmds() function is called, you should tell the
+ * updateOutputs function is called, you should tell the
  * MotionManager to keep the joint there (using one of
  * MotionManager::setOutput()'s).  If you do not set a joint after a
- * call to updateJointCmds, the MotionManager will assume you are no
+ * call to updateOutputs, the MotionManager will assume you are no
  * longer using that joint and a lower priority MotionCommand may
  * inherit it.
  *
  * MotionCommands which generate events should use the inherited
- * postEvent() instead of trying to access a global ::erouter - the
+ * MotionCommand::postEvent() instead of trying to access a global ::erouter - the
  * inherited version will properly handle sending the events
- * regardless of the current context, but trying to access a
- * non-shared global like ::erouter could cause problems.
+ * regardless of the current process context, but trying to access a
+ * non-shared global like ::erouter could cause problems otherwise.
  *
  * @warning <b>Be careful what you call in MotionManager</b> \n
  * Some functions are marked MotionCommand-safe - this is another
@@ -116,7 +121,11 @@ public:
 	//        ******************
 
 	//! Constructor: Defaults to kStdPriority and autoprune==true
-	MotionCommand() : MotionManagerMsg(), queue(NULL), autoprune(true), started(false) {}
+	MotionCommand() : MotionManagerMsg(), queue(NULL), autoprune(true), started(false)
+#ifdef PLATFORM_APERIOS
+		, state()
+#endif
+	{ }
 	//! Destructor
 	virtual ~MotionCommand() {}
 	
@@ -141,6 +150,11 @@ public:
 	
 	//! only called from MMCombo during process setup, allows MotionCommands to send events
 	void setTranslator(EventTranslator * q) { queue=q; }
+	
+#ifdef PLATFORM_APERIOS
+	//! called by MotionManager each time a process checks out the motion, makes sure #state is set for the calling process
+	void setWorldState(WorldState* s) { state.cur=s; }
+#endif
 
 protected:
 	//! this utility function will probably be of use to a lot of MotionCommand's
@@ -181,7 +195,14 @@ protected:
 
 	int autoprune; //!< default true, autoprune setting, if this is true and isAlive() returns false, MotionManager will attempt to remove the MC automatically
 	bool started; //!< true if the MotionCommand is currently running (although it may be overridden by a higher priority MotionCommand)
-
+#ifdef PLATFORM_APERIOS
+	//! purposely shadows global ::state as a member of MotionCommand, so subclasses will be guaranteed to use the current process's instance instead of that of the process they were created in
+	struct StateRedirect {
+		WorldState * operator->() const { return cur==NULL ? WorldState::getCurrent() : cur; }
+		WorldState * cur;
+	} state; 
+#endif
+	
 private:
 	MotionCommand(const MotionCommand&); //!< don't call
 	MotionCommand& operator=(const MotionCommand&); //!< don't call
@@ -192,10 +213,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.19 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.23 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2006/10/04 03:14:56 $
  */
 
 #endif
