@@ -2,6 +2,14 @@
 #include "Shared/debuget.h"
 #include "Shared/WorldState.h"
 #include "Events/EventRouter.h"
+#include "Shared/StackTrace.h"
+#include "Shared/ProjectInterface.h"
+
+#ifndef PLATFORM_APERIOS
+#  include "IPC/MessageQueue.h"
+#  include "IPC/MessageReceiver.h"
+#  include "Shared/ProjectInterface.h"
+#endif
 
 #include "Shared/ERS210Info.h"
 #include "Shared/ERS220Info.h"
@@ -55,7 +63,7 @@ MotionManager::InitAccess(OSubject* subj) {
 #else //now PLATFORM_LOCAL
 
 void
-MotionManager::InitAccess(MessageQueueBase& mcbufq) {
+MotionManager::InitAccess(MessageQueueBase& mcbufq, Resource& behaviorLock) {
 	if(numAcc==MAX_ACCESS) {
 		printf("*** ERROR *** attempted to register more accessors with MotionManager than allowed by MAX_ACCESS\n");
 		return;
@@ -66,38 +74,58 @@ MotionManager::InitAccess(MessageQueueBase& mcbufq) {
 	//	cout << "numAcc is " << &numAcc << " from " << this << endl;
 	MMlock.lock(_MMaccID);
 	subjs[_MMaccID]=&mcbufq;
+	mcrecvs[_MMaccID]=new MessageReceiver(*subjs[_MMaccID],receivedMsg);
+	procLocks[_MMaccID]=&behaviorLock;
 	if(cmdlist.size()>0) //Shouldn't happen - busy wait in doAddMotion
 		cout << "*** WARNING *** MOTIONS ADDED BEFORE ALL INITACCESSED" << endl;
 	MMlock.unlock();
 }
 
+#endif //PLATFORM-specific initialization
+
 void
 MotionManager::RemoveAccess() {
+#ifndef PLATFORM_APERIOS
+	//kill the message receiver before we get the motion manager lock
+	// that way if there's a message pending, it can be processed instead of deadlocking
+	mcrecvs[_MMaccID]->finish();
+	delete mcrecvs[_MMaccID];
+	mcrecvs[_MMaccID]=NULL;
+#endif
+	
 	func_begin();
 	for(MC_ID mc_id=cmdlist.begin(); mc_id!=cmdlist.end(); mc_id=cmdlist.next(mc_id)) {
 		if(cmdlist[mc_id].rcr[_MMaccID]!=NULL) {
-			checkoutMotion(mc_id,true);
-			cmdlist[mc_id].rcr[_MMaccID]->RemoveReference();
-			cmdlist[mc_id].rcr[_MMaccID]=NULL;
-			bool found=false;
-			for(unsigned int i=0; i<numAcc; i++)
+			MotionCommand* mc=checkoutMotion(mc_id,true);
+			int found=0;
+			for(unsigned int i=0; i<numAcc; i++) {
 				if(cmdlist[mc_id].rcr[i]!=NULL) {
-					found=true;
-					break;
+					found++;
 				}
-			if(!found) {
-				cout << "Warning: dropping motion command " << mc_id << ", was active at shutdown (leaked?)" << endl;
-				push_free(mc_id);
-				//should we check in?  The lock isn't technically valid anymore...
-				//checkinMotion(mc_id);
-			} else
+			}
+			cout << "Warning: " << ProcessID::getIDStr() << " dropping motion command " << mc_id << ", was active at shutdown " << (mc->getAutoPrune()?"(was set for autoprune)":"(leaked?)") << endl;
+#ifdef PLATFORM_APERIOS
+			int refs=1;
+#else
+			int refs=cmdlist[mc_id].rcr[_MMaccID]->NumberOfLocalReference();
+#endif
+			if(refs>1)
+				cout << "Warning: " << ProcessID::getIDStr() << " still had " <<  refs-1 << " references to motion command " << mc_id << " as it was being dropped (these are now invalid)" << endl;
+			for(int i=0; i<refs; ++i)
+				cmdlist[mc_id].rcr[_MMaccID]->RemoveReference();
+			cmdlist[mc_id].rcr[_MMaccID]=NULL;
+			if(found==1) {
+				MC_ID p=cmdlist.prev(mc_id);
+				push_free(mc_id); //don't check in -- lock destructor will release the lock as the entry is destructed
+				mc_id=p;
+			} else {
 				checkinMotion(mc_id);
+			}
 		}
 	}
 	func_end();
 }
 
-#endif //PLATFORM-specific initialization
 
 MotionManager::~MotionManager() {
 	if(!cmdlist.empty()) {
@@ -269,7 +297,7 @@ MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const
  *  or a big massive function which doesn't pollute the namespace?  This is the latter, for
  *  better or worse. */
 void
-MotionManager::getOutputs(float outputs[NumFrames][NumOutputs]) {
+MotionManager::getOutputs(float outputs[][NumOutputs]) {
 	//	if(begin(id)!=end())
 	//if(state && state->buttons[LFrPawOffset]) cout << "getAngles..." << flush;
 	if(state==NULL) {
@@ -287,7 +315,7 @@ MotionManager::getOutputs(float outputs[NumFrames][NumOutputs]) {
 	func_begin();
 	//	if(begin(id)!=end())
 	//	cout << id << "..." << flush;
-	//	cout << "CHECKOUT..." << flush;
+	//cout << "CHECKOUT..." << flush;
 	for(uint output=0; output<NumOutputs; output++)
 		cmdstates[output].clear();
 
@@ -306,10 +334,11 @@ MotionManager::getOutputs(float outputs[NumFrames][NumOutputs]) {
 		if(state->pids[output][0]==0 && state->pids[output][1]==0 && state->pids[output][2]==0)
 			cmdSums[output]=state->outputs[output];
 
-	//	std::cout << "UPDATE..." << std::flush;
+	//std::cout << "UPDATE..." << std::flush;
 	std::list<MC_ID> unlocked;
 	for(MC_ID it=begin(); it!=end(); it=next(it)) // check out all the MotionCommands (only one at a time tho)
-		unlocked.push_back(it);
+		if(cmdlist[it].lastAccessor!=(accID_t)-1)
+			unlocked.push_back(it);
 	unsigned int lastProcessed=get_time();
 	while(unlocked.size()>0) { // keep cycling through all the locks we didn't get
 		for(std::list<MC_ID>::iterator it=unlocked.begin(); it!=unlocked.end(); ) {
@@ -319,13 +348,32 @@ MotionManager::getOutputs(float outputs[NumFrames][NumOutputs]) {
 			else {
 				// we got a lock
 				cur_cmd=*it;
-				if(mc->shouldPrune()) {
+				bool prune=true;
+				try {
+					prune=mc->shouldPrune();
+				} catch(const std::exception& ex) {
+					ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during MotionCommand prune test, will prune",&ex);
+				} catch(...) {
+					ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during MotionCommand prune test, will prune",NULL);
+				}
+				if(prune) {
 					cout << "Removing expired " << *it << " (autoprune)" << endl;
+					checkinMotion(*it); // release lock, done with motion (don't need to (and shouldn't) keep lock through the removeMotion())
+					//only the last process to receive the remove notification actually does the remove, and
+					//wouldn't be able to undo the thread portion of the lock made in this process
+					//so we have to take off our own lock here first.
 					removeMotion(*it);
-				} else
-					mc->updateOutputs(); // the MotionCommand should make calls to setOutput from within here
+				} else {
+					try {
+						mc->updateOutputs(); // the MotionCommand should make calls to setOutput from within here
+					} catch(const std::exception& ex) {
+						ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during MotionCommand updateOutputs",&ex);
+					} catch(...) {
+						ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during MotionCommand updateOutputs",NULL);
+					}
+					checkinMotion(*it); // release lock, done with motion
+				}
 				cur_cmd=invalid_MC_ID;
-				checkinMotion(*it); // release lock, done with motion
 				// remove id from list of unprocessed motioncommands
 				std::list<MC_ID>::iterator rem=it++;
 				unlocked.erase(rem);
@@ -378,15 +426,13 @@ MotionManager::getOutputs(float outputs[NumFrames][NumOutputs]) {
 			while(ent!=curstatelist.end() && alpha>0) {
 				OutputCmd curcmd;
 				float curp=curstatelist[ent].priority;
-				float curalpha=1; // curalpha is multiplicative sum of leftovers (weights between 0 and 1)
-				for(;curstatelist[ent].priority==curp; ent=curstatelist.next(ent)) {
+				float curalpha=1; // curalpha is cumulative product of leftovers (weights between 0 and 1)
+				for(;ent!=curstatelist.end() && curstatelist[ent].priority==curp; ent=curstatelist.next(ent)) {
 					//weighted average within priority level
 					float curweight=curstatelist[ent].frames[frame].weight;
-					ASSERT(curweight>=0,"negative output weights are illegal");
-					if(curweight<0) { //negative weights are illegal
-						cout << "weight=" << curweight << endl;
+					ASSERT(curweight>=0,"negative output weights are illegal, MC_ID="<<curstatelist[ent].mcid<<" joint="<<outputNames[output]<<" frame="<<frame<<" weight="<<curweight);
+					if(curweight<0) //negative weights are illegal
 						curweight=0;
-					}
 					curcmd.value+=curstatelist[ent].frames[frame].value*curweight;
 					curcmd.weight+=curweight;
 					if(curweight<1)
@@ -396,14 +442,15 @@ MotionManager::getOutputs(float outputs[NumFrames][NumOutputs]) {
 				}
 				if(curcmd.weight>0) {
 					//weighted average of priority levels
-					sumcmd.value+=curcmd.value/curcmd.weight*(1-curalpha);
-					sumcmd.weight+=(1-curalpha);
+					sumcmd.value+=curcmd.value/curcmd.weight*alpha*(1-curalpha);
+					sumcmd.weight+=alpha*(1-curalpha);
 					alpha*=curalpha;
 				}
 			}
-			if(sumcmd.weight>0) 
-				outputs[frame][output]=sumcmd.value/sumcmd.weight;
-			else //if zero weight, hold last value
+			if(sumcmd.weight>0) {
+				sumcmd.value/=sumcmd.weight;
+				outputs[frame][output]=sumcmd.value;
+			} else //if zero weight, hold last value
 				sumcmd.value=outputs[frame][output]=cmdSums[output];
 			if(frame==NumFrames-1)
 				cmds[output]=sumcmd;
@@ -428,7 +475,7 @@ MotionManager::getOutputs(float outputs[NumFrames][NumOutputs]) {
 			float tmpweight=0;
 			float curp=curstatelist[ent].priority;
 			float curalpha=1; // curalpha is multiplicative sum of leftovers (weights between 0 and 1)
-			for(;curstatelist[ent].priority==curp; ent=curstatelist.next(ent)) {
+			for(;ent!=curstatelist.end() && curstatelist[ent].priority==curp; ent=curstatelist.next(ent)) {
 				//weighted average within priority level
 				float curweight=curstatelist[ent].pid.weight;
 				ASSERT(curweight>=0,"negative PID weights are illegal")
@@ -489,8 +536,6 @@ MotionManager::updateWorldState() {
 		cout << "MotionManager::updateWorldState() - could not detect model" << endl;
 }
 
-#ifdef PLATFORM_APERIOS
-
 /*! This function handles the conversion from the Tekkotsu format (one
  *  regular IEEE float per parameter, to the OPEN-R format (which
  *  takes a specialized, reduced precision floating point number) This
@@ -518,10 +563,15 @@ MotionManager::updateWorldState() {
  *  setting PIDs at too high a frequency.
  */
 bool
+#ifdef PLATFORM_APERIOS
 MotionManager::updatePIDs(OPrimitiveID primIDs[NumOutputs]) {
+#else
+MotionManager::updatePIDs() {
+#endif
 	//cout << "updatePIDs " << endl;
 	bool dirty=!pidchanges.empty();
 	while(!pidchanges.empty()) {
+#ifdef PLATFORM_APERIOS
 		float gain[3];
 		word shift[3];
 
@@ -557,6 +607,7 @@ MotionManager::updatePIDs(OPrimitiveID primIDs[NumOutputs]) {
 		//cout << gain[0] << ' ' << shift[0] << "   " << gain[1] << ' ' << shift[1] << "   " << gain[2] << ' ' << shift[2] << endl;
 
 		OPENR::SetJointGain(primIDs[pidchanges.front().joint],(word)gain[0],(word)gain[1],(word)gain[2],shift[0],shift[1],shift[2]);
+#endif //PLATFORM_APERIOS or PLATFORM_LOCAL
 		for(uint i=0; i<3; i++)
 			state->pids[pidchanges.front().joint][i]=pidchanges.front().pids[i];
 		pidchanges.pop_front();
@@ -564,6 +615,7 @@ MotionManager::updatePIDs(OPrimitiveID primIDs[NumOutputs]) {
 	return dirty;
 }
 
+#ifdef PLATFORM_APERIOS
 void
 MotionManager::receivedMsg(const ONotifyEvent& event) {
 	//	cout << "receivedMsg..." << flush;
@@ -575,7 +627,24 @@ MotionManager::receivedMsg(const ONotifyEvent& event) {
 	//	cout << "receivedMsg-done" << endl;
 	func_end();
 }
-
+#else //PLATFORM_LOCAL
+bool
+MotionManager::receivedMsg(RCRegion* msg) {
+	try {
+		MarkScope l(*motman->procLocks[_MMaccID]);
+		/*MotionManagerMsg * mminfo = reinterpret_cast<MotionManagerMsg*>(msg->Base());
+		if(mminfo->creatorPID==ProcessID::getID())
+			return true; //don't process echos*/
+		motman->processMsg(msg);
+	} catch(const std::exception& ex) {
+		if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during MotionManagerMsg processing (MotionManager::receivedMsg)",&ex))
+			throw;
+	} catch(...) {
+		if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during MotionManagerMsg processing (MotionManager::receivedMsg)",NULL))
+			throw;
+	}
+	return true;
+}
 #endif //PLATFORM_APERIOS or PLATFORM_LOCAL
 
 void
@@ -586,46 +655,94 @@ MotionManager::processMsg(RCRegion * rcr) {
 		return;
 	}
 	func_begin();
-	//	cout << id << "..." << flush;
+	//cout << ProcessID::getID() << "..." << flush;
 	MotionManagerMsg * mminfo = reinterpret_cast<MotionManagerMsg*>(rcr->Base());
 	MC_ID mc_id=mminfo->mc_id;
+	if(mc_id==invalid_MC_ID) {
+		//cout << "add message for already-deleted motion" << endl;
+		func_end();
+		return;
+	}
 	switch(mminfo->type) {
 		case MotionManagerMsg::addMotion: {
-			//cout << "receiveMotion(): rcr->NumberOfReference()==" << rcr->NumberOfReference() << endl;
-			rcr->AddReference();
-			//cout << "receiveMotion()NOW: rcr->NumberOfReference()==" << rcr->NumberOfReference() << endl;
-			cmdlist[mc_id].rcr[_MMaccID]=rcr;
-			//should be able to do a nice dynamic cast instead of a static one
-			// but it gives NULL for some reason - i blame having to do the fork trick
-			//cout << "Adding mc_id=="<< mc_id << " (and dynamic_cast is still " << dynamic_cast<MotionCommand*>(mminfo) << ")" << endl;
-			cmdlist[mc_id].baseaddrs[_MMaccID]=static_cast<MotionCommand*>(mminfo);
-			cmdlist[mc_id].baseaddrs[_MMaccID]->DoStart();
-			erouter->postEvent(new EventBase(EventBase::motmanEGID,mc_id,EventBase::activateETID,0));
+			if(cmdlist[mc_id].rcr[_MMaccID]==NULL) {
+				//cout << "receiveMotion()NOW: rcr->NumberOfReference()==" << rcr->NumberOfReference() << endl;
+				cmdlist[mc_id].rcr[_MMaccID]=rcr;
+				//cout << "receiveMotion(): rcr->NumberOfReference()==" << rcr->NumberOfReference() << endl;
+				rcr->AddReference();
+				//should be able to do a nice dynamic cast instead of a static one
+				// but it gives NULL for some reason - i blame having to do the fork trick
+				//cout << "Adding mc_id=="<< mc_id << " (and dynamic_cast is still " << dynamic_cast<MotionCommand*>(mminfo) << ")" << endl;
+				cmdlist[mc_id].baseaddrs[_MMaccID]=static_cast<MotionCommand*>(mminfo);
+			} else {
+#ifdef PLATFORM_APERIOS
+				// this shouldn't happen on Aperios (no echos), but is normal elsewhere
+				cerr << "WARNING: MotionManager::processMsg addMotion for motion which was already added!" << endl;
+#else
+				ASSERT(cmdlist[mc_id].lastAccessor==(accID_t)-1 || cmdlist[mc_id].baseaddrs[_MMaccID]==static_cast<MotionCommand*>(mminfo),"Baseaddr changed!");
+#endif
+			}
+			if(ProcessID::getID()==ProcessID::MotionProcess && cmdlist[mc_id].lastAccessor!=(accID_t)-1) {
+				checkoutMotion(mc_id,true);
+				try {
+					cmdlist[mc_id].baseaddrs[_MMaccID]->DoStart();
+				} catch(const std::exception& ex) {
+					ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during MotionCommand DoStart()",&ex);
+				} catch(...) {
+					ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during MotionCommand DoStart()",NULL);
+				}
+				checkinMotion(mc_id);
+			}
 		} break;
 		case MotionManagerMsg::deleteMotion: {
 			//cout << "deleteMotion(): cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference()==" << cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference() << endl;
-			//cout << "deleting mc_id=="<<mc_id << endl;
-			if(cmdlist[mc_id].rcr[_MMaccID]==NULL)
-				cout << "WARNING: MotionManager attempted to delete a NULL motion! mc_id="<<mc_id<<" _MMaccID=" << _MMaccID << endl;
-			else {
-				checkoutMotion(mc_id,true);
-				cmdlist[mc_id].baseaddrs[_MMaccID]->DoStop();
-				erouter->postEvent(new EventBase(EventBase::motmanEGID,mc_id,EventBase::deactivateETID,0));
+			//cout << "deleting mc_id=="<<mc_id << "..." << flush;
+			ASSERT(cmdlist[mc_id].lastAccessor==(accID_t)-1,"delete motion message for motion command not marked for deletion");
+			if(cmdlist[mc_id].rcr[_MMaccID]==NULL) {
+#ifndef PLATFORM_APERIOS
+				// on non-aperios, we get an echo of the remove request, so don't report an error, just ignore it
+				if(mminfo->creatorPID!=ProcessID::getID()) {
+#endif
+					cout << "WARNING: MotionManager attempted to delete a NULL motion! mc_id="<<mc_id<<" process=" << ProcessID::getIDStr() << endl;
+					stacktrace::displayCurrentStackTrace();
+#ifndef PLATFORM_APERIOS
+				}
+#endif
+			} else {
+				cmdlist[mc_id].lock.lock(_MMaccID);
+				int found=0;
+				for(unsigned int i=0; i<numAcc; i++) {
+					if(cmdlist[mc_id].rcr[i]!=NULL) {
+						found++;
+					}
+				}
+				if(ProcessID::getID()==ProcessID::MotionProcess) {
+					// no need to check out, motion should already be marked inaccessible from original call to removeMotion (as asserted at beginning of deleteMotion case)
+					try {
+						convertMotion(mc_id)->DoStop();
+					} catch(const std::exception& ex) {
+						ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during MotionCommand DoStop()",&ex);
+					} catch(...) {
+						ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during MotionCommand DoStop()",NULL);
+					}
+					cmdlist[mc_id].lastAccessor=(accID_t)-1; // reset inaccessiblity
+				}
 				cmdlist[mc_id].rcr[_MMaccID]->RemoveReference();
 				cmdlist[mc_id].rcr[_MMaccID]=NULL;
-				bool found=false;
-				for(unsigned int i=0; i<numAcc; i++)
-					if(cmdlist[mc_id].rcr[i]!=NULL) {
-						found=true;
-						break;
-					}
-				if(!found) {
-					push_free(mc_id);
-					//should we check in?  The lock isn't technically valid anymore...
-					//checkinMotion(mc_id);
+				cmdlist[mc_id].baseaddrs[_MMaccID]=NULL;
+				if(found==1) {
+					push_free(mc_id); //don't unlock -- lock destructor will release the lock as the entry is destructed
 				} else {
-					cout << "Warning: motion command " << mc_id << " still has attachments after delete message received" << endl;
-					checkinMotion(mc_id);
+					cmdlist[mc_id].lock.unlock();
+				}
+				if(ProcessID::getID()==ProcessID::MainProcess) {
+					try {
+						erouter->postEvent(EventBase::motmanEGID,mc_id,EventBase::deactivateETID,0);
+					} catch(const std::exception& ex) {
+						ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during event posting",&ex);
+					} catch(...) {
+						ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during event posting",NULL);
+					}
 				}
 			}
 			//cout << "deleteMotion()NOW: cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference()==" << cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference() << endl;
@@ -633,7 +750,7 @@ MotionManager::processMsg(RCRegion * rcr) {
 		default:
 			printf("*** WARNING *** unknown MotionManager msg type received\n");
 	}
-	//	cout << "processMsg-done" << endl;
+	//cout << "processMsg-done" << endl;
 	func_end();
 }
 
@@ -657,15 +774,18 @@ MotionManager::doAddMotion(const SharedObjectBase& sm, bool autoprune, float pri
 	//	cout << id << "..." << flush;
 	for(MC_ID it=cmdlist.begin(); it!=cmdlist.end(); it=cmdlist.next(it)) {
 		if(cmdlist[it].baseaddrs[_MMaccID]==mc) {
-			cerr << "Warning: re-added motion command " << it << endl;
-			return it;
+			cerr << "Warning: adding motion command at " << mc << ", is already running in motion manager as MC_ID " << it << endl;
+			return func_end(it);
 		}
 	}
 	MC_ID mc_id = pop_free();
+	//cout << sm.getRegion()->ID().key << " holds " << mc_id << endl;
 	if(mc_id==cmdlist.end()) {
 		cout << "MotionManager::addMotion() - Out of room, could not add" << endl;
 		return func_end(cmdlist.end());
 	}
+	//cout << "setAdd(" << mc_id << ")" << endl;
+	mc->setAdd(mc_id);
 	cmdlist[mc_id].baseaddrs[_MMaccID]=mc;
 	cmdlist[mc_id].rcr[_MMaccID]=sm.getRegion();
 	//cout << "addMotion(): sm.getRegion()->NumberOfReference()==" << sm.getRegion()->NumberOfReference() << endl;
@@ -673,8 +793,14 @@ MotionManager::doAddMotion(const SharedObjectBase& sm, bool autoprune, float pri
 	//cout << "addMotion()NOW: sm.getRegion()->NumberOfReference()==" << sm.getRegion()->NumberOfReference() << endl;
 	cmdlist[mc_id].lastAccessor=_MMaccID;
 	cmdlist[mc_id].priority=priority;
-	//cout << "setAdd(" << mc_id << ")" << endl;
-	mc->setAdd(mc_id);
+	try {
+		erouter->postEvent(EventBase::motmanEGID,mc_id,EventBase::activateETID,0);
+	} catch(const std::exception& ex) {
+		ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during event posting",&ex);
+	} catch(...) {
+		ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during event posting",NULL);
+	}
+	
 #ifdef PLATFORM_APERIOS
 	OStatus err;
 	/*{
@@ -691,7 +817,13 @@ MotionManager::doAddMotion(const SharedObjectBase& sm, bool autoprune, float pri
 	err=subjs[_MMaccID]->NotifyObservers();
 	ASSERT(err==oSUCCESS,"*** ERROR MotionManager: NotifyObservers returned " << err);
 #else //PLATFORM_LOCAL
-	subjs[_MMaccID]->sendMessage(sm.getRegion());
+	try {
+		subjs[_MMaccID]->sendMessage(sm.getRegion());
+	} catch(const std::exception& ex) {
+		ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during message sending",&ex);
+	} catch(...) {
+		ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during message sending",NULL);
+	}
 #endif //PLATFORM check for IPC stuff
 	//	cout << "addMotion-done" << endl;
 	//cout << " - " << get_time() << endl;
@@ -701,8 +833,9 @@ MotionManager::doAddMotion(const SharedObjectBase& sm, bool autoprune, float pri
 MotionCommand *
 MotionManager::checkoutMotion(MC_ID mcid,bool block) {
 	//cout << "checkout..." << flush;
-	if(mcid>=MAX_MOTIONS) {
-		cout << "*** WARNING *** " << _MMaccID << " tried to access invalid mcid " << mcid << endl;
+	if(mcid>=MAX_MOTIONS || mcid==invalid_MC_ID) {
+		cout << "*** WARNING *** " << ProcessID::getIDStr() << " tried to access invalid mcid " << mcid << endl;
+		stacktrace::displayCurrentStackTrace();
 		return NULL;
 	}
 	if(block)
@@ -711,37 +844,91 @@ MotionManager::checkoutMotion(MC_ID mcid,bool block) {
 		if(!cmdlist[mcid].lock.try_lock(_MMaccID))
 			return NULL;
 	if(cmdlist[mcid].lastAccessor==(accID_t)-1) {
-		cout << "*** WARNING *** " << _MMaccID << " tried to access dead mcid " << mcid << endl;
+		cout << "*** WARNING *** " << ProcessID::getIDStr() << " tried to access dead mcid " << mcid << endl;
+		stacktrace::displayCurrentStackTrace();
 		cmdlist[mcid].lock.unlock();
 		return NULL;
 	}
 	//cout << "locked..." << endl;
-	MotionCommand * base = cmdlist[mcid].baseaddrs[_MMaccID];
+	//cout << "checkout-done..." << flush;
+	return convertMotion(mcid);
+}
+
+MotionCommand *
+MotionManager::convertMotion(MC_ID mc) {
+	MotionCommand * base = cmdlist[mc].baseaddrs[_MMaccID];
 	//	cout << "base=" << base << "..." << flush;
-	if(cmdlist[mcid].lastAccessor!=_MMaccID) {
+	if(cmdlist[mc].lastAccessor!=_MMaccID) {
 		//cout << "converting from " << MCRegistrar::getRaw(base) << "..." << flush;
 		//cout << "prev=" << accRegs[cmdlist[mcid].lastAccessor].getReg(base) << "..." << flush;
 		//		accRegs[id].convert(base);
 		//cout << "to=" << MCRegistrar::getRaw(base) << ", " << accRegs[cmdlist[mcid].lastAccessor].getReg(base) << endl;
-		cmdlist[mcid].lastAccessor=_MMaccID;
+		cmdlist[mc].lastAccessor=_MMaccID;
 	}
 	base->setTranslator(etrans);
-	//cout << "checkout-done..." << flush;
+#ifdef PLATFORM_APERIOS
+	base->setWorldState(state);
+#endif
 	return base;
 }
 
 void
 MotionManager::checkinMotion(MC_ID mcid) {
-	cmdlist[mcid].baseaddrs[_MMaccID]->setTranslator(NULL);
-	if(mcid!=invalid_MC_ID)
-		cmdlist[mcid].lock.unlock();
+	if(mcid>=MAX_MOTIONS || mcid==invalid_MC_ID)
+		return;
+	if(cmdlist[mcid].lock.get_lock_level()==1 && cmdlist[mcid].rcr[_MMaccID]!=NULL) { //about to release last lock (and region hasn't been removed)
+		MotionCommand * base = cmdlist[mcid].baseaddrs[_MMaccID];
+		base->setTranslator(NULL);
+#ifdef PLATFORM_APERIOS
+		base->setWorldState(NULL);
+#endif
+	}
+	cmdlist[mcid].lock.unlock();
 }
 
 void
 MotionManager::removeMotion(MC_ID mcid) {
-	if(mcid==invalid_MC_ID)
+	if(mcid>=MAX_MOTIONS || mcid==invalid_MC_ID)
 		return;
 	func_begin();
+	if(cmdlist[mcid].lastAccessor==(accID_t)-1) {
+		cout << "WARNING: removeMotion called for a motion which has already been removed mc_id="<<mcid<<" process=" << ProcessID::getIDStr() << endl;
+		stacktrace::displayCurrentStackTrace();
+		func_end();
+		return;
+	}
+	if(cmdlist[mcid].rcr[_MMaccID]==NULL) { 
+		cout << "WARNING: removeMotion called for a NULL motion! mc_id="<<mcid<<" process=" << ProcessID::getIDStr() << endl;
+		stacktrace::displayCurrentStackTrace();
+		func_end();
+		return;
+	}
+	cmdlist[mcid].lock.lock(_MMaccID);
+	if(ProcessID::getID()==ProcessID::MotionProcess) {
+		MotionCommand * mc=checkoutMotion(mcid,true);
+		try {
+			mc->DoStop();
+		} catch(const std::exception& ex) {
+			ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during MotionCommand DoStop()",&ex);
+		} catch(...) {
+			ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during MotionCommand DoStop()",NULL);
+		}
+		checkinMotion(mcid);
+	}
+	cmdlist[mcid].lastAccessor=(accID_t)-1;
+	cmdlist[mcid].rcr[_MMaccID]->RemoveReference();
+	cmdlist[mcid].rcr[_MMaccID]=NULL;
+	cmdlist[mcid].baseaddrs[_MMaccID]=NULL;
+	cmdlist[mcid].lock.unlock();
+	if(ProcessID::getID()==ProcessID::MainProcess) {
+		try {
+			erouter->postEvent(EventBase::motmanEGID,mcid,EventBase::deactivateETID,0);
+		} catch(const std::exception& ex) {
+			ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during event posting",&ex);
+		} catch(...) {
+			ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during event posting",NULL);
+		}
+	}
 #ifdef PLATFORM_APERIOS
 	MotionManagerMsg dmsg;
 	dmsg.setDelete(mcid);
@@ -749,18 +936,18 @@ MotionManager::removeMotion(MC_ID mcid) {
 	subjs[_MMaccID]->SetData(&dmsg,sizeof(dmsg));
 	subjs[_MMaccID]->NotifyObservers();
 #else //PLATFORM_LOCAL
+	// local will "echo" the message, so we'll do the actual remove when we get the echo
 	SharedObject<MotionManagerMsg> dmsg;
 	dmsg->setDelete(mcid);
 	//cout << "Remove at " << get_time() << flush;
-	subjs[_MMaccID]->sendMessage(dmsg.getRegion());
-#endif //PLATFORM check for IPC stuff
-	 //cout << " - " << get_time() << endl;
-	 //cout << "removeMotion(): cmdlist[mcid].rcr[_MMaccID]->NumberOfReference()==" << cmdlist[mcid].rcr[_MMaccID]->NumberOfReference() << endl;
-	if(cmdlist[mcid].rcr[_MMaccID]!=NULL) {
-		cmdlist[mcid].rcr[_MMaccID]->RemoveReference();
-		cmdlist[mcid].rcr[_MMaccID]=NULL;
+	try {
+		subjs[_MMaccID]->sendMessage(dmsg.getRegion());
+	} catch(const std::exception& ex) {
+		ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during message sending",&ex);
+	} catch(...) {
+		ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during message sending",NULL);
 	}
-	//cout << "removeMotion()NOW: cmdlist[mcid].rcr[_MMaccID]->NumberOfReference()==" << cmdlist[mcid].rcr[_MMaccID]->NumberOfReference() << endl;
+#endif //PLATFORM check for IPC stuff
 	func_end();
 }
 
@@ -858,10 +1045,10 @@ MotionManager::OutputState::OutputState(unsigned int /*out*/, float pri, MC_ID m
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.43 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.61 $
  * $State: Exp $
- * $Date: 2005/06/29 22:04:51 $
+ * $Date: 2006/09/25 23:30:16 $
  */
 
 
