@@ -18,51 +18,62 @@
 #  include <OPENR/ObjcommEvent.h>
 #  include <OPENR/OObject.h>
 #else //PLATFORM_LOCAL
-#  include "IPC/MessageQueue.h"
+class MessageQueueBase;
+class MessageReceiver;
 #endif
 
 class EventTranslator;
 
-//! The purpose of this class is to provide mutually exclusive access to the MotionCommands and simplify their sharing between memory spaces
-/*! Since MotionObject and MainObject run as separate processes, they
+//! The purpose of this class is to repeatedly compute the final set of joint angles for the robot, managing a set of (possibly conflicting) MotionCommands
+/*! Since Main and Motion run as separate processes, they
  *  could potentially try to access the same motion command at the
  *  same time, leading to unpredictable behavior.  The MotionManager
- *  enforces a set of locks to solve this.
+ *  enforces a set of locks to serialize access to the MotionCommands.
+ *  Although you could call checkoutMotion() and checkinMotion() directly,
+ *  it is instead recommended to use MMAccessor to automatically handle
+ *  casting and checkin for you.
  *
- *  The other problem is that we are sharing between processes.
- *  MotionManager will do what's necessary to distribute new
- *  MotionCommand's to all the processes (currently just MainObj and
- *  MotoObj)\n You should be able to create and add a new motion in
- *  one line:
+ *  The other problem is that we are sharing the memory holding MotionCommands between processes.
+ *  MotionManager will do the necessary magic behind the scenes to distribute new
+ *  MotionCommands to all the involved processes (currently just Main and
+ *  Motion)\n You can create and add a new motion in one line:
  *
  *  @code
- *  motman->addMotion( SharedObject<YourMC>([arg1,...]) , autoprune [, priority ]);
+ *  // type A: prunable motions are automatically removed when completed:
+ *  motman->addPrunableMotion( SharedObject<YourMC>([arg1,...]) [, priority ] );
+ *
+ *  // type B: persistent motions are removed only when you explicitly request it:
+ *  MC_ID id = motman->addPersistentMotion( SharedObject<YourMC>([arg1,...]) [, priority ] );
+ *  // then later: motman->removeMotion(id);
  *  @endcode
  *  
- *  But if you want to do some more initializations not handled by the
+ *  If you want to do some more initializations not handled by the MotionCommand's
  *  constructor (the @p arg1, @p arg2, ...  params) then you would
  *  want to do something like the following:
  *  
  *  @code
- *  SharedObject<YourMC> tmpvar([arg1,[arg2,...]]);
- *  tmpvar->cmd1();
- *  tmpvar->cmd2();
+ *  SharedObject<YourMC> yourmc([arg1,[arg2,...]]);
+ *  yourmc->cmd1();
+ *  yourmc->cmd2();
  *  //...
- *  motman->addPrunableMotion(tmpvar [, ...]); //or addPersistentMotion(...)
+ *  motman->addPrunableMotion(yourmc [, ...]); //or addPersistentMotion(...)
  *  @endcode
  *
- *  Notice that tmpvar is of type SharedObject, but you're calling @c
- *  YourMC functions on it...  SharedObject is a "smart pointer" which
+ *  Notice that @c yourmc is actually of type SharedObject, but you're calling @c
+ *  YourMC's functions on it through the '->' operator...  SharedObject is a "smart pointer" which
  *  will pass your function calls on to the underlying templated type.
  *  Isn't C++ great? :)
  *
- *  @warning Once the MotionCommand has been added you must check it
- *  out to modify it or risk concurrent access problems.
- *
- *  @see MotionCommand for information on creating new motion primitives.
+ *  @warning Once the MotionCommand has been added, you must check it
+ *  out to make any future modifications it or risk concurrent access problems.
+ *  In other words, you should @e not keep the SharedObject and continue
+ *  to access the motion through that unless you know the motion is not active
+ *  in the MotionManager.  Instead, always use a MMAccessor.
  *
  *  @see MMAccessor for information on accessing motions after you've
- *  added them to MotionManager.
+ *  added them to MotionManager, or if it @e may be active in the MotionManager.
+ *
+ *  @see MotionCommand for information on creating new motion primitives.
  */
 class MotionManager {
 public:
@@ -92,9 +103,10 @@ public:
 	void InitAccess(OSubject* subj);            //!< @b LOCKS @b MotionManager Everyone who is planning to use the MotionManager needs to call this before they access it or suffer a horrible fate
 	void receivedMsg(const ONotifyEvent& event); //!< @b LOCKS @b MotionManager This gets called by an OObject when it receives a message from one of the other OObject's MotionManagerComm Subject
 #else
-	void InitAccess(MessageQueueBase& mcbufq); //!< @b LOCKS @b MotionManager Everyone who is planning to use the MotionManager needs to call this before they access it or suffer a horrible fate
-	void RemoveAccess(); //!< needed in order to dereference shared memory regions before shutting down
+	void InitAccess(MessageQueueBase& mcbufq, Resource& behaviorLock); //!< @b LOCKS @b MotionManager Everyone who is planning to use the MotionManager needs to call this before they access it or suffer a horrible fate
+	static bool receivedMsg(RCRegion* msg); //!< called with incoming messages, will pass non-echos to processMsg()
 #endif
+	void RemoveAccess(); //!< needed in order to dereference shared memory regions before shutting down
 	static void setTranslator(EventTranslator* et) {etrans=et;} //!< sets #etrans, should be called before any events can be sent
 	void processMsg(RCRegion* region); //!< @b LOCKS @b MotionManager This gets called by receivedMsg when under Aperios, or directly if you already have an RCRegion
 	~MotionManager(); //!<destructor
@@ -143,10 +155,12 @@ public:
 	//@}
 
 	//@{
-	void getOutputs(float outputs[NumFrames][NumOutputs]);  //!< @b LOCKS @b MotionManager called by MotionObject to fill in the output values for the next ::NumFrames frames (only MotoObj should call this...)
+	void getOutputs(float outputs[][NumOutputs]);  //!< @b LOCKS @b MotionManager called by MotionObject to fill in the output values for the next ::NumFrames frames (only MotoObj should call this...)
 	void updateWorldState();                                //!< call this when you want MotionManager to set the WorldState to reflect what things should be for unsensed outputs (LEDs, ears) (only MotoObj should be calling this...)
 #ifdef PLATFORM_APERIOS
 	bool updatePIDs(OPrimitiveID primIDs[NumOutputs]);      //!< call this when you want MotionManager to update modified PID values, returns true if changes made (only MotoObj should be calling this...), see PIDMC for general PID documentation
+#else
+	bool updatePIDs();      //!< call this when you want MotionManager to update modified PID values, returns true if changes made (only MotoObj should be calling this...), see PIDMC for general PID documentation
 #endif
 	//@}
 
@@ -172,6 +186,8 @@ public:
 protected:
 	//!does the actual work of adding a motion
 	MC_ID doAddMotion(const SharedObjectBase& sm, bool autoprune, float priority);
+	//! sets up a motion command to be accessed by the current process
+	MotionCommand* convertMotion(MC_ID mc);
 	
 	//! used to request pids for a given joint
 	struct PIDUpdate {
@@ -234,6 +250,8 @@ protected:
 #else //PLATFORM_LOCAL
 	//!Storage of each process's attachment of the message queue, used to internally transmit sound buffers to SoundPlay
 	MessageQueueBase * subjs[MAX_ACCESS];
+	MessageReceiver * mcrecvs[MAX_ACCESS];
+	Resource* procLocks[MAX_ACCESS];
 #endif
 
 	static int _MMaccID;          //!<Stores the accessor for the current process
@@ -252,10 +270,10 @@ extern MotionManager * motman;
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.27 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.37 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2006/10/03 22:28:15 $
  */
 
 #endif
