@@ -1,4 +1,5 @@
-#include "MotionSequenceMC.h"
+#include "MotionSequenceEngine.h"
+#include "DynamicMotionSequence.h"
 #include "Shared/get_time.h"
 #include "Shared/WorldState.h"
 #include "Shared/Config.h"
@@ -83,12 +84,12 @@ unsigned int MotionSequenceEngine::getBinSize() const {
 	return used+1;
 }
 
-unsigned int MotionSequenceEngine::LoadBuffer(const char buf[], unsigned int len) {
+unsigned int MotionSequenceEngine::loadBuffer(const char buf[], unsigned int len) {
 	unsigned int origlen=len;
 	if(strncmp("#POS",buf,4)==0) {
 		// allow inlined loading of posture files
 		PostureEngine pose;
-		unsigned int used=pose.LoadBuffer(buf,len);
+		unsigned int used=pose.loadBuffer(buf,len);
 		if(used!=0)
 			setPose(pose);
 		return used;
@@ -139,13 +140,13 @@ unsigned int MotionSequenceEngine::LoadBuffer(const char buf[], unsigned int len
 		char arg1[arglen];
 		char arg2[arglen];
 		written=readWord(buf,&buf[len],command,cmdlen);
-		if(!ChkAdvance(written,&buf,&len,"*** ERROR MotionSequenceEngine load corrupted - line %d\n",linenum)) return 0;
+		if(!checkInc(written,buf,len,"*** ERROR MotionSequenceEngine load corrupted - line %d\n",linenum)) return 0;
 		written=readWord(buf,&buf[len],arg1,arglen);
 		if(written>0)
-			if(!ChkAdvance(written,&buf,&len,"*** ERROR MotionSequenceEngine load corrupted - line %d\n",linenum)) return 0;
+			if(!checkInc(written,buf,len,"*** ERROR MotionSequenceEngine load corrupted - line %d\n",linenum)) return 0;
 		written=readWord(buf,&buf[len],arg2,arglen);
 		if(written!=0)
-			if(!ChkAdvance(written,&buf,&len,"*** ERROR MotionSequenceEngine load corrupted - line %d\n",linenum)) return 0;
+			if(!checkInc(written,buf,len,"*** ERROR MotionSequenceEngine load corrupted - line %d\n",linenum)) return 0;
 		for(;len>0 && *buf!='\n' && *buf!='\r';buf++,len--) {}
 		if(*buf=='\n') { //in case of \r\n
 			buf++;
@@ -168,27 +169,47 @@ unsigned int MotionSequenceEngine::LoadBuffer(const char buf[], unsigned int len
 			} else {
 				setTime(newtime);
 			}
-		} else if(strcasecmp(command,"load")==0) {
+		} else if(strcasecmp(command,"load")==0 || strcasecmp(command,"overlay")==0) {
 			PostureEngine pose;
-			if(pose.LoadFile(arg1)!=0) {
+			if(pose.loadFile(arg1)!=0) {
+				// it's a posture file
 				setPose(pose);
-			} else
-				cout << "*** WARNING could not read file " << arg1 << " for load - line " << linenum << endl;
-		} else if(strcasecmp(command,"overlay")==0) {
-			PostureEngine pose;
-			if(pose.LoadFile(arg1)!=0)
-				overlayPose(pose);
-			else
+			} else if(overlayMotion(arg1)!=0) {
+				// it's a motionsequence file (conditional test did the overlay)
+			} else {
+				// unknown file, give warning
 				cout << "*** WARNING could not read file " << arg1 << " for overlay - line " << linenum << endl;
+			}
+		} else if(strcasecmp(command,"loadExplicit")==0) {
+			PostureEngine pose;
+			if(pose.loadFile(arg1)!=0) {
+				setExplicitPose(pose);
+			} else
+				cout << "*** WARNING could not read file " << arg1 << " for load (loadExplicit only accepts posture files) - line " << linenum << endl;
 		} else if(strcasecmp(command,"degrees")==0) {
 			setSaveDegrees();
 		} else if(strcasecmp(command,"radians")==0) {
 			setSaveRadians();
 		} else {
 			lastOutputIdx=getOutputIndex(command,lastOutputIdx+1);
-			if(lastOutputIdx==NumOutputs)
+			bool found = (lastOutputIdx!=NumOutputs);
+			unsigned int lidx=lastOutputIdx,ridx=NumOutputs;
+			if(!found) { // base name not found
+				// try symmetric left/right versions
+				char tname[cmdlen+1];
+				strncpy(tname+1,command,cmdlen);
+				tname[0]='L';
+				lidx=getOutputIndex(tname,lastOutputIdx+1);
+				if(lidx!=NumOutputs) {
+					tname[0]='R';
+					ridx=getOutputIndex(tname,lidx+1);
+					if(ridx!=NumOutputs)
+						found=true;
+				}
+			}
+			if (!found) {
 				cout << "*** WARNING " << command << " is not a valid joint on this model." << endl;
-			else {
+			} else {
 				char* used;
 				double value=strtod(arg1,&used), weight=1;
 				if(*used!='\0')
@@ -197,11 +218,19 @@ unsigned int MotionSequenceEngine::LoadBuffer(const char buf[], unsigned int len
 					if(arg2[0]!='\0') {
 						weight=strtod(arg2,&used);
 						if(*used!='\0') {
-							cout << "*** WARNING illegal weight argument: " << arg2 << " - line " << linenum << endl;
-							weight=1;
+							 cout << "*** WARNING illegal weight argument: " << arg2 << " - line " << linenum << endl;
+							 weight=1;
 						}
 					}
-					setOutputCmd(lastOutputIdx,OutputCmd(value*loadSaveMode,weight));
+					if(lastOutputIdx!=NumOutputs) {
+						// found exact match earlier
+						setOutputCmd(lastOutputIdx,OutputCmd(value*loadSaveMode,weight));
+					} else {
+						// found symmetric matches earlier
+						setOutputCmd(lidx,OutputCmd(value*loadSaveMode,weight));
+						setOutputCmd(ridx,OutputCmd(value*loadSaveMode,weight));
+						lastOutputIdx=ridx;
+					}
 				}
 			}
 		}
@@ -213,16 +242,16 @@ unsigned int MotionSequenceEngine::LoadBuffer(const char buf[], unsigned int len
 	return origlen-len;
 }
 
-unsigned int MotionSequenceEngine::SaveBuffer(char buf[], unsigned int len) const {
+unsigned int MotionSequenceEngine::saveBuffer(char buf[], unsigned int len) const {
 	//std::cout << "SAVEBUFFER..." << std::flush;
 	unsigned int origlen=len;
 	int written=snprintf(buf,len,"#MSq\n");
-	if(!ChkAdvance(written,(const char**)&buf,&len,"*** ERROR MotionSequenceEngine save failed on header\n")) return 0;	if(len==0 || len>origlen) {
+	if(!checkInc(written,buf,len,"*** ERROR MotionSequenceEngine save failed on header\n")) return 0;	if(len==0 || len>origlen) {
 		cout << "*** ERROR MotionSequenceEngine save overflow on header" << endl;
 		return 0;
 	}
 	written=snprintf(buf,len,isSaveRadians()?"radians\n":"degrees\n");
-	if(!ChkAdvance(written,(const char**)&buf,&len,"*** ERROR MotionSequenceEngine save failed on mode\n")) return 0;	if(len==0 || len>origlen) {
+	if(!checkInc(written,buf,len,"*** ERROR MotionSequenceEngine save failed on mode\n")) return 0;	if(len==0 || len>origlen) {
 		cout << "*** ERROR MotionSequenceEngine save overflow" << endl;
 		return 0;
 	}
@@ -237,7 +266,7 @@ unsigned int MotionSequenceEngine::SaveBuffer(char buf[], unsigned int len) cons
 	}
 	if(hasInitialFrame) {
 		written=snprintf(buf,len,"setTime\t0\n");
-		if(!ChkAdvance(written,(const char**)&buf,&len,"*** ERROR MotionSequenceEngine save failed on initial frame spec\n")) return 0;
+		if(!checkInc(written,buf,len,"*** ERROR MotionSequenceEngine save failed on initial frame spec\n")) return 0;
 	}
 	while(t!=-1U) {
 		//std::cout << "t="<<t<<"..."<<std::endl;
@@ -247,10 +276,10 @@ unsigned int MotionSequenceEngine::SaveBuffer(char buf[], unsigned int len) cons
 			if((t!=0 || getKeyFrame(tprevs[i]).cmd.weight!=0) && getKeyFrame(tprevs[i]).starttime==t) {
 				if(getKeyFrame(tprevs[i]).cmd.weight==1) {
 					written=snprintf(buf,len,"%s\t%g\n",outputNames[i],getKeyFrame(tprevs[i]).cmd.value/loadSaveMode);
-					if(!ChkAdvance(written,(const char**)&buf,&len,"*** ERROR MotionSequenceEngine save failed\n")) return 0;
+					if(!checkInc(written,buf,len,"*** ERROR MotionSequenceEngine save failed\n")) return 0;
 				} else {
 					written=snprintf(buf,len,"%s\t%g\t%g\n",outputNames[i],getKeyFrame(tprevs[i]).cmd.value/loadSaveMode,getKeyFrame(tprevs[i]).cmd.weight);
-					if(!ChkAdvance(written,(const char**)&buf,&len,"*** ERROR MotionSequenceEngine save failed\n")) return 0;
+					if(!checkInc(written,buf,len,"*** ERROR MotionSequenceEngine save failed\n")) return 0;
 				}
 				if(len==0 || len>origlen) {
 					cout << "*** ERROR MotionSequenceEngine save overflow" << endl;
@@ -262,7 +291,7 @@ unsigned int MotionSequenceEngine::SaveBuffer(char buf[], unsigned int len) cons
 		t=setNextFrameTime(tprevs,tnexts);
 		if(t!=-1U) {
 			written=snprintf(buf,len,"delay\t%d\n",t-last);
-			if(!ChkAdvance(written,(const char**)&buf,&len,"*** ERROR MotionSequenceEngine save failed\n")) return 0;
+			if(!checkInc(written,buf,len,"*** ERROR MotionSequenceEngine save failed\n")) return 0;
 			if(len==0 || len>origlen) {
 				cout << "*** ERROR MotionSequenceEngine save overflow" << endl;
 				return 0;
@@ -270,7 +299,7 @@ unsigned int MotionSequenceEngine::SaveBuffer(char buf[], unsigned int len) cons
 		}
 	}
 	written=snprintf(buf,len,"#END\n");
-	if(!ChkAdvance(written,(const char**)&buf,&len,"*** ERROR MotionSequenceEngine save failed on #END\n")) return 0;
+	if(!checkInc(written,buf,len,"*** ERROR MotionSequenceEngine save failed on #END\n")) return 0;
 	if(len==0 || len>origlen) {
 		cout << "*** ERROR MotionSequenceEngine save overflow on #END" << endl;
 		return 0;
@@ -279,17 +308,23 @@ unsigned int MotionSequenceEngine::SaveBuffer(char buf[], unsigned int len) cons
 	cout << "SAVE-done!" << endl;
 }
 
-unsigned int MotionSequenceEngine::LoadFile(const char filename[]) {
-	return LoadSave::LoadFile(config->motion.makePath(filename).c_str());
+unsigned int MotionSequenceEngine::loadFile(const char filename[]) {
+	return LoadSave::loadFile(config->motion.makePath(filename).c_str());
 }
-unsigned int MotionSequenceEngine::SaveFile(const char filename[]) const {
-	return LoadSave::SaveFile(config->motion.makePath(filename).c_str());
+unsigned int MotionSequenceEngine::saveFile(const char filename[]) const {
+	return LoadSave::saveFile(config->motion.makePath(filename).c_str());
 }
 
 void MotionSequenceEngine::setTime(unsigned int x) {
 	playtime=x;
-	for(unsigned int i=0; i<NumOutputs; i++)
-		setRange(x,prevs[i],nexts[i]);
+	WorldState * st=WorldState::getCurrent();
+	for(unsigned int i=0; i<NumOutputs; i++) {
+		if(setRange(x,prevs[i],nexts[i])) {
+			OutputCmd& cmd=getKeyFrame((playspeed<0)?nexts[i]:prevs[i]).cmd;
+			if(cmd.weight<=0)
+				cmd.value=st->outputs[i];
+		}
+	}
 }
 
 void MotionSequenceEngine::setOutputCmd(unsigned int i, const OutputCmd& cmd) {
@@ -316,13 +351,24 @@ void MotionSequenceEngine::setOutputCmd(unsigned int i, const OutputCmd& cmd) {
 		prevs[i]=x;
 //		cout << "set " << i << ' ' << outputNames[i] << ' ' << cur.cmd.value << ' ' << cur.cmd.weight << ' ' << cur.starttime << " state: " << starts[i] <<' '<< prevs[i] <<' '<< prev_m.next <<' '<< nexts[i] << " new: " << cur.prev << ' ' << x << ' ' << cur.next << endl;
 	}
+	curstamps[i]=-1U;
 }
 
 void MotionSequenceEngine::setPose(const PostureEngine& pose) {
+	for(unsigned int i=0; i<NumOutputs; i++)
+		if(pose.getOutputCmd(i).weight>0)
+			setOutputCmd(i,pose.getOutputCmd(i));
+}
+
+void MotionSequenceEngine::setExplicitPose(const PostureEngine& pose) {
 	for(unsigned int i=0; i<NumOutputs; i++)
 		setOutputCmd(i,pose.getOutputCmd(i));
 }
 
+void MotionSequenceEngine::overlayPose(const PostureEngine& pose) {
+	setPose(pose);
+}
+
 PostureEngine MotionSequenceEngine::getPose() {
 	PostureEngine pose;
 	getPose(pose);
@@ -334,22 +380,84 @@ void MotionSequenceEngine::getPose(PostureEngine& pose) {
 		pose.setOutputCmd(i,getOutputCmd(i));
 }
 
-void MotionSequenceEngine::overlayPose(const PostureEngine& pose) {
-	for(unsigned int i=0; i<NumOutputs; i++)
-		if(pose.getOutputCmd(i).weight>0)
-			setOutputCmd(i,pose.getOutputCmd(i));
+unsigned int MotionSequenceEngine::overlayMotion(const std::string& msFile) {
+	DynamicMotionSequence ms;
+	if(ms.loadFile(msFile.c_str())==0)
+		return 0;
+	overlayMotion(ms);
+	return ms.getEndTime();
+}
+
+/*! @todo should better handle conflicts with keyframes in original motion
+ *  
+ *  This is not a particularly well implemented function -- it will interleave
+ *  @a ms's keyframes with any pre-existing ones, but will clobber frames which
+ *  coincide with @a ms's own.  Probably will not give the desired effect when
+ *  the motion is actually overlaying something, but it will work for basic
+ *  usage cases. */
+void MotionSequenceEngine::overlayMotion(const MotionSequenceEngine& ms) {
+	//merge keyframes for each output, advance playhead by ms.endtime at the end
+	for(unsigned int i=0; i<NumOutputs; i++) {
+		//cout << "Processing " << outputNames[i] << ":" << endl;
+		Move_idx_t myPrevIdx=prevs[i];
+		unsigned int myPrevTime=getKeyFrame(prevs[i]).starttime;
+		Move_idx_t myNextIdx=getKeyFrame(myPrevIdx).next;
+		unsigned int myNextTime=-1U;
+		if(myNextIdx!=invalid_move)
+			myNextTime=getKeyFrame(myNextIdx).starttime;
+		for(Move_idx_t curOtherIdx=ms.starts[i]; curOtherIdx!=invalid_move; curOtherIdx=ms.getKeyFrame(curOtherIdx).next) {
+			const Move& curOther=ms.getKeyFrame(curOtherIdx);
+			while(myNextTime <= curOther.starttime+getTime()) {
+				//cout << "Advancing to " << myNextTime << endl;
+				myPrevIdx=myNextIdx;
+				myPrevTime=myNextTime;
+				myNextIdx=getKeyFrame(myPrevIdx).next;
+				myNextTime= (myNextIdx==invalid_move ? -1U : getKeyFrame(myNextIdx).starttime);
+			}
+			if(curOther.cmd.weight > 0) {
+				if(curOther.starttime+getTime() == myPrevTime) {
+					//replace current 'prev'
+					//cout << "replacing frame " << myPrevIdx << " at " << myPrevTime << endl;
+					getKeyFrame(myPrevIdx).cmd=curOther.cmd;
+				} else {
+					//insert new keyframe between 'prev' and 'next'
+					Move_idx_t insIdx=newKeyFrame();
+					//cout << "adding new frame at " << curOther.starttime+getTime() << " with index " << insIdx << endl;
+					if(insIdx==invalid_move)
+						return; //newKeyFrame should have reported error, we can silently return
+					Move& ins=getKeyFrame(insIdx);
+					ins.prev=myPrevIdx;
+					ins.next=myNextIdx;
+					ins.cmd=curOther.cmd;
+					ins.starttime=curOther.starttime+getTime();
+					getKeyFrame(myPrevIdx).next=insIdx;
+					if(myNextIdx!=invalid_move)
+						getKeyFrame(myNextIdx).prev=insIdx;
+					if(myPrevIdx==prevs[i]) {
+						nexts[i]=insIdx;
+						curstamps[i]=-1U;
+					}
+					myPrevIdx=insIdx; //inserted frame is now 'prev'
+					myPrevTime=ins.starttime;
+					if(myPrevTime>endtime)
+						endtime=myPrevTime;
+				}
+			}
+		}
+	}
+	advanceTime(ms.getEndTime());
 }
 
 void MotionSequenceEngine::compress() {
 	for(unsigned int i=0; i<NumOutputs; i++) {
 		Move_idx_t prev=getKeyFrame(starts[i]).next;
-		if(prev==(Move_idx_t)-1)
+		if(prev==invalid_move)
 			break;
 		Move_idx_t cur=getKeyFrame(prev).next;
-		if(cur==(Move_idx_t)-1)
+		if(cur==invalid_move)
 			break;
 		Move_idx_t next=getKeyFrame(cur).next;
-		while(next!=(Move_idx_t)-1) {
+		while(next!=invalid_move) {
 			OutputCmd tmp;
 			Move& prev_m=getKeyFrame(prev);
 			Move& cur_m=getKeyFrame(cur);
@@ -374,18 +482,20 @@ void MotionSequenceEngine::makeSafe(const float vels[NumOutputs], float margin)
 	unsigned int t=0;
 	Move_idx_t tprevs[NumOutputs];
 	Move_idx_t tnexts[NumOutputs];
-	for(unsigned int i=0;i<NumOutputs;i++)
+	for(unsigned int i=0;i<NumOutputs;i++) {
 		tnexts[i]=getKeyFrame(tprevs[i]=starts[i]).next;
+		curstamps[i]=-1U;
+	}
 	while(t!=-1U) {
 		for(unsigned int i=0; i<NumOutputs; i++) {
 			//second and third conditionals are to skip transitions between 0 weighted frames
-			if(tnexts[i]!=(Move_idx_t)-1 && (getKeyFrame(tprevs[i]).cmd.weight!=0 || getKeyFrame(tnexts[i]).cmd.weight!=0) && getKeyFrame(tprevs[i]).starttime==t) {
+			if(tnexts[i]!=invalid_move && (getKeyFrame(tprevs[i]).cmd.weight!=0 || getKeyFrame(tnexts[i]).cmd.weight!=0) && getKeyFrame(tprevs[i]).starttime==t) {
 				float dv=fabs(getKeyFrame(tprevs[i]).cmd.value-getKeyFrame(tnexts[i]).cmd.value);
 				unsigned int dt=getKeyFrame(tnexts[i]).starttime-getKeyFrame(tprevs[i]).starttime;
 				if(dv/dt>comps[i]) {
 					unsigned int delay=(unsigned int)(dv/comps[i])-dt;
 					for(unsigned int j=0; j<NumOutputs; j++)
-						for(Move_idx_t c=tnexts[j]; c!=(Move_idx_t)-1; c=getKeyFrame(c).next)
+						for(Move_idx_t c=tnexts[j]; c!=invalid_move; c=getKeyFrame(c).next)
 							getKeyFrame(c).starttime+=delay;
 				}
 			}
@@ -411,11 +521,12 @@ void MotionSequenceEngine::play() {
 void MotionSequenceEngine::resume() {
 	playing=true;
 	lasttime=get_time();
+	WorldState * st=WorldState::getCurrent();
 	for(unsigned int i=0; i<NumOutputs; i++) {
 		Move_idx_t cur=starts[i];
-		while(cur!=(Move_idx_t)-1) {
+		while(cur!=invalid_move) {
 			if(getKeyFrame(cur).cmd.weight!=0) {
-				getKeyFrame(starts[i]).cmd.value=state->outputs[i];
+				getKeyFrame(starts[i]).cmd.value=st->outputs[i];
 				break;
 			}
 			cur=getKeyFrame(cur).next;
@@ -428,9 +539,16 @@ unsigned int MotionSequenceEngine::setNextFrameTime(Move_idx_t p[NumOutputs], Mo
 	for(unsigned int i=0; i<NumOutputs; i++)
 		if(n[i]!=invalid_move && getKeyFrame(n[i]).starttime<ans)
 			ans=getKeyFrame(n[i]).starttime;
-	if(ans!=-1U)
-		for(unsigned int i=0; i<NumOutputs; i++)
-			setRange(ans,p[i],n[i]);
+	if(ans!=-1U) {
+		WorldState * st=WorldState::getCurrent();
+		for(unsigned int i=0; i<NumOutputs; i++) {
+			if(setRange(ans,p[i],n[i])) {
+				const OutputCmd& cmd=getKeyFrame((playspeed<0)?n[i]:p[i]).cmd;
+				if(cmd.weight<=0)
+					const_cast<OutputCmd&>(cmd).value=st->outputs[i]; //it's ok to assign the value when weight is '0', still "const"... kinda
+			}
+		}
+	}
 	return ans;
 }
 
@@ -473,9 +591,9 @@ unsigned int MotionSequenceEngine::getOutputIndex(const char name[], unsigned in
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.15 $
  * $State: Exp $
- * $Date: 2005/07/14 17:09:03 $
+ * $Date: 2006/09/23 19:51:11 $
  */
 
