@@ -6,18 +6,18 @@
 #include "IPC/ListMemBuf.h"
 #include "PostureEngine.h"
 
-//! A handy little (or not so little) class for switching between a sequence of postures
-/*! Outputs are handled independently.  It's easy to add keyframes
+//! A handy class for storing a sequence of keyframed movements
+/*! Each outputs is handled independently.  It's easy to add keyframes
  *  which modify all of the outputs, but since each output is tracked
  *  individually, OutputCmd's with 0 weight can be used to not affect
- *  other motions.  For instance, pan the head left to right while
+ *  other motions.  For instance, if you want to pan the head left to right while
  *  moving the right leg up and down several times, you won't have to
- *  specify the position of the head in its motion at each of the leg
+ *  specify the intermediary position of the head in its motion at each of the leg
  *  motion keyframes.
  *
  *  Be aware that the 0 time frame will be replaced on a call to
- *  play() with the current body posture.  However, this only applies
- *  to  outputs which have a non-zero weighted frame defined at some
+ *  play() with the current body posture from ::state.  However, this only applies
+ *  to outputs which have a non-zero weighted frame defined at some
  *  point.  The weights, of the 0 time frame will remain unchanged.  
  *  These weights are initially set to 0, so that it's
  *  possible to 'fade in' the first frame of the motion sequence from
@@ -25,8 +25,9 @@
  *
  *  To fade out at the end, set a frame with 0 weight for everything.
  *  Otherwise it will simply die suddenly.  When a joint reaches its
- *  last keyframe, it will be set to 0 weight for all future
- *  updateOutputs() (unless of course the playhead is reset)
+ *  last keyframe, if #hold is set (the default) it will hold its last value
+ *  until the MotionSequence is reset or stopped.  If #hold is false,
+ *  then the joint is treated as 0 weight once it reaches its last frame.
  *
  *  Currently, MotionSequenceEngine is intended mainly for building, 
  *  not editing.  It's easy to add keyframes, but hard/impossible to
@@ -46,15 +47,93 @@
  *    - '<tt>delay </tt><i>time-delta</i>' - moves playhead forward, in milliseconds (synonym for <tt>advanceTime</tt>)
  *    - '<tt>setTime </tt><i>time</i>' - sets play time to specified value, in ms
  *    - '<i>outputname</i><tt> </tt><i>value</i><tt> </tt>[<i>weight</i>]' - sets the specified output to the value - assumes 1 for weight; you can view the list of valid joint names in the outputNames array within the RobotInfo extension namespace for your model.  (e.g. ERS210Info::outputNames[])
- *    - '<tt>load </tt><i>filename</i>' - file is a posture, sets position
- *    - '<tt>overlay </tt><i>filename</i>' - file can be a posture or another motion sequence
- *    - '<tt>degrees</tt>' - following <i>value</i>s will be interpreted as degrees [default]
- *    - '<tt>radians</tt>' - following <i>value</i>s will be interpreted as radians
+ *    - '<tt>load </tt><i>filename</i>' - file can be a posture or another motion sequence (if MS, leaves playhead at end of the motion sequence); see setPose() and overlayMotion()
+ *    - '<tt>loadExplicit </tt><i>filename</i>' - file must be a posture, sets position for all outputs, including zero-weighted ones; see setExplicitPose()
+ *    - '<tt>degrees</tt>' - all following <i>value</i>s will be interpreted as degrees [default]
+ *    - '<tt>radians</tt>' - all following <i>value</i>s will be interpreted as radians
  *    - '<tt>#</tt><i>comment</i>' - a comment line
  *  - Last line: '<tt>\#END</tt>'
  *  
  *  Lines beginning with '#' are ignored as comments.  Be aware if you
  *  load the file and then save it again, these comments will be lost.
+ *
+ *  Example 1: This motion sequence will straighten out the head, panning from right to left.\n
+<table align="center"><tr><td align=left><pre>
+\#MSq 
+degrees 
+
+<i>\# Straighten head</i>
+advanceTime  50 
+NECK:tilt       15 
+NECK:nod       0 
+
+<i>\# Pan right</i>
+advanceTime  850 
+NECK:pan~       -45 
+
+<i>\# Pan left</i>
+advanceTime  900 
+NECK:pan~       45 
+NECK:tilt       15 
+NECK:nod       0 
+
+\#END
+</pre></td></tr></table>
+ *  
+ *  This graph illustrates the motion of the tilt and pan joints in example 1:
+ *  <img src="MotionSequenceGraph1.png">
+ *  Notice how the joint will move from wherever it is initally to the first
+ *  keyframe <i>for that joint</i>.  Specifying the tilt joint a second time
+ *  at the end of the motion forces the tilt joint to be held at that position
+ *  throughout the motion, regardless of the #hold setting at the time
+ *  the sequence is run.
+ *  
+ *  Example 2: This example will straighten the head and the tail, pan the
+ *  head left to right, and @e then pan the tail left to right.\n
+<table align="center"><tr><td align=left><pre>
+\#MSq
+degrees
+
+<i>\# Bring head and tail to neural positions</i>
+advanceTime 50
+NECK:pan~ 0
+NECK:tilt 0
+TAIL:pan~ 0
+TAIL:tilt 0
+
+<i>\# Pan left</i>
+advanceTime 1000
+NECK:pan~ 90
+<i>\# Pan right</i>
+advanceTime 1000
+NECK:pan~ -90
+
+<i>\# Center head</i>
+<i>\# Update tail time index</i>
+advanceTime 500
+NECK:pan~ 0
+<i>\# Note this respecification of TAIL:pan~ at 0 -- see graph below</i>
+TAIL:pan~ 0
+
+<i>\# Wag left</i>
+advanceTime 500
+TAIL:pan~ 90
+<i>\# Wag right</i>
+advanceTime 500
+TAIL:pan~ -90
+
+\#END 
+</pre></td></tr></table>
+ *  
+ *  These graphs illustrate the motion of the pan joint for the head and the tail:
+ *  <img src="MotionSequenceGraph2-head.png">
+ *  <img src="MotionSequenceGraph2-tail.png">
+ *  The head's motion should be straightforward.  The thing to note in the tail's
+ *  graph is why the second <code>TAIL:pan~ 0</code> is necessary at time
+ *  2550.  If it were not specified, the tail would slowly move to the left over the
+ *  course of the head's movement.  We want it to stay still until the head is done,
+ *  so it must be respecified at the same position to hold it at that value in the
+ *  intervening time.
  *  
  *  After loading a motion sequence, the playtime is left at the end.
  *  This is to make it easy to append/overlay motion sequences.
@@ -71,7 +150,8 @@
  *
  *  //Over the course of the first 700 milliseconds, go to standing posture:
  *  standSit->setTime(700);
- *  standSit->setPose(PostureEngine("stand.pos")); // can also use LoadFile("stand.pos")
+ *  standSit->setPose(PostureEngine("stand.pos"));
+ *  // could also use standSit->loadFile("stand.pos")
  *
  *  //Then take another 700 milliseconds to straighten out the head:
  *  standSit->advanceTime(700);
@@ -96,8 +176,11 @@
  *  However, you can either call MotionManager::addPersistentMotion()
  *  to add it, or call setAutoPrune(false), if you want to retain the
  *  same instantiation between executions.
- *  
+ *
  *  @see PostureEngine for information on the posture files
+ *  @see <a href="http://www.cs.cmu.edu/~dst/Tekkotsu/Tutorial/postures.shtml">David Touretzky's "Postures and Motion Sequences" Chapter</a>
+ *  @see <a href="http://www.cs.cmu.edu/afs/cs/academic/class/15494-s06/www/lectures/postures.pdf">CMU's Cognitive Robotics posture slides</a>
+ *  @todo We should also have an insertMotion()
  */
 class MotionSequenceEngine : public LoadSave {
 public:
@@ -111,10 +194,10 @@ public:
 	
 	//!@name LoadSave related
 	virtual unsigned int getBinSize() const; //!< inherited, returns the size used to save the sequence
-	virtual unsigned int LoadBuffer(const char buf[], unsigned int len); //!< inherited, doesn't clear before loading - call clear yourself if you want to reset, otherwise it will overlay.  Leaves playtime at end of load.
-	virtual unsigned int SaveBuffer(char buf[], unsigned int len) const; //!< inherited, saves the motion sequence - will save a flat file - doesn't remember references to other files which were loaded
-	virtual unsigned int LoadFile(const char filename[]); //!< inherited, doesn't clear before loading - call clear yourself if you want to reset, otherwise it will overlay.  Leaves playtime at end of load.
-	virtual unsigned int SaveFile(const char filename[]) const; //!< inherited, saves the motion sequence - will save a flat file - doesn't remember references to other files which were loaded
+	virtual unsigned int loadBuffer(const char buf[], unsigned int len); //!< inherited, doesn't clear before loading - call clear yourself if you want to reset, otherwise it will overlay.  Leaves playtime at end of load.
+	virtual unsigned int saveBuffer(char buf[], unsigned int len) const; //!< inherited, saves the motion sequence - will save a flat file - doesn't remember references to other files which were loaded
+	virtual unsigned int loadFile(const char filename[]); //!< inherited, doesn't clear before loading - call clear yourself if you want to reset, otherwise it will overlay.  Leaves playtime at end of load.
+	virtual unsigned int saveFile(const char filename[]) const; //!< inherited, saves the motion sequence - will save a flat file - doesn't remember references to other files which were loaded
 	void setSaveDegrees() { loadSaveMode=M_PI/180; }       //!< will store angles as degrees on future saves
 	bool isSaveDegrees() const { return loadSaveMode!=1; } //!< returns true if will store angles as degrees on future saves
 	void setSaveRadians() { loadSaveMode=1; }              //!< will store angles as radians on future saves
@@ -127,10 +210,13 @@ public:
 	unsigned int advanceTime(unsigned int x) {setTime(playtime+x); return playtime; } //!< advance the play/edit index by @a x milliseconds, and then returns the new getTime()
 	void setOutputCmd(unsigned int i, const OutputCmd& cmd); //!< will insert a keyframe for the given output, or change an existing one
 	const OutputCmd& getOutputCmd(unsigned int i); //!< gets the value of output @a i at the playhead
-	void setPose(const PostureEngine& pose); //!< calls setOutputCmd on each of the OutputCmds in @a pose
+	void setPose(const PostureEngine& pose); //!< calls setOutputCmd for all non-zero weighted OutputCmds in @a pose (if you wish to set from a file, use loadFile)
+	void setExplicitPose(const PostureEngine& pose); //!< calls setOutputCmd on each of the OutputCmds in @a pose, even if they are zero-weight (can be used to fade joints in/out with other conflicting motions)
 	PostureEngine getPose(); //!< returns the set of OutputCmd's at the current playhead as a PostureEngine
 	void getPose(PostureEngine& pose); //!< stores the set of OutputCmd's at the current playhead into the specified PostureEngine
-	void overlayPose(const PostureEngine& pose); //!< calls setOutputCmd on non-zero weighted OutputCmds in @a pose
+	void overlayPose(const PostureEngine& pose) __attribute__((__deprecated__)); //!< deprecated, use setPose instead (what setPose used to do is now setExplicitPose)
+	unsigned int overlayMotion(const std::string& msFile); //!< loads @a msFile from disk and calls overlayMotion(const MotionSequenceEngine&) with it, returns the duration of @a msFile (0 if there was an error)
+	void overlayMotion(const MotionSequenceEngine& ms); //!< applies each keyframe of @a ms to this, leaves playhead at the end (in other words, advances playhead to end of @a ms)
 	void compress(); //!< compresses the sequence by eliminating sequences of moves which are identical
 	virtual unsigned int getMaxFrames() const=0; //!< returns the maximum number of key frames (Move's) which can be stored, determined by the instantiating MotionSequenceMC's template parameter
 	virtual unsigned int getUsedFrames() const=0; //!< returns the number of used key frames (Move's) which have been stored by the instantiation MotionSequenceEngine subclass
@@ -193,8 +279,8 @@ protected:
 		ans.set(prev.cmd,next.cmd,prevweight);
 	}
 	
-	//!Sets prev and next to the appropriate values for the given time and output index
-	virtual void setRange(unsigned int t,Move_idx_t& prev, Move_idx_t& next) const=0;
+	//!Sets prev and next to the appropriate values for the given time and output index, return true if there was a change
+	virtual bool setRange(unsigned int t,Move_idx_t& prev, Move_idx_t& next) const=0;
 
 	//!sets playtime to next time for which any output has a keyframe, -1 if none exists
 	unsigned int setNextFrameTime(Move_idx_t p[NumOutputs], Move_idx_t n[NumOutputs]) const;
@@ -211,10 +297,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.18 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2006/10/03 23:01:28 $
  */
 
 #endif
