@@ -5,6 +5,7 @@
 #include "MotionSequenceEngine.h"
 #include "MotionCommand.h"
 #include "MotionManager.h"
+#include "Events/EventBase.h"
 
 //! Instantiates MotionSequenceEngines - when you want to run a motion sequence, make one of these
 /*! Allows a compile-time variable amount of data storage through its template parameter.
@@ -18,16 +19,16 @@ public:
 
 	//!constructor
 	MotionSequenceMC()
-		: MotionCommand(), MotionSequenceEngine(), moves()
+		: MotionCommand(), MotionSequenceEngine(), moves(), lastDirty(false)
 	{
 		clear();
 	}
 	//!constructor, loads from a file and then resets the playtime to beginning and begins to play
 	explicit MotionSequenceMC(const std::string& filename)
-		: MotionCommand(), MotionSequenceEngine(), moves()
+		: MotionCommand(), MotionSequenceEngine(), moves(), lastDirty(false)
 	{
 		clear();
-		LoadFile(filename.c_str());
+		loadFile(filename.c_str());
 		setTime(1);
 	}
 	//!destructor
@@ -40,9 +41,13 @@ public:
 	virtual int updateOutputs() {
 		MotionSequenceEngine::updateOutputs();
 		if(!isPlaying()) {
+			if(lastDirty)
+				postEvent(EventBase(EventBase::motmanEGID,getID(),EventBase::statusETID));
+			lastDirty=false;
 			for(unsigned int i=0; i<NumOutputs; i++) //just copies getOutputCmd(i) across frames
 				motman->setOutput(this,i,getOutputCmd(i));
 		} else {
+			lastDirty=true;
 			//cout << getTime() << ": ";
 			for(unsigned int i=0; i<NumOutputs; i++) { //fill out the buffer of commands for smoother movement
 				Move_idx_t prev=prevs[i],next=nexts[i];
@@ -89,6 +94,7 @@ protected:
 
 	// MEMBERS:
 	list_t moves; //!< stores all of the movement keyframes
+	bool lastDirty; //!< true if last updateOutputs was dirty, so we know when to post status event
 
 	virtual Move& getKeyFrame(Move_idx_t x) { return moves[x]; } //!< returns #moves[@a x]
 	virtual const Move& getKeyFrame(Move_idx_t x) const { return moves[x]; } //!< returns #moves[@a x]
@@ -101,8 +107,10 @@ protected:
 	//! marks keyframe @a x unused
 	virtual void eraseKeyFrame(Move_idx_t x) { moves.erase(x); }
 	//! advances (or rewinds) @a prev and @a next so that @a t falls between them
-	void setRange(unsigned int t,Move_idx_t& prev, Move_idx_t& next) const {
+	bool setRange(unsigned int t,Move_idx_t& prev, Move_idx_t& next) const {
+		bool moved=false;
 		if(next!=invalid_move && moves[next].starttime<=t) {
+			moved=true;
 			do {
 				prev=next;
 				next=moves[prev].next;
@@ -111,8 +119,10 @@ protected:
 			while(moves[prev].prev!=invalid_move && t<moves[prev].starttime) {
 				next=prev;
 				prev=moves[next].prev;
+				moved=true;
 			} 
 		}
+		return moved;
 	}
 };
 
@@ -127,10 +137,10 @@ typedef MotionSequenceMC<NumOutputs*26> XLargeMotionSequenceMC;//!< eXtra Large
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.28 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.32 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2006/09/09 04:32:54 $
  */
 
 #endif
