@@ -27,12 +27,14 @@ public:
 	float weight; //!< weight to be used in averaging, 0 to "fall through"
 
 protected:
-	inline void set_pid(const float p[3]) { //!< handy utility function
+	 //! handy utility function, sets #pid[0:2] to @a p[0:2]
+	inline void set_pid(const float p[3]) {
 		pid[0]=p[0];
 		pid[1]=p[1];
 		pid[2]=p[2];
 	}
-	inline void set_pid(const float p, const float i, const float d) { //!< handy utility function
+	 //! handy utility function, sets #pid[0:2] to [@a p,@a i,@a d]
+	inline void set_pid(const float p, const float i, const float d) {
 		pid[0]=p;
 		pid[1]=i;
 		pid[2]=d;
@@ -44,10 +46,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2003/12/13 05:01:40 $
+ * $Date: 2006/09/16 17:32:39 $
  */
 
 #endif
