@@ -4,6 +4,7 @@
 
 #include "MotionCommand.h"
 #include "PostureEngine.h"
+#include "MotionManager.h"
 
 class WorldState;
 
@@ -120,7 +121,7 @@ public:
 	//!These functions merely set the dirty flag and then call the PostureEngine version of the function
 	//!@name PostureEngine Stuff
 	inline virtual void takeSnapshot() { setDirty(); PostureEngine::takeSnapshot(); }
-	inline virtual void takeSnapshot(const WorldState* st) { setDirty(); PostureEngine::takeSnapshot(st); }
+	inline virtual void takeSnapshot(const WorldState& st) { setDirty(); PostureEngine::takeSnapshot(st); }
 	inline virtual void setWeights(float w) { setWeights(w,0,NumOutputs); }
 	inline virtual void setWeights(float w, unsigned int lowjoint, unsigned int highjoint) { setDirty(); PostureEngine::setWeights(w,lowjoint,highjoint); }
 	inline virtual void clear() { setDirty(); PostureEngine::clear(); }
@@ -128,8 +129,8 @@ public:
 	inline virtual PostureEngine& setUnderlay(const PostureEngine& pe) { setDirty(); PostureEngine::setUnderlay(pe); return *this; }
 	inline virtual PostureEngine& setAverage(const PostureEngine& pe,float w=0.5) { setDirty(); PostureEngine::setAverage(pe,w); return *this; }
 	inline virtual PostureEngine& setCombine(const PostureEngine& pe) { setDirty(); PostureEngine::setCombine(pe); return *this; }
-	inline PostureEngine& setOutputCmd(unsigned int i, const OutputCmd& c) { setDirty(); PostureEngine::setOutputCmd(i,c); return *this; }
-	inline virtual unsigned int LoadBuffer(const char buf[], unsigned int len) { setDirty(); return PostureEngine::LoadBuffer(buf,len); }
+	inline PostureEngine& setOutputCmd(unsigned int i, const OutputCmd& c) { dirty=true; targetReached=false; curPositions[i]=motman->getOutputCmd(i).value; PostureEngine::setOutputCmd(i,c); return *this; }
+	inline virtual unsigned int loadBuffer(const char buf[], unsigned int len) { setDirty(); return PostureEngine::loadBuffer(buf,len); }
 	inline virtual bool solveLinkPosition(const NEWMAT::ColumnVector& Ptgt, unsigned int link, const NEWMAT::ColumnVector& Peff) { setDirty(); return PostureEngine::solveLinkPosition(Ptgt,link,Peff); }
 	inline virtual bool solveLinkPosition(float Ptgt_x, float Ptgt_y, float Ptgt_z, unsigned int link, float Peff_x, float Peff_y, float Peff_z) { setDirty(); return PostureEngine::solveLinkPosition(Ptgt_x,Ptgt_y,Ptgt_z,link,Peff_x,Peff_y,Peff_z); }
 	inline virtual bool solveLinkVector(const NEWMAT::ColumnVector& Ptgt, unsigned int link, const NEWMAT::ColumnVector& Peff) { setDirty(); return PostureEngine::solveLinkVector(Ptgt,link,Peff); }
@@ -154,10 +155,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.16 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2006/09/09 04:32:56 $
  */
 
 #endif
