@@ -389,7 +389,7 @@ UPennWalkMC::WalkLegs(double xWalk/*=0.0*/, double yWalk/*=0.0*/, double aWalk/*
   // Check to see if legs should stand rather than walk
   if ((walk_phase == 0) &&
       (xWalk == 0.0) && (yWalk == 0.0) && (aWalk == 0.0)) {
-    StandLegs(0, 0, 0);
+    //StandLegs(0, 0, 0);
     return;
   }
   
@@ -627,8 +627,8 @@ UPennWalkMC::WalkLegs(double xWalk/*=0.0*/, double yWalk/*=0.0*/, double aWalk/*
  *  ------------------------------------------------------------------------- \n
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.1 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.2 $
  * $State: Exp $
- * $Date: 2005/04/12 21:33:31 $
+ * $Date: 2006/08/31 21:37:10 $
  */
