@@ -111,9 +111,9 @@ void WalkMC::init(const char* pfile)
     legw[i].air = false;
 
 	if(pfile!=NULL)
-		LoadFile(pfile);
+		loadFile(pfile);
 	else
-		LoadFile(config->motion.walk.c_str());
+		loadFile(config->motion.walk.c_str());
 
 	double zeros[JointsPerLeg];
 	for(unsigned int i=0; i<JointsPerLeg; i++)
@@ -147,106 +147,111 @@ unsigned int WalkMC::getBinSize() const {
 	return used;	
 }
 
-unsigned int WalkMC::LoadBuffer(const char buf[], unsigned int len) {
+unsigned int WalkMC::loadBuffer(const char buf[], unsigned int len) {
+	enum {
+		VER1, // original CMPack version
+		VER2, // added calibration parameters
+		VER3 // added diff drive and sag parameter
+	} version;
+	
 	unsigned int origlen=len;
-	unsigned int used=0;
-	if((used=checkCreator("WalkMC-2.2",buf,len,false))!=0) {
-		len-=used; buf+=used;
-		if(len>=sizeof(WalkParam))
-			memcpy(&wp,buf,used=sizeof(WalkParam));
-		else
-			return 0;
-		len-=used; buf+=used;
-		if(len>=sizeof(CalibrationParam))
-			memcpy(&cp,buf,used=sizeof(CalibrationParam));
-		else
-			memcpy(&cp,buf,used=len);
-		//return 0;
-		len-=used; buf+=used;
-		//sout->printf("Loaded WalkMC Parameters n=%ud checksum=0x%X\n",origlen-len,checksum(reinterpret_cast<const char*>(&wp),sizeof(wp)+sizeof(cp)));
-		return origlen-len;	
-	} else if((used=checkCreator("WalkMC",buf,len,false))!=0) {
-		sout->printf("Pre-version 2.2 walk parameter file\n");
-		len-=used; buf+=used;
-		for(unsigned int i=0; i<4; i++) {
-			if(len>=sizeof(LegParam))
-				memcpy(&wp.leg[i],buf,used=sizeof(LegParam));
-			else
-				return 0;
-			len-=used; buf+=used;
-		}
-		if(0==(used=decode(wp.body_height,buf,len))) return 0;
-		len-=used; buf+=used;
-		if(0==(used=decode(wp.body_angle,buf,len))) return 0;
-		len-=used; buf+=used;
-		if(0==(used=decode(wp.hop,buf,len))) return 0;
-		len-=used; buf+=used;
-		if(0==(used=decode(wp.sway,buf,len))) return 0;
-		len-=used; buf+=used;
-		if(0==(used=decode(wp.period,buf,len))) return 0;
-		len-=used; buf+=used;
-		if(0==(used=decode(wp.useDiffDrive,buf,len))) return 0;
-		len-=used; buf+=used;
-		wp.sag=0;
-		if(len>=sizeof(CalibrationParam))
-			memcpy(&cp,buf,used=sizeof(CalibrationParam));
-		else
-			return 0;
-		len-=used; buf+=used;
-		//sout->printf("Loaded WalkMC Parameters n=%ud checksum=0x%X\n",origlen-len,checksum(reinterpret_cast<const char*>(&wp),sizeof(wp)+sizeof(cp)));
-		return origlen-len;	
+	if(checkCreatorInc("WalkMC-2.2",buf,len,false)) {
+		version=VER3;
+	} else if(checkCreatorInc("WalkMC",buf,len,false)) {
+		sout->printf("Pre-2.2 release walk parameter file\n");
+		version=VER2;
 	} else {
 		// backwards compatability - if there's no creator code, just assume it's a straight WalkParam
-		sout->printf("Assuming old-format walk parameter file\n");
-		for(unsigned int i=0; i<4; i++) {
-			if(len>=sizeof(LegParam))
-				memcpy(&wp.leg[i],buf,used=sizeof(LegParam));
-			else
-				return 0;
-			len-=used; buf+=used;
-		}
-		if(0==(used=decode(wp.body_height,buf,len))) return 0;
-		len-=used; buf+=used;
-		if(0==(used=decode(wp.body_angle,buf,len))) return 0;
-		len-=used; buf+=used;
-		if(0==(used=decode(wp.hop,buf,len))) return 0;
-		len-=used; buf+=used;
-		if(0==(used=decode(wp.sway,buf,len))) return 0;
-		len-=used; buf+=used;
-		if(0==(used=decode(wp.period,buf,len))) return 0;
-		len-=used; buf+=used;
-		wp.useDiffDrive=0;
-		wp.sag=0;
-		cp=CalibrationParam();
-		//sout->printf("Loaded WalkMC Parameters n=%ud checksum=0x%X\n",origlen-len,checksum(reinterpret_cast<const char*>(&wp),sizeof(wp)));
-		return origlen-len;	
+		sout->printf("Assuming CMPack format walk parameter file\n");
+		version=VER1;
 	}
+	
+	// Leg parameters
+	for(unsigned int i=0; i<NumLegs; ++i) {
+		if(!decodeInc(wp.leg[i].neutral.x,buf,len)) return 0;
+		if(!decodeInc(wp.leg[i].neutral.y,buf,len)) return 0;
+		if(!decodeInc(wp.leg[i].neutral.z,buf,len)) return 0;
+		if(!decodeInc(wp.leg[i].lift_vel.x,buf,len)) return 0;
+		if(!decodeInc(wp.leg[i].lift_vel.y,buf,len)) return 0;
+		if(!decodeInc(wp.leg[i].lift_vel.z,buf,len)) return 0;
+		if(!decodeInc(wp.leg[i].down_vel.x,buf,len)) return 0;
+		if(!decodeInc(wp.leg[i].down_vel.y,buf,len)) return 0;
+		if(!decodeInc(wp.leg[i].down_vel.z,buf,len)) return 0;
+		if(!decodeInc(wp.leg[i].lift_time,buf,len)) return 0;
+		if(!decodeInc(wp.leg[i].down_time,buf,len)) return 0;
+	}
+	// Body parameters
+	if(!decodeInc(wp.body_height,buf,len)) return 0;
+	if(!decodeInc(wp.body_angle,buf,len)) return 0;
+	if(!decodeInc(wp.hop,buf,len)) return 0;
+	if(!decodeInc(wp.sway,buf,len)) return 0;
+	if(!decodeInc(wp.period,buf,len)) return 0;
+	if(version<VER3) wp.useDiffDrive=0; else if(!decodeInc(wp.useDiffDrive,buf,len)) return 0;
+	if(version<VER3) wp.sag=0; else if(!decodeInc(wp.sag,buf,len)) return 0;
+	if(!decodeInc(wp.reserved,buf,len)) return 0;
+	// Calibration parameters
+	if(version<VER2) {
+		cp=CalibrationParam();
+	} else {
+		for(unsigned int i=0; i<3; ++i)
+			for(unsigned int j=0; j<11; ++j)
+				if(!decodeInc(cp.f_calibration[i][j],buf,len)) return 0;
+		for(unsigned int i=0; i<3; ++i)
+			for(unsigned int j=0; j<11; ++j)
+				if(!decodeInc(cp.b_calibration[i][j],buf,len)) return 0;
+		for(unsigned int i=0; i<CalibrationParam::NUM_DIM; ++i)
+			if(!decodeInc(cp.max_accel[i],buf,len)) return 0;
+		for(unsigned int i=0; i<CalibrationParam::NUM_DIM; ++i)
+			if(!decodeInc(cp.max_vel[i],buf,len)) return 0;
+	}
+	return origlen-len;	
 }
 
-unsigned int WalkMC::SaveBuffer(char buf[], unsigned int len) const {
+unsigned int WalkMC::saveBuffer(char buf[], unsigned int len) const {
 	unsigned int origlen=len;
-	unsigned int used=0;
-	if(0==(used=saveCreator("WalkMC-2.2",buf,len))) return 0;
-	len-=used; buf+=used;
-	if(len>=sizeof(WalkParam))
-		memcpy(buf,&wp,used=sizeof(WalkParam));
-	else
-		return 0;
-	len-=used; buf+=used;
-	if(len>=sizeof(CalibrationParam))
-		memcpy(buf,&cp,used=sizeof(CalibrationParam));
-	else
-		return 0;
-	len-=used; buf+=used;
-	//sout->printf("Saved WalkMC Parameters n=%ud checksum=0x%X\n",origlen-len,checksum(reinterpret_cast<const char*>(&wp),sizeof(wp)+sizeof(cp)));
-	return origlen-len;
+	// Leg parameters
+	if(!saveCreatorInc("WalkMC-2.2",buf,len)) return 0;
+	for(unsigned int i=0; i<NumLegs; ++i) {
+		if(!encodeInc(wp.leg[i].neutral.x,buf,len)) return 0;
+		if(!encodeInc(wp.leg[i].neutral.y,buf,len)) return 0;
+		if(!encodeInc(wp.leg[i].neutral.z,buf,len)) return 0;
+		if(!encodeInc(wp.leg[i].lift_vel.x,buf,len)) return 0;
+		if(!encodeInc(wp.leg[i].lift_vel.y,buf,len)) return 0;
+		if(!encodeInc(wp.leg[i].lift_vel.z,buf,len)) return 0;
+		if(!encodeInc(wp.leg[i].down_vel.x,buf,len)) return 0;
+		if(!encodeInc(wp.leg[i].down_vel.y,buf,len)) return 0;
+		if(!encodeInc(wp.leg[i].down_vel.z,buf,len)) return 0;
+		if(!encodeInc(wp.leg[i].lift_time,buf,len)) return 0;
+		if(!encodeInc(wp.leg[i].down_time,buf,len)) return 0;
+	}
+	// Body parameters
+	if(!encodeInc(wp.body_height,buf,len)) return 0;
+	if(!encodeInc(wp.body_angle,buf,len)) return 0;
+	if(!encodeInc(wp.hop,buf,len)) return 0;
+	if(!encodeInc(wp.sway,buf,len)) return 0;
+	if(!encodeInc(wp.period,buf,len)) return 0;
+	if(!encodeInc(wp.useDiffDrive,buf,len)) return 0;
+	if(!encodeInc(wp.sag,buf,len)) return 0;
+	if(!encodeInc(wp.reserved,buf,len)) return 0;
+	// Calibration parameters
+	for(unsigned int i=0; i<3; ++i)
+		for(unsigned int j=0; j<11; ++j)
+			if(!encodeInc(cp.f_calibration[i][j],buf,len)) return 0;
+	for(unsigned int i=0; i<3; ++i)
+		for(unsigned int j=0; j<11; ++j)
+			if(!encodeInc(cp.b_calibration[i][j],buf,len)) return 0;
+	for(unsigned int i=0; i<CalibrationParam::NUM_DIM; ++i)
+		if(!encodeInc(cp.max_accel[i],buf,len)) return 0;
+	for(unsigned int i=0; i<CalibrationParam::NUM_DIM; ++i)
+		if(!encodeInc(cp.max_vel[i],buf,len)) return 0;
+	return origlen-len;	
 }
 
-unsigned int WalkMC::LoadFile(const char* filename) {
-	return LoadSave::LoadFile(config->motion.makePath(filename).c_str());
+unsigned int WalkMC::loadFile(const char* filename) {
+	return LoadSave::loadFile(config->motion.makePath(filename).c_str());
 }
-unsigned int WalkMC::SaveFile(const char* filename) const {
-	return LoadSave::SaveFile(config->motion.makePath(filename).c_str());
+unsigned int WalkMC::saveFile(const char* filename) const {
+	return LoadSave::saveFile(config->motion.makePath(filename).c_str());
 }
 
 void WalkMC::setTargetVelocity(double dx,double dy,double da,int n)
@@ -406,6 +411,7 @@ int WalkMC::updateOutputs() {
 						e.setXYA(target_vel_xya.x,target_vel_xya.y,target_vel_xya.z);
 						//cout << e.getDescription(true) << endl;
 						postEvent(e);
+						postEvent(EventBase(EventBase::motmanEGID,getID(),EventBase::statusETID,getTravelTime()));
 						//		cout << "WalkMC-done" << endl;
 						return frame==0?0:NumLegs*JointsPerLeg;
 					}
@@ -622,9 +628,9 @@ void WalkMC::applyCalibration(const float mat[3][11], const vector3d& in, vector
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.34 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.38 $
  * $State: Exp $
- * $Date: 2005/06/29 22:01:55 $
+ * $Date: 2006/09/10 18:48:46 $
  */
 
