@@ -60,8 +60,7 @@
  *  function to control the direction of the walk.
  *
  *  This class is in some dire need of some cleanup - we (Tekkotsu)
- *  didn't write it, never really bothered to get a deep understanding
- *  of it, but have none the less hacked around and added stuff on top
+ *  didn't write it, have none the less hacked around and added stuff on top
  *  of it.  So pardon the mess, unless you're feeling ambitious to
  *  write your own ;)
  *
@@ -107,15 +106,15 @@ public:
 
 	//! holds information to correct for slippage, non-idealities
 	struct CalibrationParam {
-		CalibrationParam();
+		CalibrationParam(); //!< constructor, sets calibration matricies to identity
 
 		//! symbolic way to refer to each of the directions
 		enum dimension_offset {
-			forward,
-			reverse, 
-			strafe,
-			rotate,
-			NUM_DIM
+			forward, //!< forward (x)
+			reverse, //!< backward (-x)
+			strafe,  //!< sideways (y)
+			rotate,  //!< spin (z/a)
+			NUM_DIM  //!< number of directions we calibrate for
 		};
 
 		float f_calibration[3][11]; //!< matrix of calibration parameters; 3 columns for f,s,r speeds, 2 columns for abs s,r speeds, 1 gabor function, 1 squared planar speed, 3 columns for f*r,s*f,r*s, and 1 column for offset
@@ -136,14 +135,14 @@ public:
 	//! Returns true if we are walking. This modified isDirty allows the AIBO to slow down to a stop rather than stopping immediately.
 	virtual int isDirty();
 	
-	//! always true - never autoprunes
-	virtual int isAlive() { return true; }
+	//! Will prune if we've taken the requested number of steps.
+	virtual int isAlive() { return step_count != 0; }
 
 	virtual unsigned int getBinSize() const;
-	virtual unsigned int LoadBuffer(const char buf[], unsigned int len);
-	virtual unsigned int SaveBuffer(char buf[], unsigned int len) const;
-	virtual	unsigned int LoadFile(const char* filename);
-	virtual unsigned int SaveFile(const char* filename) const;
+	virtual unsigned int loadBuffer(const char buf[], unsigned int len);
+	virtual unsigned int saveBuffer(char buf[], unsigned int len) const;
+	virtual	unsigned int loadFile(const char* filename);
+	virtual unsigned int saveFile(const char* filename) const;
 
 	//! set the direction to walk
 	/*! @param dx forward velocity (millimeters per second)
@@ -208,8 +207,8 @@ public:
 	//! returns the current leg position of leg @a i
 	const vector3d& getLegPosition(LegOrder_t i) const { return legpos[i]; }
 
-	WalkParam& getWP() { return wp; }; //!< returns the current walk parameter structure
-	CalibrationParam& getCP() { return cp; }; //!< returns the current walk calibration parameter
+	struct WalkParam& getWP() { return wp; }; //!< returns the current walk parameter structure
+	struct CalibrationParam& getCP() { return cp; }; //!< returns the current walk calibration parameter
 	
 	//! takes current leg positions from WorldState and tries to match the point in the cycle most like it
 	void resetLegPos();
@@ -228,7 +227,7 @@ public:
 	static void applyCalibration(const float mat[3][11], const vector3d& in, vector3d& out);
 
  protected:
-	//! does some setup stuff, calls LoadFile(pfile)
+	//! does some setup stuff, calls loadFile(pfile)
 	void init(const char* pfile);
 
 	bool isPaused; //!< true if we are paused
@@ -310,10 +309,10 @@ public:
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.31 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.35 $
  * $State: Exp $
- * $Date: 2005/04/12 19:07:07 $
+ * $Date: 2006/10/03 21:42:50 $
  */
 
 #endif
