@@ -91,8 +91,8 @@
  *  <table cellspacing=0 cellpadding=0 width="325" class="figures" align="center" border="0"><tr>
  *  <td class="figure"><img src="Waypoint_Error.png"><div style="padding:10px;">
  *  The effect of the Waypoint::trackPath flag.  When @c true, the robot will attempt to catch up
- *  to its "ideal" location after a perterbation.  When @c false, the robot will ignore the "ideal"
- *  path, and just go straight to the destination from wherever perterbations may push it.
+ *  to its "ideal" location after a perturbation.  When @c false, the robot will ignore the "ideal"
+ *  path, and just go straight to the destination from wherever perturbations may push it.
  *  </div></td></tr></table>
  *
  *  trackPath is a per-waypoint setting, setTracking() sets the
@@ -146,25 +146,25 @@ public:
 
 	//! constructor
 	WaypointEngine()
-		: LoadSave(), waypoints(), isRunning(false), isLooping(true), isTracking(false),
+		: LoadSave(), waypoints(), isRunning(false), isLooping(false), isTracking(false),
 			curWaypoint(waypoints.end()), waypointTime(0), waypointDistance(0), pathLength(0), arcRadius(0),
 			lastUpdateTime(0), Pcorr(.5), turnSpeed(.65)
 	{init();}
 	//! constructor
 	WaypointEngine(char * f)
-		: LoadSave(), waypoints(), isRunning(false), isLooping(true), isTracking(false),
+		: LoadSave(), waypoints(), isRunning(false), isLooping(false), isTracking(false),
 			curWaypoint(waypoints.end()), waypointTime(0), waypointDistance(0), pathLength(0), arcRadius(0),
 			lastUpdateTime(0), Pcorr(.5), turnSpeed(.65)
-	{init(); LoadFile(f); }
+	{init(); loadFile(f); }
 
 	//! returns a rough overestimate of the size needed
 	/*! pretends we need to switch max_turn_speed and track_path on
 		every point, and the longest options are given for every point */
 	virtual unsigned int getBinSize() const;
-	virtual unsigned int LoadBuffer(const char buf[], unsigned int len);
-	virtual unsigned int SaveBuffer(char buf[], unsigned int len) const;
-	virtual unsigned int LoadFile(const char * filename) { return LoadSave::LoadFile(config->motion.makePath(filename).c_str()); }
-	virtual unsigned int SaveFile(const char * filename) const { return LoadSave::SaveFile(config->motion.makePath(filename).c_str()); }
+	virtual unsigned int loadBuffer(const char buf[], unsigned int len);
+	virtual unsigned int saveBuffer(char buf[], unsigned int len) const;
+	virtual unsigned int loadFile(const char * filename) { return LoadSave::loadFile(config->motion.makePath(filename).c_str()); }
+	virtual unsigned int saveFile(const char * filename) const { return LoadSave::saveFile(config->motion.makePath(filename).c_str()); }
 
 	virtual void go();      //!< starts walking towards the first waypoint
 	virtual void pause();   //!< halts execution of waypoint list
@@ -316,7 +316,7 @@ public:
 		arcRadius = (radiusRatio==0) ? 0 : (waypointDistance/2)/radiusRatio;
 		pathLength = arcRadius!=0 ? arcRadius*waypoints[iter].arc : waypointDistance;
 
-		cout << "Target is now: ("<<targetPos[0]<<','<<targetPos[1]<<','<<targetPos[2]<<")" << endl;
+		std::cout << "Target is now: ("<<targetPos[0]<<','<<targetPos[1]<<','<<targetPos[2]<<")" << std::endl;
 	}
 
 	//!if @a it follows the current waypoint, applies all the waypoints between #curWaypoint and @a it and returns result as an absolute position (angle field stores heading); otherwise calls the other calcAbsoluteCoords(WaypointListIter_t, float, float, float)
@@ -476,7 +476,7 @@ unsigned int WaypointEngine<MAX_WAY>::getBinSize() const {
 }
 
 template<unsigned int MAX_WAY>
-unsigned int WaypointEngine<MAX_WAY>::LoadBuffer(const char buf[], unsigned int len) {
+unsigned int WaypointEngine<MAX_WAY>::loadBuffer(const char buf[], unsigned int len) {
 	unsigned int origlen=len;
 	waypoints.clear();
 	if(strncmp("#WyP\n",buf,5)!=0 && strncmp("#WyP\r",buf,5)!=0) {
@@ -527,10 +527,10 @@ unsigned int WaypointEngine<MAX_WAY>::LoadBuffer(const char buf[], unsigned int
 		}
 		int used=-1U;
 		sscanf(buf,"%40s%n",cmd,&used);
-		if(!ChkAdvance(used,&buf,&len,"*** ERROR Waypoint list load corrupted - ran out of room line %d\n",linenum)) return 0;
+		if(!checkInc(used,buf,len,"*** ERROR Waypoint list load corrupted - ran out of room line %d\n",linenum)) return 0;
 		if(strncasecmp(cmd,"add_point",9)==0 || strncasecmp(cmd,"add_arc",7)==0) {
 			sscanf(buf,"%40s %g %g %40s %g %g %g%n",posType,&x_val,&y_val,angType,&angle_val,&speed_val,&arc_val,&used);
-			if(!ChkAdvance(used,&buf,&len,"*** ERROR Waypoint list load corrupted - bad read on add at line %d\n",linenum)) return 0;
+			if(!checkInc(used,buf,len,"*** ERROR Waypoint list load corrupted - bad read on add at line %d\n",linenum)) return 0;
 			if(strncasecmp(angType,"hold",4)==0)
 				ang_val=false;
 			else if(strncasecmp(angType,"follow",6)==0)
@@ -569,10 +569,10 @@ unsigned int WaypointEngine<MAX_WAY>::LoadBuffer(const char buf[], unsigned int
 			int track_tmp;
 			sscanf(buf,"%d%n",&track_tmp,&used);
 			track=track_tmp;
-			if(!ChkAdvance(used,&buf,&len,"*** ERROR Waypoint load corrupted - bad read on track_path line %d\n",linenum)) return 0;
+			if(!checkInc(used,buf,len,"*** ERROR Waypoint load corrupted - bad read on track_path line %d\n",linenum)) return 0;
 		} else if(strncasecmp(cmd,"max_turn_speed",14)==0) {
 			sscanf(buf,"%g%n",&turn,&used);
-			if(!ChkAdvance(used,&buf,&len,"*** ERROR Waypoint load corrupted - bad read on max_turn_speed line %d\n",linenum)) return 0;
+			if(!checkInc(used,buf,len,"*** ERROR Waypoint load corrupted - bad read on max_turn_speed line %d\n",linenum)) return 0;
 		} else {
 			printf("*** ERROR WaypointEngine: Invalid command %s\n",cmd);
 			return 0;
@@ -585,16 +585,16 @@ unsigned int WaypointEngine<MAX_WAY>::LoadBuffer(const char buf[], unsigned int
 }
 
 template<unsigned int MAX_WAY>
-unsigned int WaypointEngine<MAX_WAY>::SaveBuffer(char buf[], unsigned int len) const {
+unsigned int WaypointEngine<MAX_WAY>::saveBuffer(char buf[], unsigned int len) const {
 	unsigned int origLen=len;
 	unsigned int used;
 	unsigned int cnt=0;
 		
 	used=snprintf(buf,len,"#WyP\n");
-	if(!ChkAdvance(used,(const char**)&buf,&len,"*** ERROR Waypoint list save failed on header\n")) return 0;
+	if(!checkInc(used,buf,len,"*** ERROR Waypoint list save failed on header\n")) return 0;
 
 	used=snprintf(buf,len,"#add_{point|arc} {ego|off|abs} x_val y_val {hold|follow} angle_val speed_val arc_val\n");
-	if(!ChkAdvance(used,(const char**)&buf,&len,"*** ERROR Waypoint list save failed on header\n")) return 0;
+	if(!checkInc(used,buf,len,"*** ERROR Waypoint list save failed on header\n")) return 0;
 
 	//set our state variables so we'll be forced to output the first set
 	float turn=waypoints.front().turnSpeed-1;
@@ -604,12 +604,12 @@ unsigned int WaypointEngine<MAX_WAY>::SaveBuffer(char buf[], unsigned int len) c
 		if(waypoints[it].turnSpeed!=turn) {
 			turn=waypoints[it].turnSpeed;
 			used=snprintf(buf,len,"max_turn_speed %g\n",turn);
-			if(!ChkAdvance(used,(const char**)&buf,&len,"*** ERROR Waypoint list save failed on waypoint %d turnSpeed\n",cnt)) return 0;
+			if(!checkInc(used,buf,len,"*** ERROR Waypoint list save failed on waypoint %d turnSpeed\n",cnt)) return 0;
 		}
 		if(waypoints[it].trackPath!=track) {
 			track=waypoints[it].trackPath;
 			used=snprintf(buf,len,"track_path %d\n",track);
-			if(!ChkAdvance(used,(const char**)&buf,&len,"*** ERROR Waypoint list save failed on waypoint %d\n trackPath",cnt)) return 0;
+			if(!checkInc(used,buf,len,"*** ERROR Waypoint list save failed on waypoint %d\n trackPath",cnt)) return 0;
 		}
 		const char * posType=NULL;
 		switch(waypoints[it].posType) {
@@ -624,12 +624,12 @@ unsigned int WaypointEngine<MAX_WAY>::SaveBuffer(char buf[], unsigned int len) c
 			used=snprintf(buf,len,"add_point %s %g %g %s %g %g %g\n",posType,waypoints[it].x,waypoints[it].y,(waypoints[it].angleIsRelative?"FOLLOW":"HOLD"),waypoints[it].angle,waypoints[it].speed,waypoints[it].arc);
 		else //todo - store center of circle
 			used=snprintf(buf,len,"add_point %s %g %g %s %g %g %g\n",posType,waypoints[it].x,waypoints[it].y,(waypoints[it].angleIsRelative?"FOLLOW":"HOLD"),waypoints[it].angle,waypoints[it].speed,waypoints[it].arc);
-		if(!ChkAdvance(used,(const char**)&buf,&len,"*** ERROR Waypoint list save failed on waypoint %d\n",cnt)) return 0;
+		if(!checkInc(used,buf,len,"*** ERROR Waypoint list save failed on waypoint %d\n",cnt)) return 0;
 		cnt++;
 	}
 
 	used=snprintf(buf,len,"#END\n");
-	if(!ChkAdvance(used,(const char**)&buf,&len,"*** ERROR Waypoint list save failed on footer\n")) return 0;
+	if(!checkInc(used,buf,len,"*** ERROR Waypoint list save failed on footer\n")) return 0;
 
 	return origLen-len;
 }
@@ -842,10 +842,10 @@ void WaypointEngine<MAX_WAY>::computeNewVelocity(unsigned int /*t*/) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2005/08/09 23:00:50 $
+ * $Date: 2006/09/09 04:32:58 $
  */
 
 #endif
