@@ -35,10 +35,10 @@ public:
 		return WalkMC::updateOutputs();
 	}
 
-	virtual int LoadWaypointFile(const char * f) { return WaypointEngine<MAX_WAYPOINTS>::LoadFile(f); } //!< allows loading a waypoint file
-	virtual int SaveWaypointFile(const char * f) const { return WaypointEngine<MAX_WAYPOINTS>::SaveFile(f); } //!< allows saving a waypoint file
-	virtual int LoadWalkMCFile(const char * f) { return WalkMC::LoadFile(f); } //!< allows loading a WalkMC parameter file
-	virtual int SaveWalkMCFile(const char * f) const { return WalkMC::SaveFile(f); } //!< allows saving a WalkMC parameter file
+	virtual int LoadWaypointFile(const char * f) { return WaypointEngine<MAX_WAYPOINTS>::loadFile(f); } //!< allows loading a waypoint file
+	virtual int SaveWaypointFile(const char * f) const { return WaypointEngine<MAX_WAYPOINTS>::saveFile(f); } //!< allows saving a waypoint file
+	virtual int LoadWalkMCFile(const char * f) { return WalkMC::loadFile(f); } //!< allows loading a WalkMC parameter file
+	virtual int SaveWalkMCFile(const char * f) const { return WalkMC::saveFile(f); } //!< allows saving a WalkMC parameter file
 
 };
 
@@ -50,10 +50,10 @@ typedef WaypointWalk<100> WaypointWalkMC; //!< unless you need more/less waypoin
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:48 $
+ * $Date: 2006/09/09 04:32:58 $
  */
 
 #endif
