@@ -68,7 +68,7 @@ namespace ROBOOP {
 #endif
 	
 //! @brief RCS/CVS version.
-static const char rcsid[] __UNUSED__ = "$Id: config.cpp,v 1.11 2005/07/26 03:22:08 ejt Exp $";
+static const char rcsid[] __UNUSED__ = "$Id: config.cpp,v 1.12 2006/09/25 23:30:32 ejt Exp $";
 
 Config::Config(const string & filename_, bool doRead/*=false*/)
 //! @brief Constructor.
@@ -130,10 +130,10 @@ short Config::read_conf()
       while( !inconffile.eof() )
       {
 	 // Is-it comment line?
-         if(temp.substr(0,1) != "#")
+         if(temp[0] != '#')
          {
 	    // Is-it a section name?
-            if(temp.substr(0,1) == "[") // [section]
+            if(temp[0] == '[') // [section]
             {
 	       // Search for the end of the section name and ignore the rest of the line.
  	       tmpPos = temp.find("]");
@@ -149,10 +149,10 @@ short Config::read_conf()
 		   getline(inconffile, temp);
 #endif
 		   // Be sure that is not another section name.
-		   while( (temp.substr(0,1) != "[") &&
+		   while( (temp[0] != '[') &&
 			  (!inconffile.eof()) )
 		     {
-		       if(temp.substr(0,1) != "#") // ignore comments
+		       if(temp[0] != '#') // ignore comments
 			 {
 			   if(temp.find(":") != string::npos)
 			     {
@@ -175,7 +175,7 @@ short Config::read_conf()
 			       tmpPos = parameter.find(":");
 			       if (tmpPos != (int)string::npos)
 				 // remove ":" a the end of parameter
-				 parameter = parameter.substr(0, tmpPos);
+				 parameter = parameter.erase(tmpPos);
 			       else
 				 {
 #ifdef __WATCOMC__
