@@ -60,15 +60,14 @@ Revision_history:
   @brief Graphics functions.
 */
 
-//! @brief RCS/CVS version.
-static const char rcsid[] = "$Id: gnugraph.cpp,v 1.1 2004/07/20 17:55:24 ejt Exp $";
-
 #include "gnugraph.h"
 
 #ifdef use_namespace
 namespace ROBOOP {
   using namespace NEWMAT;
 #endif
+	//! @brief RCS/CVS version.
+	static const char rcsid[] __UNUSED__ = "$Id: gnugraph.cpp,v 1.3 2005/07/26 03:22:08 ejt Exp $";
 
 char *curvetype[] =
    {"lines",
@@ -139,7 +138,7 @@ Plot2d::Plot2d(void)
    {
       curves = new GNUcurve[NCURVESMAX];
    }
-   catch(bad_alloc exception)
+   catch(bad_alloc ex)
    {
       cerr << "Plot2d::Plot2d:: new ran out of memory" << endl;
    }
@@ -198,7 +197,7 @@ void Plot2d::gnuplot(void)
    {
       filedata = new char[strlen(filename)+3];
    }
-   catch(bad_alloc exception)
+   catch(bad_alloc ex)
    {
       cerr << "Plot2d::gnuplot:: new ran out of memory" << endl;
    }
@@ -683,7 +682,7 @@ short set_plot2d(const char *title_graph, const char *x_axis_title, const char *
    {
       legend = new char[strlen(label)+1];
    }
-   catch(bad_alloc exception)
+   catch(bad_alloc ex)
    {
       cerr << "set_plot2d:: new ran out of memory" << endl;
       return OUT_OF_MEMORY;
