@@ -5,6 +5,7 @@
 //! An interface for cloning objects -- needed for making copies with polymorphism (operator= doesn't work as virtual)
 class Cloneable {
 public:
+	//!destructor
 	virtual ~Cloneable() {}
 
 	//! returns a copy of @c this
@@ -30,7 +31,12 @@ public:
 	 *  gcc version to at least 3.4 and we can switch over to use the
 	 *  "covariant return type".
 	 */
-	virtual Cloneable* clone() const=0;
+
+#if defined(__GNUC__) && (__GNUC__ > 3 || (__GNUC__ == 3 && (__GNUC_MINOR__ > 3)))
+	virtual Cloneable* clone() const __attribute__ ((warn_unused_result)) =0;
+#else
+	virtual Cloneable* clone() const =0;
+#endif
 };
 
 /*! @file
@@ -38,10 +44,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.1 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2005/06/29 22:05:45 $
+ * $Date: 2006/03/16 19:28:03 $
  */
 
 #endif
