@@ -27,6 +27,9 @@ namespace RobotInfo {
 		NodOffset=RollOffset       //!< nod (second tilt)
 	};
 
+	//! Defines the indexes to use as indices to access the min and max entries of joint limit specifications (e.g. ERS7Info::outputRanges and ERS7Info::mechanicalLimits)
+	enum MinMaxRange_t { MinRange,MaxRange };
+	
 }
 
 /*! @file
@@ -34,10 +37,10 @@ namespace RobotInfo {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.1 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.2 $
  * $State: Exp $
- * $Date: 2003/12/23 06:33:43 $
+ * $Date: 2006/10/04 02:42:03 $
  */
 
 #endif
