@@ -1,6 +1,8 @@
 #include "Shared/Config.h"
+#include "Shared/ProjectInterface.h"
 #include "Behaviors/Mon/RawCamBehavior.h"
 #include "Vision/RawCameraGenerator.h"
+#include "Vision/SegmentedColorGenerator.h"
 #include <stdio.h>
 #include <string>
 #include <cstring>
@@ -19,6 +21,8 @@ const OSpeakerVolume ospkvol18dB  = 0xee00;
 const OSpeakerVolume ospkvol10dB  = 0xf600;
 #endif
 
+using namespace std;
+
 Config* config=NULL;
 
 void Config::setFileSystemRoot(const std::string& fsr) {
@@ -76,6 +80,9 @@ void* Config::setValue(section_t section, const char *key, const char *value, bo
 				if (strncasecmp(value,"indoor",49)==0) {
 					vision.white_balance=1;
 				} else if (strncasecmp(value,"flourescent",49)==0) {
+					std::cout << "Your tekkotsu.cfg file uses deprecated 'flourescent' (misspelled) -- use 'fluorescent' instead" << std::endl;
+					vision.white_balance=3;
+				} else if (strncasecmp(value,"fluorescent",49)==0) {
 					vision.white_balance=3;
 				} else if (strncasecmp(value,"outdoor",49)==0) {
 					vision.white_balance=2;
@@ -167,18 +174,24 @@ void* Config::setValue(section_t section, const char *key, const char *value, bo
 			} else if (strncasecmp(key,"rawcam_interval",29)==0) {
 				vision.rawcam_interval=(unsigned int)atoi(value);
 				return &vision.rawcam_interval;
-			} else if (strncasecmp(key,"rle_port",29)==0) {
-				vision.rle_port=atoi(value);
-				return &vision.rle_port;
-			} else if (strncasecmp(key,"rle_transport",29)==0) {
+			} else if (strncasecmp(key,"segcam_port",29)==0 || strncasecmp(key,"rle_port",29)==0) {
+				if(strncasecmp(key,"rle_port",29)==0)
+					std::cout << "Your tekkotsu.cfg file uses deprecated rle_port -- use segcam_port instead" << std::endl;
+				vision.segcam_port=atoi(value);
+				return &vision.segcam_port;
+			} else if (strncasecmp(key,"segcam_transport",29)==0 || strncasecmp(key,"rle_transport",29)==0) {
+				if(strncasecmp(key,"rle_transport",29)==0)
+					std::cout << "Your tekkotsu.cfg file uses deprecated rle_transport -- use segcam_transport instead" << std::endl;
 				if (strncasecmp(value,"udp",49)==0)
-					vision.rle_transport=0;
+					vision.segcam_transport=0;
 				else if (strncasecmp(value,"tcp",49)==0)
-					vision.rle_transport=1;
-				return &vision.rle_transport;
-			} else if (strncasecmp(key,"rle_interval",29)==0) {
-				vision.rle_interval=(unsigned int)atoi(value);
-				return &vision.rle_interval;
+					vision.segcam_transport=1;
+				return &vision.segcam_transport;
+			} else if (strncasecmp(key,"segcam_interval",29)==0 || strncasecmp(key,"rle_interval",29)==0) {
+				if(strncasecmp(key,"rle_interval",29)==0)
+					std::cout << "Your tekkotsu.cfg file uses deprecated rle_interval -- use segcam_interval instead" << std::endl;
+				vision.segcam_interval=(unsigned int)atoi(value);
+				return &vision.segcam_interval;
 			} else if (strncasecmp(key,"region_port",29)==0) {
 				vision.region_port=atoi(value);
 				return &vision.region_port;
@@ -194,6 +207,9 @@ void* Config::setValue(section_t section, const char *key, const char *value, bo
 			} else if (strncasecmp(key,"restore_image",29)==0) {
 				vision.restore_image=atoi(value);
 				return &vision.restore_image;
+			} else if (strncasecmp(key,"region_calc_total",29)==0) {
+				vision.region_calc_total=atoi(value);
+				return &vision.region_calc_total;
 			} else if (strncasecmp(key,"jpeg_dct_method",29)==0) {
 				if (strncasecmp(value,"islow",49)==0) {
 					vision.jpeg_dct_method=JDCT_ISLOW;
@@ -235,6 +251,8 @@ void* Config::setValue(section_t section, const char *key, const char *value, bo
 					vision.rawcam_compression=vision_config::COMPRESS_NONE;
 				} else if (strncasecmp(value,"jpeg",49)==0) {
 					vision.rawcam_compression=vision_config::COMPRESS_JPEG;
+				} else if (strncasecmp(value,"png",49)==0) {
+					vision.rawcam_compression=vision_config::COMPRESS_PNG;
 				}
 				return &vision.rawcam_compression;
 			} else if (strncasecmp(key,"rawcam_compress_quality",29)==0) {
@@ -242,23 +260,37 @@ void* Config::setValue(section_t section, const char *key, const char *value, bo
 				return &vision.rawcam_compress_quality;
 			} else if (strncasecmp(key,"rawcam_y_skip",29)==0) {
 				vision.rawcam_y_skip=atoi(value);
+				if(ProjectInterface::defRawCameraGenerator!=NULL && vision.rawcam_y_skip>(int)ProjectInterface::defRawCameraGenerator->getNumLayers()-1)
+					vision.rawcam_y_skip=ProjectInterface::defRawCameraGenerator->getNumLayers()-1;
 				return &vision.rawcam_y_skip;
 			} else if (strncasecmp(key,"rawcam_uv_skip",29)==0) {
 				vision.rawcam_uv_skip=atoi(value);
+				if(ProjectInterface::defRawCameraGenerator!=NULL && vision.rawcam_uv_skip>(int)ProjectInterface::defRawCameraGenerator->getNumLayers()-1)
+					vision.rawcam_uv_skip=ProjectInterface::defRawCameraGenerator->getNumLayers()-1;
 				return &vision.rawcam_uv_skip;
-			} else if (strncasecmp(key,"rlecam_skip",29)==0) {
-				vision.rlecam_skip=atoi(value);
-				return &vision.rlecam_skip;
-			} else if (strncasecmp(key,"rlecam_channel",29)==0) {
-				vision.rlecam_channel=atoi(value);
-				return &vision.rlecam_channel;
-			} else if (strncasecmp(key,"rlecam_compression",29)==0) {
+			} else if (strncasecmp(key,"segcam_skip",29)==0 || strncasecmp(key,"rlecam_skip",29)==0) {
+				if(strncasecmp(key,"rlecam_skip",29)==0)
+					std::cout << "Your tekkotsu.cfg file uses deprecated rlecam_skip -- use segcam_skip instead" << std::endl;
+				vision.segcam_skip=atoi(value);
+				if(ProjectInterface::defSegmentedColorGenerator!=NULL && vision.segcam_skip>(int)ProjectInterface::defSegmentedColorGenerator->getNumLayers()-1)
+					vision.segcam_skip=ProjectInterface::defSegmentedColorGenerator->getNumLayers()-1;
+				return &vision.segcam_skip;
+			} else if (strncasecmp(key,"segcam_channel",29)==0 || strncasecmp(key,"rlecam_channel",29)==0) {
+				if(strncasecmp(key,"rlecam_channel",29)==0)
+					std::cout << "Your tekkotsu.cfg file uses deprecated rlecam_channel -- use segcam_channel instead" << std::endl;
+				vision.segcam_channel=atoi(value);
+				return &vision.segcam_channel;
+			} else if (strncasecmp(key,"segcam_compression",29)==0 || strncasecmp(key,"rlecam_compression",29)==0) {
+				if(strncasecmp(key,"rlecam_compression",29)==0)
+					std::cout << "Your tekkotsu.cfg file uses deprecated rlecam_compression -- use segcam_compression instead" << std::endl;
 				if (strncasecmp(value,"none",49)==0) {
-					vision.rlecam_compression=vision_config::COMPRESS_NONE;
+					vision.segcam_compression=vision_config::COMPRESS_NONE;
 				} else if (strncasecmp(value,"rle",49)==0) {
-					vision.rlecam_compression=vision_config::COMPRESS_RLE;
+					vision.segcam_compression=vision_config::COMPRESS_RLE;
+				} else if (strncasecmp(value,"png",49)==0) {
+					vision.segcam_compression=vision_config::COMPRESS_PNG;
 				}
-				return &vision.rlecam_compression;
+				return &vision.segcam_compression;
 			} else if (strncasecmp(key,"regioncam_skip",29)==0) {
 				vision.regioncam_skip=atoi(value);
 				return &vision.regioncam_skip;
@@ -307,6 +339,15 @@ void* Config::setValue(section_t section, const char *key, const char *value, bo
 			} else if (strncasecmp(key,"console_port",29)==0) {
 				main.console_port=atoi(value);
 				return &main.console_port;
+			} else if (strncasecmp(key,"consoleMode",29)==0) {
+				if (strncasecmp(value,"controller",49)==0) {
+					main.consoleMode=main_config::CONTROLLER;
+				} else if (strncasecmp(value,"textmsg",49)==0) {
+					main.consoleMode=main_config::TEXTMSG;
+				} else if (strncasecmp(value,"auto",49)==0) {
+					main.consoleMode=main_config::AUTO;
+				}
+				return &main.consoleMode;
 			} else if (strncasecmp(key,"stderr_port",29)==0) {
 				main.stderr_port=atoi(value);
 				return &main.stderr_port;
@@ -439,7 +480,7 @@ void* Config::setValue(section_t section, const char *key, const char *value, bo
 				else if(strncasecmp(value,"level_3",49)==0)
 					sound.volume=ospkvol10dB;
 				else
-					sound.volume=strtol(value,NULL,0);
+					return NULL;
 				return &sound.volume;
 			} else if (strncasecmp(key,"sample_rate",29)==0) {
 				sound.sample_rate = atoi(value);
@@ -450,13 +491,16 @@ void* Config::setValue(section_t section, const char *key, const char *value, bo
 			} else if (strncasecmp(key,"preload",29)==0) {
 				sound.preload.push_back(value);
 				return &sound.preload ;
+			} else if (strncasecmp(key,"pitchConfidenceThreshold",29)==0) {
+				sound.pitchConfidenceThreshold=atof(value);
+				return &sound.pitchConfidenceThreshold ;
 			} else if (strncasecmp(key,"streaming.mic_port",29)==0) {
 				sound.streaming.mic_port = atoi(value);
 				return &sound.streaming.mic_port;
 			} else if (strncasecmp(key,"streaming.mic_sample_rate",29)==0) {
 				sound.streaming.mic_sample_rate = atoi(value);
 				return &sound.streaming.mic_sample_rate;
-			} else if (strncasecmp(key,"streaming.mic_sample_bits",29)==0) {
+			} else if (strncasecmp(key,"streaming.mic_bits",29)==0) {
 				sound.streaming.mic_sample_bits = atoi(value);
 				return &sound.streaming.mic_sample_bits;
 			} else if (strncasecmp(key,"streaming.mic_stereo",29)==0) {
@@ -465,7 +509,7 @@ void* Config::setValue(section_t section, const char *key, const char *value, bo
 			} else if (strncasecmp(key,"streaming.speaker_port",29)==0) {
 				sound.streaming.speaker_port = atoi(value);
 				return &sound.streaming.speaker_port;
-			} else if (strncasecmp(key,"streaming.speaker_frame_length",30)==0) {
+			} else if (strncasecmp(key,"streaming.speaker_frame_len",29)==0) {
 				sound.streaming.speaker_frame_length = atoi(value);
 				return &sound.streaming.speaker_frame_length;
 			} else if (strncasecmp(key,"streaming.speaker_max_delay",29)==0) {
@@ -473,7 +517,7 @@ void* Config::setValue(section_t section, const char *key, const char *value, bo
 				return &sound.streaming.speaker_max_delay;
 			}
 			break;
-		default:
+		case sec_invalid:
 			break;
 	}
 	return NULL;
@@ -500,12 +544,14 @@ Config::section_t Config::parseSection(const char* key) {
 }
 
 void Config::readConfig(const std::string& filename) {
-	FILE* fp = fopen(filename.c_str(), "r");
-	char buf[80], key[30], value[50];
-	section_t section=sec_invalid;
-	if (fp==NULL) return;
+	FILE* fp = fopen(portPath(filename).c_str(), "r");
+	if (fp==NULL)
+		return;
 	
+	char buf[256], key[30], value[50];
+	section_t section=sec_invalid;
 	bool ignoring=false;
+	
 	std::vector<std::string> curmodel;
 #ifdef PLATFORM_APERIOS
 	char rdStr[orobotdesignNAME_MAX + 1];
@@ -532,8 +578,14 @@ void Config::readConfig(const std::string& filename) {
 	
 	
 	unsigned int lineno=0;
-	while (fscanf(fp,"%79[^\n]\n", buf)!=EOF) {
+	while (fgets(buf,256,fp)!=NULL) {
 		lineno++;
+		char * p=buf;
+		while(*p!='\0' && isspace(*p))
+			p++;
+		if(*p=='\0' || *p=='#')
+			continue; //empty line or comment
+		
 		if (sscanf(buf,"<%29[^>]>",key)>0) {
 			if(key[0]=='/') {
 				if(curmodel.size()==0) {
@@ -572,10 +624,16 @@ void Config::readConfig(const std::string& filename) {
 		} else if(!ignoring) {
 			if (sscanf(buf,"[%29[^]]]",key)>0) {
 				section=parseSection(key);
+				if(section==sec_invalid)
+					std::cerr << "WARNING: Reading " << filename << ", unknown section " << key << " at line number " << lineno << endl;
 				//std::cout << "now parsing section " << section << std::endl;
-			} else if (sscanf(buf,"%29[^=]=%49s",key,value)>1) {
+			} else if (sscanf(buf,"%29[^ =] =%49s",key,value)>1) {
 				//printf("setValue(%d,'%s','%s');\n",section,key,value);
-				setValue(section, key, value);    
+				if(section!=sec_invalid)
+					if(setValue(section, key, value)==NULL)
+						std::cerr << "WARNING: Reading " << filename << ", illegal key/value " << key << '/' << value << " at line number " << lineno << endl;
+			} else {
+				std::cerr << "WARNING: Reading " << filename << ", parse error on key/value " << key << '/' << value << " at line number " << lineno << endl;
 			}
 		}
 	}
@@ -635,9 +693,9 @@ bool Config::extractBool(const char * value) {
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.49 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.59 $
  * $State: Exp $
- * $Date: 2005/08/05 19:44:22 $
+ * $Date: 2006/09/27 20:36:06 $
  */
 
