@@ -59,13 +59,14 @@ class Config {
 		int rawcam_port;      //!< port to send raw frames on
 		int rawcam_transport; //!< transport protocol: 0 for udp, 1 for tcp
 		unsigned int rawcam_interval;  //!< interval between images: 0 for fast-as-possible, 100 for 10 FPS, 200 for 5 FPS, etc.
-		int rle_port;         //!< port to send RLE frames on
-		int rle_transport;    //!< transport protocol: 0 for udp, 1 for tcp
-		unsigned int rle_interval;     //!< interval between images: 0 for fast-as-possible, 100 for 10 FPS, 200 for 5 FPS, etc.
+		int segcam_port;         //!< port to send segmented color frames on
+		int segcam_transport;    //!< transport protocol: 0 for udp, 1 for tcp
+		unsigned int segcam_interval;     //!< interval between images: 0 for fast-as-possible, 100 for 10 FPS, 200 for 5 FPS, etc.
 		int region_port;      //!< port to send Region information on
 		int region_transport; //!< transport protocol: 0 for udp, 1 for tcp
 		int obj_port;         //!< port to send object info on
 		bool restore_image;   //!< if true, replaces pixels holding image info with actual image pixels (as much as possible anyway)
+		bool region_calc_total; //!< if true, RegionGenerator will calculate total area for each color (has to run through the region list for each color)
 		J_DCT_METHOD jpeg_dct_method;  //!< pick between dct methods for jpeg compression
 		float aspectRatio;    //!< ratio of width to height (x_res/y_res); this is *not* read from configuration file, but set from most recent camera image (or RobotInfo namespace values if no camera image has been received)
 		float x_range;        //!< range of values for the x axis when using generalized coordinates; this is *not* read from configuration file, but set from most recent camera image (or RobotInfo namespace values if no camera image has been received)
@@ -83,6 +84,7 @@ class Config {
 		enum compression_t {
 			COMPRESS_NONE, //!< no compression (other than subsampling)
 			COMPRESS_JPEG, //!< JPEG compression
+			COMPRESS_PNG, //!< PNG compression
 			COMPRESS_RLE   //!< RLE compression
 		};
 		compression_t rawcam_compression;//!< holds whether to send jpeg compression
@@ -90,9 +92,9 @@ class Config {
 		int rawcam_compress_quality;//!< 0-100, compression quality (currently only used by jpeg)
 		int rawcam_y_skip;     //!< resolution level to transmit y channel at
 		int rawcam_uv_skip;    //!< resolution level to transmit uv channel at
-		int rlecam_skip;       //!< resolution level to transmit segmented images at
-		int rlecam_channel;    //!< channel of RLEGenerator to send
-		compression_t rlecam_compression; //!< what compression to use on the segmented image
+		int segcam_skip;       //!< resolution level to transmit segmented images at
+		int segcam_channel;    //!< channel to send (which color threshold map to use)
+		compression_t segcam_compression; //!< what compression to use on the segmented image
     int regioncam_skip;    //!< resolution level to transmit segmented images at 
 
 		//!These values represent a "Plumb Bob" model introduced by Brown in 1966
@@ -128,8 +130,8 @@ class Config {
 			float xd=(x-principle_point_x)/focal_len_x-skew*yd;
 			float r2=xd*xd+yd*yd; //estimate of original
 			float radial=(1 + kc1_r2*r2 + kc2_r4*r2*r2 + kc5_r6*r2*r2*r2);
-			r_x=(xd - 2*kc3_tan1*x*y - kc4_tan2*(r2+2*x*x))/radial; //estimating tangential component
-			r_y=(yd - kc3_tan1*(r2+2*y*y) - 2*kc4_tan2*x*y)/radial; //estimating tangential component
+			r_x=(xd - 2*kc3_tan1*xd*yd - kc4_tan2*(r2+2*xd*xd))/radial; //estimating tangential component
+			r_y=(yd - kc3_tan1*(r2+2*yd*yd) - 2*kc4_tan2*xd*yd)/radial; //estimating tangential component
 			r_z=1;
 		}
       
@@ -161,23 +163,31 @@ class Config {
 		//!constructor
 		vision_config()
 			: white_balance(3), gain(2), shutter_speed(2), resolution(2),
-				thresh(), colors(), rawcam_port(10011), rawcam_transport(0), rawcam_interval(0),
-				rle_port(10012), rle_transport(0), rle_interval(0), region_port(0), region_transport(0), obj_port(0), restore_image(true), 
+				thresh(), rawcam_port(10011), rawcam_transport(0), rawcam_interval(0),
+				segcam_port(10012), segcam_transport(0), segcam_interval(0), region_port(0), region_transport(0), obj_port(0), restore_image(true), region_calc_total(true),
 				jpeg_dct_method(JDCT_IFAST), aspectRatio(CameraResolutionX/(float)CameraResolutionY),
 				x_range(aspectRatio>1?1:aspectRatio), y_range(aspectRatio>1?1/aspectRatio:1), 
 				rawcam_encoding(ENCODE_COLOR), rawcam_channel(0),
 				rawcam_compression(COMPRESS_NONE), rawcam_compress_quality(75), rawcam_y_skip(0),
-				rawcam_uv_skip(0), rlecam_skip(1), rlecam_channel(0), rlecam_compression(COMPRESS_RLE), regioncam_skip(1),
+				rawcam_uv_skip(0), segcam_skip(1), segcam_channel(0), segcam_compression(COMPRESS_RLE), regioncam_skip(1),
 				focal_len_x(CameraResolutionX),focal_len_y(CameraResolutionX),principle_point_x(CameraResolutionX/2),
 				principle_point_y(CameraResolutionY/2),skew(0),kc1_r2(0),kc2_r4(0),kc5_r6(0),kc3_tan1(0),kc4_tan2(0),
 				calibration_res_x(CameraResolutionX), calibration_res_y(CameraResolutionY)
-		{}
+		{colors[0]='\0';}
 	} vision;
 	
 	//!core functionality information
 	struct main_config {
 		bool seed_rng;     //!< if true, will call srand with timestamp data, mangled by current sensor data
 		int console_port;  //!< port to send/receive "console" information on (separate from system console)
+		//! types that #consoleMode can take on
+		enum consoleMode_t {
+			CONTROLLER, //!< all input is interpreted as Controller commands, using same syntax as the GUI sends
+			TEXTMSG, //!< all input is broadcast as a text message event
+			AUTO //!< if the GUI is connected, interpret as text messages, otherwise as controller commands.  This was the historical behavior, but seems to be more confusing than helpful.
+		};
+		//! determines how input on #console_port is interpreted
+		consoleMode_t consoleMode; 
 		int stderr_port;   //!< port to send error information to
 		int error_level;   //!< controls amount of info to error port
 		int debug_level;   //!< controls amount of debug info
@@ -194,7 +204,7 @@ class Config {
 		unsigned int worldState_interval; //!< time (in milliseconds) to wait between sending WorldState updates over wireless
 		//!constructor
 		main_config()
-			: seed_rng(true), console_port(10001), stderr_port(10002), error_level(0), debug_level(0),
+			: seed_rng(true), console_port(10001), consoleMode(CONTROLLER), stderr_port(10002), error_level(0), debug_level(0),
 				verbose_level(0),wsjoints_port(10031),wspids_port(10032),headControl_port(10052),
 				walkControl_port(10050),estopControl_port(10053),stewart_port(10055),aibo3d_port(10051),
 				wmmonitor_port(10061), use_VT100(true), worldState_interval(0)
@@ -273,6 +283,7 @@ class Config {
 		unsigned int sample_rate; //!< sample rate to send to system, currently only 8000 or 16000 supported
 		unsigned int sample_bits; //!< sample bit depth, either 8 or 16
 		std::vector<std::string> preload; //!< list of sounds to preload at boot
+		float pitchConfidenceThreshold; //!< confidence threshold required to generate a pitch event [0-1]
 			
 		//!returns an absolute path if @a is relative (to root), otherwise just @a name
 		std::string makePath(const std::string& name) { 
@@ -303,7 +314,7 @@ class Config {
 		} streaming;
 
 		//!constructor
-		sound_config(Config* c) : thisconfig(c), root(), volume(0xF600), sample_rate(0), sample_bits(0), preload(), streaming() {}
+		sound_config(Config* c) : thisconfig(c), root(), volume(0xF600), sample_rate(0), sample_bits(0), preload(), pitchConfidenceThreshold(.6f), streaming() {}
 	private:
 		sound_config(const sound_config&); //!< don't call
 		sound_config& operator=(const sound_config&); //!< don't call
@@ -337,10 +348,10 @@ extern Config* config;
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.49 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.55 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:03 $
+ * $Date: 2006/09/21 21:26:08 $
  */
 
 #endif
