@@ -26,6 +26,7 @@ namespace ERS210Info {
 	//       ROBOT CONFIGURATION
 	// *******************************
 
+	const char* const RobotName="ERS-210"; //!< the name of the model, to be used for logging and remote GUIs
 
 	const unsigned int FrameTime=8;        //!< time between frames in the motion system (milliseconds)
 	const unsigned int NumFrames=4;        //!< the number of frames per buffer (don't forget also double buffered)
@@ -57,9 +58,14 @@ namespace ERS210Info {
 	const float CameraFOV=CameraHorizFOV; //!< should be set to maximum of #CameraHorizFOV or #CameraVertFOV
 	const unsigned int CameraResolutionX=176; //!< the number of pixels available in the 'full' layer
 	const unsigned int CameraResolutionY=144; //!< the number of pixels available in the 'full' layer
+	const float BallOfFootRadius=27.922/2; //!< radius of the ball of the foot
+	const float CylinderOfFootRadius=24.606/2; //!< radius of the cylinder of the foot
 
-	const bool IsFastOutput[NumOutputs] = { true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,false,false }; //!< true for joints which can be updated every 32 ms (all but the ears)
+	//! true for joints which can be updated every 32 ms (all but the ears)
+	/*! @hideinitializer */
+	const bool IsFastOutput[NumOutputs] = { true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,false,false };
 	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in ERS-2xx target mode
+	/*! @hideinitializer */
 	const bool IsRealERS210[NumOutputs] = { true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true };
 	//@}
 
@@ -135,8 +141,20 @@ namespace ERS210Info {
 	const LEDBitMask_t TlRedLEDMask= 1<<(TlRedLEDOffset-LEDOffset); //!< red tail light
 	const LEDBitMask_t TlBluLEDMask= 1<<(TlBluLEDOffset-LEDOffset); //!< blue tail light
 
-	const LEDBitMask_t FaceLEDMask = BotLLEDMask|BotRLEDMask|MidLLEDMask|MidRLEDMask|TopLLEDMask|TopRLEDMask|TopBrLEDMask; //!< LEDs for face (all but tail)
-	const LEDBitMask_t HeadLEDMask = BotLLEDMask|BotRLEDMask|MidLLEDMask|MidRLEDMask|TopLLEDMask|TopRLEDMask|TopBrLEDMask; //!< LEDs for face (all but tail)
+	//! LEDs for face (all but tail)
+	const LEDBitMask_t FaceLEDMask
+	= BotLLEDMask	| BotRLEDMask
+	| MidLLEDMask	| MidRLEDMask
+	| TopLLEDMask	| TopRLEDMask
+	| TopBrLEDMask;
+
+	//! LEDs for face (all but tail)
+	const LEDBitMask_t HeadLEDMask
+	= BotLLEDMask | BotRLEDMask
+	| MidLLEDMask | MidRLEDMask
+	| TopLLEDMask | TopRLEDMask
+	| TopBrLEDMask;
+
 	const LEDBitMask_t BackLEDMask = 0; //!< 210 has no back LEDs
 	const LEDBitMask_t TailLEDMask = TlRedLEDMask|TlBluLEDMask; //!< LEDs on tail
 	const LEDBitMask_t AllLEDMask  = (LEDBitMask_t)~0; //!< selects all of the leds
@@ -168,6 +186,7 @@ namespace ERS210Info {
 		ChinButOffset= 4,
 		BackButOffset,
 		HeadFrButOffset, //!< not in reliable pressure units, but 1.0 is fairly stiff pressure, 0 is none
+		HeadButOffset=HeadFrButOffset,  //!< for ERS-7 compatibility
 		HeadBkButOffset //!< not in reliable pressure units, but 1.0 is fairly stiff pressure, 0 is none
 	};
 	
@@ -395,9 +414,6 @@ namespace ERS210Info {
 	#define __RI_RAD_FLAG
 	#endif
 	
-	//! Defines the indexes to use to access the min and max entries of ERS210Info::outputRanges and ERS210Info::mechanicalLimits
-	enum MinMaxRange_t { MinRange,MaxRange };
-
 	//! This table holds the software limits of each of the outputs
 	const double outputRanges[NumOutputs][2] =
 		{
@@ -485,10 +501,10 @@ namespace ERS210Info {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.20 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.26 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:48 $
+ * $Date: 2006/10/04 02:41:51 $
  */
 
 #endif
