@@ -29,6 +29,7 @@ namespace ERS220Info {
 	//       ROBOT CONFIGURATION
 	// *******************************
 
+	const char* const RobotName="ERS-220"; //!< the name of the model, to be used for logging and remote GUIs
 
 	const unsigned int FrameTime=8;        //!< time between frames in the motion system (milliseconds)
 	const unsigned int NumFrames=4;        //!< the number of frames per buffer (don't forget also double buffered)
@@ -60,7 +61,10 @@ namespace ERS220Info {
 	const float CameraFOV=CameraHorizFOV; //!< should be set to maximum of #CameraHorizFOV or #CameraVertFOV
 	const unsigned int CameraResolutionX=176; //!< the number of pixels available in the 'full' layer
 	const unsigned int CameraResolutionY=144; //!< the number of pixels available in the 'full' layer
+	const float BallOfFootRadius=27.922/2; //!< radius of the ball of the foot
+	const float CylinderOfFootRadius=24.606/2; //!< radius of the cylinder of the foot
 
+	//! true for joints which can be updated every 32 ms (true for all)
 	const bool IsFastOutput[NumOutputs] = {
 		// for PID joints
 		true, true, true,
@@ -78,7 +82,7 @@ namespace ERS220Info {
 		true, true, true,           // face front LEDs x3
 		true,                       // retractable head light x1
 		// for binary joints (none supported/exist on 220)
-	}; //!< true for joints which can be updated every 32 ms (all but the ears on a 210)
+	};
 
 	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in ERS-2xx target mode
 	const bool IsRealERS220[NumOutputs] = {
@@ -98,7 +102,7 @@ namespace ERS220Info {
 		true, true, true,           // face front LEDs x3
 		true,                       // retractable head light x1
 		// for binary joints (none supported/exist on 220)
-	}; //!< true for joints which can be updated every 32 ms (all but the ears on a 210)
+	};
 
 
 	// *******************************
@@ -201,6 +205,7 @@ namespace ERS220Info {
 	const LEDBitMask_t TlRedLEDMask= 1<<(TlRedLEDOffset-LEDOffset); //!< red tail light
 	const LEDBitMask_t TlBluLEDMask= 1<<(TlBluLEDOffset-LEDOffset); //!< blue tail light
 
+	//! LEDs for face
 	const LEDBitMask_t FaceLEDMask
 	= FaceFrontLeftLEDMask
 	| FaceFrontRightLEDMask
@@ -211,26 +216,29 @@ namespace ERS220Info {
 	| FaceFrontALEDMask
 	| FaceFrontBLEDMask
 	| FaceFrontCLEDMask
-	| ModeLEDMask;              //!< LEDs for face
+	| ModeLEDMask;
  
+	//! LEDs on head (face plus retractable light)
 	const LEDBitMask_t HeadLEDMask
-	= FaceLEDMask
-	| RetractableHeadLEDMask;   //!< LEDs on head (face plus retractable light)
+	= FaceLEDMask | RetractableHeadLEDMask;   
  
+	//! LEDs on back
 	const LEDBitMask_t BackLEDMask
 	= BackLeft1LEDMask
 	| BackLeft2LEDMask
 	| BackLeft3LEDMask
 	| BackRight1LEDMask
 	| BackRight2LEDMask
-	| BackRight3LEDMask; //!< LEDs on back
+	| BackRight3LEDMask;
  
+	//! LEDs for tail
 	const LEDBitMask_t TailLEDMask
 	= TailLeftLEDMask
 	| TailCenterLEDMask
-	| TailRightLEDMask;  //!< LEDs for tail
+	| TailRightLEDMask;
  
-	const LEDBitMask_t AllLEDMask  = (LEDBitMask_t)~0; //!< selects all of the leds
+	//! selects all of the leds
+	const LEDBitMask_t AllLEDMask  = (LEDBitMask_t)~0;
 	//@}
 
 
@@ -259,6 +267,7 @@ namespace ERS220Info {
 		ChinButOffset= 4,
 		BackButOffset,
 		HeadFrButOffset, //!< for the "antenna" - this is <.2 if pushed back all the way
+		HeadButOffset=HeadFrButOffset,  //!< for ERS-7 compatibility
 		HeadBkButOffset, //!< for the "antenna" - this is >.98 if pulled forward, <.2 if pushed back partly
 		TailLeftButOffset,
 		TailCenterButOffset,
@@ -497,9 +506,6 @@ namespace ERS220Info {
 #define __RI_RAD_FLAG
 #endif
 
-	//! Defines the indexes to use to access the min and max entries of ERSInfo::outputRanges and ERS7Info::mechanicalLimits
-	enum MinMaxRange_t { MinRange,MaxRange };
-
 	//! This table holds the software limits of each of the outputs
 	const double outputRanges[NumOutputs][2] =
 		{
@@ -589,10 +595,10 @@ namespace ERS220Info {
  * @author Daishi MORI (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.21 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.27 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:48 $
+ * $Date: 2006/10/04 02:41:51 $
  */
 
 #endif
