@@ -25,6 +25,7 @@ namespace ERS2xxInfo {
 	//       ROBOT CONFIGURATION
 	// *******************************
 
+	const char* const RobotName="ERS-2xx"; //!< the name of the model, to be used for logging and remote GUIs
 
 	const unsigned int FrameTime=8;        //!< time between frames in the motion system (milliseconds)
 	const unsigned int NumFrames=4;        //!< the number of frames per buffer (don't forget also double buffered)
@@ -56,7 +57,10 @@ namespace ERS2xxInfo {
 	const float CameraFOV=CameraHorizFOV; //!< should be set to maximum of #CameraHorizFOV or #CameraVertFOV
 	const unsigned int CameraResolutionX=176; //!< the number of pixels available in the 'full' layer
 	const unsigned int CameraResolutionY=144; //!< the number of pixels available in the 'full' layer
+	const float BallOfFootRadius=27.922/2; //!< radius of the ball of the foot
+	const float CylinderOfFootRadius=24.606/2; //!< radius of the cylinder of the foot
 
+	//! true for joints which can be updated every 32 ms (all but the ears on a 210)
 	const bool IsFastOutput[NumOutputs] = {
 		// for PID joints
 		true, true, true, //legs
@@ -78,7 +82,7 @@ namespace ERS2xxInfo {
 		true, true,                 // tail red/blue from 210
 		// for binary joints
 		false, false
-	}; //!< true for joints which can be updated every 32 ms (all but the ears on a 210)
+	};
 
 	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in compatability mode
 	const bool IsRealERS210[NumOutputs] = {
@@ -102,7 +106,7 @@ namespace ERS2xxInfo {
 		true, true,                 // tail red/blue from 210
 		// for binary joints
 		true, true
-	}; //!< true for joints which can be updated every 32 ms (all but the ears on a 210)
+	};
 
 	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in compatability mode
 	const bool IsRealERS220[NumOutputs] = {
@@ -126,7 +130,7 @@ namespace ERS2xxInfo {
 		false, false,               // tail red/blue from 210
 		// for binary joints
 		false, false
-	}; //!< true for joints which can be updated every 32 ms (all but the ears on a 210)
+	};
 
 
 	// *******************************
@@ -234,6 +238,7 @@ namespace ERS2xxInfo {
 	const LEDBitMask_t TopRLEDMask = 1<<(TopRLEDOffset-LEDOffset); //!< top right (red - angry)
 	const LEDBitMask_t TopBrLEDMask= 1<<(TopBrLEDOffset-LEDOffset); //!< top bar (green)
 
+	//! LEDs for face
 	const LEDBitMask_t FaceLEDMask
 	= FaceFrontLeftLEDMask
 	| FaceFrontRightLEDMask
@@ -244,28 +249,31 @@ namespace ERS2xxInfo {
 	| FaceFrontALEDMask
 	| FaceFrontBLEDMask
 	| FaceFrontCLEDMask
-	| ModeLEDMask;              //!< LEDs for face
+	| ModeLEDMask;
  
+	//! LEDs on head (face plus retractable light)
 	const LEDBitMask_t HeadLEDMask
-	= FaceLEDMask
-	| RetractableHeadLEDMask;   //!< LEDs on head (face plus retractable light)
+	= FaceLEDMask | RetractableHeadLEDMask;
  
+	//! LEDs on back
 	const LEDBitMask_t BackLEDMask
 	= BackLeft1LEDMask
 	| BackLeft2LEDMask
 	| BackLeft3LEDMask
 	| BackRight1LEDMask
 	| BackRight2LEDMask
-	| BackRight3LEDMask; //!< LEDs on back
+	| BackRight3LEDMask;
  
+	//! LEDs for tail
 	const LEDBitMask_t TailLEDMask
 	= TailLeftLEDMask
 	| TailCenterLEDMask
 	| TailRightLEDMask
 	| TlRedLEDMask
-	| TlBluLEDMask;  //!< LEDs for tail
+	| TlBluLEDMask;
  
-	const LEDBitMask_t AllLEDMask  = (LEDBitMask_t)~0; //!< selects all of the leds
+	//! selects all of the leds
+	const LEDBitMask_t AllLEDMask  = (LEDBitMask_t)~0;
 	//@}
 
 
@@ -294,6 +302,7 @@ namespace ERS2xxInfo {
 		ChinButOffset= 4,
 		BackButOffset,
 		HeadFrButOffset, //!< see ERS210Info::HeadFrButOffset, ERS220Info::HeadFrButOffset
+		HeadButOffset=HeadFrButOffset,  //!< for ERS-7 compatibility
 		HeadBkButOffset, //!< see ERS210Info::HeadBkButOffset, ERS220Info::HeadBkButOffset
 		TailLeftButOffset,
 		TailCenterButOffset,
@@ -562,9 +571,6 @@ namespace ERS2xxInfo {
 #define __RI_RAD_FLAG
 #endif
 
-	//! Defines the indexes to use to access the min and max entries of ERS2xxInfo::outputRanges and ERS2xxInfo::mechanicalLimits
-	enum MinMaxRange_t { MinRange,MaxRange };
-
 	//! This table holds the software limits of each of the outputs
 	const double outputRanges[NumOutputs][2] =
 		{
@@ -631,10 +637,10 @@ namespace ERS2xxInfo {
  * @author Daishi MORI (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.21 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:49 $
+ * $Date: 2006/10/04 02:41:51 $
  */
 
 #endif
