@@ -13,12 +13,58 @@ typedef unsigned short word; //!< otherwise defined in Types.h
 using namespace RobotInfo;
 
 //! Contains information about the ERS-7 Robot, such as number of joints, PID defaults, timing information, etc.
+/*! 
+You may be particularly interested in the "Output Offsets" section, which, along with the offsets of the common RobotInfo namespace,
+allows you to reference any specific joint or LED on the robot.
+
+The "Input Offsets" section gives the index order of the buttons (#ButtonOffset_t) and sensors (#SensorOffset_t), as well as
+string names for each for easier debugging (#buttonNames, #sensorNames)
+
+"Output Types" section provides "meta-information" regarding the capabilities of the robot, such as the number of head joints, or the number of LEDs, etc.
+
+For more information on your robot's specifications, see also #DefaultPIDs, #MaxOutputSpeed, #outputRanges, and #mechanicalLimits.
+
+"Outputs" (i.e. Joints, LEDs) are often refered to by index ("offset") value within an array.
+These values are formed by specifying a @e section offset, plus a @e specific offset.  Sections are typically general across robot models, whereas the specifics are model-dependent (but can be aliased to provide compatability).
+
+For most joints, the positive direction is "up", and the 0 position yields a forward looking, fully extended standing posture.
+
+- {L,R}{FrBk}LegOffset - #NumLegs combinations, each with #JointsPerLeg items, add #REKOffset_t; see also #LegOffset_t
+  - + #RotatorOffset: positive moves "out", away from body
+  - + #ElevatorOffset: positive moves up, away from body
+  - + #KneeOffset: positive bends knee (slight negative possible)
+- #HeadOffset - #NumHeadJoints items, add #TPROffset_t:
+  - + #TiltOffset: positive looks up
+  - + #PanOffset: positive looks left
+  - + #NodOffset: positive looks up
+- #TailOffset - #NumTailJoints items, add #TPROffset_t:
+  - + #TiltOffset: positive raises the joint (lowers the tail itself)
+  - + #PanOffset: positive points the tail to the Aibo's right
+- MouthOffset - #NumMouthJoints items (no specific, only 1 joint)
+- LEDs: #NumLEDs items, see #LEDOffset_t; these are all direct offsets, and do not need to be added to anything else
+- #EarOffset - #NumEarJoints items (no specifics, first is left ear, second is right ear)
+
+It happens that these joints can also be grouped by the @e type of joint, so there are additionally a few other offsets that can be used in order to loop across a group of joints:
+- PIDJointOffset - #NumPIDJoints items, servos using PID control
+- LegOffset - #NumLegJoints items, a subset of PID servos corresponding to the leg joints
+- LEDOffset - #NumLEDs items
+- BinJointOffset - #NumBinJoints items, solenoids, such as the ears (if any) which flip between two positions
+- #NumOutputs - total number of outputs available
+
+LEDs are often handled in groups to display patterns.  Some functions take an #LEDBitMask_t
+parameter, which allows you to specify a set of several LEDs in a single parameter.  
+For any given LED offset @c fooLEDOffset, the corresponding bitmask constant is @c fooLEDMask.
+Alternatively, you could calculate the bitmask of @c fooLEDOffset by <code>1&lt;&lt;(fooLEDOffset-LEDOffset)</code>.
+
+@see <a href="../media/TekkotsuQuickReference_ERS7.pdf">ERS-7 Quick Reference Sheet</a>
+*/
 namespace ERS7Info {
 
 	// *******************************
 	//       ROBOT CONFIGURATION
 	// *******************************
 
+	const char* const RobotName="ERS-7"; //!< the name of the model, to be used for logging and remote GUIs
 
 	const unsigned int FrameTime=8;        //!< time between frames in the motion system (milliseconds)
 	const unsigned int NumFrames=4;        //!< the number of frames per buffer (don't forget also double buffered)
@@ -39,6 +85,7 @@ namespace ERS7Info {
 	const unsigned NumButtons     =  2+4+3+1; //!< the number of buttons that are available, 2 head, 4 paws, 3 back, 1 underbelly see ERS7Info::ButtonOffset_t
 	const unsigned NumSensors     =  3+3+5;  //!< 3 IR (distance), 3 accel (force), 5 from power, see ERS7Info::SensorOffset_t
 	const unsigned NumLEDs        =  27; //!< The number of LEDs which can be controlled
+	const unsigned NumFacePanelLEDs = 14; //!< The number of face panel LEDs
 	
 	const unsigned NumPIDJoints   = NumLegJoints+NumHeadJoints+NumTailJoints+NumMouthJoints; //!< The number of joints which use PID motion - everything except ears
 	const unsigned NumBinJoints   = NumEarJoints; //!< The number of binary joints - just the ears
@@ -50,14 +97,17 @@ namespace ERS7Info {
 	const float CameraFOV=CameraHorizFOV; //!< should be set to maximum of #CameraHorizFOV or #CameraVertFOV
 	const unsigned int CameraResolutionX=208; //!< the number of pixels available in the 'full' layer
 	const unsigned int CameraResolutionY=160; //!< the number of pixels available in the 'full' layer
+	const float BallOfFootRadius=23.433/2; //!< radius of the ball of the foot
 
-	//! true for joints which can be updated every 32 ms (all ers-7 joints)
+	//! true for joints which can be updated every 32 ms (all joints on ERS-7)
+	/*! @hideinitializer */
 	const bool IsFastOutput[NumOutputs] = {
 		true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true, //PID joints
 		true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true, //leds
 		true,true //ears
 	};
 	//! we need this so you can tell programmatically which joints are "real" and which are "fake" in a compatability mode
+	/*! @hideinitializer */
 	const bool IsRealERS7[NumOutputs] = { 
 		true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true, //PID joints
 		true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,false, //leds
@@ -74,15 +124,15 @@ namespace ERS7Info {
 	//!@name Output Offsets
 
 	const unsigned PIDJointOffset = 0; //!< The beginning of the PID Joints
-	const unsigned LegOffset   = PIDJointOffset;           //!< the offset of the beginning of the leg joints
-	const unsigned HeadOffset  = LegOffset+NumLegJoints;   //!< the offset of the beginning of the head joints
-	const unsigned TailOffset  = HeadOffset+NumHeadJoints; //!< the offset of the beginning of the tail joints
-	const unsigned MouthOffset = TailOffset+NumTailJoints; //!< the offset of the beginning of the mouth joint
+	const unsigned LegOffset   = PIDJointOffset;           //!< the offset of the beginning of the leg joints, #NumLegs of #JointsPerLeg each, in #LegOrder_t order; see #LegOffset_t
+	const unsigned HeadOffset  = LegOffset+NumLegJoints;   //!< the offset of the beginning of the head joints, add #TPROffset_t to get specific joint
+	const unsigned TailOffset  = HeadOffset+NumHeadJoints; //!< the offset of the beginning of the tail joints, add #TPROffset_t to get specific joint (except RollOffset not available)
+	const unsigned MouthOffset = TailOffset+NumTailJoints; //!< the offset of the beginning of the mouth joint, is specific joint
 
-	const unsigned LEDOffset   = PIDJointOffset + NumPIDJoints; //!< the offset of LEDs in WorldState::outputs and MotionCommand functions
+	const unsigned LEDOffset   = PIDJointOffset + NumPIDJoints; //!< the offset of LEDs in WorldState::outputs and MotionCommand functions, see LedOffset_t for specific offsets
 
 	const unsigned BinJointOffset = LEDOffset + NumLEDs;   //!< The beginning of the binary joints
-	const unsigned EarOffset   = BinJointOffset;           //!< the offset of the beginning of the ear joints - note that ears aren't sensed.  They can be flicked by the environment and you won't know.  Nor will they be flicked back
+	const unsigned EarOffset   = BinJointOffset;           //!< the offset of the beginning of the ear joints - note that ears aren't sensed.  They can be flicked by the environment and you won't know.
 
 	const unsigned BaseFrameOffset   = NumOutputs; //!< Use with kinematics to refer to base reference frame
 	const unsigned PawFrameOffset    = BaseFrameOffset+1; //!< Use with kinematics to refer to paw reference frames (add appropriate LegOrder_t to specify which paw)
@@ -92,45 +142,46 @@ namespace ERS7Info {
 	const unsigned ChestIRFrameOffset = FarIRFrameOffset+1; //!< Use with kinematics to refer to chest-mounted infrared (distance) sensor reference frame
 
 
-	//! The offsets of the individual legs
+	//! The offsets of the individual legs, add #REKOffset_t value to access specific joint
+	/*! @hideinitializer */
 	enum LegOffset_t {
-		LFrLegOffset = LegOffset+LFrLegOrder*JointsPerLeg, //!< beginning of left front leg
-		RFrLegOffset = LegOffset+RFrLegOrder*JointsPerLeg, //!< beginning of right front leg
-		LBkLegOffset = LegOffset+LBkLegOrder*JointsPerLeg, //!< beginning of left back leg
-		RBkLegOffset = LegOffset+RBkLegOrder*JointsPerLeg  //!< beginning of right back leg
+		LFrLegOffset = LegOffset+LFrLegOrder*JointsPerLeg, //!< beginning of left front leg's joints
+		RFrLegOffset = LegOffset+RFrLegOrder*JointsPerLeg, //!< beginning of right front leg's joints
+		LBkLegOffset = LegOffset+LBkLegOrder*JointsPerLeg, //!< beginning of left back leg's joints
+		RBkLegOffset = LegOffset+RBkLegOrder*JointsPerLeg  //!< beginning of right back leg's joints
 	};
 	
-	//@}
-	
 	//! The offsets of the individual LEDs on the head and tail.  Note that left/right are robot's point of view.  See also LEDBitMask_t
+	/*! @hideinitializer */
 	enum LEDOffset_t {
-		HeadColorLEDOffset = LEDOffset,
-		HeadWhiteLEDOffset,
-		ModeRedLEDOffset,
-		ModeGreenLEDOffset,
-		ModeBlueLEDOffset,
-		WirelessLEDOffset,
-		FaceLEDPanelOffset, //!< the first LED in the panel - add to this to get the other 13 (14 total)
-		FrBackColorLEDOffset = FaceLEDPanelOffset+14, // blue/purple
-		FrBackWhiteLEDOffset,
-		MdBackColorLEDOffset,                    // orange
-		MdBackWhiteLEDOffset,
-		RrBackColorLEDOffset,                    // red
-		RrBackWhiteLEDOffset,
+		HeadColorLEDOffset = LEDOffset, //!< the orange LED immediately above the head button (copositioned with #HeadWhiteLEDOffset)
+		HeadWhiteLEDOffset, //!< the LED immediately above the head button (copositioned with #HeadColorLEDOffset)
+		ModeRedLEDOffset, //!< controls both of the red LEDs above the ears (copositioned with #ModeGreenLEDOffset and #ModeBlueLEDOffset)
+		ModeGreenLEDOffset, //!< controls both of the green LEDs above the ears (copositioned with #ModeRedLEDOffset and #ModeBlueLEDOffset)
+		ModeBlueLEDOffset, //!< controls both of the blue LEDs above the ears (copositioned with #ModeRedLEDOffset and #ModeGreenLEDOffset)
+		WirelessLEDOffset, //!< controls the small rectangular blue LED on the back of the head
+		FaceLEDPanelOffset, //!< the first LED in the panel - add 0 up to (not including) #NumFacePanelLEDs to this to access specific face panel LEDs, see LedEngine for diagram of placement
+		FrBackColorLEDOffset = FaceLEDPanelOffset+NumFacePanelLEDs, //!< @b blue/purple LED on back, closest to head (copositioned with #FrBackWhiteLEDOffset)
+		FrBackWhiteLEDOffset,  //!< white LED on back, closest to head (copositioned with #FrBackColorLEDOffset)
+		MdBackColorLEDOffset, //!< @b orange LED on back, in between FrBackColorLEDOffset and RrBackColorLEDOffset (copositioned with #MdBackWhiteLEDOffset)
+		MdBackWhiteLEDOffset, //!< white LED on back, in between FrBackWhiteLEDOffset and RrBackWhiteLEDOffset (copositioned with #MdBackColorLEDOffset)
+		RrBackColorLEDOffset, //!< @b red LED on back, farthest from head (copositioned with #RrBackWhiteLEDOffset)
+		RrBackWhiteLEDOffset, //!< white LED on back, farthest from head (copositioned with #RrBackColorLEDOffset)
 		LEDABModeOffset, // allows you to control A/B mode setting (this is a "virtual" LED)
 
 		// aliases for 2xx cross-compatibility
-		BotLLEDOffset = FaceLEDPanelOffset+0,//!< aliases for backward compatability (use mode A); bottom left
-		BotRLEDOffset = FaceLEDPanelOffset+1, //!< bottom right
-		MidLLEDOffset = FaceLEDPanelOffset+2, //!< middle left
-		MidRLEDOffset = FaceLEDPanelOffset+3, //!< middle right
-		TopLLEDOffset = FaceLEDPanelOffset+6, //!< top left
-		TopRLEDOffset = FaceLEDPanelOffset+7, //!< top right
-		TopBrLEDOffset= HeadColorLEDOffset,//!< top bar
-		TlRedLEDOffset= RrBackColorLEDOffset,//!< red tail light
-		TlBluLEDOffset= FrBackColorLEDOffset //!< blue tail light
+		BotLLEDOffset = FaceLEDPanelOffset+1,//!< aliases for backward compatability with ERS-210 (use mode A); bottom left of face panel
+		BotRLEDOffset = FaceLEDPanelOffset+0, //!< aliases for backward compatability with ERS-210 (use mode A); bottom right of face panel
+		MidLLEDOffset = FaceLEDPanelOffset+3, //!< aliases for backward compatability with ERS-210 (use mode A); middle left of face panel
+		MidRLEDOffset = FaceLEDPanelOffset+2, //!< aliases for backward compatability with ERS-210 (use mode A); middle right of face panel
+		TopLLEDOffset = FaceLEDPanelOffset+7, //!< aliases for backward compatability with ERS-210 (use mode A); top left of face panel
+		TopRLEDOffset = FaceLEDPanelOffset+6, //!< aliases for backward compatability  with ERS-210(use mode A); top right of face panel
+		TopBrLEDOffset= HeadColorLEDOffset,//!< aliases for backward compatability with ERS-210 (use mode A); top bar (#HeadColorLEDOffset)
+		TlRedLEDOffset= RrBackColorLEDOffset,//!< aliases for backward compatability with ERS-210; red tail light (#RrBackColorLEDOffset)
+		TlBluLEDOffset= FrBackColorLEDOffset //!< aliases for backward compatability with ERS-210; blue tail light (#FrBackColorLEDOffset)
 	};
-	
+	//@}
+		
 	//! Bitmasks for use when specifying combinations of LEDs (see LedEngine ) Note that left/right are robot's point of view
 	//!@name LED Bitmasks
 	typedef unsigned int LEDBitMask_t; //!< So you can be clear when you're refering to a LED bitmask
@@ -160,11 +211,27 @@ namespace ERS7Info {
 	const LEDBitMask_t TlRedLEDMask= 1<<(TlRedLEDOffset-LEDOffset); //!< red tail light
 	const LEDBitMask_t TlBluLEDMask= 1<<(TlBluLEDOffset-LEDOffset); //!< blue tail light
 
-	const LEDBitMask_t FaceLEDMask = (FaceLEDPanelMask<<0) | (FaceLEDPanelMask<<1) | (FaceLEDPanelMask<<2) | (FaceLEDPanelMask<<3) | (FaceLEDPanelMask<<4) | (FaceLEDPanelMask<<5) | (FaceLEDPanelMask<<6) | (FaceLEDPanelMask<<7) | (FaceLEDPanelMask<<8) | (FaceLEDPanelMask<<9) | (FaceLEDPanelMask<<10) | (FaceLEDPanelMask<<11) | (FaceLEDPanelMask<<12) | (FaceLEDPanelMask<<13); //!< LEDs for the face panel
-	const LEDBitMask_t HeadLEDMask = FaceLEDMask | HeadColorLEDMask | HeadWhiteLEDMask | ModeRedLEDMask | ModeGreenLEDMask | ModeBlueLEDMask | WirelessLEDMask; //!< LEDs for face (all but back lights)
-	const LEDBitMask_t BackLEDMask = FrBackColorLEDMask | FrBackWhiteLEDMask | MdBackColorLEDMask | MdBackWhiteLEDMask | RrBackColorLEDMask | RrBackWhiteLEDMask; //!< LEDS on the back
-	const LEDBitMask_t TailLEDMask = 0; //!< LEDs on tail (ERS-7 has none)
-	const LEDBitMask_t AllLEDMask  = (LEDBitMask_t)~0; //!< selects all of the leds
+	//! LEDs for the face panel (all FaceLEDPanelMask<<(0:NumFacePanelLEDs-1) entries)
+	/*! @hideinitializer */
+	const LEDBitMask_t FaceLEDMask = (FaceLEDPanelMask<<0) | (FaceLEDPanelMask<<1) | (FaceLEDPanelMask<<2) | (FaceLEDPanelMask<<3) | (FaceLEDPanelMask<<4) | (FaceLEDPanelMask<<5) | (FaceLEDPanelMask<<6) | (FaceLEDPanelMask<<7) | (FaceLEDPanelMask<<8) | (FaceLEDPanelMask<<9) | (FaceLEDPanelMask<<10) | (FaceLEDPanelMask<<11) | (FaceLEDPanelMask<<12) | (FaceLEDPanelMask<<13);
+
+	//! LEDs for face (all but back lights)
+	const LEDBitMask_t HeadLEDMask
+	= FaceLEDMask | HeadColorLEDMask | HeadWhiteLEDMask
+	| ModeRedLEDMask | ModeGreenLEDMask | ModeBlueLEDMask
+	| WirelessLEDMask;
+
+	//! LEDS on the back
+	const LEDBitMask_t BackLEDMask
+	= FrBackColorLEDMask | FrBackWhiteLEDMask
+	| MdBackColorLEDMask | MdBackWhiteLEDMask
+	| RrBackColorLEDMask | RrBackWhiteLEDMask;
+
+	//! LEDs on tail (ERS-7 has none)
+	const LEDBitMask_t TailLEDMask = 0;
+
+	//! selects all of the leds
+	const LEDBitMask_t AllLEDMask  = (LEDBitMask_t)~0;
 	//@}
 
 
@@ -184,7 +251,8 @@ namespace ERS7Info {
 	 *  normal way.  If you want to know when it is pressed (and you are
 	 *  about to shut down) see PowerSourceID::PauseSID.
 	 *
-	 *  @see WorldState::buttons @see ButtonSourceID_t */
+	 *  @see WorldState::buttons @see ButtonSourceID_t
+	 * @hideinitializer */
 	enum ButtonOffset_t {
 		LFrPawOffset = LFrLegOrder,
 		RFrPawOffset = RFrLegOrder,
@@ -238,71 +306,39 @@ namespace ERS7Info {
 	const unsigned outputNameLen = 9;
 	//! A name of uniform length for referring to joints - handy for posture files, etc.
 	const char* const outputNames[NumOutputs] = {
-		"LFr:rotor",
-		"LFr:elvtr",
-		"LFr:knee~",
-		"RFr:rotor",
-		"RFr:elvtr",
-		"RFr:knee~",
-		"LBk:rotor",
-		"LBk:elvtr",
-		"LBk:knee~",
-		"RBk:rotor",
-		"RBk:elvtr",
-		"RBk:knee~",
+		"LFr:rotor","LFr:elvtr","LFr:knee~",
+		"RFr:rotor","RFr:elvtr","RFr:knee~",
+		"LBk:rotor","LBk:elvtr","LBk:knee~",
+		"RBk:rotor","RBk:elvtr","RBk:knee~",
 		
-		"NECK:tilt",
-		"NECK:pan~",
-		"NECK:nod~",
+		"NECK:tilt","NECK:pan~","NECK:nod~",
 		
-		"TAIL:tilt",
-		"TAIL:pan~",
+		"TAIL:tilt",	"TAIL:pan~",
 		
 		"MOUTH~~~~",
 		
-		"LED:headC",
-		"LED:headW",
-		"LED:modeR",
-		"LED:modeG",
-		"LED:modeB",
-		"LED:wless",
-		"LED:faceA",
-		"LED:faceB",
-		"LED:faceC",
-		"LED:faceD",
-		"LED:faceE",
-		"LED:faceF",
-		"LED:faceG",
-		"LED:faceH",
-		"LED:faceI",
-		"LED:faceJ",
-		"LED:faceK",
-		"LED:faceL",
-		"LED:faceM",
-		"LED:faceN",
-		"LED:bkFrC",
-		"LED:bkFrW",
-		"LED:bkMdC",
-		"LED:bkMdW",
-		"LED:bkRrC",
-		"LED:bkRrW",
+		"LED:headC","LED:headW",
+		"LED:modeR","LED:modeG",
+		"LED:modeB","LED:wless",
+		"LED:faceA","LED:faceB","LED:faceC","LED:faceD","LED:faceE","LED:faceF","LED:faceG",
+		"LED:faceH","LED:faceI","LED:faceJ","LED:faceK","LED:faceL","LED:faceM","LED:faceN",
+		"LED:bkFrC","LED:bkFrW",
+		"LED:bkMdC","LED:bkMdW",
+		"LED:bkRrC","LED:bkRrW",
 		"LED:ABmod",
 		
-		"EAR:left~",
-		"EAR:right"
+		"EAR:left~","EAR:right"
 	};
 	
 
 	//! the joint identifier strings used to refer to specific joints in OPEN-R (but not needed for others)
 	/*!@showinitializer 
-	 * @warning IMPORTANT!!!!  DO NOT CHANGE THE ORDER OF ITEMS IN THIS TABLE!!!\n
-	 *
 	 * The offset consts defined in this file correspond to this table and will make life easier
-	 * if you feel the need to reorder things, but they aren't used perfect @e everywhere \n
+	 * if you feel the need to reorder things, but they can't be arbitrarily reordered... \n
 	 * In particular, assumptions are made that the pid joints will be in slots 0-numPIDJoints
 	 * and that the fast outputs (ie NOT ears) will be in slots 0-NumFastOutputs\n
 	 * There may be other assumptions not noted here!!!
-	 * @note These entries DON'T correspond to the CPC index numbers defined in WorldState (this only lists joints, and in a different order defined by OPEN-R, that one has sensors as well*/
+	 * @note These entries DON'T correspond to the CPC index numbers (this only lists joints for identifying joints to Aperios, CPCs are for identifying sensors from Aperios */
 	const char* const PrimitiveName [NumOutputs] = {
 		"PRM:/r2/c1-Joint2:21",       //!< the left front leg   the rotator
 		"PRM:/r2/c1/c2-Joint2:22",    //!< the left front leg   the elevator 
@@ -439,10 +475,7 @@ namespace ERS7Info {
 	#define __RI_RAD_FLAG
 	#endif
 	
-	//! Defines the indexes to use to access the min and max entries of ERS7Info::outputRanges and ERS7Info::mechanicalLimits
-	enum MinMaxRange_t { MinRange,MaxRange };
-
-	//! This table holds the software limits of each of the outputs
+	//! This table holds the software limits of each of the outputs, first index is the output offset, second index is #MinMaxRange_t (i.e. #MinRange or #MaxRange)
 	const double outputRanges[NumOutputs][2] =
 		{
 			{ RAD(-115),RAD(130) },{ RAD(-10),RAD(88) },{ RAD(-25),RAD(122) }, //left front REK
@@ -464,7 +497,8 @@ namespace ERS7Info {
 			{0,1},{0,1} //ears
 		};
 
-	//! This table holds the mechanical limits of each of the outputs @todo same as outputLimits right now, don't know actual values yet
+	//! This table holds the mechanical limits of each of the outputs, first index is the output offset, second index is #MinMaxRange_t (i.e. #MinRange or #MaxRange)
+	/*! Same as #outputLimits, don't know actual values because they were never specified by Sony */
 	const double mechanicalLimits[NumOutputs][2] =
 		{
 			{ RAD(-115),RAD(130) },{ RAD(-10),RAD(88) },{ RAD(-25),RAD(122) }, //left front REK
@@ -478,8 +512,11 @@ namespace ERS7Info {
 
 			{ RAD(-55),RAD(-3) }, //mouth
 
-			{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1}, //LEDs
-		
+			{0,1},{0,1},{0,1},{0,1},{0,1},{0,1}, //misc head LEDs
+			{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1},{0,1}, //Face LEDs
+			{0,1},{0,1},{0,1},{0,1},{0,1},{0,1}, //back LEDs
+			{0,1}, //virtual mode A/B switcher
+
 			{0,1},{0,1} //ears
 		};
 
@@ -490,7 +527,7 @@ namespace ERS7Info {
 
 
 	/*! @name CPC IDs
-	 * values defined by OPEN-R, used to interface with lower level OPEN-R code to read sensors - DOESN'T correspond to ERS7Info::PrimitiveName */
+	 * Values defined by OPEN-R, used to interface with lower level OPEN-R code to read sensors - values @e don't correspond to order of ERS7Info::PrimitiveName */
 	static const int CPCJointMouth      =  0; //!< Mouth                           
 	static const int CPCSwitchChin      =  1; //!< Chin sensor                     
 	static const int CPCJointNeckNod    =  2; //!< Neck tilt2                      
@@ -530,14 +567,14 @@ namespace ERS7Info {
 }
 	
 /*! @file
- * @brief Defines RobotInfo namespace for ERS-210 models, gives some information about the robot's capabilities, such as joint counts, offsets, names and PID values
+ * @brief Defines RobotInfo namespace for ERS-7 models, gives some information about the robot's capabilities, such as joint counts, offsets, names and PID values
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.25 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.35 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:49 $
+ * $Date: 2006/10/04 02:41:51 $
  */
 
 #endif
