@@ -11,11 +11,13 @@
  *  @param NAME the name of this section for reporting
  *  @param PROF the actual profiler to use
  */
+#ifndef PROFSECTION
 #define PROFSECTION(NAME,PROF) \
-  static unsigned int _PROFSECTION_id=PROF.getNewID(NAME);\
-  Profiler::Timer _PROFSECTION_timer(_PROFSECTION_id,&PROF.prof);
+  static unsigned int _PROFSECTION_id=(PROF).getNewID(NAME);\
+  Profiler::Timer _PROFSECTION_timer(_PROFSECTION_id,&(PROF).prof);
+#endif
 
-//! Managers a hierarchy of timers for profiling time spent in code, gives microsecond resolution
+//! Manages a hierarchy of timers for profiling time spent in code, gives microsecond resolution
 /*! Doesn't use any pointers so it's safe to put this in shared memory regions.\n
  *  That's handy so one process can collate all the profiling information across processes
  *  to give a summary report to the user.\n
@@ -43,7 +45,7 @@
  *  void g() {
  *    PROFSECTION("g",prof);   // <== Most of the time, this is all you need
  *    //...                    // (unless you're doing something fancy like conditional timers)
- *    f(); // will note f's time as g's child time
+ *    f(); // will note f's time as g's child time, as well as g's own time
  *    //...
  *  }
  *  @endcode
@@ -52,6 +54,13 @@
  *  resolution than a function, you can use tricks shown in MMAccessor's documentation to limit
  *  the timer's scope.
  *
+ *  For convenience, there are three global profilers predefined: #mainProfiler, #motionProfiler,
+ *  and #soundProfiler.  These are what are polled by the ProfilerCheckControl -- if you instantiate
+ *  a new profiler, you will have to call its report() function yourself to get the results.  (If it's simply
+ *  a matter of running out of sections in mainProfiler, increase the template parameter at the end
+ *  of Profiler.h)  Keep in mind however, that these global profilers are pointers, and need to be
+ *  dereferenced to use with the macro, e.g. <code>PROFSECTION("g2",*mainProfiler)</code>
+ *
  *  Here were the constraints I set for myself:
  *  - Processes can read each other's Profilers - so must be able to live in shared memory\n
  *    This is so one process can generate a report on performance of the entire system at once
@@ -193,8 +202,8 @@ protected:
 	//! Automatically causes initialization of the histogram buckets when the first Profiler is instantiated
 	class AutoInit {
 	public:
-		AutoInit();
-		~AutoInit();
+		AutoInit(); //!< constructor, adds to #refcount and #totalcount, causes initalization if was 0
+		~AutoInit(); //!< destructor, decrements #refcount, does teardown if it hits 0
 	protected:
 		static unsigned int refcount; //!< the number of profilers in existance
 		static unsigned int totalcount; //!< the number of profilers which have been created
@@ -217,15 +226,23 @@ public:
 	Profiler::SectionInfo infos[MaxSections]; //!< the actual profiling information storage
 };
 
+// feel free to ignore these or add your own as well -- these are the ones that framework-included code will use
+typedef ProfilerOfSize<20> mainProfiler_t; //!< defines type for code profiling information for MainObject; use this instead of the templated type so you don't rely on a particular size
+typedef ProfilerOfSize<6> motionProfiler_t; //!< defines type for code profiling information for MotionObject; use this instead of the templated type so you don't rely on a particular size
+typedef ProfilerOfSize<6> soundProfiler_t; //!< defines type for code profiling information for SoundPlay; use this instead of the templated type so you don't rely on a particular size
+extern mainProfiler_t * mainProfiler; //!< holds code profiling information for MainObject
+extern motionProfiler_t * motionProfiler; //!< holds code profiling information for MotoObject
+extern soundProfiler_t * soundProfiler; //!< holds code profiling information for SoundPlay
+
 /*! @file
  * @brief Describes Profiler, which managers a hierarchy of timers for profiling time spent in code
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.17 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:04 $
+ * $Date: 2006/09/16 17:32:40 $
  */
 
 #endif
