@@ -4,10 +4,15 @@
 
 #include <iostream>
 
-//class ReferenceCounter;
-//const char* findname(ReferenceCounter* x); // !< tests if @a x is a behavior and outputs its name, otherwise outputs its address
-
 //! Performs simple reference counting, will delete the object when removing the last reference
+/*! Remember to call SetAutoDelete(false) if you
+ *  instantiate a subclass on the stack instead of the heap -- don't want to try to free memory
+ *  on the stack if/when last reference is removed!  (The stack limits the allocation of the behavior
+ *  to the current scope, so reference counting is moot.)
+ *
+ *  @todo It would be nice if there was a way for ReferenceCounter to automatically know whether it
+ *  has been allocated on the stack... is that possible?
+ */
 class ReferenceCounter {
  public:
 	//! constructor
@@ -25,13 +30,18 @@ class ReferenceCounter {
 
 	//! adds one to #references
 	virtual void AddReference() { references++; }
-	//! subtracts one from #references AND DELETES the object IF ZERO
-	virtual void RemoveReference() {
+	//! subtracts one from #references AND DELETES the object IF ZERO (and RC_autodelete is set)
+	/*! @return true if the last reference was removed, false otherwise */
+	virtual bool RemoveReference() {
 		if(--references==0) {
 			if(RC_autodelete)
 				delete this;
-		} else if(references==(unsigned int)-1)
+			return true;
+		} else if(references==(unsigned int)-1) {
 			std::cout << "*** WARNING RefCounter went negative" << std::endl;
+			return true;
+		} else
+			return false;
 	}
 	//! returns the number of references
 	/*! @return references */
@@ -73,10 +83,10 @@ const char* findname(ReferenceCounter* x) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2005/02/02 18:22:29 $
+ * $Date: 2006/10/03 19:13:16 $
  */
 
 #endif
