@@ -1,15 +1,15 @@
 #include "TimeET.h"
 
-struct timezone TimeET::tz;
+struct timezone TimeET::tz={0,0};
 
 /*! @file
  * @brief Implements TimeET, a nice class for handling time values with high precision (but all that's in the .cc is implementation of struct timezone TimeET::tz)
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.3 $
- * $State: Rel $
- * $Date: 2003/09/25 15:31:53 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.4 $
+ * $State: Exp $
+ * $Date: 2006/03/15 16:44:07 $
  */
 
