@@ -14,10 +14,10 @@
  *  @author alokl (Ported)
  *  
  *  $Author: ejt $
- *  $Name: tekkotsu-2_4_1 $
- *  $Revision: 1.5 $
+ *  $Name: tekkotsu-3_0 $
+ *  $Revision: 1.7 $
  *  $State: Exp $
- *  $Date: 2005/07/26 03:22:04 $
+ *  $Date: 2006/09/11 23:05:15 $
  *
  * \par These macros allow you to quickly create a WM variable, but only if
  * it's staticly defined - you can't use these with a dynamic number
@@ -133,13 +133,13 @@ public:
   //! Turn on monitoring of changes to the variable described by this entry.
   void watch(void) const {
 		entry->watched = 1; 
-		erouter->postEvent(new EventBase(EventBase::wmVarEGID,reinterpret_cast<unsigned int>(entry),EventBase::activateETID));
+		erouter->postEvent(EventBase::wmVarEGID,reinterpret_cast<size_t>(entry),EventBase::activateETID);
 	};
 
   //! Turn off monitoring of changes to the variable described by this entry.
   void unwatch(void) const {
 		entry->watched = 0;
-		erouter->postEvent(new EventBase(EventBase::wmVarEGID,reinterpret_cast<unsigned int>(entry),EventBase::deactivateETID));
+		erouter->postEvent(EventBase::wmVarEGID,reinterpret_cast<size_t>(entry),EventBase::deactivateETID);
 	};
 
 private:
@@ -250,7 +250,7 @@ void dump(const WMitem<WMregistry> &wmreg);
 template<class T>
 std::string WMitem<T>::toString(void) const {
   char print_buffer[30];
-  sprintf(print_buffer,"%x",reinterpret_cast<unsigned int>(value));
+  sprintf(print_buffer,"%p",value);
   return "<" + entry->type_name + " at 0x" + print_buffer + ">";
 }
 
@@ -268,7 +268,7 @@ WMitem<T>& WMitem<T>::operator= (const T &new_value) {
 template<class T>
 void WMitem<T>::announce (const T&) {
   if (entry->watched) {
-		erouter->postEvent(new EventBase(EventBase::wmVarEGID,reinterpret_cast<unsigned int>(entry),EventBase::statusETID));
+		erouter->postEvent(EventBase::wmVarEGID,reinterpret_cast<size_t>(entry),EventBase::statusETID);
 	}
 	/*    if (wmMonitorBehavior!=NULL) {
 				std::string s(entry->item_name);
