@@ -1,12 +1,3 @@
-#ifdef PLATFORM_APERIOS
-#include <OPENR/core_macro.h>
-#include <OPENR/ObjcommTypes.h>
-#include <OPENR/OPENR.h>
-#include <OPENR/OPENRAPI.h>
-#include <OPENR/OPENRMessages.h>
-#include <OPENR/OPower.h>
-#endif
-
 #include "WorldState.h"
 #include "Shared/get_time.h"
 #include "Events/EventRouter.h"
@@ -14,6 +5,18 @@
 #include "ERS220Info.h"
 #include "ERS7Info.h"
 #include "Shared/Config.h"
+#include "IPC/ProcessID.h"
+
+#ifdef PLATFORM_APERIOS
+#  include <OPENR/core_macro.h>
+#  include <OPENR/ObjcommTypes.h>
+#  include <OPENR/OPENR.h>
+#  include <OPENR/OPENRAPI.h>
+#  include <OPENR/OPENRMessages.h>
+#  include <OPENR/OPower.h>
+#else
+#  include "Motion/PostureEngine.h"
+#endif
 
 #define GETD(cpc) (((float)sensor.GetData(cpc)->frame[lastFrame].value) / 1.0E6f) //!< returns value from OPEN-R, converted from micro in int to base in float
 #define GETB(cpc) ((bool)sensor.GetData(cpc)->frame[lastFrame].value) //!< returns value from OPEN-R, as bool
@@ -24,13 +27,17 @@
 const double WorldState::g=9.80665;
 const double WorldState::IROORDist = 900.0;
 
+#ifdef PLATFORM_APERIOS
+WorldState ** WorldState::stateLookupMap=NULL;
+#endif
+
 WorldState * state=NULL;
 
 WorldState::WorldState()
 	: alwaysGenerateStatus(false), vel_x(0), vel_y(0), vel_a(0), vel_time(0),
 		robotStatus(0), batteryStatus(0),
-		lastSensorUpdateTime(0), mainProfile(), motionProfile(),
-		robotDesign(0), curtime(get_time())
+		lastSensorUpdateTime(0), frameNumber(1), framesProcessed(0),
+		robotDesign(0), curtime(0)
 {
 	for(unsigned int i=0; i< NumOutputs; i++)
 		outputs[i]=0;
@@ -85,14 +92,31 @@ WorldState::WorldState()
 
 #ifdef PLATFORM_APERIOS
 
-/*! This will cause events to be posted
- *  @todo change to use most recent instead of oldest - is a buffer! */
-void WorldState::read(OSensorFrameVectorData& sensor, EventRouter* er) {
+/*! This will cause events to be posted */
+void WorldState::read(OSensorFrameVectorData& sensor, WorldState* lastState, EventRouter* er) {
+	//always using GetInfo(0) to get "global" information for the vector, other infos contain metadata for individual data fields
+	unsigned int newFrameNumber=sensor.GetInfo(0)->frameNumber;
+	if(frameNumber>=newFrameNumber)
+		return; //sensors have already been filled in
+	
 	curtime=get_time();
 
-	std::vector<EventBase*> evtBuf;
+	std::vector<EventBase> evtBuf;
 	unsigned int lastFrame=sensor.GetInfo(0)->numFrames-1;
 
+	if(lastState!=NULL && lastState!=this) {
+		alwaysGenerateStatus=lastState->alwaysGenerateStatus;
+		//pid and velocity values will be copied at "completion"
+		robotStatus=lastState->robotStatus;
+		batteryStatus=lastState->batteryStatus;
+		for(unsigned int i=0; i<PowerSourceID::NumPowerSIDs; i++)
+			powerFlags[i]=lastState->powerFlags[i];
+		
+		//important part -- copy over button_times before calls to chkEvent
+		for(unsigned int i=0; i<NumButtons; i++)
+			button_times[i]=lastState->button_times[i];
+	}
+	
 	if(robotDesign&ERS210Mask) {
 		outputs[LFrLegOffset + RotatorOffset   ] = GETD(ERS210Info::CPCJointLFRotator);
 		outputs[LFrLegOffset + ElevatorOffset  ] = GETD(ERS210Info::CPCJointLFElevator);
@@ -138,17 +162,33 @@ void WorldState::read(OSensorFrameVectorData& sensor, EventRouter* er) {
 		outputs[ERS210Info::MouthOffset] = GETD(ERS210Info::CPCJointMouth);
 		pidduties[ERS210Info::MouthOffset] = GETDUTY(ERS210Info::CPCJointMouth);
 
-		// Get foot switches
-		chkEvent(evtBuf,ERS210Info::LFrPawOffset,GETB(ERS210Info::CPCSensorLFPaw),buttonNames[ERS210Info::LFrPawOffset]);
-		chkEvent(evtBuf,ERS210Info::RFrPawOffset,GETB(ERS210Info::CPCSensorRFPaw),buttonNames[ERS210Info::RFrPawOffset]);
-		chkEvent(evtBuf,ERS210Info::LBkPawOffset,GETB(ERS210Info::CPCSensorLHPaw),buttonNames[ERS210Info::LBkPawOffset]);
-		chkEvent(evtBuf,ERS210Info::RBkPawOffset,GETB(ERS210Info::CPCSensorRHPaw),buttonNames[ERS210Info::RBkPawOffset]);
+		if(lastState!=NULL && lastState!=this) {
+			// Copy over new buttons
+			buttons[ERS210Info::LFrPawOffset]=GETB(ERS210Info::CPCSensorLFPaw);
+			buttons[ERS210Info::RFrPawOffset]=GETB(ERS210Info::CPCSensorRFPaw);
+			buttons[ERS210Info::LBkPawOffset]=GETB(ERS210Info::CPCSensorLHPaw);
+			buttons[ERS210Info::RBkPawOffset]=GETB(ERS210Info::CPCSensorRHPaw);
+			
+			buttons[ERS210Info::ChinButOffset]=GETB(ERS210Info::CPCSensorChinSwitch);
+			buttons[ERS210Info::BackButOffset]=GETB(ERS210Info::CPCSensorBackSwitch);
+			buttons[ERS210Info::HeadFrButOffset]=GETD(ERS210Info::CPCSensorHeadFrontPressure);
+			buttons[ERS210Info::HeadBkButOffset]=GETD(ERS210Info::CPCSensorHeadBackPressure);
+			
+			//! process changes
+			chkEvent(evtBuf,lastState);
+		} else {
+			// Get foot switches
+			chkEvent(evtBuf,ERS210Info::LFrPawOffset,GETB(ERS210Info::CPCSensorLFPaw),buttonNames[ERS210Info::LFrPawOffset]);
+			chkEvent(evtBuf,ERS210Info::RFrPawOffset,GETB(ERS210Info::CPCSensorRFPaw),buttonNames[ERS210Info::RFrPawOffset]);
+			chkEvent(evtBuf,ERS210Info::LBkPawOffset,GETB(ERS210Info::CPCSensorLHPaw),buttonNames[ERS210Info::LBkPawOffset]);
+			chkEvent(evtBuf,ERS210Info::RBkPawOffset,GETB(ERS210Info::CPCSensorRHPaw),buttonNames[ERS210Info::RBkPawOffset]);
 
-		// Get buttons
-		chkEvent(evtBuf,ERS210Info::ChinButOffset,  GETB(ERS210Info::CPCSensorChinSwitch),buttonNames[ERS210Info::ChinButOffset]);
-		chkEvent(evtBuf,ERS210Info::BackButOffset,  GETB(ERS210Info::CPCSensorBackSwitch),buttonNames[ERS210Info::BackButOffset]);
-		chkEvent(evtBuf,ERS210Info::HeadFrButOffset,GETD(ERS210Info::CPCSensorHeadFrontPressure),buttonNames[ERS210Info::HeadFrButOffset]);
-		chkEvent(evtBuf,ERS210Info::HeadBkButOffset,GETD(ERS210Info::CPCSensorHeadBackPressure),buttonNames[ERS210Info::HeadBkButOffset]);
+			// Get buttons
+			chkEvent(evtBuf,ERS210Info::ChinButOffset,  GETB(ERS210Info::CPCSensorChinSwitch),buttonNames[ERS210Info::ChinButOffset]);
+			chkEvent(evtBuf,ERS210Info::BackButOffset,  GETB(ERS210Info::CPCSensorBackSwitch),buttonNames[ERS210Info::BackButOffset]);
+			chkEvent(evtBuf,ERS210Info::HeadFrButOffset,GETD(ERS210Info::CPCSensorHeadFrontPressure),buttonNames[ERS210Info::HeadFrButOffset]);
+			chkEvent(evtBuf,ERS210Info::HeadBkButOffset,GETD(ERS210Info::CPCSensorHeadBackPressure),buttonNames[ERS210Info::HeadBkButOffset]);
+		}
 
 		// Get IR distance sensor
 		sensors[ERS210Info::IRDistOffset]=GETSENSOR(ERS210Info::CPCSensorPSD) / 1000.0f;
@@ -199,21 +239,39 @@ void WorldState::read(OSensorFrameVectorData& sensor, EventRouter* er) {
 		pidduties[HeadOffset+PanOffset ] = GETDUTY(ERS220Info::CPCJointNeckPan);
 		pidduties[HeadOffset+RollOffset] = GETDUTY(ERS220Info::CPCJointNeckRoll);
 
-	 	chkEvent(evtBuf, ERS220Info::TailLeftButOffset, GETB(ERS220Info::CPCSensorTailLeftSwitch),  buttonNames[ERS220Info::TailLeftButOffset]);
-	 	chkEvent(evtBuf, ERS220Info::TailCenterButOffset, GETB(ERS220Info::CPCSensorTailCenterSwitch),buttonNames[ERS220Info::TailCenterButOffset]);
-	 	chkEvent(evtBuf, ERS220Info::TailRightButOffset, GETB(ERS220Info::CPCSensorTailRightSwitch), buttonNames[ERS220Info::TailRightButOffset]);
+		if(lastState!=NULL && lastState!=this) {
+			// Copy over new buttons
+			buttons[ERS220Info::LFrPawOffset]=GETB(ERS220Info::CPCSensorLFPaw);
+			buttons[ERS220Info::RFrPawOffset]=GETB(ERS220Info::CPCSensorRFPaw);
+			buttons[ERS220Info::LBkPawOffset]=GETB(ERS220Info::CPCSensorLHPaw);
+			buttons[ERS220Info::RBkPawOffset]=GETB(ERS220Info::CPCSensorRHPaw);
+			
+			buttons[ERS220Info::ChinButOffset]=GETB(ERS220Info::CPCSensorChinSwitch);
+			buttons[ERS220Info::BackButOffset]=GETB(ERS220Info::CPCSensorBackSwitch);
+			buttons[ERS220Info::HeadFrButOffset]=GETD(ERS220Info::CPCSensorHeadFrontPressure);
+			buttons[ERS220Info::HeadBkButOffset]=GETD(ERS220Info::CPCSensorHeadBackPressure);
+			buttons[ERS220Info::TailLeftButOffset]=GETB(ERS220Info::CPCSensorTailLeftSwitch);
+			buttons[ERS220Info::TailCenterButOffset]=GETB(ERS220Info::CPCSensorTailCenterSwitch);
+			buttons[ERS220Info::TailRightButOffset]=GETB(ERS220Info::CPCSensorTailRightSwitch);
+			
+			//! process changes
+			chkEvent(evtBuf,lastState);
+		} else {
+			// Get foot switches
+			chkEvent(evtBuf,ERS220Info::LFrPawOffset,GETB(ERS220Info::CPCSensorLFPaw),buttonNames[ERS220Info::LFrPawOffset]);
+			chkEvent(evtBuf,ERS220Info::RFrPawOffset,GETB(ERS220Info::CPCSensorRFPaw),buttonNames[ERS220Info::RFrPawOffset]);
+			chkEvent(evtBuf,ERS220Info::LBkPawOffset,GETB(ERS220Info::CPCSensorLHPaw),buttonNames[ERS220Info::LBkPawOffset]);
+			chkEvent(evtBuf,ERS220Info::RBkPawOffset,GETB(ERS220Info::CPCSensorRHPaw),buttonNames[ERS220Info::RBkPawOffset]);
 
-		// Get foot switches
-		chkEvent(evtBuf,ERS220Info::LFrPawOffset,GETB(ERS220Info::CPCSensorLFPaw),buttonNames[ERS220Info::LFrPawOffset]);
-		chkEvent(evtBuf,ERS220Info::RFrPawOffset,GETB(ERS220Info::CPCSensorRFPaw),buttonNames[ERS220Info::RFrPawOffset]);
-		chkEvent(evtBuf,ERS220Info::LBkPawOffset,GETB(ERS220Info::CPCSensorLHPaw),buttonNames[ERS220Info::LBkPawOffset]);
-		chkEvent(evtBuf,ERS220Info::RBkPawOffset,GETB(ERS220Info::CPCSensorRHPaw),buttonNames[ERS220Info::RBkPawOffset]);
-
-		// Get buttons
-		chkEvent(evtBuf,ERS220Info::ChinButOffset,  GETB(ERS220Info::CPCSensorChinSwitch),buttonNames[ERS220Info::ChinButOffset]);
-		chkEvent(evtBuf,ERS220Info::BackButOffset,  GETB(ERS220Info::CPCSensorBackSwitch),buttonNames[ERS220Info::BackButOffset]);
-		chkEvent(evtBuf,ERS220Info::HeadFrButOffset,GETD(ERS220Info::CPCSensorHeadFrontPressure),buttonNames[ERS220Info::HeadFrButOffset]);
-		chkEvent(evtBuf,ERS220Info::HeadBkButOffset,GETD(ERS220Info::CPCSensorHeadBackPressure),buttonNames[ERS220Info::HeadBkButOffset]);
+			// Get buttons
+			chkEvent(evtBuf,ERS220Info::ChinButOffset,  GETB(ERS220Info::CPCSensorChinSwitch),buttonNames[ERS220Info::ChinButOffset]);
+			chkEvent(evtBuf,ERS220Info::BackButOffset,  GETB(ERS220Info::CPCSensorBackSwitch),buttonNames[ERS220Info::BackButOffset]);
+			chkEvent(evtBuf,ERS220Info::HeadFrButOffset,GETD(ERS220Info::CPCSensorHeadFrontPressure),buttonNames[ERS220Info::HeadFrButOffset]);
+			chkEvent(evtBuf,ERS220Info::HeadBkButOffset,GETD(ERS220Info::CPCSensorHeadBackPressure),buttonNames[ERS220Info::HeadBkButOffset]);
+			chkEvent(evtBuf,ERS220Info::TailLeftButOffset, GETB(ERS220Info::CPCSensorTailLeftSwitch),  buttonNames[ERS220Info::TailLeftButOffset]);
+			chkEvent(evtBuf,ERS220Info::TailCenterButOffset, GETB(ERS220Info::CPCSensorTailCenterSwitch),buttonNames[ERS220Info::TailCenterButOffset]);
+			chkEvent(evtBuf,ERS220Info::TailRightButOffset, GETB(ERS220Info::CPCSensorTailRightSwitch), buttonNames[ERS220Info::TailRightButOffset]);
+		}
 
 		// Get IR distance sensor
 		sensors[ERS220Info::IRDistOffset]=GETSENSOR(ERS220Info::CPCSensorPSD) / 1000.0f;
@@ -272,20 +330,39 @@ void WorldState::read(OSensorFrameVectorData& sensor, EventRouter* er) {
 		outputs[ERS7Info::MouthOffset] = GETD(ERS7Info::CPCJointMouth);
 		pidduties[ERS7Info::MouthOffset] = GETDUTY(ERS7Info::CPCJointMouth);
 
-		// Get foot switches
-		chkEvent(evtBuf,ERS7Info::LFrPawOffset,GETB(ERS7Info::CPCSwitchLFPaw),buttonNames[ERS7Info::LFrPawOffset]);
-		chkEvent(evtBuf,ERS7Info::RFrPawOffset,GETB(ERS7Info::CPCSwitchRFPaw),buttonNames[ERS7Info::RFrPawOffset]);
-		chkEvent(evtBuf,ERS7Info::LBkPawOffset,GETB(ERS7Info::CPCSwitchLHPaw),buttonNames[ERS7Info::LBkPawOffset]);
-		chkEvent(evtBuf,ERS7Info::RBkPawOffset,GETB(ERS7Info::CPCSwitchRHPaw),buttonNames[ERS7Info::RBkPawOffset]);
+		if(lastState!=NULL && lastState!=this) {
+			// Copy over new buttons
+			buttons[ERS7Info::LFrPawOffset]=GETB(ERS7Info::CPCSwitchLFPaw);
+			buttons[ERS7Info::RFrPawOffset]=GETB(ERS7Info::CPCSwitchRFPaw);
+			buttons[ERS7Info::LBkPawOffset]=GETB(ERS7Info::CPCSwitchLHPaw);
+			buttons[ERS7Info::RBkPawOffset]=GETB(ERS7Info::CPCSwitchRHPaw);
+			
+			// the sensors are scaled to be relatively similar to the pressure values given by the head on the 210
+			buttons[ ERS7Info::ChinButOffset]=GETSENSOR(ERS7Info::CPCSwitchChin);
+			buttons[ ERS7Info::HeadButOffset]=GETSENSOR(ERS7Info::CPCSensorHead)/120;
+			buttons[ ERS7Info::FrontBackButOffset]=GETSENSOR(ERS7Info::CPCSensorBackFront)/150;
+			buttons[ ERS7Info::MiddleBackButOffset]=GETSENSOR(ERS7Info::CPCSensorBackMiddle)/150;
+			buttons[ ERS7Info::RearBackButOffset]=GETSENSOR(ERS7Info::CPCSensorBackRear)/150;
+			buttons[ ERS7Info::WirelessSwOffset]=GETSENSOR(ERS7Info::CPCSwitchWireless);
+			
+			//! process changes
+			chkEvent(evtBuf,lastState);
+		} else {
+			// Get foot switches
+			chkEvent(evtBuf,ERS7Info::LFrPawOffset,GETB(ERS7Info::CPCSwitchLFPaw),buttonNames[ERS7Info::LFrPawOffset]);
+			chkEvent(evtBuf,ERS7Info::RFrPawOffset,GETB(ERS7Info::CPCSwitchRFPaw),buttonNames[ERS7Info::RFrPawOffset]);
+			chkEvent(evtBuf,ERS7Info::LBkPawOffset,GETB(ERS7Info::CPCSwitchLHPaw),buttonNames[ERS7Info::LBkPawOffset]);
+			chkEvent(evtBuf,ERS7Info::RBkPawOffset,GETB(ERS7Info::CPCSwitchRHPaw),buttonNames[ERS7Info::RBkPawOffset]);
 
-		// Get buttons/switches
-		// the sensors are scaled to be relatively similar to the pressure values given by the head on the 210
-		chkEvent(evtBuf, ERS7Info::ChinButOffset,       GETSENSOR(ERS7Info::CPCSwitchChin),      buttonNames[ERS7Info::ChinButOffset]);
-		chkEvent(evtBuf, ERS7Info::HeadButOffset,       GETSENSOR(ERS7Info::CPCSensorHead)/120,      buttonNames[ERS7Info::HeadButOffset]);
-	 	chkEvent(evtBuf, ERS7Info::FrontBackButOffset,  GETSENSOR(ERS7Info::CPCSensorBackFront)/150, buttonNames[ERS7Info::FrontBackButOffset]);
-	 	chkEvent(evtBuf, ERS7Info::MiddleBackButOffset, GETSENSOR(ERS7Info::CPCSensorBackMiddle)/150,buttonNames[ERS7Info::MiddleBackButOffset]);
-	 	chkEvent(evtBuf, ERS7Info::RearBackButOffset,   GETSENSOR(ERS7Info::CPCSensorBackRear)/150,  buttonNames[ERS7Info::RearBackButOffset]);
-	 	chkEvent(evtBuf, ERS7Info::WirelessSwOffset,GETSENSOR(ERS7Info::CPCSwitchWireless),  buttonNames[ERS7Info::WirelessSwOffset]);
+			// Get buttons/switches
+			// the sensors are scaled to be relatively similar to the pressure values given by the head on the 210
+			chkEvent(evtBuf, ERS7Info::ChinButOffset,       GETSENSOR(ERS7Info::CPCSwitchChin),      buttonNames[ERS7Info::ChinButOffset]);
+			chkEvent(evtBuf, ERS7Info::HeadButOffset,       GETSENSOR(ERS7Info::CPCSensorHead)/120,      buttonNames[ERS7Info::HeadButOffset]);
+			chkEvent(evtBuf, ERS7Info::FrontBackButOffset,  GETSENSOR(ERS7Info::CPCSensorBackFront)/150, buttonNames[ERS7Info::FrontBackButOffset]);
+			chkEvent(evtBuf, ERS7Info::MiddleBackButOffset, GETSENSOR(ERS7Info::CPCSensorBackMiddle)/150,buttonNames[ERS7Info::MiddleBackButOffset]);
+			chkEvent(evtBuf, ERS7Info::RearBackButOffset,   GETSENSOR(ERS7Info::CPCSensorBackRear)/150,  buttonNames[ERS7Info::RearBackButOffset]);
+			chkEvent(evtBuf, ERS7Info::WirelessSwOffset,GETSENSOR(ERS7Info::CPCSwitchWireless),  buttonNames[ERS7Info::WirelessSwOffset]);
+		}
 
 		// Get IR distance sensor
 		sensors[ERS7Info::NearIRDistOffset] = GETSENSOR(ERS7Info::CPCSensorNearPSD) / 1000.0f;
@@ -298,16 +375,21 @@ void WorldState::read(OSensorFrameVectorData& sensor, EventRouter* er) {
 		sensors[DAccelOffset] = GETD(ERS7Info::CPCSensorAccelUD);
 	}
 
+	//unsigned int dif=curtime-(lastState==NULL ? lastSensorUpdateTime : lastState->lastSensorUpdateTime);
+	lastSensorUpdateTime=curtime;
+	frameNumber=newFrameNumber;
+	framesProcessed=(lastState!=NULL?lastState->framesProcessed:framesProcessed)+1;
+	for(unsigned int i=0; i<evtBuf.size(); i++)
+		er->postEvent(evtBuf[i]);
+	
+	
 	//Apply sensor calibrations (currently only joint positions - perhaps IR as well?)
 	for(unsigned int i=0; i<NumPIDJoints; i++)
 		outputs[PIDJointOffset+i]*=config->motion.calibration[i];
 
-	unsigned int dif=curtime-lastSensorUpdateTime;
-	lastSensorUpdateTime=curtime;
-	for(unsigned int i=0; i<evtBuf.size(); i++)
-		er->postEvent(evtBuf[i]);
-	//we don't delete the events in evtBuf - we're handing them off to erouter, which will delete them itself
-	er->postEvent(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID,dif,"SensorSouceID::UpdatedSID",1);
+	//this version of read doesn't post the sensor update event -- the caller should do that
+	//this event gets posted by MMCombo only if there's no back log on the interprocess event queue (don't want to stack these up for sensor frames missed by main)
+	//er->postEvent(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID,dif,"SensorSouceID::UpdatedSID",1);
 }
 
 /*! This will cause events to be posted */
@@ -383,35 +465,136 @@ void WorldState::read(const OPowerStatus& power, EventRouter* er) {
 	er->postEvent(EventBase::powerEGID,PowerSourceID::UpdatedSID,EventBase::statusETID,0,"PowerSourceID::UpdatedSID",1);
 }
 
-#endif //PLATFORM_APERIOS
+#else  //PLATFORM_LOCAL
 
-void WorldState::chkEvent(std::vector<EventBase*>& evtBuf, unsigned int sid, float newval, const char* name) {
+/*! This version of read() doesn't post the sensor update event -- the caller should do that
+ *  (this variant is used by the simulator, different parts fill in different sections, the last one should trigger the event)
+ *
+ *  This function assumes that the pose (and any associated sensor readings)
+ *  are for the current model robot, and that any calibration has already 
+ *  been applied (so the values can be used unchanged)
+ */
+void WorldState::read(const PostureEngine& pose, WorldState* lastState, EventRouter* er) {
+	curtime=get_time();
+	std::vector<EventBase> evtBuf;
+	WorldState* ext=pose.getLoadedSensors();
+
+	unsigned int newFrameNumber=(lastState!=NULL?lastState->frameNumber:frameNumber)+NumFrames;
+
+	for(unsigned int i=0; i<NumOutputs; i++)
+		if(pose(i).weight>0)
+			outputs[i]=pose(i).value;
+
+	if(frameNumber>=newFrameNumber)
+		return; //sensors have already been filled in
+	
+	if(lastState!=NULL && lastState!=this) {
+		alwaysGenerateStatus=lastState->alwaysGenerateStatus;
+		//pid and velocity values will be copied at "completion"
+		robotStatus=lastState->robotStatus;
+		batteryStatus=lastState->batteryStatus;
+		for(unsigned int i=0; i<PowerSourceID::NumPowerSIDs; i++)
+			powerFlags[i]=lastState->powerFlags[i];
+
+		//important part -- copy over button_times before calls to chkEvent
+		for(unsigned int i=0; i<NumButtons; i++)
+			button_times[i]=lastState->button_times[i];
+	}
+	
+	if(ext!=NULL) {
+		if(ext==this) {
+			chkEvent(evtBuf,lastState);
+		} else {
+			if(lastState!=NULL && lastState!=this) {
+				for(unsigned int i=0; i<NumButtons; i++)
+					buttons[i]=ext->buttons[i];
+				chkEvent(evtBuf,lastState);
+			} else {
+				for(unsigned int i=0; i<NumButtons; i++)
+					chkEvent(evtBuf,i,ext->buttons[i],buttonNames[i]);
+			}
+			for(unsigned int i=0; i<NumSensors; i++)
+				sensors[i]=ext->sensors[i];
+			for(unsigned int i=0; i<NumPIDJoints; i++)
+				pidduties[i]=ext->pidduties[i];
+		}
+	} else if(lastState!=NULL && lastState!=this) {
+		// no loaded sensors at all -- copy over previous values
+		for(unsigned int i=0; i<NumButtons; i++)
+			buttons[i]=lastState->buttons[i];
+		for(unsigned int i=0; i<NumSensors; i++)
+			sensors[i]=lastState->sensors[i];
+		for(unsigned int i=0; i<NumPIDJoints; i++)
+			pidduties[i]=lastState->pidduties[i];
+	}
+
+	//unsigned int dif=curtime-(lastState==NULL ? lastSensorUpdateTime : lastState->lastSensorUpdateTime);
+	lastSensorUpdateTime=curtime;
+	if(newFrameNumber!=-1U)
+		frameNumber=newFrameNumber;
+	framesProcessed=(lastState!=NULL?lastState->framesProcessed:framesProcessed)+1;
+	for(unsigned int i=0; i<evtBuf.size(); i++)
+		er->postEvent(evtBuf[i]);
+	
+	//this version of read doesn't post the sensor update event -- the caller should do that
+	// (this variant is used by the simulator, different parts fill in different sections, the last one should trigger the event)
+	//er->postEvent(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID,dif,"SensorSourceID::UpdatedSID",1);
+}
+
+#endif //platform-specific sensor updating
+
+void WorldState::chkEvent(std::vector<EventBase>& evtBuf, unsigned int sid, float newval, const char* name) {
 	if(newval>=0.1) { //now on
 		if(buttons[sid]<0.1) { //was off: activation
-			evtBuf.push_back(new EventBase(EventBase::buttonEGID,sid,EventBase::activateETID,0,name,newval));
+			cout << ProcessID::getIDStr() << " post activate" << endl;
+			evtBuf.push_back(EventBase(EventBase::buttonEGID,sid,EventBase::activateETID,0,name,newval));
 			button_times[sid]=curtime;
 		} else if(alwaysGenerateStatus || buttons[sid]!=newval) { //already on - always or change? : status
 			unsigned int dur=curtime-button_times[sid];
-			evtBuf.push_back(new EventBase(EventBase::buttonEGID,sid,EventBase::statusETID,dur,name,newval));
+			cout << ProcessID::getIDStr() << " post status" << endl;
+			evtBuf.push_back(EventBase(EventBase::buttonEGID,sid,EventBase::statusETID,dur,name,newval));
 		}
 	} else { //now off
 		if(buttons[sid]>=0.1) { //was on: deactivation
 			unsigned int dur=curtime-button_times[sid];
 			button_times[sid]=0;
-			evtBuf.push_back(new EventBase(EventBase::buttonEGID,sid,EventBase::deactivateETID,dur,name,0));
+			cout << ProcessID::getIDStr() << " post deactivate" << endl;
+			evtBuf.push_back(EventBase(EventBase::buttonEGID,sid,EventBase::deactivateETID,dur,name,0));
 		}
 	}
 	//update value
 	buttons[sid]=newval;
 }
 
+void WorldState::chkEvent(std::vector<EventBase>& evtBuf, WorldState* lastState) {
+	// posture already loaded data into this instance of WorldState
+	// variation on chkEvent -- instead, we already hold the latest data, need to compare against lastState
+	for(unsigned int sid=0; sid<NumButtons; sid++) {
+		if(buttons[sid]>=0.1) { //now on
+			if(lastState->buttons[sid]<0.1) { //was off: activation
+				evtBuf.push_back(EventBase(EventBase::buttonEGID,sid,EventBase::activateETID,0,buttonNames[sid],buttons[sid]));
+				button_times[sid]=curtime;
+			} else if(alwaysGenerateStatus || lastState->buttons[sid]!=buttons[sid]) { //already on - always or change? : status
+				unsigned int dur=curtime-button_times[sid];
+				evtBuf.push_back(EventBase(EventBase::buttonEGID,sid,EventBase::statusETID,dur,buttonNames[sid],buttons[sid]));
+			}
+		} else { //now off
+			if(lastState->buttons[sid]>=0.1) { //was on: deactivation
+				unsigned int dur=curtime-button_times[sid];
+				button_times[sid]=0;
+				evtBuf.push_back(EventBase(EventBase::buttonEGID,sid,EventBase::deactivateETID,dur,buttonNames[sid],0));
+			}
+		}
+	}
+}
+
 /*! @file
  * @brief Implements WorldState, maintains information about the robot's environment, namely sensors and power status
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.30 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.40 $
  * $State: Exp $
- * $Date: 2005/07/10 20:02:17 $
+ * $Date: 2006/09/29 16:56:09 $
  */
