@@ -3,16 +3,18 @@
 #define INCLUDED_WorldState_h
 
 #ifdef PLATFORM_APERIOS
+#include "IPC/ProcessID.h"
 #include <OPENR/core_macro.h>
 #include <OPENR/ObjcommTypes.h>
 #include <OPENR/OPENR.h>
 #include <OPENR/OPENRAPI.h>
 #include <OPENR/OPENRMessages.h>
+#else
+class PostureEngine;
 #endif
 
 #include "Shared/RobotInfo.h"
 #include "Events/EventBase.h"
-#include "Shared/Profiler.h"
 #include <math.h>
 #include <vector>
 
@@ -93,11 +95,23 @@ namespace PowerSourceID {
 		NumPowerSIDs
 	};
 }
+
+class WorldState;
+extern WorldState * state; //!< the global state object, is a shared memory region, created by MainObject
 	
 //! The state of the robot and its environment
-/*! Contains sensor readings, current joint positions, etc.\n
- * This is a shared memory region between MainObj, MotoObj, and possibly others in the future
+/*! Contains sensor readings, current joint positions, etc.  Notable members are:
+ * - #outputs - joint positions and current LED values
+ * - #buttons - current button values
+ * - #sensors - values from other sensors (IR, acceleration, temperature, power levels)
+ * - #pids - current PID settings for each joint (more specifically, each PID-controlled joint)
+ * - #pidduties - how hard each of the PID joints is working to get to its target value
  *
+ * Generally you will use enumerated values from a robot-specific namespace to
+ * index into these arrays.  Each of those members' documentation specifies where
+ * to find the list of indices to use with them.
+ *
+ * This is a shared memory region between Main, Motion, and possibly others in the future.
  * Be very careful about including structures that use pointers in
  * this class... they will only be valid from the OObject that created
  * them, others may cause a crash if they try to access them.
@@ -107,11 +121,11 @@ namespace PowerSourceID {
  * events when some of these values change, listed in the
  * SensorSourceID, PowerSourceID namespaces, and the ButtonOffset_t
  * enumeration for your robot model's info
- * namespace. (e.g. ERS210Info::ButtonOffset_t)
+ * namespace. (e.g. ERS7Info::ButtonOffset_t)
  *
  * Status events for buttons only generated if the
- * WorldState::alwaysGenerateStatus flag is turned on, otherwise, by
- * default, they are only generated when a value has changed
+ * WorldState::alwaysGenerateStatus flag is turned on.  Otherwise, by
+ * default, they are only generated when a value has changed.
  * (i.e. when the pressure sensitive buttons get a new pressure
  * reading)
  */
@@ -122,11 +136,11 @@ public:
 
 	bool alwaysGenerateStatus; //!< controls whether status events are generated for the boolean buttons
 
-	float outputs[NumOutputs];     //!< last sensed positions of joints, for ears (or other future "boolean joints"), x<.5 is up, x>=.5 is down; indexes (aka offsets) are defined in the target model's namespace (e.g. ERS210Info)
-	float buttons[NumButtons];     //!< magnitude is pressure for some, 0/1 for others; indexes are defined in the ButtonOffset_t of the target model's namespace (e.g. ERS210Info::ButtonOffset_t)
-	float sensors[NumSensors];     //!< IR, Accel, Thermo, Power stuff; indexes are defined in SensorOffset_t of the target model's namespace (e.g. ERS210Info::SensorOffset_t)
-	float pids[NumPIDJoints][3];   //!< current PID settings (same ordering as the #outputs)
-	float pidduties[NumPIDJoints]; //!< duty cycles - -1 means the motor is trying to move full power in negative direction, 1 means full power in positive direction, in practice, these values stay rather small - 0.15 is significant force. (same ordering as the #outputs)
+	float outputs[NumOutputs];     //!< last sensed positions of joints, last commanded value of LEDs; indexes (aka offsets) are defined in the target model's namespace (e.g. "Output Offsets" section of ERS7Info)
+	float buttons[NumButtons];     //!< magnitude is pressure for some, 0/1 for others; indexes are defined in the ButtonOffset_t of the target model's namespace (e.g. ERS7Info::ButtonOffset_t)
+	float sensors[NumSensors];     //!< IR, Accel, Thermo, Power stuff; indexes are defined in SensorOffset_t of the target model's namespace (e.g. ERS7Info::SensorOffset_t)
+	float pids[NumPIDJoints][3];   //!< current PID settings (same ordering as the #outputs), not sensed -- updated by MotionManager whenever it sends a PID setting to the system; note this is only valid for PID joints, has NumPIDJoint entries (as opposed to NumOutputs)
+	float pidduties[NumPIDJoints]; //!< duty cycles - -1 means the motor is trying to move full power in negative direction, 1 means full power in positive direction, in practice, these values stay rather small - 0.15 is significant force. (same ordering as the #outputs); note this is only valid for PID joints, has NumPIDJoint entries (as opposed to NumOutputs)
 	
 	float vel_x; //!< the current, egocentric rate of forward locomotion, mm/second
 	float vel_y; //!< the current, egocentric rate of sideways (leftward is positive) locomotion, mm/second
@@ -139,17 +153,34 @@ public:
 
 	unsigned int button_times[NumButtons]; //!< value is time of current press, 0 if not down
 	
-	unsigned int lastSensorUpdateTime;     //!<primarily so calcDers can determine the time difference between updates, but others might want to know this too...
+	unsigned int lastSensorUpdateTime;     //!< primarily so calcDers can determine the time difference between updates, but others might want to know this too...
+	unsigned int frameNumber;              //!< the serial number of the currently available frame
+	unsigned int framesProcessed;          //!< the number of sensor updates which have been processed
 
 	static const double g;                 //!< the gravitational acceleration of objects on earth
 	static const double IROORDist;         //!< If IR returns this, we're out of range
 
-	ProfilerOfSize<20> mainProfile;        //!< holds code profiling information for MainObject
-	ProfilerOfSize<06> motionProfile;      //!< holds code profiling information for MotionObject
-
 #ifdef PLATFORM_APERIOS
-	void read(OSensorFrameVectorData& sensor, EventRouter* er); //!< will process a sensor reading as given by OPEN-R
+	void read(OSensorFrameVectorData& sensor, WorldState* lastState, EventRouter* er); //!< will process a sensor reading as given by OPEN-R
 	void read(const OPowerStatus& power, EventRouter* er);      //!< will process a power status update as given by OPEN-R
+	
+	//! returns the current WorldState instance for the running process, needed if your code may be in a shared memory region; otherwise you can directly access ::state
+	/*! Generally you can access ::state directly, but if your code is running as a member of an object in a shared memory region,
+	 *  this handles the shared object context switching problem on Aperios, and simply returns ::state on non-Aperios. */
+	static WorldState* getCurrent() { return stateLookupMap==NULL ? NULL : stateLookupMap[ProcessID::getID()]; }
+	
+	// sets the current WorldState instance for the running process (handles the shared object context switching problem on Aperios, simply returns ::state on non-Aperios)
+	// static void setCurrent(WorldState* st) { stateLookupMap[ProcessID::getID()]=st; }
+	
+	//! sets the lookup table (held in a shared region, WorldStatePool::stateMap) used by getCurrent under Aperios
+	static void setWorldStateLookup(WorldState * curMap[ProcessID::NumProcesses]) { stateLookupMap=curMap; }
+#else
+	void read(const PostureEngine& pose, WorldState* lastState, EventRouter* er); //!< will process the posture's output positions as a new sensor reading
+	
+	//! returns the current WorldState instance for the running process, needed if your code may be in a shared memory region; otherwise you can directly access ::state
+	/*! Generally you can access ::state directly, but if your code is running as a member of an object in a shared memory region,
+	 *  this handles the shared object context switching problem on Aperios, and simply returns ::state on non-Aperios. */
+	static WorldState* getCurrent() { return ::state; }
 #endif
 
 	//! bitmask corresponding to OPENR::GetRobotDesign()
@@ -165,13 +196,16 @@ public:
 	unsigned int robotDesign;  
 	static const unsigned int ERS210Mask=1<<0;  //!< use this to test for ERS-210 features
 	static const unsigned int ERS220Mask=1<<1;  //!< use this to test for ERS-220 features
+	static const unsigned int ERS2xxMask = ERS210Mask | ERS220Mask;  //!< use this to test for ERS-2xx features
 	static const unsigned int ERS7Mask=1<<2;  //!< use this to test for ERS-7 features
 
 protected:
 	unsigned int curtime; //!< set by read(OSensorFrameVectorData& sensor, EventRouter* er) for chkEvent() so each call doesn't have to
 
 	//! Tests to see if the button status has changed and post events as needed
-	void chkEvent(std::vector<EventBase*>& evtBuf, unsigned int off, float newval, const char* name);
+	void chkEvent(std::vector<EventBase>& evtBuf, unsigned int off, float newval, const char* name);
+	//! Tests to see if any button statuses have changed and post events as needed, bases comparison between already filled-in WorldStates 
+	void chkEvent(std::vector<EventBase>& evtBuf, WorldState* lastState);
 
 	//! sets the names of the flags that will be generating events
 	/*! note that this function does not actually do the event posting,
@@ -201,23 +235,25 @@ protected:
 		vel=next;
 		acc=diff*invtimediff;
 	}
-
+	
+#ifdef PLATFORM_APERIOS
+	static WorldState ** stateLookupMap; //!< array used by getCurrent()/setCurrent() to store the state in use by each process -- should be initialized by setWorldStateLookup() to point into a shared memory region
+#endif
+	
 private:
-	WorldState(const WorldState&); //!< don't use
-	WorldState operator=(const WorldState&); //!< don't use
+	WorldState(const WorldState&); //!< this shouldn't be called...
+	WorldState& operator=(const WorldState&); //!< this shouldn't be called...
 };
 
-extern WorldState * state; //!< the global state object, is a shared memory region, created by MainObject
-
 /*! @file
  * @brief Describes WorldState, maintains information about the robot's environment, namely sensors and power status
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.28 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.36 $
  * $State: Exp $
- * $Date: 2004/07/27 14:36:50 $
+ * $Date: 2006/10/03 22:00:08 $
  */
 
 #endif
