@@ -68,7 +68,7 @@ unsigned int XMLLoadSave::getBinSize() const {
 		if(compressionLevel>=0)
 			xmlSetDocCompressMode(xmldocument,compressionLevel);
 		xmlNode * cur = FindRootXMLElement(xmldocument);
-		SaveXML(cur);
+		saveXML(cur);
 		xmlChar* buf=NULL;
 		int size=0;
 		xmlDocDumpFormatMemory(xmldocument, &buf, &size, autoFormat);
@@ -79,7 +79,7 @@ unsigned int XMLLoadSave::getBinSize() const {
 		return 0;
 	}
 }
-unsigned int XMLLoadSave::LoadBuffer(const char buf[], unsigned int len) {
+unsigned int XMLLoadSave::loadBuffer(const char buf[], unsigned int len) {
 	if(xmldocument!=NULL)
 		xmlFreeDoc(xmldocument);
 	
@@ -112,7 +112,7 @@ unsigned int XMLLoadSave::LoadBuffer(const char buf[], unsigned int len) {
 	
 	try {
 		xmlNodePtr cur = FindRootXMLElement(xmldocument);
-		LoadXML(cur);
+		loadXML(cur);
 		return size;
 	} catch(const bad_format& err) {
 		reportError("During load of memory buffer:",err);
@@ -121,21 +121,21 @@ unsigned int XMLLoadSave::LoadBuffer(const char buf[], unsigned int len) {
 		return 0;
 	}
 }
-unsigned int XMLLoadSave::SaveBuffer(char buf[], unsigned int len) const {
+unsigned int XMLLoadSave::saveBuffer(char buf[], unsigned int len) const {
 	try {
 		if(xmldocument==NULL)
 			setParseTree(xmlNewDoc((const xmlChar*)"1.0"));
 		if(compressionLevel>=0)
 			xmlSetDocCompressMode(xmldocument,compressionLevel);
 		xmlNode * cur = FindRootXMLElement(xmldocument);
-		SaveXML(cur);
+		saveXML(cur);
 		xmlChar* xbuf=NULL;
 		int size=0;
 		xmlDocDumpFormatMemory(xmldocument, &xbuf, &size, autoFormat);
 		if((unsigned int)size<=len)
 			memcpy(buf,xbuf,size);
 		else {
-			cerr << "Error: XMLLoadSave::SaveBuffer xmlDocDumpFormatMemory returned larger region than the target buffer" << endl;
+			cerr << "Error: XMLLoadSave::saveBuffer xmlDocDumpFormatMemory returned larger region than the target buffer" << endl;
 			size=0;
 		}
 		return size;
@@ -145,7 +145,7 @@ unsigned int XMLLoadSave::SaveBuffer(char buf[], unsigned int len) const {
 	}
 }
 
-unsigned int XMLLoadSave::LoadFile(const char* filename) {
+unsigned int XMLLoadSave::loadFile(const char* filename) {
 	if(xmldocument!=NULL)
 		xmlFreeDoc(xmldocument);
 	
@@ -178,7 +178,7 @@ unsigned int XMLLoadSave::LoadFile(const char* filename) {
 	
 	try {
 		xmlNodePtr cur = FindRootXMLElement(xmldocument);
-		LoadXML(cur);
+		loadXML(cur);
 		return size;
 	} catch(const bad_format& err) {
 		string context("During load of '");
@@ -190,17 +190,17 @@ unsigned int XMLLoadSave::LoadFile(const char* filename) {
 		return 0;
 	}
 }
-unsigned int XMLLoadSave::SaveFile(const char* filename) const {
+unsigned int XMLLoadSave::saveFile(const char* filename) const {
 	try {
 		if(xmldocument==NULL)
 			setParseTree(xmlNewDoc((const xmlChar*)"1.0"));
 		if(compressionLevel>=0)
 			xmlSetDocCompressMode(xmldocument,compressionLevel);
 		xmlNode * cur = FindRootXMLElement(xmldocument);
-		SaveXML(cur);
+		saveXML(cur);
 		int size=xmlSaveFormatFile (filename, xmldocument, autoFormat);
 		if(size==-1)
-			cerr << "Error: XMLLoadSave::SaveFile: xmlSaveFormatFile(\"" << filename << "\",...) returned -1" << endl;
+			cerr << "Error: XMLLoadSave::saveFile: xmlSaveFormatFile(\"" << filename << "\",...) returned -1" << endl;
 		return size==-1?0:size;
 	} catch(const bad_format& err) {
 		string context("During save to '");
@@ -211,7 +211,7 @@ unsigned int XMLLoadSave::SaveFile(const char* filename) const {
 	}
 }
 
-unsigned int XMLLoadSave::LoadFileStream(FILE* f) {
+unsigned int XMLLoadSave::loadFileStream(FILE* f) {
 	if(xmldocument!=NULL)
 		xmlFreeDoc(xmldocument);
 	
@@ -236,7 +236,7 @@ unsigned int XMLLoadSave::LoadFileStream(FILE* f) {
 	
 	try {
 		xmlNodePtr cur = FindRootXMLElement(xmldocument);
-		LoadXML(cur);
+		loadXML(cur);
 		return size;
 	} catch(const bad_format& err) {
 		reportError("During load of file stream:",err);
@@ -245,17 +245,17 @@ unsigned int XMLLoadSave::LoadFileStream(FILE* f) {
 		return 0;
 	}
 }
-unsigned int XMLLoadSave::SaveFileStream(FILE* f) const {
+unsigned int XMLLoadSave::saveFileStream(FILE* f) const {
 	try {
 		if(xmldocument==NULL)
 			setParseTree(xmlNewDoc((const xmlChar*)"1.0"));
 		if(compressionLevel>=0)
 			xmlSetDocCompressMode(xmldocument,compressionLevel);
 		xmlNode * cur = FindRootXMLElement(xmldocument);
-		SaveXML(cur);
+		saveXML(cur);
 		int size=xmlDocFormatDump(f, xmldocument, autoFormat);
 		if(size==-1)
-			cerr << "Error: XMLLoadSave::SaveFileStream: xmlDocFormatDump(...) returned -1" << endl;
+			cerr << "Error: XMLLoadSave::saveFileStream: xmlDocFormatDump(...) returned -1" << endl;
 		return size==-1?0:size;
 	} catch(const bad_format& err) {
 		reportError("During save to file stream:",err);
@@ -278,7 +278,7 @@ void XMLLoadSave::readParseTree() {
 		return;
 	try {
 		xmlNodePtr cur = FindRootXMLElement(xmldocument);
-		LoadXML(cur);
+		loadXML(cur);
 	} catch(const bad_format& err) {
 		reportError("During readParseTree:",err);
 		xmlFreeDoc(xmldocument);
@@ -292,7 +292,7 @@ void XMLLoadSave::writeParseTree() {
 		if(compressionLevel>=0)
 			xmlSetDocCompressMode(xmldocument,compressionLevel);
 		xmlNode * cur = FindRootXMLElement(xmldocument);
-		SaveXML(cur);
+		saveXML(cur);
 	} catch(const bad_format& err) {
 		reportError("During writeParseTree:",err);
 	}
@@ -347,8 +347,8 @@ xmlNode* XMLLoadSave::skipToElement(xmlNode* cur, std::string& comment) {
  * @author Ethan Tira-Thompson (ejt) (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2005/07/27 05:58:24 $
+ * $Date: 2006/09/09 04:33:02 $
  */
