@@ -6,12 +6,14 @@
 
 //!@name libxml2 forward declarations
 //!forward declaration of the libxml2 struct of the same name
-struct _xmlNode;
-struct _xmlDoc;
-struct _xmlAttr;
-typedef _xmlNode xmlNode;
-typedef _xmlDoc xmlDoc;
-typedef _xmlAttr xmlAttr;
+extern "C" {
+	struct _xmlNode;
+	struct _xmlDoc;
+	struct _xmlAttr;
+	typedef _xmlNode xmlNode;
+	typedef _xmlDoc xmlDoc;
+	typedef _xmlAttr xmlAttr;
+}
 //@}
 
 //! XMLLoadSave adds functions for XML format serialization, although if you write binary LoadSave functions as well, you can do either
@@ -22,17 +24,19 @@ public:
 	class bad_format : std::exception {
 	public:
 		//!constructor
-		bad_format(xmlNode * node, const char * msg="invalid format in plist") throw() : std::exception(), node_(node), msg_(msg) {}
+		bad_format(xmlNode * node) throw() : std::exception(), node_(node), msg_("invalid format in plist") {}
+		//!constructor
+		bad_format(xmlNode * node, const std::string& msg) throw() : std::exception(), node_(node), msg_(msg) {}
 		//!copy constructor
 		bad_format(const bad_format& bf) : std::exception(bf), node_(bf.node_), msg_(bf.msg_) {}
 		//!assignment
 		bad_format& operator=(const bad_format& bf) { std::exception::operator=(bf); node_=bf.node_; msg_=bf.msg_; return *this; }
 		virtual ~bad_format() throw() {} //!< destructor
-		virtual const char * what() const throw() { return msg_; } //!< standard interface for getting the exception's message string
+		virtual const char * what() const throw() { return msg_.c_str(); } //!< standard interface for getting the exception's message string
 		virtual xmlNode * getNode() const throw() { return node_; } //!< returns the xmlNode at which the error occurred
 	protected:
 		xmlNode * node_; //!< the node of the error
-		const char * msg_; //!< message regarding the type of error
+		std::string msg_; //!< message regarding the type of error
 	};
 	
 	XMLLoadSave(); //!< constructor
@@ -43,21 +47,21 @@ public:
 	//! This is called when the subclass needs to update its values from those values in the parse tree
 	/*! @a node is the current node in the tree -- it may be the root, but it
 	 *  may also be a subnode within the tree if a recursive structure is used */
-	virtual void LoadXML(xmlNode* node)=0;
+	virtual void loadXML(xmlNode* node)=0;
 	//! This is called when XMLLoadSave needs to have the subclass update values in the tree currently in memory -- may already be filled out by previous contents
 	/*! @a node is the current node in the tree -- it may be the root, but it
 	 *  may also be a subnode within the tree if a recursive structure is used */
-	virtual void SaveXML(xmlNode * node) const=0;
+	virtual void saveXML(xmlNode * node) const=0;
 	
 	virtual unsigned int getBinSize() const;
-	virtual unsigned int LoadBuffer(const char buf[], unsigned int len);
-	virtual unsigned int SaveBuffer(char buf[], unsigned int len) const;
+	virtual unsigned int loadBuffer(const char buf[], unsigned int len);
+	virtual unsigned int saveBuffer(char buf[], unsigned int len) const;
 
-	virtual	unsigned int LoadFile(const char* filename);
-	virtual unsigned int SaveFile(const char* filename) const;
+	virtual unsigned int loadFile(const char* filename);
+	virtual unsigned int saveFile(const char* filename) const;
 	
-	virtual unsigned int LoadFileStream(FILE* f);
-	virtual unsigned int SaveFileStream(FILE* f) const;
+	virtual unsigned int loadFileStream(FILE* f);
+	virtual unsigned int saveFileStream(FILE* f) const;
 	
 	//! resets the parse tree currently in memory so that a future save will write a "fresh" copy from scratch.
 	/*! You may also want to call this in order to save memory after a Load so that
@@ -75,9 +79,9 @@ public:
 	//! returns the current parse tree, either from a previous Load, Save, or setParseTree()
 	virtual xmlDoc* getParseTree() const { return xmldocument; }
 	
-	//! calls LoadXML with the root of the current parse tree
+	//! calls loadXML with the root of the current parse tree
 	virtual void readParseTree();
-	//! calls SaveXML with the root of the current parse tree
+	//! calls saveXML with the root of the current parse tree
 	virtual void writeParseTree();
 	
 	//! allows you to set the compression level used by libxml2 -- this corresponds to the compression level setting of zlib, i.e. 0-9
@@ -133,10 +137,10 @@ protected:
  * @author Ethan Tira-Thompson (ejt) (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:04 $
+ * $Date: 2006/09/09 04:33:02 $
  */
 
 #endif
