@@ -16,6 +16,7 @@ namespace project_get_time {
 		return static_cast<unsigned int>(first.Age().Value()*1000);
 	}
 	unsigned int (*get_time_callback)()=&default_get_time_callback;
+	float (*get_timeScale_callback)()=NULL;
 }
 #endif
 
@@ -24,8 +25,8 @@ namespace project_get_time {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:49 $
+ * $Date: 2006/10/04 02:40:42 $
  */
