@@ -52,6 +52,17 @@ namespace mathutils {
 	inline double log2t(double x) {
 		return log(x)/M_LN2;
 	}
+
+  template <class num>
+  inline num deg2rad(num x) {
+    return x*M_PI/180;
+  }
+
+  template <class num>
+  inline num rad2deg(num x) {
+    return x*180/M_PI;
+  }
+
 }
 
 #endif
