@@ -1,31 +1,61 @@
 #include "string_util.h"
 #include <ctype.h>
+#include <pwd.h>
+#include <stdlib.h>
+
+using namespace std;
 
 namespace string_util {
 
-	std::string makeLower(const std::string& s) {
-		std::string ans(s.size(),'#');
+	string makeLower(const string& s) {
+		string ans(s.size(),'#');
 		unsigned int i=s.size();
 		while(i--!=0)
 			ans[i]=::tolower(s[i]);
 		return ans;
 	}
 
-	std::string makeUpper(const std::string& s) {
-		std::string ans(s.size(),'#');
+	string makeUpper(const string& s) {
+		string ans(s.size(),'#');
 		unsigned int i=s.size();
 		while(i--!=0)
 			ans[i]=::toupper(s[i]);
 		return ans;
 	}
 
-	std::string removePrefix(const std::string& str, const std::string& pre) {
+	string removePrefix(const string& str, const string& pre) {
 		if(str.compare(0,pre.size(),pre)==0)
 			return str.substr(pre.size());
-		return std::string();
+		return string();
+	}
+	
+	string tildeExpansion(const string& str) {
+		string ans;
+		if(str[0]!='~') {
+			return str;
+		}
+#ifndef PLATFORM_APERIOS
+		else if(str=="~" || str[1]=='/') {
+			char* home=getenv("HOME");
+			if(home==NULL)
+				return str;
+			if(str=="~")
+				return home;
+			return home+str.substr(1);
+		} else {
+			string::size_type p=str.find('/');
+			struct passwd * pw;
+			pw=getpwnam(str.substr(1,p-1).c_str());
+			if(pw==NULL)
+				return str;
+			return pw->pw_dir+str.substr(p);
+		}
+#else
+		return str.substr(1);
+#endif
 	}
 
-	std::string trim(const std::string& str) {
+	string trim(const string& str) {
 		if(str.size()==0)
 			return str;
 		unsigned int b=0;
@@ -37,8 +67,8 @@ namespace string_util {
 		return str.substr(b,e-b+1);
 	}
 	
-	bool parseArgs(const std::string& input, std::vector<std::string>& args, std::vector<unsigned int>& offsets) {
-		std::string cur;
+	bool parseArgs(const string& input, vector<string>& args, vector<unsigned int>& offsets) {
+		string cur;
 		bool isDoubleQuote=false;
 		bool isSingleQuote=false;
 		args.clear();
@@ -101,8 +131,8 @@ namespace string_util {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:49 $
+ * $Date: 2006/03/16 22:07:28 $
  */
