@@ -1,6 +1,6 @@
 #include "Shared/Config.h"
 #include "SoundManager.h"
-#include "IPC/LockScope.h"
+#include "Shared/MarkScope.h"
 #include "WAV.h"
 #include "Events/EventRouter.h"
 #include <sys/types.h>
@@ -17,7 +17,7 @@ using namespace std;
 SoundManager * sndman=NULL;
 
 //!for convenience when locking each of the functions
-typedef LockScope<ProcessID::NumProcesses> AutoLock;
+typedef MarkScope AutoLock;
 
 SoundManager::SoundManager()
 : mixerBuffer(0), mixerBufferSize(0), sndlist(),playlist(),chanlist(),mix_mode(Fast),queue_mode(Override),max_chan(4),lock(),sn(0)
@@ -36,7 +36,7 @@ SoundManager::InitAccess(MessageQueueBase& sndbufq) {
 #endif //PLATFORM-specific initialization
 
 SoundManager::~SoundManager() {
-	StopPlay();
+	stopPlay();
 	if(!sndlist.empty())
 		cerr << "Warning: SoundManager was deleted with active sound buffer references" << endl;
 	while(!sndlist.empty()) {
@@ -54,11 +54,11 @@ SoundManager::~SoundManager() {
 
 //!@todo this does one more copy than it really needs to
 SoundManager::Snd_ID
-SoundManager::LoadFile(std::string const &name) {
-	AutoLock autolock(lock,ProcessID::getID());
+SoundManager::loadFile(std::string const &name) {
+	AutoLock autolock(lock);
 	if (name.size() == 0) {
-	  cout << "SoundManager::LoadFile() null filename" << endl;
-	  return invalid_Snd_ID;
+		cout << "SoundManager::loadFile() null filename" << endl;
+		return invalid_Snd_ID;
 	};
 	std::string path(config->sound.makePath(name));
 	Snd_ID id=lookupPath(path);
@@ -69,7 +69,7 @@ SoundManager::LoadFile(std::string const &name) {
 		//		cout << "load new file" << endl;
 		struct stat buf;
 		if(stat(path.c_str(),&buf)==-1) {
-			cout << "SoundManager::LoadFile(): Sound file not found: " << path << endl;
+			cout << "SoundManager::loadFile(): Sound file not found: " << path << endl;
 			return invalid_Snd_ID;
 		}
 		byte * sndbuf=new byte[buf.st_size];
@@ -78,15 +78,15 @@ SoundManager::LoadFile(std::string const &name) {
 		WAV wav;
 		WAVError error = wav.Set(sndbuf);
 		if (error != WAV_SUCCESS) {
-			printf("%s : %s %d: '%s'","SoundManager::LoadFile()","wav.Set() FAILED",error, path.c_str());
+			printf("%s : %s %d: '%s'","SoundManager::loadFile()","wav.Set() FAILED",error, path.c_str());
 			return invalid_Snd_ID;
 		}
 		if(wav.GetSamplingRate()!=config->sound.sample_rate || wav.GetBitsPerSample()!=config->sound.sample_bits) {
-			printf("%s : %s %d","SoundManager::LoadFile()","bad sample rate/bits", error);
+			printf("%s : %s %d","SoundManager::loadFile()","bad sample rate/bits", error);
 			return invalid_Snd_ID;
 		}
-		//cout << "Loading " << name << endl;
-		id=LoadBuffer(reinterpret_cast<char*>(wav.GetDataStart()),wav.GetDataEnd()-wav.GetDataStart());
+		cout << "Loading " << name << endl;
+		id=loadBuffer(reinterpret_cast<char*>(wav.GetDataStart()),wav.GetDataEnd()-wav.GetDataStart());
 		delete [] sndbuf;
 		if(path.size()>MAX_NAME_LEN)
 			strncpy(sndlist[id].name,path.substr(path.size()-MAX_NAME_LEN).c_str(),MAX_NAME_LEN);
@@ -97,11 +97,11 @@ SoundManager::LoadFile(std::string const &name) {
 }
 
 SoundManager::Snd_ID
-SoundManager::LoadBuffer(const char buf[], unsigned int len) {
-	cout << "SoundManager::LoadBuffer() of " << len << " bytes" << endl;
+SoundManager::loadBuffer(const char buf[], unsigned int len) {
+  // cout << "SoundManager::loadBuffer() of " << len << " bytes" << endl;
 	if(buf==NULL || len==0)
 		return invalid_Snd_ID;
-	AutoLock autolock(lock,ProcessID::getID());
+	AutoLock autolock(lock);
 	//setup region
 	RCRegion * region=initRegion(len+MSG_SIZE);
 	//setup message
@@ -145,20 +145,20 @@ SoundManager::LoadBuffer(const char buf[], unsigned int len) {
 }
 	
 void
-SoundManager::ReleaseFile(std::string const &name) {
-	AutoLock autolock(lock,ProcessID::getID());
-	Release(lookupPath(config->sound.makePath(name)));
+SoundManager::releaseFile(std::string const &name) {
+	AutoLock autolock(lock);
+	release(lookupPath(config->sound.makePath(name)));
 }
 
 void
-SoundManager::Release(Snd_ID id) {
+SoundManager::release(Snd_ID id) {
 	if(id==invalid_Snd_ID)
 		return;
 	if(sndlist[id].ref==0) {
-		cerr << "SoundManager::Release() " << id << " extra release" << endl;
+		cerr << "SoundManager::release() " << id << " extra release" << endl;
 		return;
 	}
-	AutoLock autolock(lock,ProcessID::getID());
+	AutoLock autolock(lock);
 	sndlist[id].ref--;
 	if(sndlist[id].ref==0) {
 		if(sndlist[id].rcr!=NULL) {
@@ -197,35 +197,36 @@ SoundManager::Release(Snd_ID id) {
 }
 
 SoundManager::Play_ID
-SoundManager::PlayFile(std::string const &name) {
+SoundManager::playFile(std::string const &name) {
   if(playlist.size()>=playlist_t::MAX_ENTRIES)
 		return invalid_Play_ID;	
-	AutoLock autolock(lock,ProcessID::getID());
-	Snd_ID sndid=LoadFile(name);
+	AutoLock autolock(lock);
+	Snd_ID sndid=loadFile(name);
 	if(sndid==invalid_Snd_ID)
 		return invalid_Play_ID;
 	sndlist[sndid].ref--;
-	return Play(sndid);
+	cout << "Playing " << name /*<< " from process " << ProcessID::getID()*/ << endl;
+	return play(sndid);
 }
 
 SoundManager::Play_ID
-SoundManager::PlayBuffer(const char buf[], unsigned int len) {
+SoundManager::playBuffer(const char buf[], unsigned int len) {
 	if(playlist.size()>=playlist_t::MAX_ENTRIES || buf==NULL || len==0)
 		return invalid_Play_ID;	
-	AutoLock autolock(lock,ProcessID::getID());
-	Snd_ID sndid=LoadBuffer(buf,len);
+	AutoLock autolock(lock);
+	Snd_ID sndid=loadBuffer(buf,len);
 	if(sndid==invalid_Snd_ID)
 		return invalid_Play_ID;
 	sndlist[sndid].ref--;
-	return Play(sndid);
+	return play(sndid);
 }
 	
 SoundManager::Play_ID
-SoundManager::Play(Snd_ID id) {
-	//	cout << "Play " << id << endl;
+SoundManager::play(Snd_ID id) {
+        // cout << "Play " << id << endl;
 	if(id==invalid_Snd_ID)
 		return invalid_Play_ID;
-	AutoLock autolock(lock,ProcessID::getID());
+	AutoLock autolock(lock);
 	Play_ID playid=playlist.new_front();
 	if(playid!=invalid_Play_ID) {
 		sndlist[id].ref++;
@@ -267,16 +268,16 @@ SoundManager::Play(Snd_ID id) {
 }
 	
 SoundManager::Play_ID
-SoundManager::ChainFile(Play_ID base, std::string const &next) {
+SoundManager::chainFile(Play_ID base, std::string const &next) {
        if(base==invalid_Play_ID)
-		return base;
+		return playFile(next);
 	Play_ID orig=base;
 	while(playlist[base].next_id!=invalid_Play_ID)
 		base=playlist[base].next_id;
 	Play_ID nplay=playlist.new_front();
 	if(nplay==invalid_Play_ID)
 		return nplay;
-	Snd_ID nsnd=LoadFile(next);
+	Snd_ID nsnd=loadFile(next);
 	if(nsnd==invalid_Snd_ID) {
 		playlist.pop_front();
 		return invalid_Play_ID;
@@ -287,16 +288,16 @@ SoundManager::ChainFile(Play_ID base, std::string const &next) {
 }
 
 SoundManager::Play_ID
-SoundManager::ChainBuffer(Play_ID base, const char buf[], unsigned int len) {
+SoundManager::chainBuffer(Play_ID base, const char buf[], unsigned int len) {
 	if(base==invalid_Play_ID || buf==NULL || len==0)
-		return base;
+		return playBuffer(buf,len);
 	Play_ID orig=base;
 	while(playlist[base].next_id!=invalid_Play_ID)
 		base=playlist[base].next_id;
 	Play_ID nplay=playlist.new_front();
 	if(nplay==invalid_Play_ID)
 		return nplay;
-	Snd_ID nsnd=LoadBuffer(buf,len);
+	Snd_ID nsnd=loadBuffer(buf,len);
 	if(nsnd==invalid_Snd_ID) {
 		playlist.pop_front();
 		return invalid_Play_ID;
@@ -307,9 +308,9 @@ SoundManager::ChainBuffer(Play_ID base, const char buf[], unsigned int len) {
 }
 
 SoundManager::Play_ID
-SoundManager::Chain(Play_ID base, Snd_ID next) {
+SoundManager::chain(Play_ID base, Snd_ID next) {
 	if(base==invalid_Play_ID || next==invalid_Snd_ID)
-		return base;
+		return play(next);
 	Play_ID orig=base;
 	while(playlist[base].next_id!=invalid_Play_ID)
 		base=playlist[base].next_id;
@@ -322,22 +323,22 @@ SoundManager::Chain(Play_ID base, Snd_ID next) {
 }
 
 void
-SoundManager::StopPlay() {
+SoundManager::stopPlay() {
 	while(!playlist.empty())
-		StopPlay(playlist.begin());
+		stopPlay(playlist.begin());
 }
 
 void
-SoundManager::StopPlay(Play_ID id) {
+SoundManager::stopPlay(Play_ID id) {
 	if(id==invalid_Play_ID)
 		return;
-	AutoLock autolock(lock,ProcessID::getID());
+	AutoLock autolock(lock);
 	//cout << "Stopping sound " << id << ": " << sndlist[playlist[id].snd_id].name << endl;
 	//we start at the back (oldest) since these are the most likely to be removed...
 	for(chanlist_t::index_t it=chanlist.prev(chanlist.end()); it!=chanlist.end(); it=chanlist.prev(it))
 		if(chanlist[it]==id) {
 			std::string name=sndlist[playlist[id].snd_id].name;
-			Release(playlist[id].snd_id);
+			release(playlist[id].snd_id);
 			playlist.erase(id);
 			chanlist.erase(it);
 			playlist[id].cumulative+=playlist[id].offset;
@@ -348,14 +349,14 @@ SoundManager::StopPlay(Play_ID id) {
 				erouter->postEvent(EventBase::audioEGID,id,EventBase::deactivateETID,ms);
 			return;
 		}
-	cerr << "SoundManager::StopPlay(): " << id << " does not seem to be playing" << endl;
+	cerr << "SoundManager::stopPlay(): " << id << " does not seem to be playing" << endl;
 }
 
 void
-SoundManager::PausePlay(Play_ID id) {
+SoundManager::pausePlay(Play_ID id) {
 	if(id==invalid_Play_ID)
 		return;
-	AutoLock autolock(lock,ProcessID::getID());
+	AutoLock autolock(lock);
 	for(chanlist_t::index_t it=chanlist.begin(); it!=chanlist.end(); it=chanlist.next(it))
 		if(chanlist[it]==id) {
 			chanlist.erase(it);
@@ -364,10 +365,10 @@ SoundManager::PausePlay(Play_ID id) {
 }
 	
 void
-SoundManager::ResumePlay(Play_ID id) {
+SoundManager::resumePlay(Play_ID id) {
 	if(id==invalid_Play_ID)
 		return;
-	AutoLock autolock(lock,ProcessID::getID());
+	AutoLock autolock(lock);
 	for(chanlist_t::index_t it=chanlist.begin(); it!=chanlist.end(); it=chanlist.next(it))
 		if(chanlist[it]==id)
 			return;
@@ -375,16 +376,16 @@ SoundManager::ResumePlay(Play_ID id) {
 }
 	
 void
-SoundManager::SetMode(unsigned int max_channels, MixMode_t mixer_mode, QueueMode_t queuing_mode) {
-	AutoLock autolock(lock,ProcessID::getID());
+SoundManager::setMode(unsigned int max_channels, MixMode_t mixer_mode, QueueMode_t queuing_mode) {
+	AutoLock autolock(lock);
 	max_chan=max_channels;
 	mix_mode=mixer_mode;
 	queue_mode=queuing_mode;
 }
 
 unsigned int
-SoundManager::GetRemainTime(Play_ID id) const {
-	AutoLock autolock(lock,ProcessID::getID());
+SoundManager::getRemainTime(Play_ID id) const {
+	AutoLock autolock(lock);
 	unsigned int t=0;
 	while(id!=invalid_Play_ID) {
 		t+=sndlist[playlist[id].snd_id].len-playlist[id].offset;
@@ -395,7 +396,7 @@ SoundManager::GetRemainTime(Play_ID id) const {
 }
 
 void
-SoundManager::MixChannel(Play_ID channelId, void* buf, size_t destSize) {
+SoundManager::mixChannel(Play_ID channelId, void* buf, size_t destSize) {
 	char *dest = (char*) buf;
 	
 	PlayState& channel = playlist[channelId];
@@ -425,7 +426,7 @@ SoundManager::MixChannel(Play_ID channelId, void* buf, size_t destSize) {
 }
 
 void
-SoundManager::MixChannelAdditively(Play_ID channelId, int bitsPerSample, MixMode_t mode,
+SoundManager::mixChannelAdditively(Play_ID channelId, int bitsPerSample, MixMode_t mode,
                                    short scalingFactor, void* buf, size_t destSize)
 {
 	PlayState& channel = playlist[channelId];
@@ -496,7 +497,7 @@ SoundManager::MixChannelAdditively(Play_ID channelId, int bitsPerSample, MixMode
 #ifdef PLATFORM_APERIOS
 unsigned int
 SoundManager::CopyTo(OSoundVectorData* data) {
-	AutoLock autolock(lock,ProcessID::getID());
+	AutoLock autolock(lock);
 	return CopyTo(data->GetData(0), data->GetInfo(0)->dataSize);
 }
 
@@ -509,7 +510,7 @@ SoundManager::ReceivedMsg(const ONotifyEvent& event) {
 #endif
 
 unsigned int SoundManager::CopyTo(void * dest, size_t destSize) {
-	AutoLock autolock(lock,ProcessID::getID());
+	AutoLock autolock(lock);
 
 	void * origdest=dest;
 	size_t origDestSize=destSize;
@@ -526,7 +527,7 @@ unsigned int SoundManager::CopyTo(void * dest, size_t destSize) {
 		memset(dest, 0, destSize); 
 	} else if (channels.size() == 1) {
 		// One channel to mix
-		MixChannel(channels.front(), dest, destSize);
+		mixChannel(channels.front(), dest, destSize);
 	} else {
 		// Several channels to mix	
 		const MixMode_t mode = mix_mode;
@@ -550,7 +551,7 @@ unsigned int SoundManager::CopyTo(void * dest, size_t destSize) {
 		const int channelCount = channels.size();
 		const short scalingFactor = (short) ((mode == Fast) ? channelCount : 1);  
 		for(std::vector<Play_ID>::iterator i = channels.begin(); i != channels.end(); i++)
-			MixChannelAdditively(*i, bitsPerSample, mode, scalingFactor, dest, destSize);
+			mixChannelAdditively(*i, bitsPerSample, mode, scalingFactor, dest, destSize);
 		
 		if (mode == Quality) {
 			// Quality mixing uses an intermediate buffer
@@ -649,7 +650,8 @@ SoundManager::initRegion(unsigned int size) {
 #ifdef PLATFORM_APERIOS
 	unsigned int pagesize=4096;
 	sError err=GetPageSize(&pagesize);
-	ASSERT(err==sSUCCESS,"Error "<<err<<" getting page size");
+	if(err!=sSUCCESS)
+		cerr << "Error "<<err<<" getting page size " << pagesize << endl;
 	unsigned int pages=(size+pagesize-1)/pagesize;
 	return new RCRegion(pages*pagesize);
 #else
@@ -773,13 +775,13 @@ SoundManager::updateChannels(const std::vector<Play_ID>& mixs,size_t used) {
 bool
 SoundManager::endPlay(Play_ID id) {
 	if(playlist[id].next_id==invalid_Play_ID) {
-		StopPlay(id);
+		stopPlay(id);
 		return true;
 	} else {
 		//copies the next one into current so that the Play_ID consistently refers to the same "sound"
 		Play_ID next=playlist[id].next_id;
 		//		cout << "play " << id << " moving from " << playlist[id].snd_id << " to " << playlist[next].snd_id << endl;
-		Release(playlist[id].snd_id);
+		release(playlist[id].snd_id);
 		playlist[id].snd_id=playlist[next].snd_id;
 		playlist[id].cumulative+=playlist[id].offset;
 		playlist[id].offset=0;
@@ -806,15 +808,34 @@ SoundManager::PlayState::PlayState()
 {}
 
 
+SoundManager::Snd_ID SoundManager::LoadFile(std::string const &name) { return loadFile(name); }
+SoundManager::Snd_ID SoundManager::LoadBuffer(const char buf[], unsigned int len) { return loadBuffer(buf,len); }
+void SoundManager::ReleaseFile(std::string const &name) { releaseFile(name); }
+void SoundManager::Release(Snd_ID id) { release(id); }
+SoundManager::Play_ID SoundManager::PlayFile(std::string const &name) { return playFile(name); }
+SoundManager::Play_ID SoundManager::PlayBuffer(const char buf[], unsigned int len) { return playBuffer(buf,len); }
+SoundManager::Play_ID SoundManager::Play(Snd_ID id) { return play(id); }
+SoundManager::Play_ID SoundManager::ChainFile(Play_ID base, std::string const &next) { return chainFile(base,next); }
+SoundManager::Play_ID SoundManager::ChainBuffer(Play_ID base, const char buf[], unsigned int len) { return chainBuffer(base,buf,len); }
+SoundManager::Play_ID SoundManager::Chain(Play_ID base, Snd_ID next) { return chain(base,next); }
+void SoundManager::StopPlay() { stopPlay(); }
+void SoundManager::StopPlay(Play_ID id) { stopPlay(id); }
+void SoundManager::PausePlay(Play_ID id) { pausePlay(id); }
+void SoundManager::ResumePlay(Play_ID id) { resumePlay(id); }
+void SoundManager::SetMode(unsigned int max_channels, MixMode_t mixer_mode, QueueMode_t queuing_mode) { setMode(max_channels,mixer_mode,queuing_mode); }
+unsigned int SoundManager::GetRemainTime(Play_ID id) const { return getRemainTime(id); }
+unsigned int SoundManager::GetNumPlaying() { return getNumPlaying(); }
+
+
 /*! @file
  * @brief Implements SoundManager, which provides sound effects and caching services, as well as mixing buffers for the SoundPlay process
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:53 $
+ * $Date: 2006/09/18 18:08:08 $
  */
 
 
@@ -872,7 +893,7 @@ SoundManager::PlayState::PlayState()
 					for(;beg<(unsigned int*)end; beg++)
 						*beg+=offset>>shift;
 					playlist[mixs[c]].offset=sndlist[playlist[mixs[c]].snd_id].len;
-					StopPlay(mixs[c]);
+					stopPlay(mixs[c]);
 				}
 			}
 			unsigned int leftover=(offset>>shift)*((1<<shift)-mixs.size());
