@@ -11,6 +11,7 @@
 #include "IPC/MutexLock.h"
 #include "SoundManagerMsg.h"
 #include "IPC/ProcessID.h"
+#include "Shared/attributes.h"
 
 #ifdef PLATFORM_APERIOS
 class OSubject;
@@ -29,9 +30,9 @@ class ONotifyEvent;
  *  at a time and chain them so it seamlessly moves from one to the
  *  other.
  *  
- *  You can also preload sounds (LoadFile()) before playing them so
+ *  You can also preload sounds (loadFile()) before playing them so
  *  there's no delay while loading after you request a sound to be
- *  played.  Just be sure to release the file (ReleaseFile()) again
+ *  played.  Just be sure to release the file (releaseFile()) again
  *  when you're done with it ;)
  *
  *  All functions will attempt to lock the SoundManager.  Remember,
@@ -46,14 +47,15 @@ class ONotifyEvent;
  *  synthesizer, ...?)
  *
  *  @todo Volume control, variable playback speed, support more wav
- *  file formats (latter two are the same thing if you think about it
- *  - need to be able to resample on the fly)
+ *  file formats (latter two are the same thing if you think about it - need
+ *  to be able to resample on the fly)
  *  
  *  @todo Add functions to hand out regions to be filled out to avoid
  *  copying into the buffer.
  */
 class SoundManager {
 public:
+	//! destructor
 	virtual ~SoundManager();
 
 	//!constructor, should only be called by the receiving process (SoundPlay)
@@ -86,6 +88,7 @@ public:
 		Quality  //!< uses real division to maintain volume level, using an intermediary higher precision buffer for mixing
 	};
 
+	//! indicates how to handle channel overflow (trying to play more sounds than maximum number of mixing channels). See #queue_mode
 	enum QueueMode_t {
 		Enqueue,        //!< newer sounds are played when a channel opens up (when old sound finishes)
 		Pause,          //!< newer sounds pause oldest sound, which continues when a channel opens
@@ -97,66 +100,66 @@ public:
 	/*!Since the SoundManager does the loading, if the same file is being played more than once, only once copy is stored in memory 
 	 * @param name can be either a full path, or a partial path relative to Config::sound_config::root
 	 * @return ID number for future references (can also use name)
-	 * The sound data will be cached until ReleaseFile() or Release() is called a matching number of times*/
-	Snd_ID LoadFile(std::string const &name);
+	 * The sound data will be cached until releaseFile() or release() is called a matching number of times*/
+	Snd_ID loadFile(std::string const &name);
 
 	//!loads raw samples from a buffer (assumes matches Config::sound_config settings)
-	/*!The sound data will be cached until Release() is called a matching number of times.\n
+	/*!The sound data will be cached until release() is called a matching number of times.\n
 	 * This function is useful for dynamic sound sources.  A copy will be made. */
-	Snd_ID LoadBuffer(const char buf[], unsigned int len);
+	Snd_ID loadBuffer(const char buf[], unsigned int len);
 	
 	//!Marks the sound buffer to be released after the last play command completes (or right now if not being played)
-	void ReleaseFile(std::string const &name);
+	void releaseFile(std::string const &name);
 
 	//!Marks the sound buffer to be released after the last play command completes (or right now if not being played)
-	void Release(Snd_ID id);
+	void release(Snd_ID id);
 	
 	//!play a wav file (if it matches Config::sound_config settings - can't do resampling yet)
-	/*!Will do a call to LoadFile() first, and then automatically release the sound again when complete.
+	/*!Will do a call to loadFile() first, and then automatically release the sound again when complete.
 	 * @param name can be either a full path, or a partial path relative to Config::sound_config::root
 	 * @return ID number for future references
-	 * The sound data will not be cached after done playing unless a call to LoadFile is made*/
-	Play_ID PlayFile(std::string const &name);
+	 * The sound data will not be cached after done playing unless a call to loadFile is made*/
+	Play_ID playFile(std::string const &name);
 
 	//!loads raw samples from a buffer (assumes buffer matches Config::sound_config settings)
 	/*!The sound data will be released after done playing*/
-	Play_ID PlayBuffer(const char buf[], unsigned int len);
+	Play_ID playBuffer(const char buf[], unsigned int len);
 	
 	//!plays a previously loaded buffer or file
-	Play_ID Play(Snd_ID id);
+	Play_ID play(Snd_ID id);
 	
 	//!allows automatic queuing of sounds - good for dynamic sound sources!
 	/*!if you chain more than once to the same base, the new buffers are appended
 	 * to the end of the chain - the new buffer doesn't replace the current chain
 	 * @return @a base - just for convenience of multiple calls*/
-	Play_ID ChainFile(Play_ID base, std::string const &next);
+	Play_ID chainFile(Play_ID base, std::string const &next);
 
 	//!allows automatic queuing of sounds - good for dynamic sound sources!
 	/*!if you chain more than once to the same base, the new buffers are appended
 	 * to the end of the chain - the new buffer doesn't replace the current chain
 	 * @return @a base - just for convenience of multiple calls*/
-	Play_ID ChainBuffer(Play_ID base, const char buf[], unsigned int len);
+	Play_ID chainBuffer(Play_ID base, const char buf[], unsigned int len);
 
 	//!allows automatic queuing of sounds - good for dynamic sound sources!
 	/*!if you chain more than once to the same base, the new buffers are appended
 	 * to the end of the chain - the new buffer doesn't replace the current chain
 	 * @return @a base - just for convenience of multiple calls*/
-	Play_ID Chain(Play_ID base, Snd_ID next);
+	Play_ID chain(Play_ID base, Snd_ID next);
 	
 	//!Lets you stop playback of all sounds
-	void StopPlay();
+	void stopPlay();
 
 	//!Lets you stop playback of a sound
-	void StopPlay(Play_ID id);
+	void stopPlay(Play_ID id);
 	
 	//!Lets you pause playback
-	void PausePlay(Play_ID id);
+	void pausePlay(Play_ID id);
 	
 	//!Lets you resume playback
-	void ResumePlay(Play_ID id);
+	void resumePlay(Play_ID id);
 	
 	//!Lets you control the maximum number of channels (currently playing sounds), method for mixing (applies when max_chan>1), and queuing method (for when overflow channels)
-	void SetMode(unsigned int max_channels, MixMode_t mixer_mode, QueueMode_t queuing_mode);
+	void setMode(unsigned int max_channels, MixMode_t mixer_mode, QueueMode_t queuing_mode);
 
 	//!Gives the time until the sound finishes, in milliseconds.  Subtract 32 to get guarranteed valid time for this ID.
 	/*!You should be passing the beginning of a chain to get proper results...\n
@@ -168,7 +171,7 @@ public:
 	 * (and cause the ID to go invalid) up to RobotInfo::SoundBufferTime (32 ms)
 	 * before the sound finishes.  So subtract SoundBufferTime if you want to be
 	 * absolutely sure the ID will still valid. */
-	unsigned int GetRemainTime(Play_ID id) const;
+	unsigned int getRemainTime(Play_ID id) const;
 	
 #ifdef PLATFORM_APERIOS
 	//!Copies the sound data to the OPENR buffer, ready to be passed to the system, only called by SoundPlay
@@ -187,16 +190,41 @@ public:
 	void ProcessMsg(RCRegion * rcr);
 	
 	//! returns number of sounds currently playing
-	unsigned int GetNumPlaying() { return chanlist.size(); }
+	unsigned int getNumPlaying() { return chanlist.size(); }
+	
+	//! return the next region serial number -- doesn't actually increment it though, repeated calls will return the same value until the value is actually used
+	virtual unsigned int getNextKey() { return sn+1; }
+	
+	/*! @brief These functions retain an older style first-letter capitalization derived from the OPEN-R
+	 *  sample code.  You should use the Java-style naming convention instead (first letter lowercase) */
+	//!@name Deprecated
+	Snd_ID LoadFile(std::string const &name) ATTR_deprecated; //!< deprecated, use loadFile() (note first letter lower case)
+	Snd_ID LoadBuffer(const char buf[], unsigned int len) ATTR_deprecated; //!< deprecated, use loadBuffer() (note first letter lower case)
+	void ReleaseFile(std::string const &name) ATTR_deprecated; //!< deprecated, use releaseFile() (note first letter lower case)
+	void Release(Snd_ID id) ATTR_deprecated; //!< deprecated, use release() (note first letter lower case)
+	Play_ID PlayFile(std::string const &name) ATTR_deprecated; //!< deprecated, use playFile() (note first letter lower case)
+	Play_ID PlayBuffer(const char buf[], unsigned int len) ATTR_deprecated; //!< deprecated, use playBuffer() (note first letter lower case)
+	Play_ID Play(Snd_ID id) ATTR_deprecated; //!< deprecated, use play() (note first letter lower case)
+	Play_ID ChainFile(Play_ID base, std::string const &next) ATTR_deprecated; //!< deprecated, use chainFile() (note first letter lower case)
+	Play_ID ChainBuffer(Play_ID base, const char buf[], unsigned int len) ATTR_deprecated; //!< deprecated, use chainBuffer() (note first letter lower case)
+	Play_ID Chain(Play_ID base, Snd_ID next) ATTR_deprecated; //!< deprecated, use chain() (note first letter lower case)
+	void StopPlay() ATTR_deprecated; //!< deprecated, use stopPlay() (note first letter lower case)
+	void StopPlay(Play_ID id) ATTR_deprecated; //!< deprecated, use stopPlay() (note first letter lower case)
+	void PausePlay(Play_ID id) ATTR_deprecated; //!< deprecated, use pausePlay() (note first letter lower case)
+	void ResumePlay(Play_ID id) ATTR_deprecated; //!< deprecated, use resumePlay() (note first letter lower case)
+	void SetMode(unsigned int max_channels, MixMode_t mixer_mode, QueueMode_t queuing_mode) ATTR_deprecated; //!< deprecated, use setMode() (note first letter lower case)
+	unsigned int GetRemainTime(Play_ID id) const ATTR_deprecated; //!< deprecated, use getRemainTime() (note first letter lower case)
+	unsigned int GetNumPlaying() ATTR_deprecated; //!< deprecated, use getNumPlaying() (note first letter lower case)
+	//@}
 	
 protected:
 	//!Mixes the channel into the buffer
-	void MixChannel(Play_ID channelId, void* buf, size_t size);
+	void mixChannel(Play_ID channelId, void* buf, size_t size);
 	
 	//!Mixes the channel into the buffer additively
 	/*!If mode is Quality, then the size of the buffer should be double the normal
 	* size. */
-	void MixChannelAdditively(Play_ID channelId, int bitsPerSample, MixMode_t mode, short scalingFactor, void* buf, size_t size);
+	void mixChannelAdditively(Play_ID channelId, int bitsPerSample, MixMode_t mode, short scalingFactor, void* buf, size_t size);
 	
 	//!The intermediate mixer buffer used for Quality mode mixing
 	int* mixerBuffer;
@@ -216,7 +244,7 @@ protected:
 	//!update the offsets of sounds which weren't mixed (when needed depending on queue_mode)
 	void updateChannels(const std::vector<Play_ID>& mixs,size_t used);
 
-	//!called when a buffer end is reached, may reset buffer to next in chain, or just StopPlay()
+	//!called when a buffer end is reached, may reset buffer to next in chain, or just stopPlay()
 	bool endPlay(Play_ID id);
 
 	//!Holds data about the loaded sounds
@@ -254,10 +282,10 @@ protected:
 	//!Holds a list of all currently playing sounds, ordered newest (front) to oldest(back)
 	chanlist_t chanlist;
 	
-	//!Current mixing mode, set by SetMode();
+	//!Current mixing mode, set by setMode();
 	MixMode_t mix_mode;
 
-	//!Current queuing mode, set by SetMode();
+	//!Current queuing mode, set by setMode();
 	QueueMode_t queue_mode;
 
 	//!Current maximum number of sounds to mix together
@@ -300,10 +328,10 @@ extern SoundManager * sndman;
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:04 $
+ * $Date: 2006/09/29 16:56:10 $
  */
 
 #endif
