@@ -13,7 +13,12 @@ private:
 	typedef unsigned short Snd_ID;
 
 	//! Denotes what type of message this is
-	enum MsgType { add, del, wakeup, unknown } type;
+	enum MsgType {
+		add, //!< indicates a new sound to be played
+		del, //!< indicates the sound with #id should be stopped
+		wakeup, //!< indicates that it's time to start sending sounds to the system
+		unknown //!< initial value for #type until one of the others is assigned
+	} type; //!< indicates how this message should be processed
 	
 	//! The id of the sound this is in reference to
 	Snd_ID id;
@@ -61,10 +66,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2005/06/01 05:47:54 $
+ * $Date: 2006/09/16 20:11:53 $
  */
 
 #endif // INCLUDED_SoundManagerMsg_h
