@@ -1,10 +1,10 @@
 #include "BallDetectionGenerator.h"
 #include "Events/EventRouter.h"
 #include "Shared/Util.h"
-#include "Shared/WorldState.h"
 #include "Wireless/Wireless.h"
 #include "Shared/Config.h"
 #include "Events/VisionObjectEvent.h"
+#include "Shared/Profiler.h"
 
 #include "Vision/SegmentedColorGenerator.h"
 #include "Vision/RegionGenerator.h"
@@ -17,7 +17,7 @@ BallDetectionGenerator::BallDetectionGenerator(unsigned int mysid, const RegionG
 
 void
 BallDetectionGenerator::processEvent(const EventBase& e) {
-	PROFSECTION("BallDetection::processEvent()",state->mainProfile);
+	PROFSECTION("BallDetection::processEvent()",*mainProfiler);
 	EventGeneratorBase::processEvent(e);
 	if(e.getGeneratorID()!=getListenGeneratorID() || e.getSourceID()!=getListenSourceID())
 		return;
@@ -260,18 +260,19 @@ BallDetectionGenerator::testSendEvent(const FilterBankEvent& ev, float conf, int
 	float cx2=2.0f*(regX2+1)/dim - cw;
 	float cy1=2.0f*regY1/dim - ch;
 	float cy2=2.0f*(regY2+1)/dim - ch;
+	float carea=4.0f*area/(dim*dim);
 	unsigned int frame_number=ev.getFrameNumber();	
 
 	if (conf>confidenceThreshold) {
 		if (present) {
 			count=0;
-			createEvent(EventBase::statusETID,cx1,cx2,cy1,cy2,area,cw,ch,frame_number);
+			createEvent(EventBase::statusETID,cx1,cx2,cy1,cy2,carea,cw,ch,frame_number);
 		} else {
 			count++;
 			if (count>noiseThreshold) {
 				count=0;
 				present=true;
-				createEvent(EventBase::activateETID,cx1,cx2,cy1,cy2,area,cw,ch,frame_number);
+				createEvent(EventBase::activateETID,cx1,cx2,cy1,cy2,carea,cw,ch,frame_number);
 			}
 		}
 	} else {
@@ -282,9 +283,9 @@ BallDetectionGenerator::testSendEvent(const FilterBankEvent& ev, float conf, int
 			if (count>noiseThreshold) {
 				count=0;
 				present=false;
-				createEvent(EventBase::deactivateETID,0,0,0,0,area,cw,ch,frame_number);
+				createEvent(EventBase::deactivateETID,0,0,0,0,carea,cw,ch,frame_number);
 			} else {
-				createEvent(EventBase::statusETID,cx1,cx2,cy1,cy2,area,cw,ch,frame_number);
+				createEvent(EventBase::statusETID,cx1,cx2,cy1,cy2,carea,cw,ch,frame_number);
 			}
 		}
 	}
@@ -292,8 +293,8 @@ BallDetectionGenerator::testSendEvent(const FilterBankEvent& ev, float conf, int
 
 void
 BallDetectionGenerator::createEvent(EventBase::EventTypeID_t etid, float bbX1,float bbX2,float bbY1,float bbY2,float area,float rx,float ry,unsigned int frame) const {
-	VisionObjectEvent * vo=new VisionObjectEvent(mySourceID,etid,bbX1,bbX2,bbY1,bbY2,area,rx,ry,frame);
-	vo->setName(getName());
+	VisionObjectEvent vo(mySourceID,etid,bbX1,bbX2,bbY1,bbY2,area,rx,ry,frame);
+	vo.setName(getName());
 	erouter->postEvent(vo);
 }
 
@@ -324,8 +325,8 @@ BallDetectionGenerator::calcEdgeMask(int x1,int x2,int y1,int y2, int width, int
  * reviewed the code, so I guess it's all ours...
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.18 $
  * $State: Exp $
- * $Date: 2005/07/06 22:49:22 $
+ * $Date: 2006/09/11 23:05:18 $
  */
