@@ -3,6 +3,7 @@
 #define INCLUDED_BallDetectionGenerator_h_
 
 #include "Events/EventGeneratorBase.h"
+#include <math.h>
 
 class FilterBankEvent;
 class RegionGenerator;
@@ -91,10 +92,10 @@ private:
  * reviewed the code, so I guess it's all ours...
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2005/06/23 18:46:15 $
+ * $Date: 2005/11/04 23:28:21 $
  * $ Modified: 2005/12/01 $
  * @ Functions to create VisionObjectEvents include now BB and area info. 
  */
