@@ -4,7 +4,7 @@
 #include "Events/SegmentedColorFilterBankEvent.h"
 #include "Wireless/Wireless.h"
 #include "Shared/Config.h"
-#include "Shared/WorldState.h"
+#include "Shared/Profiler.h"
 
 #include "Shared/ODataFormats.h"
 #include "OFbkImage.h"
@@ -81,7 +81,7 @@ CDTGenerator::processEvent(const EventBase& event) {
 		framesProcessed++;
 	}
 	// todo - i wish we had some color infomation to pass here so we could use the event for CMVision's RLE, etc.
-	erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),event.getTypeID(),NULL,0,NULL,NULL));
+	erouter->postEvent(SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),event.getTypeID(),NULL,0,NULL,NULL));
 }
 
 unsigned int
@@ -95,17 +95,17 @@ CDTGenerator::getBinSize() const {
 }
 
 unsigned int
-CDTGenerator::LoadBuffer(const char [] /*buf*/, unsigned int /*len*/) {
+CDTGenerator::loadBuffer(const char [] /*buf*/, unsigned int /*len*/) {
 	//all our memory is in system controlled buffers - we probably shouldn't overwrite it...
 	serr->printf("Can't load into CDTGenerator");
 	return 0;
 }
 
 unsigned int
-CDTGenerator::SaveBuffer(char buf[], unsigned int len) const {
+CDTGenerator::saveBuffer(char buf[], unsigned int len) const {
 	unsigned int origlen=len;
 	unsigned int used;
-	if(0==(used=FilterBankGenerator::SaveBuffer(buf,len))) return 0;
+	if(0==(used=FilterBankGenerator::saveBuffer(buf,len))) return 0;
 	len-=used; buf+=used;
 	// todo - once we have color information - we could make this interoperable with SegmentedColorGenerator
 	// by following the same serialization format
@@ -113,11 +113,11 @@ CDTGenerator::SaveBuffer(char buf[], unsigned int len) const {
 	len-=used; buf+=used;
 	
 	if(images[selectedSaveLayer][selectedSaveChannel]==NULL) {
-		serr->printf("CDTImage::SaveBuffer() failed because selected image is NULL -- call selectSaveImage first to make sure it's up to date\n");
+		serr->printf("CDTImage::saveBuffer() failed because selected image is NULL -- call selectSaveImage first to make sure it's up to date\n");
 		return 0;
 	}
 	if(!imageValids[selectedSaveLayer][selectedSaveChannel]) {
-		serr->printf("CDTImage::SaveBuffer() failed because selected image is invalid -- call selectSaveImage first to make sure it's up to date\n");
+		serr->printf("CDTImage::saveBuffer() failed because selected image is invalid -- call selectSaveImage first to make sure it's up to date\n");
 		return 0;
 	}
 	unsigned char* img=images[selectedSaveLayer][selectedSaveChannel];
@@ -198,7 +198,7 @@ CDTGenerator::createImageCache(unsigned int /*layer*/, unsigned int /*chan*/) co
 
 void
 CDTGenerator::calcImage(unsigned int layer, unsigned int chan) {
-	PROFSECTION("CDTGenerator::calcImage(...)",state->mainProfile);
+	PROFSECTION("CDTGenerator::calcImage(...)",*mainProfiler);
 	unsigned int numNotRealLayers=numLayers-numRealLayers;
 	if(layer>=numNotRealLayers) {
 		unsigned int fbkdatChan=ofbkimageBAND_CDT;
@@ -262,9 +262,9 @@ CDTGenerator::destruct() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2005/06/03 22:56:30 $
+ * $Date: 2006/09/11 23:05:19 $
  */
 
