@@ -25,8 +25,8 @@
  *  First, be sure to get a good overview of the LoadSave style.  Most
  *  serialization is handled using this interface.
  *
- *  When, for instance, RawCameraGenerator::SaveBuffer() is called, it
- *  first calls it's super class, FilterBankGenerator::SaveBuffer(),
+ *  When, for instance, RawCameraGenerator::saveBuffer() is called, it
+ *  first calls it's super class, FilterBankGenerator::saveBuffer(),
  *  which will write out the general image information, common to all
  *  subclasses of FilterBankGenerator. (i'll cover the specifics in a
  *  second) Once that's done, the RawCameraGenerator adds it's own bit
@@ -45,7 +45,7 @@
  *  it's a binary stream).  Each field is of the form '<@c type:name>
  *  <i>(notes)</i>'
  *  
- *  FilterBankGenerator Header: (from FilterBankGenerator::SaveBuffer())
+ *  FilterBankGenerator Header: (from FilterBankGenerator::saveBuffer())
  *  - <@c string: "FbkImage">  <i>(remember a 'string' is len+str+0; so this is the literal "\010\0\0\0FbkImage\0"; also remember "\010" is octal for 8)</i>
  *  - <@c unsigned @c int: width> 
  *  - <@c unsigned @c int: height> 
@@ -54,13 +54,13 @@
  * 
  *  Generator Specific Header (selected examples follow, or similarly, any of the other generators)
  *  
- *  - RawCameraGenerator: (from RawCameraGenerator::SaveBuffer())
+ *  - RawCameraGenerator: (from RawCameraGenerator::saveBuffer())
  *    - <@c string: "RawImage">
  *    - <<tt>char[</tt>width<tt>*</tt>height<tt>]</tt>: image data> <i>(note, just once channel being stored)</i>
- *  - InterleavedYUVGenerator: (from InterleavedYUVGenerator::SaveBuffer())
+ *  - InterleavedYUVGenerator: (from InterleavedYUVGenerator::saveBuffer())
  *    - <@c string: "InterleavedYUVImage">
  *    - <<tt>char[</tt>width<tt>*</tt>height<tt>*3]</tt>: image data> <i>(in YVU order, technically YCbCr)</i>
- *  - SegmentedColorGenerator: (from SegmentedColorGenerator::SaveBuffer())
+ *  - SegmentedColorGenerator: (from SegmentedColorGenerator::saveBuffer())
  *    - <@c string: "SegColorImage">
  *    - <<tt>char[</tt>width<tt>*</tt>height<tt>]</tt>: image data> <i>(one byte per sample)</i>
  *    - <@c unsigned @c int: num_cols> <i>(number of different colors available)</i>
@@ -68,7 +68,7 @@
  *      - <@c char: red> <i>red color to use for display of this index</i>
  *      - <@c char: green> <i>green color to use for display of this index</i>
  *      - <@c char: blue> <i>blue color to use for display of this index</i>
- *  - RLEGenerator: (from RLEGenerator::SaveBuffer())
+ *  - RLEGenerator: (from RLEGenerator::saveBuffer())
  *    - <@c string: "RLEImage">  <i>(remember a 'string' is len+str+0; so this is the literal "\010\0\0\0RLEImage\0"; also remember "\010" is octal for 8)</i>
  *    - <@c unsigned @c int: num_runs> <i>(how many runs will follow)</i>
  *    - for each of num_runs:
@@ -143,6 +143,11 @@ public:
 	/*! this will cause the data to be calculated and cached if it's not already available */
 	virtual unsigned char * getImage(unsigned int layer, unsigned int channel);
 
+	//! returns whether or not an image has already been calculated for the current frame
+	/*! If you call this immediately after getImage() and this still returns false, 
+	 *  then an error must have occurred during processing */
+	virtual bool getImageCached(unsigned int layer, unsigned int channel) const { return imageValids[layer][channel]; }
+
 	//! returns width (in samples) of the image in a given layer
 	unsigned int getWidth(unsigned int layer) const { return widths[layer]; }
 
@@ -241,13 +246,13 @@ public:
 
 	virtual unsigned int getBinSize() const;
 
-	virtual unsigned int LoadBuffer(const char buf[], unsigned int len);
+	virtual unsigned int loadBuffer(const char buf[], unsigned int len);
 
-	virtual unsigned int SaveBuffer(char buf[], unsigned int len) const;
+	virtual unsigned int saveBuffer(char buf[], unsigned int len) const;
 
 	//! Not actually part of the LoadSave interface, but allows you to select which image of the bank will be saved
 	/*! Calling this will also cause the image data for that image to be calculated,
-	 *  otherwise SaveBuffer won't have up-to-date data to save.
+	 *  otherwise saveBuffer won't have up-to-date data to save.
 	 *  
 	 *  When loading, the saved image's layer and channel will reset this */
 	virtual void selectSaveImage(unsigned int layer, unsigned int channel) { selectedSaveLayer=layer; selectedSaveChannel=channel; getImage(layer,channel);}
@@ -386,10 +391,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.18 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.20 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:04 $
+ * $Date: 2006/09/09 04:33:04 $
  */
 
 #endif
