@@ -9,7 +9,7 @@ using namespace std;
 // ! check memory boundaries of image, first that we are after the start of the image, second that we are before the end of the image, and third that we are within a valid row (in case of interleaved rows), fourth that we are within a valid column (interleaved pixels)
 #define CHKBOUNDS(p,ERR_F) { \
 	unsigned int rowoffset=(p-img)-(p-img)/yInc*yInc; \
-	if(p<img || p>=img+w*xInc+h*yInc || rowoffset>=w*xInc || rowoffset/xInc*xInc!=rowoffset) { \
+	if(p<img || p>=img+h*yInc || rowoffset>=w*xInc || rowoffset/xInc*xInc!=rowoffset) { \
 		cout << "Graphics Bad draw! line:" << __LINE__ << " frame=" << (gen!=NULL?gen->getFrameNumber():0) << ' '  /*<< (void*)p << '-' << (void*)img << '='*/ << (int)(p-img) << " w=" << w << " xInc=" << xInc << " h=" << h << " yInc=" << yInc << endl; \
 		ERR_F; \
 	} \
@@ -53,8 +53,8 @@ void Graphics::drawRect(int x, int y, int width, int height) {
 		return;
 	unsigned int left=x>0?x:0;
 	unsigned int top=y>0?y:0;
-	unsigned int right=x+width>=(int)w?w:x+width; //not inclusive
-	unsigned int bot=y+height>=(int)h?h:y+height; //not inclusive
+	unsigned int right=( (x+width>=(int)w) ? w : x+width); //not inclusive
+	unsigned int bot=( (y+height>=(int)h) ? h : y+height); //not inclusive
 	//left vertical
 	if(x>=0) {
 		unsigned char * p=img+top*yInc+left*xInc;
@@ -96,7 +96,7 @@ void Graphics::drawRect(int x, int y, int width, int height) {
 		}
 	}
 	//bottom right corner
-	if((unsigned int)right<w && (unsigned int)bot<h) {
+	if(right<w && bot<h) {
 		unsigned char * p=img+bot*yInc+right*xInc;
 		CHKBOUNDS(p,return);
 		*p=c;
@@ -240,8 +240,8 @@ void Graphics::getRealCoordinates(float& x, float& y, unsigned int px, unsigned
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2005/07/10 20:02:39 $
+ * $Date: 2006/07/03 01:54:58 $
  */
