@@ -2,7 +2,7 @@
 #include "Events/EventRouter.h"
 #include "Events/FilterBankEvent.h"
 #include "Wireless/Wireless.h"
-#include "Shared/WorldState.h"
+#include "Shared/Profiler.h"
 
 #include "Shared/debuget.h"
 
@@ -30,9 +30,12 @@ void
 InterleavedYUVGenerator::processEvent(const EventBase& event) {
 	FilterBankGenerator::processEvent(event);
 	if(event.getGeneratorID()==getListenGeneratorID() && event.getSourceID()==getListenSourceID()) {
-		erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID(),EventBase::activateETID));
-		erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID(),EventBase::statusETID));
-		erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID(),EventBase::deactivateETID));
+		FilterBankEvent fbkev(this,getGeneratorID(),getSourceID(),EventBase::activateETID);
+		erouter->postEvent(fbkev);
+		fbkev.setTypeID(EventBase::statusETID);
+		erouter->postEvent(fbkev);
+		fbkev.setTypeID(EventBase::deactivateETID);
+		erouter->postEvent(fbkev);
 	}
 }
 
@@ -45,19 +48,16 @@ InterleavedYUVGenerator::getBinSize() const {
 }
 
 unsigned int
-InterleavedYUVGenerator::LoadBuffer(const char buf[], unsigned int len) {
+InterleavedYUVGenerator::loadBuffer(const char buf[], unsigned int len) {
 	unsigned int origlen=len;
-	unsigned int used;
+	if(!checkInc(FilterBankGenerator::loadBuffer(buf,len),buf,len)) return 0;
 	std::string tmp;
-	if(0==(used=FilterBankGenerator::LoadBuffer(buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=decode(tmp,buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!decodeInc(tmp,buf,len)) return 0;
 	if(tmp!="InterleavedYUVImage") {
 		serr->printf("Unhandled image type for InterleavedYUVGenerator: %s",tmp.c_str());
 		return 0;
 	} else {
-		used=widths[selectedSaveLayer]*heights[selectedSaveLayer]*3;
+		unsigned int used=widths[selectedSaveLayer]*heights[selectedSaveLayer]*3;
 		if(used>len)
 			return 0;
 		if(images[selectedSaveLayer][selectedSaveChannel]==NULL)
@@ -73,23 +73,20 @@ InterleavedYUVGenerator::LoadBuffer(const char buf[], unsigned int len) {
 }
 
 unsigned int
-InterleavedYUVGenerator::SaveBuffer(char buf[], unsigned int len) const {
+InterleavedYUVGenerator::saveBuffer(char buf[], unsigned int len) const {
 	unsigned int origlen=len;
-	unsigned int used;
-	if(0==(used=FilterBankGenerator::SaveBuffer(buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode("InterleavedYUVImage",buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!checkInc(FilterBankGenerator::saveBuffer(buf,len),buf,len)) return 0;
+	if(!encodeInc("InterleavedYUVImage",buf,len)) return 0;
 	
-	used=widths[selectedSaveLayer]*heights[selectedSaveLayer]*3;
+	unsigned int used=widths[selectedSaveLayer]*heights[selectedSaveLayer]*3;
 	if(used>len)
 		return 0;
 	if(images[selectedSaveLayer][selectedSaveChannel]==NULL) {
-		serr->printf("InterleavedYUVGenerator::SaveBuffer() failed because selected image is NULL -- call selectSaveImage first to make sure it's up to date\n");
+		serr->printf("InterleavedYUVGenerator::saveBuffer() failed because selected image is NULL -- call selectSaveImage first to make sure it's up to date\n");
 		return 0;
 	}
 	if(!imageValids[selectedSaveLayer][selectedSaveChannel]) {
-		serr->printf("InterleavedYUVGenerator::SaveBuffer() failed because selected image is invalid -- call selectSaveImage first to make sure it's up to date\n");
+		serr->printf("InterleavedYUVGenerator::saveBuffer() failed because selected image is invalid -- call selectSaveImage first to make sure it's up to date\n");
 		return 0;
 	}
 	unsigned char* img=images[selectedSaveLayer][selectedSaveChannel];
@@ -163,7 +160,7 @@ InterleavedYUVGenerator::createImageCache(unsigned int layer, unsigned int chan)
 
 void
 InterleavedYUVGenerator::calcImage(unsigned int layer, unsigned int chan) {
-	PROFSECTION("InterleavedYUVGenerator::calcImage(...)",state->mainProfile);
+	PROFSECTION("InterleavedYUVGenerator::calcImage(...)",*mainProfiler);
 	if(imageValids[layer][chan]) //check if createCache set valid flag
 		return; //indicates pass through from previous stage
 	
@@ -177,15 +174,15 @@ InterleavedYUVGenerator::calcImage(unsigned int layer, unsigned int chan) {
 	for(unsigned int y=0; y<getHeight(layer); y++) {
 		for(unsigned int x=0; x<getWidth(layer); x++) {
 			*dimg++=*syimg;
-			*dimg++=*svimg;
 			*dimg++=*suimg;
+			*dimg++=*svimg;
 			syimg+=inc;
-			svimg+=inc;
 			suimg+=inc;
+			svimg+=inc;
 		}
 		syimg+=skip;
-		svimg+=skip;
 		suimg+=skip;
+		svimg+=skip;
 	}
 	imageValids[layer][chan]=true;
 }
@@ -195,9 +192,9 @@ InterleavedYUVGenerator::calcImage(unsigned int layer, unsigned int chan) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.19 $
  * $State: Exp $
- * $Date: 2005/08/15 22:57:16 $
+ * $Date: 2006/09/11 23:05:20 $
  */
 
