@@ -29,16 +29,22 @@ extern "C" {
  *  and others might find the interleaved format handy for passing to
  *  other libraries which expect that format, such as what happened
  *  with libjpeg.
+ *  
+ *  This class shares a lot of non-JPEG specific code with PNGGenerator,
+ *  so you may want to replicate any changes made in that class as well.
  *
  *  @todo possible speedup by using jpeg_write_raw_data
+ *  @todo create a common super class with PNGGenerator to hold common setup code
  */
 class JPEGGenerator : public FilterBankGenerator {
 public:
 	static const unsigned int JPEG_HEADER_PAD=500; //!< add a bit to the expected size in getBinSize just to leave a little extra room for small images
+	
+	//! defines how to interpret the source images (see #srcMode and #curMode)
 	enum src_mode_t {
 		SRC_AUTO,       //!< if src is not a InterleavedYUVGenerator, SRC_GREYSCALE, otherwise SRC_COLOR
-		SRC_GRAYSCALE,
-		SRC_COLOR
+		SRC_GRAYSCALE,  //!< indicates each channel of source should be compressed individually as grayscale images
+		SRC_COLOR       //!< indicates first channel should be in an interleaved layout which can be compressed into a "color" image
 	};
 
 	//! constructor
@@ -56,17 +62,18 @@ public:
 	//! returns #curMode
 	virtual src_mode_t getCurrentSourceFormat() const { return curMode; }
 
-	static std::string getClassDescription() { return "Converts a compresses its source FilterBankGenerator's data into JPEG format"; }
+	static std::string getClassDescription() { return "Compresses its source FilterBankGenerator's data into JPEG format"; }
 
 	//! should receive FilterBankEvents from a RawCameraGenerator (or a subclass thereof)
 	virtual void processEvent(const EventBase& event);
 	
 	//! if we don't already know bytesUsed, let's assume the size will be smaller than the original uncompressed. If we fail this assumption, probably better to fail anyway.
 	virtual unsigned int getBinSize() const;
-
-	virtual unsigned int LoadBuffer(const char buf[], unsigned int len);
-
-	virtual unsigned int SaveBuffer(char buf[], unsigned int len) const;
+	
+	virtual unsigned int loadBuffer(const char buf[], unsigned int len);
+	
+	//! you probably don't want to be calling this to access the JPEG -- use getImage() instead (saveBuffer will prepend some header information before the actual image data)
+	virtual unsigned int saveBuffer(char buf[], unsigned int len) const;
 
 	//! returns #quality
 	virtual unsigned int getQuality() const { return quality; }
@@ -107,10 +114,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:04 $
+ * $Date: 2006/09/16 17:32:40 $
  */
 
 #endif
