@@ -2,7 +2,7 @@
 #include "Events/EventRouter.h"
 #include "Events/SegmentedColorFilterBankEvent.h"
 #include "Wireless/Wireless.h"
-#include "Shared/WorldState.h"
+#include "Shared/Profiler.h"
 
 #include "Shared/debuget.h"
 
@@ -24,21 +24,29 @@ RLEGenerator::processEvent(const EventBase& event) {
 		//Technically, we should do things this way:
 		/*
 		if(const SegmentedColorFilterBankEvent * segsrc=dynamic_cast<const SegmentedColorFilterBankEvent *>(&event)) {
-			erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),EventBase::activateETID,*segsrc));
-			erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),EventBase::statusETID,*segsrc));
-			erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),EventBase::deactivateETID,*segsrc));
+			SegmentedColorFilterBankEvent segev(this,getGeneratorID(),getSourceID(),EventBase::activateETID,*segsrc);
+			erouter->postEvent(fbkev);
+			segev.setTypeID(EventBase::statusETID);
+			erouter->postEvent(fbkev);
+			segev.setTypeID(EventBase::deactivateETID);
+			erouter->postEvent(fbkev);
 		} else {
-			erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID(),EventBase::activateETID));
-			erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID(),EventBase::statusETID));
-			erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID(),EventBase::deactivateETID));
+			FilterBankEvent fbkev(this,getGeneratorID(),getSourceID(),EventBase::activateETID);
+			erouter->postEvent(fbkev);
+			fbkev.setTypeID(EventBase::statusETID);
+			erouter->postEvent(fbkev);
+			fbkev.setTypeID(EventBase::deactivateETID);
+			erouter->postEvent(fbkev);
 		}
 		*/
 		//But until RLEGraphics is in place, we'll do it this way so recompression can be triggered
 		//after drawing into segmented image
 		if(const SegmentedColorFilterBankEvent * segsrc=dynamic_cast<const SegmentedColorFilterBankEvent *>(&event)) {
-			erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),event.getTypeID(),*segsrc));
+			SegmentedColorFilterBankEvent segev(this,getGeneratorID(),getSourceID(),event.getTypeID(),*segsrc);
+			erouter->postEvent(segev);
 		} else {
-			erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID(),event.getTypeID()));
+			FilterBankEvent fbkev(this,getGeneratorID(),getSourceID(),event.getTypeID());
+			erouter->postEvent(fbkev);
 		}
 	}
 }
@@ -57,20 +65,16 @@ RLEGenerator::getBinSize() const {
 
 /*! this isn't really tested, don't rely on it working without a little debugging... specifically, doesn't set parent or next fields*/
 unsigned int
-RLEGenerator::LoadBuffer(const char buf[], unsigned int len) {
+RLEGenerator::loadBuffer(const char buf[], unsigned int len) {
 	unsigned int origlen=len;
-	unsigned int used;
 	std::string tmp;
-	if(0==(used=FilterBankGenerator::LoadBuffer(buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=decode(tmp,buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!checkInc(FilterBankGenerator::loadBuffer(buf,len),buf,len)) return 0;
+	if(!decodeInc(tmp,buf,len)) return 0;
 	if(tmp!="RLEImage") {
 		serr->printf("Unhandled image type for RLEGenerator: %s",tmp.c_str());
 		return 0;
 	} else {
-		if(0==(used=decode(numRuns[selectedSaveLayer][selectedSaveChannel],buf,len))) return 0;
-		len-=used; buf+=used;
+		if(!decodeInc(numRuns[selectedSaveLayer][selectedSaveChannel],buf,len)) return 0;
 		if(maxRuns[selectedSaveLayer]<numRuns[selectedSaveLayer][selectedSaveChannel])
 			return 0;
 		if(images[selectedSaveLayer][selectedSaveChannel]==NULL)
@@ -80,12 +84,9 @@ RLEGenerator::LoadBuffer(const char buf[], unsigned int len) {
 			return 0;
 		unsigned int y=0;
 		for(unsigned int i=0; i<numRuns[selectedSaveLayer][selectedSaveChannel]; i++) {
-			if(0==(used=decode(runs[i].color,buf,len))) return 0;
-			len-=used; buf+=used;
-			if(0==(used=decode(runs[i].x,buf,len))) return 0;
-			len-=used; buf+=used;
-			if(0==(used=decode(runs[i].width,buf,len))) return 0;
-			len-=used; buf+=used;
+			if(!decodeInc(runs[i].color,buf,len)) return 0;
+			if(!decodeInc(runs[i].x,buf,len)) return 0;
+			if(!decodeInc(runs[i].width,buf,len)) return 0;
 			if((unsigned int)(runs[i].x+runs[i].width)>=getWidth(selectedSaveLayer))
 				y++;
 			runs[i].y=y;
@@ -96,35 +97,28 @@ RLEGenerator::LoadBuffer(const char buf[], unsigned int len) {
 }
 
 unsigned int
-RLEGenerator::SaveBuffer(char buf[], unsigned int len) const {
+RLEGenerator::saveBuffer(char buf[], unsigned int len) const {
 	unsigned int origlen=len;
-	unsigned int used;
-	if(0==(used=FilterBankGenerator::SaveBuffer(buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode("RLEImage",buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!checkInc(FilterBankGenerator::saveBuffer(buf,len),buf,len)) return 0;
+	if(!encodeInc("RLEImage",buf,len)) return 0;
 	
 	if(images[selectedSaveLayer][selectedSaveChannel]==NULL) {
-		serr->printf("RLEGenerator::SaveBuffer() failed because selected image is NULL -- call selectSaveImage first to make sure it's up to date\n");
+		serr->printf("RLEGenerator::saveBuffer() failed because selected image is NULL -- call selectSaveImage first to make sure it's up to date\n");
 		return 0;
 	}
 	if(!imageValids[selectedSaveLayer][selectedSaveChannel]) {
-		serr->printf("RLEGenerator::SaveBuffer() failed because selected image is invalid -- call selectSaveImage first to make sure it's up to date\n");
+		serr->printf("RLEGenerator::saveBuffer() failed because selected image is invalid -- call selectSaveImage first to make sure it's up to date\n");
 		return 0;
 	}
 	unsigned char* img=images[selectedSaveLayer][selectedSaveChannel];
 	run * runs=reinterpret_cast<run*>(img);
 	if(runs==NULL)
 		return 0;
-	if(0==(used=encode(numRuns[selectedSaveLayer][selectedSaveChannel],buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!encodeInc(numRuns[selectedSaveLayer][selectedSaveChannel],buf,len)) return 0;
 	for(unsigned int i=0; i<numRuns[selectedSaveLayer][selectedSaveChannel]; i++) {
-		if(0==(used=encode(runs[i].color,buf,len))) return 0;
-		len-=used; buf+=used;
-		if(0==(used=encode(runs[i].x,buf,len))) return 0;
-		len-=used; buf+=used;
-		if(0==(used=encode(runs[i].width,buf,len))) return 0;
-		len-=used; buf+=used;
+		if(!encodeInc(runs[i].color,buf,len)) return 0;
+		if(!encodeInc(runs[i].x,buf,len)) return 0;
+		if(!encodeInc(runs[i].width,buf,len)) return 0;
 	}
 	return origlen-len;
 }
@@ -158,7 +152,7 @@ RLEGenerator::createImageCache(unsigned int layer, unsigned int /*chan*/) const
 //! a single call to the CMVision library to do the work, and we're done.
 void
 RLEGenerator::calcImage(unsigned int layer, unsigned int chan) {
-	PROFSECTION("RLEGenerator::calcImage(...)",state->mainProfile);
+	PROFSECTION("RLEGenerator::calcImage(...)",*mainProfiler);
   numRuns[layer][chan] = CMVision::EncodeRuns(reinterpret_cast<run*>(images[layer][chan]),src->getImage(layer,chan),getWidth(layer),getHeight(layer),maxRuns[layer]);
 	imageValids[layer][chan]=true; // <--- don't forget to do this, otherwise you'll recompute on every access, even if the cache is still valid
 }
@@ -180,9 +174,9 @@ RLEGenerator::destruct() {
  * @author ejt (reorganized)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2005/06/13 21:24:11 $
+ * $Date: 2006/09/11 23:05:21 $
  */
 
