@@ -4,7 +4,7 @@
 #include "Events/FilterBankEvent.h"
 #include "Wireless/Wireless.h"
 #include "Shared/Config.h"
-#include "Shared/WorldState.h"
+#include "Shared/Profiler.h"
 
 #include "Shared/ODataFormats.h"
 #include "OFbkImage.h"
@@ -94,7 +94,7 @@ RawCameraGenerator::processEvent(const EventBase& event) {
 		invalidateCaches();	
 		framesProcessed++;
 	}
-	erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID(),event.getTypeID()));
+	erouter->postEvent(FilterBankEvent(this,getGeneratorID(),getSourceID(),event.getTypeID()));
 }
 
 unsigned int
@@ -106,14 +106,11 @@ RawCameraGenerator::getBinSize() const {
 }
 
 unsigned int
-RawCameraGenerator::LoadBuffer(const char buf[], unsigned int len) {
+RawCameraGenerator::loadBuffer(const char buf[], unsigned int len) {
 	unsigned int origlen=len;
-	unsigned int used;
 	std::string tmp;
-	if(0==(used=FilterBankGenerator::LoadBuffer(buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=decode(tmp,buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!checkInc(FilterBankGenerator::loadBuffer(buf,len),buf,len)) return 0;
+	if(!decodeInc(tmp,buf,len)) return 0;
 	if(tmp!="RawImage") {
 		serr->printf("Unhandled image type for RawCameraGenerator: %s",tmp.c_str());
 		return 0;
@@ -124,7 +121,7 @@ RawCameraGenerator::LoadBuffer(const char buf[], unsigned int len) {
 		if(images[selectedSaveLayer][selectedSaveChannel]==NULL)
 			images[selectedSaveLayer][selectedSaveChannel]=createImageCache(selectedSaveLayer,selectedSaveChannel);
 		unsigned char* img=images[selectedSaveLayer][selectedSaveChannel];
-		used=widths[selectedSaveLayer]*heights[selectedSaveLayer];
+		unsigned int used=widths[selectedSaveLayer]*heights[selectedSaveLayer];
 		ASSERTRETVAL(used<=len,"buffer too small",0);
 		memcpy(img,buf,used);
 		len-=used; buf+=used;
@@ -134,24 +131,21 @@ RawCameraGenerator::LoadBuffer(const char buf[], unsigned int len) {
 }
 
 unsigned int
-RawCameraGenerator::SaveBuffer(char buf[], unsigned int len) const {
+RawCameraGenerator::saveBuffer(char buf[], unsigned int len) const {
 	unsigned int origlen=len;
-	unsigned int used;
-	if(0==(used=FilterBankGenerator::SaveBuffer(buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode("RawImage",buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!checkInc(FilterBankGenerator::saveBuffer(buf,len),buf,len)) return 0;
+	if(!encodeInc("RawImage",buf,len)) return 0;
 	
 	if(images[selectedSaveLayer][selectedSaveChannel]==NULL) {
-		serr->printf("RawCameraGenerator::SaveBuffer() failed because selected image is NULL -- call selectSaveImage first to make sure it's up to date\n");
+		serr->printf("RawCameraGenerator::saveBuffer() failed because selected image is NULL -- call selectSaveImage first to make sure it's up to date\n");
 		return 0;
 	}
 	if(!imageValids[selectedSaveLayer][selectedSaveChannel]) {
-		serr->printf("RawCameraGenerator::SaveBuffer() failed because selected image is invalid -- call selectSaveImage first to make sure it's up to date\n");
+		serr->printf("RawCameraGenerator::saveBuffer() failed because selected image is invalid -- call selectSaveImage first to make sure it's up to date\n");
 		return 0;
 	}
 	unsigned char* img=images[selectedSaveLayer][selectedSaveChannel];
-	used=widths[selectedSaveLayer]*heights[selectedSaveLayer];
+	unsigned int used=widths[selectedSaveLayer]*heights[selectedSaveLayer];
 	ASSERTRETVAL(used<=len,"buffer too small",0);
 	unsigned int inc=getIncrement(selectedSaveLayer);
 	if(inc==1) {
@@ -178,20 +172,20 @@ RawCameraGenerator::SaveBuffer(char buf[], unsigned int len) const {
 }
 
 unsigned int
-RawCameraGenerator::SaveFileStream(FILE * f) const {
+RawCameraGenerator::saveFileStream(FILE * f) const {
 	unsigned int totalused=0;
 	unsigned int used;
-	{ //sigh, inheritance has failed me (I wouldn't want FilterBankGenerator::SaveFileStream() to call the virtuals...)
+	{ //sigh, inheritance has failed me (I wouldn't want FilterBankGenerator::saveFileStream() to call the virtuals...)
 		unsigned int sz=FilterBankGenerator::getBinSize();
 		char * buf = new char[sz];
 		memset(buf,0xF0,sz);
 		if(buf==NULL) {
-			std::cout << "*** WARNING could not allocate " << sz << " bytes for LoadFile";
+			std::cout << "*** WARNING could not allocate " << sz << " bytes for loadFile";
 			return 0;
 		}
-		unsigned int resp=FilterBankGenerator::SaveBuffer(buf,sz);
+		unsigned int resp=FilterBankGenerator::saveBuffer(buf,sz);
 		if(resp==0) {
-			std::cout << "*** WARNING SaveBuffer didn't write any data (possibly due to overflow or other error)" << std::endl;
+			std::cout << "*** WARNING saveBuffer didn't write any data (possibly due to overflow or other error)" << std::endl;
 			fwrite(buf,1,sz,f);
 		}	else {
 			unsigned int wrote=fwrite(buf,1,resp,f);
@@ -207,11 +201,11 @@ RawCameraGenerator::SaveFileStream(FILE * f) const {
 	totalused+=used;
 	
 	if(images[selectedSaveLayer][selectedSaveChannel]==NULL) {
-		serr->printf("RawCameraGenerator::SaveBuffer() failed because selected image is NULL -- call selectSaveImage first to make sure it's up to date\n");
+		serr->printf("RawCameraGenerator::saveBuffer() failed because selected image is NULL -- call selectSaveImage first to make sure it's up to date\n");
 		return 0;
 	}
 	if(!imageValids[selectedSaveLayer][selectedSaveChannel]) {
-		serr->printf("RawCameraGenerator::SaveBuffer() failed because selected image is invalid -- call selectSaveImage first to make sure it's up to date\n");
+		serr->printf("RawCameraGenerator::saveBuffer() failed because selected image is invalid -- call selectSaveImage first to make sure it's up to date\n");
 		return 0;
 	}
 	unsigned char* img=images[selectedSaveLayer][selectedSaveChannel];
@@ -298,7 +292,7 @@ RawCameraGenerator::createImageCache(unsigned int layer, unsigned int chan) cons
 
 void
 RawCameraGenerator::calcImage(unsigned int layer, unsigned int chan) {
-	PROFSECTION("RawCameraGenerator::calcImage(...)",state->mainProfile);
+	PROFSECTION("RawCameraGenerator::calcImage(...)",*mainProfiler);
 	unsigned int numNotRealLayers=numLayers-1-numRealLayers;
 	if(layer==numLayers-1) {
 		//This is the only layer for which we calculate and store any data of our own...
@@ -367,9 +361,9 @@ RawCameraGenerator::mapChannelID(channel_id_t chan) {
 	case CHAN_Y:
 		return ofbkimageBAND_Y;
 	case CHAN_U:
-		return ofbkimageBAND_Cr;
-	case CHAN_V:
 		return ofbkimageBAND_Cb;
+	case CHAN_V:
+		return ofbkimageBAND_Cr;
 	case CHAN_Y_DY:
 		return ofbkimageBAND_Y_LH;
 	case CHAN_Y_DX:
@@ -475,9 +469,9 @@ RawCameraGenerator::reconstructImage() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.21 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.25 $
  * $State: Exp $
- * $Date: 2005/06/06 19:33:31 $
+ * $Date: 2006/09/11 23:05:22 $
  */
 
