@@ -1,19 +1,25 @@
 #include "RegionGenerator.h"
 #include "Events/EventRouter.h"
 #include "Wireless/Wireless.h"
-#include "Shared/WorldState.h"
+#include "Shared/Profiler.h"
+#include "SegmentedColorGenerator.h"
 
 #include "Vision/RLEGenerator.h"
 
 #include "Shared/debuget.h"
 
 RegionGenerator::RegionGenerator(unsigned int mysid, RLEGenerator* rleg, EventBase::EventTypeID_t tid)
-	: FilterBankGenerator("RegionGenerator","RegionGenerator",EventBase::visRegionEGID,mysid,rleg,tid), srcNumColors(0), srcColors(0), regions(NULL)
+	: FilterBankGenerator("RegionGenerator","RegionGenerator",EventBase::visRegionEGID,mysid,rleg,tid), srcNumColors(0), srcColors(NULL), regions(NULL)
 {
-	//this part is only necessary if you override setNumImages yourself
 	if(rleg!=NULL) {
 		numLayers=numChannels=0; //this is to force setNumImages to override settings provided by FilterBankGenerator
 		setNumImages(rleg->getNumLayers(),rleg->getNumChannels());
+		if(const SegmentedColorGenerator* seg=dynamic_cast<const SegmentedColorGenerator*>(rleg->getSourceGenerator())) {
+			srcNumColors=seg->getNumColors();
+			srcColors=seg->getColors();
+		} else {
+			serr->printf("WARNING: Region generator expects it's source's source to be a SegmentedColorGenerator so that it can access color table information.\n");
+		}
 	}
 }
 
@@ -45,9 +51,12 @@ RegionGenerator::processEvent(const EventBase& event) {
 			freeCaches();
 		srcNumColors=segev->getNumColors();
 		srcColors=segev->getColors();
-		erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),EventBase::activateETID,*segev));
-		erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),EventBase::statusETID,*segev));
-		erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),EventBase::deactivateETID,*segev));
+		SegmentedColorFilterBankEvent fbkev(this,getGeneratorID(),getSourceID(),EventBase::activateETID,*segev);
+		erouter->postEvent(fbkev);
+		fbkev.setTypeID(EventBase::statusETID);
+		erouter->postEvent(fbkev);
+		fbkev.setTypeID(EventBase::deactivateETID);
+		erouter->postEvent(fbkev);
 	}
 }
 
@@ -75,21 +84,17 @@ RegionGenerator::getBinSize() const {
 }
 
 unsigned int
-RegionGenerator::LoadBuffer(const char buf[], unsigned int len) {
+RegionGenerator::loadBuffer(const char buf[], unsigned int len) {
 	unsigned int origlen=len;
-	unsigned int used;
+	if(!checkInc(FilterBankGenerator::loadBuffer(buf,len),buf,len)) return 0;
 	std::string tmp;
-	if(0==(used=FilterBankGenerator::LoadBuffer(buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=decode(tmp,buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!decodeInc(tmp,buf,len)) return 0;
 	if(tmp!="RegionImage") {
 		serr->printf("Unhandled image type for RegionGenerator: %s",tmp.c_str());
 		return 0;
 	} else {
 		unsigned int tmpNumClr=0;
-		if(0==(used=decode(tmpNumClr,buf,len))) return 0;
-		len-=used; buf+=used;
+		if(!decodeInc(tmpNumClr,buf,len)) return 0;
 		if(tmpNumClr!=srcNumColors)
 			freeCaches();
 		srcNumColors=tmpNumClr;
@@ -100,42 +105,29 @@ RegionGenerator::LoadBuffer(const char buf[], unsigned int len) {
 			return 0;
 		for(unsigned int i=0; i<srcNumColors; i++) {
 			unsigned int tmpNumReg=0;
-			if(0==(used=decode(tmpNumReg,buf,len))) return 0;
-			len-=used; buf+=used;
+			if(!decodeInc(tmpNumReg,buf,len)) return 0;
 			if(MAX_REGIONS<=tmpNumReg)
 				return 0;
 			for(unsigned int j=0; j<tmpNumReg; j++) {
 				region * curreg=&regions[selectedSaveLayer][selectedSaveChannel][j];
-				if(0==(used=decode(curreg->color,buf,len))) return 0;
-				len-=used; buf+=used;
-				if(0==(used=decode(curreg->x1,buf,len))) return 0;
-				len-=used; buf+=used;
-				if(0==(used=decode(curreg->y1,buf,len))) return 0;
-				len-=used; buf+=used;
-				if(0==(used=decode(curreg->x2,buf,len))) return 0;
-				len-=used; buf+=used;
-				if(0==(used=decode(curreg->y2,buf,len))) return 0;
-				len-=used; buf+=used;
-				if(0==(used=decode(curreg->cen_x,buf,len))) return 0;
-				len-=used; buf+=used;
-				if(0==(used=decode(curreg->cen_y,buf,len))) return 0;
-				len-=used; buf+=used;
-				if(0==(used=decode(curreg->area,buf,len))) return 0;
-				len-=used; buf+=used;
-				if(0==(used=decode(curreg->run_start,buf,len))) return 0;
-				len-=used; buf+=used;
+				if(!decodeInc(curreg->color,buf,len)) return 0;
+				if(!decodeInc(curreg->x1,buf,len)) return 0;
+				if(!decodeInc(curreg->y1,buf,len)) return 0;
+				if(!decodeInc(curreg->x2,buf,len)) return 0;
+				if(!decodeInc(curreg->y2,buf,len)) return 0;
+				if(!decodeInc(curreg->cen_x,buf,len)) return 0;
+				if(!decodeInc(curreg->cen_y,buf,len)) return 0;
+				if(!decodeInc(curreg->area,buf,len)) return 0;
+				if(!decodeInc(curreg->run_start,buf,len)) return 0;
 				if(j==tmpNumReg-1)
 					curreg->next=NULL;
 				else
 					curreg->next=&regions[selectedSaveLayer][selectedSaveChannel][j+1];
 			}
 			//we're only going to save the region part (not the color info)
-			if(0==(used=decode(stats[i].min_area,buf,len))) return 0;
-			len-=used; buf+=used;
-			if(0==(used=decode(stats[i].total_area,buf,len))) return 0;
-			len-=used; buf+=used;
-			if(0==(used=decode(stats[i].merge_threshold,buf,len))) return 0;
-			len-=used; buf+=used;
+			if(!decodeInc(stats[i].min_area,buf,len)) return 0;
+			if(!decodeInc(stats[i].total_area,buf,len)) return 0;
+			if(!decodeInc(stats[i].merge_threshold,buf,len)) return 0;
 			stats[i].list=regions[selectedSaveLayer][selectedSaveChannel];
 			stats[i].num=tmpNumReg;
 		}
@@ -145,60 +137,43 @@ RegionGenerator::LoadBuffer(const char buf[], unsigned int len) {
 }
 
 unsigned int
-RegionGenerator::SaveBuffer(char buf[], unsigned int len) const {
+RegionGenerator::saveBuffer(char buf[], unsigned int len) const {
 	unsigned int origlen=len;
-	unsigned int used;
-	if(0==(used=FilterBankGenerator::SaveBuffer(buf,len))) return 0;
-	len-=used; buf+=used;
-	if(0==(used=encode("RegionImage",buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!checkInc(FilterBankGenerator::saveBuffer(buf,len),buf,len)) return 0;
+	if(!encodeInc("RegionImage",buf,len)) return 0;
 	
 	if(images[selectedSaveLayer][selectedSaveChannel]==NULL) {
-		serr->printf("RegionGenerator::SaveBuffer() failed because selected image is NULL -- call selectSaveImage first to make sure it's up to date\n");
+		serr->printf("RegionGenerator::saveBuffer() failed because selected image is NULL -- call selectSaveImage first to make sure it's up to date\n");
 		return 0;
 	}
 	if(!imageValids[selectedSaveLayer][selectedSaveChannel]) {
-		serr->printf("RegionGenerator::SaveBuffer() failed because selected image is invalid -- call selectSaveImage first to make sure it's up to date\n");
+		serr->printf("RegionGenerator::saveBuffer() failed because selected image is invalid -- call selectSaveImage first to make sure it's up to date\n");
 		return 0;
 	}
 	unsigned char* img=images[selectedSaveLayer][selectedSaveChannel];
 	region_stats * stats=reinterpret_cast<region_stats*>(img);
 	if(stats==NULL)
 		return 0;
-	if(0==(used=encode(srcNumColors,buf,len))) return 0;
-	len-=used; buf+=used;
+	if(!encodeInc(srcNumColors,buf,len)) return 0;
 	for(unsigned int i=0; i<srcNumColors; i++) {
-		if(0==(used=encode(stats[i].num,buf,len))) return 0;
-		len-=used; buf+=used;
+		if(!encodeInc(stats[i].num,buf,len)) return 0;
 		region * curreg=stats[i].list;
 		for(int j=0; j<stats[i].num; j++) {
-			if(0==(used=encode(curreg->color,buf,len))) return 0;
-			len-=used; buf+=used;
-			if(0==(used=encode(curreg->x1,buf,len))) return 0;
-			len-=used; buf+=used;
-			if(0==(used=encode(curreg->y1,buf,len))) return 0;
-			len-=used; buf+=used;
-			if(0==(used=encode(curreg->x2,buf,len))) return 0;
-			len-=used; buf+=used;
-			if(0==(used=encode(curreg->y2,buf,len))) return 0;
-			len-=used; buf+=used;
-			if(0==(used=encode(curreg->cen_x,buf,len))) return 0;
-			len-=used; buf+=used;
-			if(0==(used=encode(curreg->cen_y,buf,len))) return 0;
-			len-=used; buf+=used;
-			if(0==(used=encode(curreg->area,buf,len))) return 0;
-			len-=used; buf+=used;
-			if(0==(used=encode(curreg->run_start,buf,len))) return 0;
-			len-=used; buf+=used;
+			if(!encodeInc(curreg->color,buf,len)) return 0;
+			if(!encodeInc(curreg->x1,buf,len)) return 0;
+			if(!encodeInc(curreg->y1,buf,len)) return 0;
+			if(!encodeInc(curreg->x2,buf,len)) return 0;
+			if(!encodeInc(curreg->y2,buf,len)) return 0;
+			if(!encodeInc(curreg->cen_x,buf,len)) return 0;
+			if(!encodeInc(curreg->cen_y,buf,len)) return 0;
+			if(!encodeInc(curreg->area,buf,len)) return 0;
+			if(!encodeInc(curreg->run_start,buf,len)) return 0;
 			curreg=curreg->next;
 		}
 		//we're only going to save the region part (not the color info)
-		if(0==(used=encode(stats[i].min_area,buf,len))) return 0;
-		len-=used; buf+=used;
-		if(0==(used=encode(stats[i].total_area,buf,len))) return 0;
-		len-=used; buf+=used;
-		if(0==(used=encode(stats[i].merge_threshold,buf,len))) return 0;
-		len-=used; buf+=used;
+		if(!encodeInc(stats[i].min_area,buf,len)) return 0;
+		if(!encodeInc(stats[i].total_area,buf,len)) return 0;
+		if(!encodeInc(stats[i].merge_threshold,buf,len)) return 0;
 	}
 	return origlen-len;
 }
@@ -233,7 +208,7 @@ RegionGenerator::createImageCache(unsigned int layer, unsigned int chan) const {
 
 void
 RegionGenerator::calcImage(unsigned int layer, unsigned int chan) {
-	PROFSECTION("RegionGenerator::calcImage(...)",state->mainProfile);
+	PROFSECTION("RegionGenerator::calcImage(...)",*mainProfiler);
 	
 	//some shorthand to make the rest of the code more readable
 	RLEGenerator& srcRLE=dynamic_cast<RLEGenerator&>(*src); //source generator
@@ -246,6 +221,7 @@ RegionGenerator::calcImage(unsigned int layer, unsigned int chan) {
   unsigned int maxArea = CMVision::SeparateRegions(stats,srcNumColors,regions[layer][chan],numReg);
   CMVision::SortRegions(stats,srcNumColors,maxArea);
   CMVision::MergeRegions(stats,(int)srcNumColors,rmap); //yes that (int) is necessary or compiler complains of ambiguous function call
+  CMVision::CalcTotalArea(stats,srcNumColors);
 
 	//and set the flag so we don't recompute if getImage() is called again before the next frame
 	imageValids[layer][chan]=true;
@@ -266,9 +242,9 @@ RegionGenerator::destruct() {
  * @author ejt (reorganized)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.16 $
  * $State: Exp $
- * $Date: 2005/06/06 20:23:15 $
+ * $Date: 2006/09/11 23:05:23 $
  */
 
