@@ -11,6 +11,7 @@
 #  include <fcntl.h>
 #endif
 #include "Shared/Config.h"
+#include "Shared/MarkScope.h"
 #include <unistd.h>
 
 Socket* sout=NULL;
@@ -44,23 +45,41 @@ byte*
 Socket::getWriteBuffer(int bytesreq)
 {
 #ifndef PLATFORM_APERIOS
-  wireless->getLock().lock();
+  MarkScope l(wireless->getLock());
 #endif
+	byte* buf=NULL;
   if (sendBufSize-writeSize>=bytesreq
       && state==CONNECTION_CONNECTED)
-    return writeData+writeSize;
-  if (state!=CONNECTION_CONNECTED) {
+    buf=writeData+writeSize;
+  else if (state!=CONNECTION_CONNECTED) {
 		if(forwardSock!=NULL)
-			return forwardSock->getWriteBuffer(bytesreq);
-		if(textForward)
-			return (byte*)(textForwardBuf=new char[bytesreq]);
+			buf=forwardSock->getWriteBuffer(bytesreq);
+		else if(textForward)
+			buf=(byte*)(textForwardBuf=new char[bytesreq]);
   }
-	return NULL;
+#ifndef PLATFORM_APERIOS
+	// the lock is about to expire as we leave, but if buf is
+	// valid, we want to retain the lock until write() is called
+	if(buf!=NULL)
+		wireless->getLock().useResource(Resource::emptyData);
+#endif
+	return buf;
 }
 
 void
 Socket::write(int size)
 {
+#ifndef PLATFORM_APERIOS
+#  ifdef DEBUG
+	//we should be coming in with a lock from getWriteBuffer...
+	if(ThreadNS::Lock * lock=dynamic_cast<ThreadNS::Lock*>(&wireless->getLock())) {
+		if(lock->getLockLevel()==0) {
+			serr->printf("Socket: Attempted write() without previously successful getWriteBuffer()\n");
+			return;
+		}
+	}
+#  endif
+#endif
   writeSize+=size;
 	if(textForwardBuf) {
 		::write(STDOUT_FILENO,textForwardBuf,size);
@@ -69,7 +88,7 @@ Socket::write(int size)
 	} else
 		flush();
 #ifndef PLATFORM_APERIOS
-  wireless->getLock().unlock();
+  wireless->getLock().releaseResource(Resource::emptyData);
 #endif
 }
 
@@ -90,14 +109,16 @@ void
 Socket::init()
 {
 #ifndef PLATFORM_APERIOS
-  ThreadNS::Lock(wireless->getLock());
+  MarkScope l(wireless->getLock());
 #endif
   sendSize=0;
   writeSize=0;
   peer_addr=peer_port=-1;
 #ifndef PLATFORM_APERIOS
 	if(endpoint!=-1)
-		::close(endpoint);
+		if(::close(endpoint)==-1)
+			perror("Wireless::close(): close");
+	state = CONNECTION_CLOSED;
 	endpoint = ::socket ( AF_INET,trType,0 );
 	if(endpoint==-1) {
 		perror("Socket::init(): socket()");
@@ -112,6 +133,10 @@ Socket::init()
 		if ( ::setsockopt ( endpoint, SOL_SOCKET, SO_BROADCAST, ( const char* ) &on, sizeof ( on ) ) == -1 ) {
 			perror("Socket::init(): SO_BROADCAST setsockopt");
 		}
+		const int sndbuf=(1<<16)-28;
+		if ( ::setsockopt ( endpoint, SOL_SOCKET, SO_SNDBUF, ( const char* ) &sndbuf, sizeof ( sndbuf ) ) == -1 ) {
+			perror("Socket::init(): SO_SNDBUF setsockopt");
+		}
 	}
 	if( ::fcntl(endpoint,F_SETFL,O_NONBLOCK) ==-1 ) {
 		perror("Socket::init(): fcntl");
@@ -131,7 +156,7 @@ void
 Socket::flush()
 {
 #ifndef PLATFORM_APERIOS
-  ThreadNS::Lock(wireless->getLock());
+  MarkScope l(wireless->getLock());
 #endif
   if (state!=CONNECTION_CONNECTED) {
 		if(forwardSock!=NULL)
@@ -197,7 +222,7 @@ Socket::vprintf(const char *fmt, va_list al)
 			return vfprintf(stdout, fmt, al);
   } else {
 #ifndef PLATFORM_APERIOS
-		ThreadNS::Lock(wireless->getLock());
+		MarkScope l(wireless->getLock());
 #endif
 		int ret=vsnprintf((char *)(writeData+writeSize), sendBufSize-writeSize, fmt, al);
 		writeSize+=ret;
@@ -217,7 +242,7 @@ Socket::write(const byte *buf, int size)
 			return ::write(STDOUT_FILENO,buf,size);
 	} else {
 #ifndef PLATFORM_APERIOS
-		ThreadNS::Lock(wireless->getLock());
+		MarkScope l(wireless->getLock());
 #endif
 		byte *destbuf=getWriteBuffer(size);
 		if (destbuf==NULL) return -1;
@@ -250,9 +275,9 @@ std::string Socket::getPeerAddressAsString() const {
  * @author alokl (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.20 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.26 $
  * $State: Exp $
- * $Date: 2005/08/02 22:24:29 $
+ * $Date: 2006/07/04 01:36:46 $
  */
 
