@@ -1,6 +1,6 @@
 //-*-c++-*-
-#ifndef Socket_h_DEFINED
-#define Socket_h_DEFINED
+#ifndef INCLUDED_Socket_h_
+#define INCLUDED_Socket_h_
 
 #ifdef PLATFORM_APERIOS
 #  include <ant.h>
@@ -62,11 +62,8 @@ using namespace SocketNS;
 //! Tekkotsu wireless Socket class
 /*! 
  * For more information on using wireless, please read the following tutorials:
- * - <a href="../AiboMon.html">TekkotsuMon</a>
+ * - <a href="../TekkotsuMon.html">TekkotsuMon</a>
  * - <a href="../Wireless.html">TCP/IP</a>
- * - <a href="../RemoteProcess.html">Remote Processing OPENR</a>
- * Tekkotsu Wireless and Remote Processing OPENR provide different
- * interfaces to comparable wireless functionality.
  *
  * The networking interface needs more documentation.  It also needs a
  * cleanup.  In the mean time, take a look at the TekkotsuMon objects
@@ -133,6 +130,11 @@ public:
    * @return pointer to the buffer the previous call to blocking read wrote into or NULL if no data was read
    */
   byte* getReadBuffer();
+	
+	unsigned int getMaxSendSize() const { return sendBufSize; } //!< returns the maximum buffer size for a send
+	unsigned int getMaxReceiveSize() const { return recvBufSize; } //!< returns the maximum buffer size for a receive
+	unsigned int getAvailableSendSize() const { return sendBufSize-writeSize; } //!< returns the maximum *currently available* buffer size for a send
+	unsigned int getAvailableReceiveSize() const { return recvBufSize; } //!< returns the maximum *currently available* buffer size for a receive
 
   //! initialize socket member variables. This is different from the constructor since sockets are reused
   void init(); 
@@ -145,9 +147,13 @@ public:
    * @return 0 on success
    */
   int setFlushType(FlushType_t fType);
+  //! returns flush mode
+  FlushType_t getFlushType() const { return flType; }
 	
   //! can choose between different transports; will reset the socket
   int setTransport(TransportType_t tr);
+  //! returns the transport in use
+  TransportType_t getTransport() const { return trType; }
 
 	//!causes this socket to forward output to stdout if it is not connected, call setForward(NULL) to unset
   void setTextForward() { textForward=true; forwardSock=NULL; }
@@ -275,10 +281,10 @@ extern Socket* serr;  //!< the standard tekkotsu error output (default port 1000
  * @author alokl (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.23 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.27 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:04 $
+ * $Date: 2006/10/03 22:32:49 $
  */
 
 #endif
