@@ -191,7 +191,7 @@ try {
 
 	if ( sockets[sock]->trType == SOCK_STREAM )
 		{
-			TCPEndpointListenMsg * listenMsg = ( TCPEndpointListenMsg * ) msg;
+			TCPEndpointListenMsg * listenMsg = ( TCPEndpointListenMsg * ) antEnvMsg::Receive( msg );
 
 			if ( listenMsg->error != TCP_SUCCESS )
 				{
@@ -227,7 +227,7 @@ try {
 
 	if ( sockets[sock]->trType == SOCK_STREAM )
 		{
-			TCPEndpointConnectMsg * connectMsg = ( TCPEndpointConnectMsg * ) msg;
+			TCPEndpointConnectMsg * connectMsg = ( TCPEndpointConnectMsg * ) antEnvMsg::Receive( msg );
 			if ( connectMsg->error != TCP_SUCCESS )
 				{
 					sockets[sock]->state = CONNECTION_ERROR;
@@ -253,7 +253,7 @@ void
 Wireless::BindCont(void *msg)
 {
 try {
-	UDPEndpointBindMsg* bindMsg = (UDPEndpointBindMsg*)msg;
+	UDPEndpointBindMsg* bindMsg = (UDPEndpointBindMsg*) antEnvMsg::Receive( msg );
 	int sock = (int)bindMsg->continuation;
 
 	if (bindMsg->error != UDP_SUCCESS) {
@@ -316,7 +316,7 @@ try {
 
 	if ( sockets[sock]->trType == SOCK_STREAM )
 		{
-			TCPEndpointSendMsg * sendMsg = ( TCPEndpointSendMsg * ) msg;
+			TCPEndpointSendMsg * sendMsg = ( TCPEndpointSendMsg * ) antEnvMsg::Receive( msg );
 			sockets[sock]->tx = false;
 			if ( sendMsg->error != TCP_SUCCESS )
 				{
@@ -328,7 +328,7 @@ try {
 
 	else if ( sockets[sock]->trType == SOCK_DGRAM )
 		{
-			UDPEndpointSendMsg * sendMsg = ( UDPEndpointSendMsg * ) msg;
+			UDPEndpointSendMsg * sendMsg = ( UDPEndpointSendMsg * ) antEnvMsg::Receive( msg );
 			sockets[sock]->tx = false;
 			if ( sendMsg->error != UDP_SUCCESS )
 				{
@@ -445,7 +445,7 @@ try {
 
 	if ( sockets[sock]->trType == SOCK_STREAM )
 		{
-			TCPEndpointReceiveMsg * receiveMsg = ( TCPEndpointReceiveMsg * ) msg;
+			TCPEndpointReceiveMsg * receiveMsg = ( TCPEndpointReceiveMsg * ) antEnvMsg::Receive( msg );
 			if ( receiveMsg->error != TCP_SUCCESS )
 				{
 					sockets[sock]->state = CONNECTION_ERROR;
@@ -569,7 +569,7 @@ void
 Wireless::CloseCont(void* msg)
 {
 try {
-	antEnvMsg * closeMsg = ( antEnvMsg * ) msg;
+	antEnvMsg * closeMsg = ( antEnvMsg * ) antEnvMsg::Receive( msg );
 	int sock = ( int )( closeMsg->continuation );
 	if ( sockets[sock] == NULL )
 		return;
@@ -614,12 +614,13 @@ try {
 #  include <unistd.h>
 #  include <iostream>
 #  include <errno.h>
+#  include "Shared/MarkScope.h"
 
 using namespace std;
 
 
 Wireless::Wireless ()
-: interruptChk(-1), interruptCtl(-1), rfds(), wfds(), efds(), fdsMax(0), freeSockets(), usedSockets()
+	: callbackLock(NULL), interruptChk(-1), interruptCtl(-1), rfds(), wfds(), efds(), fdsMax(0), freeSockets(), usedSockets()
 {
 	sockets[0]=new DummySocket(0);
 	for (int sock = 1; sock < WIRELESS_MAX_SOCKETS; sock++) {
@@ -642,7 +643,7 @@ Wireless::Wireless ()
 
 Wireless::~Wireless ()
 {
-	ThreadNS::Lock l(getLock());
+	MarkScope l(getLock());
 	::close(interruptChk);
 	::close(interruptCtl);
 	interruptChk=interruptCtl=-1;
@@ -655,6 +656,7 @@ Wireless::~Wireless ()
 		freeSockets.insert(freeSockets.end(),usedSockets.begin(),usedSockets.end());
 		usedSockets.clear();
 	}
+	delete sockets[0]; // DummySocket
 }
 
 void Wireless::setReceiver(int sock, int (*rcvcbckfn) (char*, int) ) {
@@ -662,16 +664,13 @@ void Wireless::setReceiver(int sock, int (*rcvcbckfn) (char*, int) ) {
 }
 
 void Wireless::close(int sock) {
-	ThreadNS::Lock l(getLock());
+	MarkScope l(getLock());
 	if ( sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL)
 		return;
 	sockets[sock]->flush();
 	sockets[sock]->peer_port = sockets[sock]->peer_addr = -1;
 	if(sockets[sock]->daemon) {
-		if(::close(sockets[sock]->endpoint)==-1)
-			perror("Wireless::close(): close");
-		sockets[sock]->endpoint=-1;
-		sockets[sock]->state = CONNECTION_CLOSED;
+		sockets[sock]->init();
 		listen(sock,sockets[sock]->server_port);
 	} else {
 		bool found=false;
@@ -687,14 +686,14 @@ void Wireless::close(int sock) {
 			return;
 		}
 		Socket * s=sockets[sock];
-		sockets[sock] = NULL;
+		sockets[sock] = NULL; //we don't delete the socket here -- wakeup() will cause pollProcess to do that
 		wakeup(s); //avoid select giving error about bad FD
 		freeSockets.push_back( sock );
 	}
 }
 
 int Wireless::connect(int sock, const char* ipaddr, int port) {
-	ThreadNS::Lock l(getLock());
+	MarkScope l(getLock());
 	if ( port <= 0 || port >= 65535 || sock <= 0 || sock >= WIRELESS_MAX_SOCKETS
 			 || sockets[sock] == NULL || sockets[sock]->state != CONNECTION_CLOSED && sockets[sock]->trType!=SocketNS::SOCK_DGRAM )
 		return -1;
@@ -739,7 +738,7 @@ int Wireless::connect(int sock, const char* ipaddr, int port) {
 }
 
 int Wireless::listen(int sock, int port) {
-  ThreadNS::Lock l(getLock());
+  MarkScope l(getLock());
   if ( port <= 0 || port >= 65535 || sock <= 0 || sock >= WIRELESS_MAX_SOCKETS
        || sockets[sock] == NULL || sockets[sock]->state != CONNECTION_CLOSED )
 		return -1;
@@ -775,7 +774,7 @@ Socket* Wireless::socket(TransportType_t ttype) {
 	return socket(ttype, WIRELESS_DEF_RECV_SIZE, WIRELESS_DEF_SEND_SIZE);
 }
 Socket* Wireless::socket(TransportType_t ttype, int recvsize, int sendsize) {
-	ThreadNS::Lock l(getLock());
+	MarkScope l(getLock());
 	if (freeSockets.empty()
 			|| (recvsize + sendsize) <= 256) return sockets[0];
 	int sock_num=freeSockets.front();
@@ -823,7 +822,7 @@ uint32 Wireless::getIPAddress(unsigned int idx/*=0*/) {
 void
 Wireless::send(int sock)
 {
-	ThreadNS::Lock l(getLock());
+	MarkScope l(getLock());
 	if ( sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL
 	    || sockets[sock]->state != CONNECTION_CONNECTED || sockets[sock]->sendSize <= 0 )
 		return;
@@ -832,9 +831,14 @@ Wireless::send(int sock)
 	int s=sockets[sock]->endpoint;
 	int sent=::send(s,sockets[sock]->sendData+sockets[sock]->sentSize,sockets[sock]->sendSize-sockets[sock]->sentSize,0);
 	if(sent==-1) {
-		perror("Wireless::pollProcess(): send");
-		sockets[sock]->tx = false;
-		sockets[sock]->sendSize = sockets[sock]->sentSize = 0;
+		if(errno==ECONNREFUSED) {
+			close(sock);
+		} else {
+			perror("Wireless::send(): send");
+			cerr << "Wireless::send() data size was " << sockets[sock]->sendSize-sockets[sock]->sentSize << endl;
+			sockets[sock]->tx = false;
+			sockets[sock]->sendSize = sockets[sock]->sentSize = 0;
+		}
 	} else {
 		sockets[sock]->sentSize+=sent;
 		if(sockets[sock]->sentSize==sockets[sock]->sendSize) {
@@ -853,7 +857,7 @@ Wireless::send(int sock)
 void
 Wireless::blockingSend(int sock)
 {
-	ThreadNS::Lock l(getLock());
+	MarkScope l(getLock());
 	if ( sock <= 0 || sock >= WIRELESS_MAX_SOCKETS || sockets[sock] == NULL
 	    || sockets[sock]->state != CONNECTION_CONNECTED || sockets[sock]->sendSize <= 0 )
 		return;
@@ -894,7 +898,7 @@ void Wireless::pollSetup() {
 	FD_SET(interruptChk, &rfds);
 
 	fdsMax=interruptChk;
-	ThreadNS::Lock l(getLock());
+	MarkScope l(getLock());
 	//cout << "pollSetup " << usedSockets.size() << endl;
 	for(list<int>::const_iterator it=usedSockets.begin(); it!=usedSockets.end(); ++it) {
 		if(sockets[*it]==NULL) {
@@ -925,7 +929,8 @@ bool Wireless::pollTest(struct timeval* tv) {
 }
 
 void Wireless::pollProcess() {
-	ThreadNS::Lock l(getLock());
+	MarkScope cl(getCallbackLock()); //note how this will go out of scope and release the lock if an exception occurs... sexy!
+	MarkScope l(getLock());
 	if(FD_ISSET(interruptChk,&rfds)) {
 		//wakeup sent to handle non-blocking write
 		int res=1;
@@ -961,7 +966,8 @@ void Wireless::pollProcess() {
 					socklen_t addrlen=sizeof(m_addr);
 					int n=accept(s,(sockaddr*)&m_addr,&addrlen);
 					if(n==-1) {
-						perror("Wireless::pollProcess(): accept");
+						if(errno!=EAGAIN) //EAGAIN indicates we were woken due to some other issue, like a previous close completing
+							perror("Wireless::pollProcess(): accept");
 						continue;
 					}
 					sockets[*it]->peer_addr=ntohl(m_addr.sin_addr.s_addr);
@@ -1013,14 +1019,14 @@ void Wireless::pollProcess() {
 						sockets[*it]->recvSize = 0;
 					}
 				}
-			} else 	if(sockets[*it]->state==CONNECTION_CONNECTED || sockets[*it]->state==CONNECTION_CLOSING) {
+			} else if(sockets[*it]->state==CONNECTION_CONNECTED || sockets[*it]->state==CONNECTION_CLOSING) {
 				sockets[*it]->recvSize = recvfrom(s,sockets[*it]->recvData,sockets[*it]->recvBufSize,0,NULL,NULL);
 				if(sockets[*it]->recvSize==-1) {
 					if(errno!=EAGAIN) { //may have just completed connection, not a problem
-						if(errno==ECONNREFUSED) {
-							cerr << "connection refused: endpoint=" << s << " sock=" << *it << " Socket=" << sockets[*it] << endl;
+						if(errno==ECONNREFUSED || errno==ECONNRESET) {
+							//cerr << "connection refused: endpoint=" << s << " sock=" << *it << " Socket=" << sockets[*it] << endl;
 							list<int>::const_iterator tmp=it;
-							//a UDP server could come in here
+							//a UDP server could come in here if the client closes down (i.e. packet is refused)
 							if(!sockets[*it]->daemon) //don't decrement if the socket is going to stay open
 								--it;
 							close(*tmp);
@@ -1106,24 +1112,34 @@ void Wireless::wakeup(Socket * del/*=NULL*/) {
 	::write(interruptCtl,&del,sizeof(del)); 
 }
 
-ThreadNS::Lock& Wireless::getLock() {
+Resource& Wireless::getLock() {
 	static ThreadNS::Lock lock;
 	return lock;
 }
 
+void Wireless::setCallbackLock(Resource& l) {
+	MarkScope pcl(getCallbackLock()); //put a lock on previous callback until we've switched
+	callbackLock=&l;
+}
+
+void Wireless::clearCallbackLock() {
+	callbackLock=NULL;
+}
+
 #endif
 
 /*! @file
  * @brief Interacts with the system to provide networking services
  * @author alokl (Creator)
  * @author Erik Berglund and Bryan Johnson (UDP support)
+ * @author ejt simulator support
  * 
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.27 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.37 $
  * $State: Exp $
- * $Date: 2005/08/16 18:37:05 $
+ * $Date: 2006/06/26 16:24:17 $
  */
 
