@@ -1,6 +1,6 @@
 //-*-c++-*-
-#ifndef Wireless_h_DEFINED
-#define Wireless_h_DEFINED
+#ifndef INCLUDED_Wireless_h_
+#define INCLUDED_Wireless_h_
 
 #ifdef PLATFORM_APERIOS
 #  include <OPENR/OObject.h>
@@ -8,10 +8,9 @@
 #  include <OPENR/OObserver.h>
 #  include <ant.h>
 #else
-namespace ThreadNS {
-	class Lock;
-}
-typedef unsigned int uint32;
+#  include "IPC/Thread.h"
+#  include "Shared/Resource.h"
+typedef unsigned long uint32;
 #endif
 #include "Socket.h"
 #include "DummySocket.h"
@@ -91,6 +90,10 @@ public:
   bool isConnected(int sock) {
     return sockets[sock]==NULL ? false : sockets[sock]->state==CONNECTION_CONNECTED;
   }
+  bool isError(int sock) {
+    return sockets[sock]==NULL ? false : sockets[sock]->state==CONNECTION_ERROR;
+  }
+
   bool isReady(int sock) { return !sockets[sock]->tx; }
   bool hasData(int sock) { return !sockets[sock]->rx; }
   //@}
@@ -143,11 +146,14 @@ public:
   //@}
 
 #else
-	void pollSetup(); //!< on non-aperios, set up structures to be checked in pollTest() (may want to protect this with a mutex lock)
+	void pollSetup(); //!< on non-aperios, set up structures to be checked in pollTest()
 	bool pollTest(struct timeval* tv); //!< on non-aperios, check to see any network communication has occurred
-	void pollProcess(); //!< on non-aperios, process callbacks and state changes as signaled in pollTest() (may want to protect this with a mutex lock)
+	void pollProcess(); //!< on non-aperios, process callbacks and state changes as signaled in pollTest()
 	void wakeup(Socket * del=NULL); //!< writes @a del on #interruptCtl, breaking out of a pending pollTest() and thus giving an opportunity to change the contents of the FD sets being used;
-	
+
+	void setCallbackLock(Resource& l); //!< sets #callbackLock
+	void clearCallbackLock(); //!< resets #callbackLock to a self-defined lock, which you can request from getCallbackLock() (there's always a callbackLock, the only question is it internally or externally instantiated)
+	Resource& getCallbackLock() const { static ThreadNS::Lock cl; return callbackLock==NULL ? cl : *callbackLock; } //!< returns #callbackLock
 #endif
 
 protected:
@@ -160,13 +166,14 @@ protected:
   antStackRef ipstackRef;
   OID myOID;
 #else
-  static ThreadNS::Lock& getLock(); //! returns the lock to use during wireless operations
-  int interruptChk;
-  int interruptCtl;
-  fd_set rfds;
-  fd_set wfds;
-  fd_set efds;
-  int fdsMax;
+  static Resource& getLock(); //!< returns the lock to use during @e all wireless operations (not just callbacks, this is more general)
+  Resource* callbackLock; //!< this lock will be aquired during any callbacks which might occur during pollProcess()
+  int interruptChk; //!< a socket, connected to #interruptCtl, which allows pollTest() to be interrupted if new sockets need to be polled
+  int interruptCtl; //!< a socket, connected to #interruptChk, which allows pollTest() to be interrupted if new sockets need to be polled
+  fd_set rfds; //!< a set of file descriptors which should be polled for readable data; set up by pollSetup(), watched (blocking) by pollTest(), and processed by pollProcess()
+  fd_set wfds; //!< a set of file descriptors which should be polled for write-complete; set up by pollSetup(), watched (blocking) by pollTest(), and processed by pollProcess()
+  fd_set efds; //!< a set of file descriptors which should be polled for errors; set up by pollSetup(), watched (blocking) by pollTest(), and processed by pollProcess()
+  int fdsMax; //!< maximum file descriptor value in the #rfds, #wfds, #efds fd_set's
 #endif
   Socket* sockets[WIRELESS_MAX_SOCKETS];
   std::list<int> freeSockets;
@@ -188,10 +195,10 @@ extern Wireless* wireless;
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.22 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.27 $
  * $State: Exp $
- * $Date: 2005/08/07 04:11:04 $
+ * $Date: 2006/09/22 16:59:26 $
  */
 
 #endif // Wireless_h_DEFINED
