@@ -1,11 +1,11 @@
 #include "MMCombo.h"
-#include "Shared/WorldState.h"
+#include "Shared/WorldStatePool.h"
 #include "Shared/Profiler.h"
 #include "Shared/debuget.h"
 #include "Shared/Config.h"
 #include "IPC/SharedObject.h"
-#include "IPC/ProcessID.h"
 #include "Events/EventRouter.h"
+#include "Events/EventTranslator.h"
 #include "Behaviors/BehaviorBase.h"
 #include "Motion/MotionManager.h"
 #include "Motion/Kinematics.h"
@@ -34,9 +34,9 @@
 using namespace std;
 
 MMCombo::MMCombo()
-	: OObject(), motmanMemRgn(NULL), worldStateMemRgn(NULL),
-		soundManagerMemRgn(NULL),
-		runLevel(0), num_open(0), etrans(NULL), isStopped(true)
+	: OObject(), motmanMemRgn(NULL), motionProfilerMemRgn(NULL), soundProfilerMemRgn(NULL),
+		worldStatePoolMemRgn(NULL), soundManagerMemRgn(NULL), processMapMemRgn(NULL),
+		runLevel(0), num_open(0), etrans(NULL), wspool(NULL), entryPt(), isStopped(true)
 {
 try {
 	for(unsigned int i=0; i<NumOutputs; i++) {
@@ -70,20 +70,27 @@ try {
 	NEW_ALL_SUBJECT_AND_OBSERVER;
 	REGISTER_ALL_ENTRY;
 	SET_ALL_READY_AND_NOTIFY_ENTRY;
-		
+	
 	// make sure the library doesn't drop data "for" us on this reliable communication channel
-	observer[obsReceiveWorldState]->SetBufCtrlParam(0,1,1);
+	observer[obsReceiveWorldStatePool]->SetBufCtrlParam(0,1,1);
 	observer[obsReceiveMotionManager]->SetBufCtrlParam(0,1,1);
 	observer[obsReceiveSoundManager]->SetBufCtrlParam(0,1,1);
+	observer[obsReceiveProcessMap]->SetBufCtrlParam(0,1,1);
+	observer[obsEventTranslatorComm]->SetBufCtrlParam(0,1,20); //allows up to 20 messages to be sent in a burst before dropping any
 	observer[obsMotionManagerComm]->SetBufCtrlParam(0,1,MotionManager::MAX_MOTIONS+1);
+	observer[obsReceiveMotionProfiler]->SetBufCtrlParam(0,1,1);
+	observer[obsReceiveSoundProfiler]->SetBufCtrlParam(0,1,2);
 	//+1 to MAX_MOTIONS so we can get a delete message after we've filled up
 
-	cout << objectName << ": sbjRegisterWorldState==" << sbjRegisterWorldState << " selector==" << subject[sbjRegisterWorldState]->GetID().GetSelector() << '\n'
-			 << objectName << ": obsReceiveWorldState==" << obsReceiveWorldState << " selector==" << observer[obsReceiveWorldState]->GetID().GetSelector() << '\n'
+	cout << objectName << ": sbjRegisterWorldStatePool==" << sbjRegisterWorldStatePool << " selector==" << subject[sbjRegisterWorldStatePool]->GetID().GetSelector() << '\n'
+			 << objectName << ": obsReceiveWorldStatePool==" << obsReceiveWorldStatePool << " selector==" << observer[obsReceiveWorldStatePool]->GetID().GetSelector() << '\n'
 			 << objectName << ": sbjRegisterMotionManager==" << sbjRegisterMotionManager << " selector==" << subject[sbjRegisterMotionManager]->GetID().GetSelector() << '\n'
 			 << objectName << ": obsReceiveMotionManager==" << obsReceiveMotionManager << " selector==" << observer[obsReceiveMotionManager]->GetID().GetSelector() << '\n'
 			 << objectName << ": obsEventTranslatorComm==" << obsEventTranslatorComm << " selector==" << observer[obsEventTranslatorComm]->GetID().GetSelector() << '\n'
 			 << objectName << ": sbjEventTranslatorComm==" << sbjEventTranslatorComm << " selector==" << observer[sbjEventTranslatorComm]->GetID().GetSelector() << '\n'
+			 << objectName << ": obsReceiveMotionProfiler==" << obsReceiveMotionProfiler << " selector==" << observer[obsReceiveMotionProfiler]->GetID().GetSelector() << '\n'
+			 << objectName << ": obsReceiveSoundProfiler==" << obsReceiveSoundProfiler << " selector==" << observer[obsReceiveSoundProfiler]->GetID().GetSelector() << '\n'
+			 << objectName << ": sbjRegisterProfiler==" << sbjRegisterProfiler << " selector==" << observer[sbjRegisterProfiler]->GetID().GetSelector() << '\n'
 			 << objectName << ": sbjMoveJoint==" << sbjMoveJoint << " selector==" << subject[sbjMoveJoint]->GetID().GetSelector() << '\n'
 			 << objectName << ": obsSensorFrame==" << obsSensorFrame << " selector==" << observer[obsSensorFrame]->GetID().GetSelector() << '\n'
 			 << objectName << ": obsImage==" << obsImage << " selector==" << observer[obsImage]->GetID().GetSelector() << '\n'
@@ -91,14 +98,24 @@ try {
 			 << objectName << ": sbjMotionManagerComm==" << sbjMotionManagerComm << " selector==" << subject[sbjMotionManagerComm]->GetID().GetSelector() << '\n'
 			 << objectName << ": obsMotionManagerComm==" << obsMotionManagerComm << " selector==" << observer[obsMotionManagerComm]->GetID().GetSelector() << '\n'
 			 << objectName << ": obsReceiveSoundManager==" << obsReceiveSoundManager << " selector==" << observer[obsReceiveSoundManager]->GetID().GetSelector() << '\n'
+			 << objectName << ": sbjRegisterProcessMap==" << sbjRegisterProcessMap << " selector==" << subject[sbjRegisterProcessMap]->GetID().GetSelector() << '\n'
+			 << objectName << ": obsReceiveProcessMap==" << obsReceiveProcessMap << " selector==" << observer[obsReceiveProcessMap]->GetID().GetSelector() << '\n'
 			 << objectName << ": sbjSoundManagerComm==" << sbjSoundManagerComm << " selector==" << subject[sbjSoundManagerComm]->GetID().GetSelector() << '\n'
 			 << flush;
 
-	if(strcmp(objectName,"MainObj")==0)
+	if(strcmp(objectName,"MainObj")==0) {
 		ProcessID::setID(ProcessID::MainProcess);
-	else if(strcmp(objectName,"MotoObj")==0)
-		ProcessID::setID(ProcessID::MotionProcess);
 		
+		//processMapMemRgn -> ProcessID::setMap() setup
+		processMapMemRgn = InitRegion(sizeof(stacktrace::StackFrame)*ProcessID::NumProcesses);
+		memset(processMapMemRgn->Base(),0,sizeof(stacktrace::StackFrame)*ProcessID::NumProcesses);
+		ProcessID::setMap(reinterpret_cast<stacktrace::StackFrame*>(processMapMemRgn->Base()));
+	} else if(strcmp(objectName,"MotoObj")==0)
+		ProcessID::setID(ProcessID::MotionProcess);
+
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
+	
+	
 	//Read config file
 	config=new Config("/ms/config/tekkotsu.cfg");
 
@@ -121,43 +138,51 @@ try {
 			return oFAIL;
 		}
 		
-    //Setup wireless
-    wireless = new Wireless();
-    sout=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*12);
-    serr=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*4);
-    wireless->setDaemon(sout);
-    wireless->setDaemon(serr);
-		serr->setFlushType(SocketNS::FLUSH_BLOCKING);
-    sout->setTextForward();
-    serr->setForward(sout);
-
-		//worldStateMemRgn -> state setup
-		worldStateMemRgn = InitRegion(sizeof(WorldState));
-		state=new ((WorldState*)worldStateMemRgn->Base()) WorldState;
+		//Setup wireless
+		wireless = new Wireless();
+		sout=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*12);
+		serr=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*4);
+		wireless->setDaemon(sout);
+		wireless->setDaemon(serr);
+			serr->setFlushType(SocketNS::FLUSH_BLOCKING);
+		sout->setTextForward();
+		serr->setForward(sout);
+		
+		//worldStatePoolMemRgn -> state setup
+		worldStatePoolMemRgn = InitRegion(sizeof(WorldStatePool));
+		wspool=new ((WorldStatePool*)worldStatePoolMemRgn->Base()) WorldStatePool;
+		wspool->InitAccess();
+		entryPt.setPool(wspool);
+		
+		mainProfiler = new mainProfiler_t;
 
 		etrans=new NoOpEventTranslator(*erouter);
 		MotionManager::setTranslator(etrans);
 	}
 	if(strcmp(objectName,"MotoObj")==0) {
 		SetupOutputs(IsFastOutput);
-    OPENR::SetMotorPower(opowerON);
+		OPENR::SetMotorPower(opowerON);
 		OPENR::EnableJointGain(oprimitiveID_UNDEF); //oprimitiveID_UNDEF means enable all
 
-    //Setup wireless
-    wireless = new Wireless();
-    sout=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*6);
-    serr=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*2);
-    wireless->setDaemon(sout);
-    wireless->setDaemon(serr);
+		//Setup wireless
+		wireless = new Wireless();
+		sout=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*6);
+		serr=wireless->socket(SocketNS::SOCK_STREAM,Wireless::WIRELESS_DEF_RECV_SIZE,Wireless::WIRELESS_DEF_SEND_SIZE*2);
+		wireless->setDaemon(sout);
+		wireless->setDaemon(serr);
 		serr->setFlushType(SocketNS::FLUSH_BLOCKING);
-    sout->setTextForward();
-    serr->setForward(sout);
+		sout->setTextForward();
+		serr->setForward(sout);
 		
 		//motmanMemRgn -> motman setup
 		motmanMemRgn = InitRegion(sizeof(MotionManager));
-		motman = new (motmanMemRgn->Base()) MotionManager();
+		motman = new (motmanMemRgn->Base()) MotionManager;
 		motman->InitAccess(subject[sbjMotionManagerComm]);
-
+		
+		//motionProfilerMemRgn -> motionProfiler setup
+		motionProfilerMemRgn = InitRegion(sizeof(motionProfiler_t));
+		motionProfiler = new (motionProfilerMemRgn->Base()) motionProfiler_t;
+		
 		etrans=new IPCEventTranslator(*subject[sbjEventTranslatorComm]);
 		MotionManager::setTranslator(etrans);
 		//MotionCommands enqueue directly, so there shouldn't be any riff-raff to catch
@@ -167,7 +192,7 @@ try {
 				erouter->addTrapper(etrans,static_cast<EventBase::EventGeneratorID_t>(i));
 	}
 	kine = new Kinematics();
-
+	
 	cout << objectName << "::DoInit()-DONE" << endl;
 	return oSUCCESS;
 
@@ -184,6 +209,7 @@ return oSUCCESS;
 OStatus
 MMCombo::DoStart(const OSystemEvent&)
 {
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 try {
 	cout << objectName << "::DoStart() " << endl;
 
@@ -207,7 +233,9 @@ try {
 	ENABLE_ALL_SUBJECT;
 	ASSERT_READY_TO_ALL_OBSERVER;
 
-	addRunLevel();
+	if(strcmp(objectName,"MainObj")==0) {
+		addRunLevel();
+	}
 	
 	cout << objectName << "::DoStart()-DONE" << endl;
 	return oSUCCESS;
@@ -225,12 +253,14 @@ return oSUCCESS;
 OStatus
 MMCombo::DoStop(const OSystemEvent&)
 {
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 try {
 	cout << objectName << "::DoStop()..." << endl;
 	if(strcmp(objectName,"MainObj")==0) {
 		ProjectInterface::startupBehavior().DoStop();
 		wireless->close(sout);
 		wireless->close(serr);
+		motman->RemoveAccess();
 	}
 	DISABLE_ALL_SUBJECT;
 	DEASSERT_READY_TO_ALL_OBSERVER;
@@ -251,6 +281,7 @@ return oSUCCESS;
 OStatus
 MMCombo::DoDestroy(const OSystemEvent&)
 {
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 try {
 	cout << objectName << "::DoDestroy()..." << endl;
 	delete etrans;
@@ -258,12 +289,32 @@ try {
 	MotionManager::setTranslator(NULL);
 	if(strcmp(objectName,"MainObj")==0) {
 		delete erouter;
-		motmanMemRgn->RemoveReference();
+		if(motmanMemRgn!=NULL) {
+			motmanMemRgn->RemoveReference();
+			motmanMemRgn=NULL;
+		}
+		if(motionProfilerMemRgn!=NULL) {
+			motionProfilerMemRgn->RemoveReference();
+			motionProfilerMemRgn=NULL;
+		}
+		delete mainProfiler;
 	}
 	if(strcmp(objectName,"MotoObj")==0) {
-		worldStateMemRgn->RemoveReference();
+		if(worldStatePoolMemRgn!=NULL) {
+			worldStatePoolMemRgn->RemoveReference();
+			worldStatePoolMemRgn=NULL;
+			entryPt.setPool(NULL);
+		}
+		if(processMapMemRgn!=NULL) {
+			processMapMemRgn->RemoveReference();
+			processMapMemRgn=NULL;
+		}
 	}
-	soundManagerMemRgn->RemoveReference();
+	if(soundManagerMemRgn!=NULL) {
+		soundManagerMemRgn->RemoveReference();
+		soundManagerMemRgn=NULL;
+	}
+	
 	DELETE_ALL_SUBJECT_AND_OBSERVER;
 	cout << objectName << "::DoDestroy()-DONE" << endl;
 	return oSUCCESS;
@@ -282,30 +333,45 @@ return oSUCCESS;
  *  processing the previous message - we only want to do this the first time
  *  otherwise we infinite loop. */
 void
-MMCombo::ReadyRegisterWorldState(const OReadyEvent&){
+MMCombo::ReadyRegisterWorldStatePool(const OReadyEvent&){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 	static bool is_init=true;
 	if(is_init) {
 		is_init=false;
-		cout << objectName << " Registering WorldState" << endl;
+		cout << objectName << " Registering WorldStatePool" << endl;
 		if(strcmp(objectName,"MainObj")==0) {
-			subject[sbjRegisterWorldState]->SetData(worldStateMemRgn);
-			subject[sbjRegisterWorldState]->NotifyObservers();
+			subject[sbjRegisterWorldStatePool]->SetData(worldStatePoolMemRgn);
+			subject[sbjRegisterWorldStatePool]->NotifyObservers();
 		}
 	}
 }
 
 void
-MMCombo::GotWorldState(const ONotifyEvent& event){
-	cout << objectName << "-GOTWORLDSTATE..." << flush;
-	//	PROFSECTION("GotMemRegion()",state->mainProfile);
+MMCombo::GotWorldStatePool(const ONotifyEvent& event){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
+try {
+	cout << objectName << "-GOTWORLDSTATEPOOL..." << flush;
+	//	PROFSECTION("GotMemRegion()",*mainProfiler);
 	if(strcmp(objectName,"MotoObj")==0) {
-		ASSERT(event.NumOfData()==1,"Too many WorldStates");
-		worldStateMemRgn = event.RCData(0);
-		worldStateMemRgn->AddReference();
-		state = reinterpret_cast<WorldState*>(worldStateMemRgn->Base());
+		ASSERT(event.NumOfData()==1,"Too many WorldStatePools");
+		worldStatePoolMemRgn = event.RCData(0);
+		worldStatePoolMemRgn->AddReference();
+		wspool = reinterpret_cast<WorldStatePool*>(worldStatePoolMemRgn->Base());
+		wspool->InitAccess();
+		if(ProcessID::getMapFrame()!=NULL) // must have process map first
+			entryPt.setPool(wspool);
 	}
-  observer[obsReceiveWorldState]->AssertReady();
+	observer[obsReceiveWorldStatePool]->AssertReady();
 	cout << "done" << endl;
+} catch(const std::exception& ex) {
+  observer[obsSensorFrame]->AssertReady();
+	if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during GotWorldStatePool",&ex))
+		throw;
+} catch(...) {
+  observer[obsSensorFrame]->AssertReady();
+	if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during GotWorldStatePool",NULL))
+		throw;
+}
 }
 
 		
@@ -314,6 +380,7 @@ MMCombo::GotWorldState(const ONotifyEvent& event){
  *  otherwise we infinite loop. */
 void
 MMCombo::ReadyRegisterMotionManager(const OReadyEvent&){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 	static bool is_init=true;
 	if(is_init) {
 		is_init=false;
@@ -327,8 +394,9 @@ MMCombo::ReadyRegisterMotionManager(const OReadyEvent&){
 
 void
 MMCombo::GotMotionManager(const ONotifyEvent& event){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 	cout << objectName << "-GOTMOTIONMANAGER..." << flush;
-	//	PROFSECTION("GotMemRegion()",state->mainProfile);
+	//	PROFSECTION("GotMemRegion()",*mainProfiler);
 	if(strcmp(objectName,"MainObj")==0) {
 		ASSERT(event.NumOfData()==1,"Too many MotionManagers");
 		motmanMemRgn = event.RCData(0);
@@ -346,20 +414,53 @@ MMCombo::GotMotionManager(const ONotifyEvent& event){
 
 void
 MMCombo::GotInterProcessEvent(const ONotifyEvent& event){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 	EventBase* evt=NULL;
 try {
 	//cout << objectName << "-GOTInterProcessEvent " << event.NumOfData() << "..." << flush;
 	//cout << TimeET() << endl;
-	//	PROFSECTION("GotMemRegion()",state->mainProfile);
+	//	PROFSECTION("GotMemRegion()",*mainProfiler);
 	if(etrans==NULL)
 		return;
+	static unsigned int lastSensorTime=-1U;
+	static unsigned int lastSensorFrame=-1U;
 	for(int i=0; i<event.NumOfData(); i++) {
 		RCRegion * msg = event.RCData(i);
 		evt=etrans->decodeEvent(msg->Base(),msg->Size());
+		if(evt->getGeneratorID()==EventBase::sensorEGID) {
+			// sensor events are dropped if there's a backlog
+			// so if we get one of these, update the timestamp info
+			if(lastSensorTime==-1U) {
+				addRunLevel();
+				lastSensorTime=0;
+			}
+			if(state->frameNumber==lastSensorFrame) { //already saw this one
+				delete evt;
+				evt=NULL;
+			} else {
+				evt->setTimeStamp(get_time());
+				evt->setDuration(evt->getTimeStamp()-lastSensorTime);
+				lastSensorTime=evt->getTimeStamp();
+				//if(state->frameNumber-lastSensorFrame!=NumFrames && lastSensorFrame!=-1U)
+				//cout << ProcessID::getIDStr() << " dropped " << (state->frameNumber-lastSensorFrame-NumFrames)/NumFrames << " sensor frames" << endl;
+				lastSensorFrame=state->frameNumber;
+			}
+		}
 		if(evt!=NULL)
-			erouter->postEvent(evt);
+			erouter->postEvent(*evt);
+		delete evt;
 	}
-  observer[obsEventTranslatorComm]->AssertReady();
+	if(state->frameNumber>lastSensorFrame && lastSensorTime!=-1U) {
+		// there's new sensor info, but we didn't get the event
+		//(Motion drops event if there's anything else already in the queue, might not have been a sensor event in the queue though)
+		unsigned int t=get_time();
+		erouter->postEvent(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID,t-lastSensorTime,"SensorSouceID::UpdatedSID",1);
+		lastSensorTime=t;
+		//if(state->frameNumber-lastSensorFrame!=NumFrames && lastSensorFrame!=-1U)
+		//cout << ProcessID::getIDStr() << " dropped " << (state->frameNumber-lastSensorFrame-NumFrames)/NumFrames << " sensor frames" << endl;
+		lastSensorFrame=state->frameNumber;
+	}
+	observer[obsEventTranslatorComm]->AssertReady();
 	//cout << "done" << endl;
 
 } catch(const std::exception& ex) {
@@ -380,8 +481,55 @@ try {
 }
 
 		
+void
+MMCombo::ReadyRegisterProfiler(const OReadyEvent&){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
+	static bool is_init=true;
+	if(is_init) {
+		is_init=false;
+		if(strcmp(objectName,"MotoObj")==0) {
+			cout << objectName << " Registering Motion Profiler" << endl;
+			subject[sbjRegisterProfiler]->SetData(motionProfilerMemRgn);
+			subject[sbjRegisterProfiler]->NotifyObservers();
+		}
+	}
+}
+
+void
+MMCombo::GotMotionProfiler(const ONotifyEvent& event){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
+	cout << objectName << "-GOTMOTIONPROFILER..." << flush;
+	//	PROFSECTION("GotMemRegion()",*mainProfiler);
+	if(strcmp(objectName,"MainObj")==0) {
+		ASSERT(event.NumOfData()==1,"Too many Profilers");
+		motionProfilerMemRgn = event.RCData(0);
+		motionProfilerMemRgn->AddReference();
+		motionProfiler = reinterpret_cast<motionProfiler_t*>(motionProfilerMemRgn->Base());
+		addRunLevel();
+	}
+	observer[obsReceiveMotionProfiler]->AssertReady();
+	cout << "done" << endl;
+}
+void
+MMCombo::GotSoundProfiler(const ONotifyEvent& event){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
+	cout << objectName << "-GOTSOUNDPROFILER..." << flush;
+	//	PROFSECTION("GotMemRegion()",*mainProfiler);
+	if(strcmp(objectName,"MainObj")==0) {
+		ASSERT(event.NumOfData()==1,"Too many Profilers");
+		soundProfilerMemRgn = event.RCData(0);
+		soundProfilerMemRgn->AddReference();
+		soundProfiler = reinterpret_cast<soundProfiler_t*>(soundProfilerMemRgn->Base());
+		addRunLevel();
+	}
+	observer[obsReceiveSoundProfiler]->AssertReady();
+	cout << "done" << endl;
+}
+
+
 void
 MMCombo::ReadySendJoints(const OReadyEvent& sysevent) {
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 try {
 
 	if(isStopped) {
@@ -392,15 +540,13 @@ try {
 	static unsigned int id=-1U;
 	Profiler::Timer timer;
 	if(ProcessID::getID()==ProcessID::MotionProcess) {
-		if(state) {
-			if(id==-1U)
-				id=state->motionProfile.getNewID("ReadySendJoints()");
-			timer.setID(id,&state->motionProfile.prof);
-		}
+		if(id==-1U)
+			id=motionProfiler->getNewID("ReadySendJoints()");
+		timer.setID(id,&motionProfiler->prof);
 	}	else if(ProcessID::getID()==ProcessID::MainProcess) {
 		if(id==-1U)
-			id=state->mainProfile.getNewID("ReadySendJoints()");
-		timer.setID(id,&state->mainProfile.prof);
+			id=mainProfiler->getNewID("ReadySendJoints()");
+		timer.setID(id,&mainProfiler->prof);
 	}
 
 	if(num_open==0) //If we don't have any joints to open, leave now. (i.e. MainObj on a 220, has no ears)
@@ -551,6 +697,7 @@ try {
 
 void
 MMCombo::GotSensorFrame(const ONotifyEvent& event){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 try {
 	erouter->processTimers();
 } catch(const std::exception& ex) {
@@ -568,38 +715,86 @@ try {
 		return;
 	}
 
-	PROFSECTION("GotSensorFrame()",state->mainProfile);
-
-  OSensorFrameVectorData* rawsensor = reinterpret_cast<OSensorFrameVectorData*>(event.RCData(0)->Base());
-	state->read(rawsensor[0],erouter);
-	static unsigned int throwaway=1; //i thought the first few sensor updates might be flakey, but now i think not.  But a good way to delay startup.
-	if(throwaway!=0) {
-		throwaway--;
-		if(throwaway==0) {
-			//seed the random number generator with time value and sensor noise
-			if(config->main.seed_rng) {
-				double t=TimeET().Value(); //current time with nanosecond resolution
-				unsigned int * tm=reinterpret_cast<unsigned int*>(&t);
-				unsigned int seed=tm[0]+tm[1];
-				for(unsigned int i=0; i<NumPIDJoints; i++) { //joint positions
-					unsigned int * x=reinterpret_cast<unsigned int*>(&state->outputs[i]);
-					seed+=(*x)<<((i%sizeof(unsigned int))*8);
-				}
-				for(unsigned int i=0; i<NumPIDJoints; i++) { //joint forces
-					unsigned int * x=reinterpret_cast<unsigned int*>(&state->pidduties[i]);
-					seed+=(*x)<<((i%sizeof(unsigned int))*8);
-				}
-				for(unsigned int i=0; i<NumSensors; i++) {
-					unsigned int * x=reinterpret_cast<unsigned int*>(&state->sensors[i]);
-					seed+=(*x)<<((i%sizeof(unsigned int))*8); //sensor values
-				}
-				cout << "RNG seed=" << seed << endl;;
-				srand(seed);
-			}
-			addRunLevel();
-		}
+	static unsigned int id=-1U;
+	Profiler::Timer timer;
+	if(ProcessID::getID()==ProcessID::MotionProcess) {
+		if(id==-1U)
+			id=motionProfiler->getNewID("GotSensorFrame()");
+		timer.setID(id,&motionProfiler->prof);
+	}	else if(ProcessID::getID()==ProcessID::MainProcess) {
+		if(id==-1U)
+			id=mainProfiler->getNewID("GotSensorFrame()");
+		timer.setID(id,&mainProfiler->prof);
 	}
-  observer[obsSensorFrame]->AssertReady();
+	TimeET t;
+
+	OSensorFrameVectorData* rawsensor = reinterpret_cast<OSensorFrameVectorData*>(event.RCData(0)->Base());
+	static unsigned int lastFrameNumber=-1U;
+	static unsigned int throwaway=1; //i thought the first few sensor updates might be flakey, but now i think not.  But a good way to delay startup.
+	bool wasLastThrowAway=false;
+	if(throwaway!=0) {
+		if(--throwaway==0)
+			wasLastThrowAway=true;
+	}
+	//cout << objectName << " got sensors " << rawsensor[0].GetInfo(0)->frameNumber << " at " << t << endl;
+	if(wspool==NULL) {
+		if(wasLastThrowAway)
+			throwaway++; //postpone until wspool comes through
+		observer[obsSensorFrame]->AssertReady();
+		//cout << "burning throwaway, left: " << throwaway << endl;
+		return;
+	}
+	WorldStatePool::UpdateInfo * info=wspool->isUnread(rawsensor[0],lastFrameNumber);
+	if(info==NULL) {
+		//cout << objectName << " done checking sensors " << rawsensor[0].GetInfo(0)->frameNumber << " at " << TimeET() << " (" << (t.Age()*1000) << "ms)" << endl;
+	} else {
+		EntryPoint::WorldStateWrite wsw(info->frameNumber); MarkScope epw(entryPt,wsw);
+		if(state==NULL) {
+			observer[obsSensorFrame]->AssertReady();
+			cout << objectName << " had error updating sensors " << info->frameNumber << endl;
+			return;
+		}
+		//cout << objectName << " writing " << wsw.frame << " state=" << state << "(" << wsw.bufUsed << ") source=" << wsw.src << "("<<wsw.srcRequest.bufUsed<<") status="<<wsw.getStatus() << " complete="<<wsw.getComplete() << endl;
+		if(!wsw.getComplete()) {
+			// could already be complete if both processes were trying to get the write lock at the same time
+			// and the first in filled everything by itself (i.e. no feedback required, or the one with feedback was there first)
+			ASSERT(info->msg==&rawsensor[0],"message changed");
+			ASSERT(wsw.bufUsed==info->intendedBuf,"read() not using expected state buffer");
+			if(erouter!=NULL)
+				state->read(rawsensor[0],wsw.src,erouter);
+			wsw.setComplete(true);
+			//cout << objectName << " fr=" << info->frameNumber << " set status="<<wsw.getStatus() << " complete=" << wsw.getComplete() << endl;
+		}	
+		//if(wsw.frame-lastFrameNumber!=NumFrames)
+		//	cout << objectName << " dropped " << (wsw.frame-lastFrameNumber-NumFrames)/NumFrames << " sensor frame(s)" << endl;
+		lastFrameNumber=wsw.frame;
+		//seed the random number generator with time value and sensor noise
+		if(wasLastThrowAway && config->main.seed_rng) {
+			double tv=TimeET().Value(); //current time with nanosecond resolution
+			unsigned int * tm=reinterpret_cast<unsigned int*>(&tv);
+			unsigned int seed=tm[0]+tm[1];
+			for(unsigned int i=0; i<NumPIDJoints; i++) { //joint positions
+				unsigned int * x=reinterpret_cast<unsigned int*>(&state->outputs[i]);
+				seed+=(*x)<<((i%sizeof(unsigned int))*8);
+			}
+			for(unsigned int i=0; i<NumPIDJoints; i++) { //joint forces
+				unsigned int * x=reinterpret_cast<unsigned int*>(&state->pidduties[i]);
+				seed+=(*x)<<((i%sizeof(unsigned int))*8);
+			}
+			for(unsigned int i=0; i<NumSensors; i++) {
+				unsigned int * x=reinterpret_cast<unsigned int*>(&state->sensors[i]);
+				seed+=(*x)<<((i%sizeof(unsigned int))*8); //sensor values
+			}
+			cout << "RNG seed=" << seed << endl;;
+			srand(seed);
+		}
+		//cout << objectName << " done updating sensors " << info->frameNumber << " at " << TimeET() << " (" << (t.Age()*1000) << "ms)" << endl;
+	}
+	if(info!=NULL) { // notify main of update, but only if there's no backlog
+		etrans->encodeEvent(EventBase(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID,0,"SensorSouceID::UpdatedSID",1),true);
+	}
+		
+	observer[obsSensorFrame]->AssertReady();
 	//	if(state && state->buttons[RFrPawOffset])
 	//	cout << "done" << endl;
 
@@ -616,6 +811,7 @@ try {
 
 void
 MMCombo::GotImage(const ONotifyEvent& event){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 	if(isStopped) {
 		//cout << "BAH!GotImage" << endl;
 		return;
@@ -631,14 +827,14 @@ try {
 		throw;
 }
 try {
-	PROFSECTION("GotImage()",state->mainProfile);
+	PROFSECTION("GotImage()",*mainProfiler);
   
 	WMvari(int, frame_counter, 0);
 	++frame_counter;
 	
-	erouter->postEvent(new DataEvent<const OFbkImageVectorData*>(reinterpret_cast<const OFbkImageVectorData*>(event.Data(0)),EventBase::visOFbkEGID,0,EventBase::activateETID));
-	erouter->postEvent(new DataEvent<const OFbkImageVectorData*>(reinterpret_cast<const OFbkImageVectorData*>(event.Data(0)),EventBase::visOFbkEGID,0,EventBase::statusETID));
-	erouter->postEvent(new DataEvent<const OFbkImageVectorData*>(reinterpret_cast<const OFbkImageVectorData*>(event.Data(0)),EventBase::visOFbkEGID,0,EventBase::deactivateETID));
+	erouter->postEvent(DataEvent<const OFbkImageVectorData*>(reinterpret_cast<const OFbkImageVectorData*>(event.Data(0)),EventBase::visOFbkEGID,0,EventBase::activateETID));
+	erouter->postEvent(DataEvent<const OFbkImageVectorData*>(reinterpret_cast<const OFbkImageVectorData*>(event.Data(0)),EventBase::visOFbkEGID,0,EventBase::statusETID));
+	erouter->postEvent(DataEvent<const OFbkImageVectorData*>(reinterpret_cast<const OFbkImageVectorData*>(event.Data(0)),EventBase::visOFbkEGID,0,EventBase::deactivateETID));
 	
   observer[obsImage]->AssertReady();
 
@@ -664,16 +860,17 @@ try {
 
 void
 MMCombo::GotAudio(const ONotifyEvent& event){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 try {
 	if(isStopped) {
 		//cout << "BAH!GotAudio" << endl;
 		return;
 	}
 
-	PROFSECTION("GotAudio()",state->mainProfile);
+	PROFSECTION("GotAudio()",*mainProfiler);
 
 	for (int i = 0; i < event.NumOfData(); i++) {
-		erouter->postEvent(new DataEvent<const OSoundVectorData*>(reinterpret_cast<const OSoundVectorData*>(event.Data(i)),EventBase::micOSndEGID,0,EventBase::statusETID));
+		erouter->postEvent(DataEvent<const OSoundVectorData*>(reinterpret_cast<const OSoundVectorData*>(event.Data(i)),EventBase::micOSndEGID,0,EventBase::statusETID));
 		try {
 			erouter->processTimers();
 		} catch(const std::exception& ex) {
@@ -700,6 +897,7 @@ try {
 
 void
 MMCombo::GotPowerEvent(void * msg){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 	if(isStopped) {
 		//cout << "BAH!GotPowerEvent" << endl;
 		return;
@@ -716,7 +914,7 @@ try {
 try {
 
 	//	cout << "POWER..."<<flush;
-	PROFSECTION("PowerEvent()",state->mainProfile);
+	PROFSECTION("PowerEvent()",*mainProfiler);
 
 	static bool first=true;
 	if(first) {
@@ -747,6 +945,7 @@ try {
 
 void
 MMCombo::GotMotionMsg(const ONotifyEvent& event){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 	if(isStopped) {
 		//cout << "BAH!GotMotionMsg" << endl;
 		return;
@@ -763,18 +962,63 @@ MMCombo::GotMotionMsg(const ONotifyEvent& event){
 
 void
 MMCombo::GotSoundManager(const ONotifyEvent& event) {
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 	cout << objectName << "-GOTSOUNDMANAGER..." << flush;
-	//	PROFSECTION("GotMemRegion()",state->mainProfile);
+	//	PROFSECTION("GotMemRegion()",*mainProfiler);
 	ASSERT(event.NumOfData()==1,"Too many SoundManagers");
 	soundManagerMemRgn = event.RCData(0);
 	soundManagerMemRgn->AddReference();
 	sndman = reinterpret_cast<SoundManager*>(soundManagerMemRgn->Base());
-  observer[obsReceiveSoundManager]->AssertReady();
+	observer[obsReceiveSoundManager]->AssertReady();
 	sndman->InitAccess(subject[sbjSoundManagerComm]);
-	addRunLevel();
+	if(strcmp(objectName,"MainObj")==0) {
+		addRunLevel();
+	}
 	cout << "done" << endl;
 }
 
+void
+MMCombo::ReadyRegisterProcessMap(const OReadyEvent&){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
+	static bool is_init=true;
+	if(is_init) {
+		is_init=false;
+		cout << objectName << " Registering Process Map" << endl;
+		if(strcmp(objectName,"MainObj")==0) {
+			subject[sbjRegisterProcessMap]->SetData(processMapMemRgn);
+			subject[sbjRegisterProcessMap]->NotifyObservers();
+		}
+	}
+}
+
+void
+MMCombo::GotProcessMap(const ONotifyEvent& event){
+try {
+	cout << objectName << "-GOTPROCESSMAP..." << flush;
+	//	PROFSECTION("GotMemRegion()",*mainProfiler);
+	if(strcmp(objectName,"MotoObj")==0) {
+		ASSERT(event.NumOfData()==1,"Too many ProcessMaps");
+		processMapMemRgn = event.RCData(0);
+		processMapMemRgn->AddReference();
+		ProcessID::setMap(reinterpret_cast<stacktrace::StackFrame*>(processMapMemRgn->Base()));
+		//doesn't handle setting map within entry point, have to do that part first
+		EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
+		if(wspool!=NULL) // if we were waiting on initializing the pool, do so now
+			entryPt.setPool(wspool);
+	}
+	observer[obsReceiveProcessMap]->AssertReady();
+	cout << "done" << endl;
+} catch(const std::exception& ex) {
+  observer[obsSensorFrame]->AssertReady();
+	if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during GotProcessMap",&ex))
+		throw;
+} catch(...) {
+  observer[obsSensorFrame]->AssertReady();
+	if(!ProjectInterface::uncaughtException(__FILE__,__LINE__,"Occurred during GotProcessMap",NULL))
+		throw;
+}
+}
+
 void
 MMCombo::OpenPrimitives()
 {
@@ -894,7 +1138,8 @@ RCRegion*
 MMCombo::InitRegion(unsigned int size) {
 	unsigned int pagesize=4096;
 	sError err=GetPageSize(&pagesize);
-	ASSERT(err==sSUCCESS,"Error "<<err<<" getting page size");
+	if(err!=sSUCCESS)
+		cerr << "Error "<<err<<" getting page size " << pagesize << endl;
 	unsigned int pages=(size+pagesize-1)/pagesize;
 	return new RCRegion(pages*pagesize);
 }
@@ -923,10 +1168,10 @@ MMCombo::addRunLevel() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.20 $
  * $State: Exp $
- * $Date: 2005/08/16 18:27:58 $
+ * $Date: 2006/09/19 20:10:33 $
  */
 
 
