@@ -3,15 +3,20 @@
 #define INCLUDED_MMCombo_h_
 
 #include "Shared/debuget.h"
+#include "Shared/MarkScope.h"
 #include "Shared/RobotInfo.h"
 #include "Wireless/Wireless.h"
-#include "Events/EventTranslator.h"
+#include "IPC/ProcessID.h"
+#include "aperios/EntryPoint.h"
 
 #include <OPENR/OObject.h>
 #include <OPENR/OSubject.h>
 #include <OPENR/OObserver.h>
 #include "aperios/MMCombo/def.h"
 
+class EventTranslator;
+class WorldStatePool;
+
 //! Contains code for both MainObj and MotoObj processes
 /*! Why go to all this trouble?  Virtual functions and polymorphism!  Instead
  *  of writing my own object typing and serialization system, I would rather
@@ -40,11 +45,14 @@ public:
 	virtual OStatus DoStop   (const OSystemEvent&);      //!< next to last call, stop sending and receiving messages
 	virtual OStatus DoDestroy(const OSystemEvent&);      //!< last call (before destructor), clean up memory here
 	
-	void ReadyRegisterWorldState(const OReadyEvent&);    //!< main only, send out the state global
-	void GotWorldState(const ONotifyEvent& event);       //!< motion only, called when state global is received
+	void ReadyRegisterWorldStatePool(const OReadyEvent&);    //!< main only, send out the state global
+	void GotWorldStatePool(const ONotifyEvent& event);       //!< motion only, called when state global is received
 	void ReadyRegisterMotionManager(const OReadyEvent&); //!< motion only, send out motman global
 	void GotMotionManager(const ONotifyEvent& event);    //!< main only, called when motman global is received
 	void GotInterProcessEvent(const ONotifyEvent& event);//!< main only, called when another process sends an event
+	void ReadyRegisterProfiler(const OReadyEvent&); //!< motion only, send out motion's profiler
+	void GotMotionProfiler(const ONotifyEvent& event);    //!< main only, called when Motion's profiler is received
+	void GotSoundProfiler(const ONotifyEvent& event);    //!< main only, called when SoundPlay's profiler is received
 	
 	void ReadySendJoints(const OReadyEvent& event);      //!< motion only (until main does ears again, then both) calls SendJoints, if DoStart has already been called
 	void GotSensorFrame(const ONotifyEvent& event);      //!< main only, called when new sensor information is available
@@ -56,12 +64,15 @@ public:
 	
 	void GotSoundManager(const ONotifyEvent& event);     //!< both, called when the sndman global is received
 
-	void ListenCont (void* msg) { wireless->ListenCont(msg); }  //!< main only, called when //ALTODO
-	void BindCont   (void* msg) { wireless->BindCont(msg); }    //!< main only, called when //ALTODO
-	void ConnectCont(void* msg) { wireless->ConnectCont(msg); } //!< main only, called when //ALTODO
-	void SendCont   (void* msg) { wireless->SendCont(msg); }    //!< main only, called when //ALTODO
-	void ReceiveCont(void* msg) { wireless->ReceiveCont(msg); } //!< main only, called when //ALTODO
-	void CloseCont  (void* msg) { wireless->CloseCont(msg); }   //!< main only, called when //ALTODO
+	void ReadyRegisterProcessMap(const OReadyEvent&);    //!< main only, send out the process map
+	void GotProcessMap(const ONotifyEvent& event);       //!< motion only, called when process map is received	
+	
+	void ListenCont (void* msg) { EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr); wireless->ListenCont(msg); }  //!< main only, called when //ALTODO
+	void BindCont   (void* msg) { EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr); wireless->BindCont(msg); }    //!< main only, called when //ALTODO
+	void ConnectCont(void* msg) { EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr); wireless->ConnectCont(msg); } //!< main only, called when //ALTODO
+	void SendCont   (void* msg) { EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr); wireless->SendCont(msg); }    //!< main only, called when //ALTODO
+	void ReceiveCont(void* msg) { EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr); wireless->ReceiveCont(msg); } //!< main only, called when //ALTODO
+	void CloseCont  (void* msg) { EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr); wireless->CloseCont(msg); }   //!< main only, called when //ALTODO
 
 protected:
 	void OpenPrimitives();                               //!< both, called from SetupOutputs() (mostly for motion, but main does ears), uses #open to tell which to open
@@ -69,8 +80,11 @@ protected:
 	RCRegion* InitRegion(unsigned int size);             //!< both, called to set up a shared memory region of a given size
 
 	RCRegion * motmanMemRgn;     //!< Motion creates, Main receives
-	RCRegion * worldStateMemRgn; //!< Main creates, Motion receives
+	RCRegion * motionProfilerMemRgn; //!< Motion creates, Main receives
+	RCRegion * soundProfilerMemRgn; //!< Sound creates, Main receives
+	RCRegion * worldStatePoolMemRgn; //!< Main creates, Motion receives
 	RCRegion * soundManagerMemRgn; //!< SoundPlay creates, Main & Motion receives
+	RCRegion * processMapMemRgn; //!< Main creates, Motion receives
 
 	OPrimitiveID primIDs[NumOutputs];    //!< both, Main ears only, Motion the rest
 	static const unsigned int NUM_COMMAND_VECTOR=2; //!< both, for double buffering
@@ -79,13 +93,16 @@ protected:
 	float  ledActivation[NumLEDs]; //!< Motion, used for partial LED activation
 
 	unsigned int runLevel;           //!< Main, incremented until all sections are ready
-	static const unsigned int readyLevel=5; //!< Main, runLevel at which StartBehavior is created. (1st power event, 1st sensor event, motman init, sndman init, MainObj::DoStart())
+	static const unsigned int readyLevel=7; //!< Main, runLevel at which StartBehavior is created. (1st power event, 1st sensor event, motman init, motion profiler, sndman init, MainObj::DoStart())
 	void addRunLevel();              //!< Main, checks runLevel and creates StartBehavior when ready
 
 	bool open[NumOutputs];    //!< both, holds information regarding which outputs are open in ("controlled by") this process
 	unsigned int num_open;  //!< both, count of how many are open
 
 	EventTranslator * etrans; //!< both, allows events to be sent between processes (from other processes besides these two too)
+	
+	WorldStatePool * wspool; //!< WorldStatePool allows efficient updating of sensor data, avoids sensor deprivation of other processes if Main process blocks
+	EntryPoint entryPt; //!< should be used with MarkScope to wrap each entry point from the system, handles marking root stack frame and getting current WorldState
 
 	bool isStopped; //!< true if we've received a DoStart and no DoStop - we need this because sometimes an extra message seems to slip in after we've been told to stop, in which case we should ignore it
 
@@ -118,7 +135,6 @@ protected:
 	}
 
 private:
-//	WorldStateSerializer* wstateserializer;
 	MMCombo(const MMCombo&); //!< should never be called...
 	MMCombo& operator=(const MMCombo&); //!< should never be called...
 };
@@ -128,10 +144,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2005/06/29 22:06:33 $
+ * $Date: 2006/08/22 22:23:06 $
  */
 
 #endif
