@@ -23,9 +23,11 @@
 #include "Shared/Config.h"
 #include "Shared/debuget.h"
 #include "Events/EventRouter.h"
+#include "Shared/Profiler.h"
+#include "Shared/MarkScope.h"
 
 SndPlay::SndPlay()
-	: active(0), soundManagerMemRgn(NULL), etrans(NULL), speakerID(oprimitiveID_UNDEF)
+	: active(0), soundManagerMemRgn(NULL), processMapMemRgn(NULL), soundProfilerMemRgn(NULL), etrans(NULL), entryPt(), speakerID(oprimitiveID_UNDEF)
 {
 	for (unsigned int i = 0; i < SOUND_NUM_BUFFER; i++)
 		region[i] = 0;
@@ -43,6 +45,7 @@ SndPlay::DoInit(const OSystemEvent&)
 	REGISTER_ALL_ENTRY;
 	SET_ALL_READY_AND_NOTIFY_ENTRY;
 
+	observer[obsReceiveProcessMap]->SetBufCtrlParam(0,1,1);
 	observer[obsSoundManagerComm]->SetBufCtrlParam(0,1,SoundManager::MAX_SND+1);
 	//+1 to MAX_SND so that we can still get a delete message after we've filled up
 
@@ -54,14 +57,23 @@ SndPlay::DoInit(const OSystemEvent&)
 
 	erouter = new EventRouter;
 	etrans=new IPCEventTranslator(*subject[sbjEventTranslatorComm]);
+	// only expect to be handling audioEGID, but just in case,
+	// subscribe to everything except erouterEGID
+	for(unsigned int i=0; i<EventBase::numEGIDs; i++)
+		if(i!=EventBase::erouterEGID)
+			erouter->addTrapper(etrans,static_cast<EventBase::EventGeneratorID_t>(i));
 
 	//soundManagerMemRgn -> sndman setup
 	soundManagerMemRgn = InitRegion(sizeof(SoundManager));
-	sndman=new ((SoundManager*)soundManagerMemRgn->Base()) SoundManager;
+	sndman=new (soundManagerMemRgn->Base()) SoundManager;
 	sndman->InitAccess(subject[sbjSoundManagerComm]);
 	for(unsigned int i=0; i<config->sound.preload.size(); i++)
-		sndman->LoadFile(config->sound.preload[i]);
-
+		sndman->loadFile(config->sound.preload[i]);
+	
+	//soundProfilerMemRgn -> soundProfiler setup
+	soundProfilerMemRgn = InitRegion(sizeof(soundProfiler_t));
+	soundProfiler=new (soundProfilerMemRgn->Base()) soundProfiler_t;
+	
 	OpenSpeaker();
 	NewSoundVectorData();
 	SetPowerAndVolume();
@@ -71,6 +83,7 @@ SndPlay::DoInit(const OSystemEvent&)
 OStatus
 SndPlay::DoStart(const OSystemEvent&)
 {
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
   //OSYSDEBUG(("SndPlay::DoStart()\n"));
 
 	ENABLE_ALL_SUBJECT;
@@ -81,9 +94,10 @@ SndPlay::DoStart(const OSystemEvent&)
 OStatus
 SndPlay::DoStop(const OSystemEvent&)
 {
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 	//OSYSDEBUG(("SndPlay::DoStop()\n"));
 
-	sndman->StopPlay();
+	sndman->stopPlay();
 
 	DISABLE_ALL_SUBJECT;
 	DEASSERT_READY_TO_ALL_OBSERVER;
@@ -94,11 +108,16 @@ SndPlay::DoStop(const OSystemEvent&)
 OStatus
 SndPlay::DoDestroy(const OSystemEvent&)
 {
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 	for(unsigned int i=0; i<config->sound.preload.size(); i++)
-		sndman->ReleaseFile(config->sound.preload[i]);
+		sndman->releaseFile(config->sound.preload[i]);
 	delete etrans;
 	etrans=NULL;
 	delete erouter;
+	if(processMapMemRgn!=NULL) {
+		processMapMemRgn->RemoveReference();
+		processMapMemRgn=NULL;
+	}
 	DELETE_ALL_SUBJECT_AND_OBSERVER;
 	return oSUCCESS;
 }
@@ -106,12 +125,14 @@ SndPlay::DoDestroy(const OSystemEvent&)
 void
 SndPlay::ReadySendSound(const OReadyEvent&)
 {
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 	//	OSYSDEBUG(("SndPlay::Ready()\n"));
 	doSendSound();
 }
 
 void
 SndPlay::ReadyRegisterSoundManager(const OReadyEvent&) {
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 	static bool is_init=true;
 	if(is_init) {
 		is_init=false;
@@ -121,11 +142,24 @@ SndPlay::ReadyRegisterSoundManager(const OReadyEvent&) {
 	}
 }
 
+void
+SndPlay::ReadyRegisterProfiler(const OReadyEvent&) {
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
+	static bool is_init=true;
+	if(is_init) {
+		is_init=false;
+		cout << objectName << " Registering soundProfiler" << endl;
+		subject[sbjRegisterProfiler]->SetData(soundProfilerMemRgn);
+		subject[sbjRegisterProfiler]->NotifyObservers();
+	}
+}
+
 void
 SndPlay::GotSoundMsg(const ONotifyEvent& event) {
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
 	//	OSYSDEBUG(("SndPlay::GotSoundMsg()\n"));
 	sndman->ReceivedMsg(event);
-	unsigned int curact=sndman->GetNumPlaying();
+	unsigned int curact=sndman->getNumPlaying();
 	//	std::cout << "got-active=" << active << " cur=" << curact << std::endl;
 	if(active==0 && curact>0) {
 		active=curact;
@@ -134,12 +168,26 @@ SndPlay::GotSoundMsg(const ONotifyEvent& event) {
 	observer[obsSoundManagerComm]->AssertReady();
 }
 
+void
+SndPlay::GotProcessMap(const ONotifyEvent& event){
+	EntryPoint::WorldStateRead wsr; MarkScope ep(entryPt,wsr);
+	//cout << objectName << "-GOTPROCESSMAP..." << flush;
+	//	PROFSECTION("GotMemRegion()",soundProfiler);
+	ASSERT(event.NumOfData()==1,"Too many ProcessMaps");
+	processMapMemRgn = event.RCData(0);
+	processMapMemRgn->AddReference();
+	ProcessID::setMap(reinterpret_cast<stacktrace::StackFrame*>(processMapMemRgn->Base()));
+	observer[obsReceiveProcessMap]->AssertReady();
+	//cout << "done" << endl;
+}
+
 void
 SndPlay::doSendSound() {
+	PROFSECTION("doSendSound()",*soundProfiler);
 	//	std::cout << "do-active=" << active << std::endl;
 	static unsigned int bufInUse=0;
 
-	active=sndman->GetNumPlaying();
+	active=sndman->getNumPlaying();
 	if(active==0) { //if we don't have any active channels, don't send a buffer
 		if(bufInUse>0)
 			bufInUse--;
@@ -229,7 +277,8 @@ RCRegion*
 SndPlay::InitRegion(unsigned int size) {
 	unsigned int pagesize=4096;
 	sError err=GetPageSize(&pagesize);
-	ASSERT(err==sSUCCESS,"Error "<<err<<" getting page size");
+	if(err!=sSUCCESS)
+		std::cerr << "Error "<<err<<" getting page size " << pagesize << std::endl;
 	unsigned int pages=(size+pagesize-1)/pagesize;
 	return new RCRegion(pages*pagesize);
 }
@@ -260,9 +309,9 @@ SndPlay::FindFreeRegion()
  * implied warranties of fitness for a particular purpose.
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2005/06/29 22:06:37 $
+ * $Date: 2006/09/18 18:08:02 $
  */
 
