@@ -1,10 +1,11 @@
 #ifndef INCLUDED_SndPlay_h_
 #define INCLUDED_SndPlay_h_
 
+#include "aperios/EntryPoint.h"
 #include <OPENR/OObject.h>
 #include <OPENR/OSubject.h>
 #include <OPENR/OObserver.h>
-#include "aperios/MMCombo/def.h"
+#include "aperios/SndPlay/def.h"
 
 #include "Events/EventTranslator.h"
 
@@ -37,8 +38,10 @@ class SndPlay : public OObject {
 
 	void ReadySendSound(const OReadyEvent& event);            //!< called by system when it's ready for another sound buffer
 	void ReadyRegisterSoundManager(const OReadyEvent& event); //!< called by system when observers are ready to receive the SoundManager
+	void ReadyRegisterProfiler(const OReadyEvent&); //!< send out sound's profiler
 
 	void GotSoundMsg(const ONotifyEvent& event); //!< called by system when SoundManager has sent itself a message on a different process (either to add or remove sounds from memory)
+	void GotProcessMap(const ONotifyEvent& event); //!< called when process map is received from Main
 
 	OSubject*  subject[numOfSubject];   //!< array of subject IDs, used to identify outgoing data
 	OObserver* observer[numOfObserver]; //!< array of observer IDs, used to identify what's ready
@@ -56,7 +59,11 @@ class SndPlay : public OObject {
 	unsigned int active; //!< number of active sound channels - if it's 0, we'll purposely starve system of sound buffers
 
 	RCRegion*      soundManagerMemRgn; //!< SndPlay creates, Main & Motion receive - Shared region used by SoundManager
+	RCRegion*      processMapMemRgn; //!< Main creates, SndPlay receives
+	RCRegion*      soundProfilerMemRgn; //!< Sound creates, Main receives
+	
 	EventTranslator * etrans; //!< will be given all events created by SoundManager to be forwarded to Main
+	EntryPoint entryPt; //!< should be used with MarkScope to wrap each entry point from the system, handles marking root stack frame
 
 	OPrimitiveID   speakerID;  //!< ID returned to system after opening SPEAKER_LOCATOR
 	RCRegion*      region[SOUND_NUM_BUFFER]; //!< holds references to shared regions holding sound clips
@@ -82,10 +89,10 @@ class SndPlay : public OObject {
  * implied warranties of fitness for a particular purpose.
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2005/06/29 22:06:37 $
+ * $Date: 2006/08/22 22:23:06 $
  */
 
 #endif // SndPlay_h_DEFINED
