@@ -12,7 +12,7 @@
 
 #ifdef TK_ENABLE_WIRELESS
 #  include "Wireless/Wireless.h"
-#  include "IPC/Thread.h"
+#  define TK_ENABLE_THREADING
 #endif
 #ifdef TK_ENABLE_SOUTSERR
 #  include "Wireless/Socket.h"
@@ -24,6 +24,10 @@
 #  include "Motion/Kinematics.h"
 #endif
 
+#ifdef TK_ENABLE_THREADING
+#  include "IPC/Thread.h"
+#endif
+
 #define TK_cstr(s) TK_str(s)
 #define TK_str(s) #s
 
@@ -32,6 +36,15 @@ namespace minisim {
 #ifdef TK_ENABLE_WIRELESS
 	class WirelessThread : public Thread {
 	public:
+		//! constructor
+		WirelessThread() : Thread() {}
+		//! destructor -- stop thread
+		virtual ~WirelessThread() {
+			if(isRunning()) {
+				stop();
+				join();
+			}
+		}
 		virtual unsigned int runloop() {
 			// initial setup done by wireless's own constructor
 			wireless->pollTest(NULL); // by passing NULL, we wait indefinitely, so no need to usleep in the Thread code
@@ -39,6 +52,10 @@ namespace minisim {
 			wireless->pollSetup(); // reinitialize for next test
 			return 0; //no sleep time because pollTest blocks
 		}
+		virtual void stop() {
+			Thread::stop();
+			wireless->wakeup();
+		}
 	} wireless_thread;
 #endif
 	
@@ -54,6 +71,9 @@ namespace minisim {
 		erouter=new EventRouter;
 #endif
 		
+#ifdef TK_ENABLE_THREADING
+		Thread::initMainThread();
+#endif
 #ifdef TK_ENABLE_WIRELESS
 		wireless = new Wireless();
 #endif
@@ -119,7 +139,6 @@ namespace minisim {
 	void destruct() {
 #ifdef TK_ENABLE_WIRELESS
 		wireless_thread.stop();
-		wireless->wakeup();
 		wireless_thread.join();
 #endif
 		
@@ -170,10 +189,10 @@ namespace minisim {
  * @author Ethan Tira-Thompson (ejt) (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2005/08/01 23:18:00 $
+ * $Date: 2006/07/13 17:25:50 $
  */
 
 #endif
