@@ -9,7 +9,10 @@
 #include "SharedGlobals.h"
 #include "Motion/MotionManager.h"
 #include "Sound/SoundManager.h"
-#include "Shared/WorldState.h"
+#include "Shared/WorldStatePool.h"
+#include "Shared/Profiler.h"
+#include "local/EntryPoint.h"
+#include <list>
 
 class Motion : public Process {
 public:
@@ -27,19 +30,32 @@ public:
 	
 	static const char * getMotionCommandID() { return "MotionCommands"; }
 	static const char * getMotionManagerID() { return "MotionManager"; }
+	static const char * getMotionProfilerID() { return "MotionProfiler"; }
 
 protected:
 	SharedObject<sim::SoundPlayQueue_t> sounds;
 	SharedObject<sim::MotionCommandQueue_t> motions;
 	SharedObject<sim::EventQueue_t> events;
+	SharedObject<sim::SensorQueue_t> sensorFrames;
+	SharedObject<sim::StatusRequest_t> statusRequest;
 	SharedObject<MotionManager> motionmanager;
 	SharedObject<SoundManager> soundmanager;
-	SharedObject<WorldState> worldstate;
+	SharedObject<WorldStatePool> worldstatepool;
+	SharedObject<sim::MotionWakeup_t> motionWakeup;
+	SharedObject<motionProfiler_t> motionProf;
+	
 	IPCEventTranslator * etrans;
-	class MessageReceiver * mcrecv;
+	class MessageReceiver * sensrecv;
+	class MessageReceiver * statusrecv;
+	class MessageReceiver * wakeuprecv;
+	class MotionExecThread * motionExec;
 	WirelessThread wireless_thread;
 
-	static bool gotMC(RCRegion* msg) { motman->processMsg(msg); return true; }
+	EntryPoint motionLock;
+	
+	static bool gotSensors(RCRegion* msg);
+	static bool gotWakeup(RCRegion* msg);
+	unsigned int lastSensorSN;
 	
 private:
 	Motion(const Motion&); //!< don't call (copy constructor)
@@ -51,10 +67,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2005/06/29 22:06:41 $
+ * $Date: 2006/09/28 20:42:52 $
  */
 
 #endif
