@@ -5,6 +5,8 @@
 #include "IPC/ProcessID.h"
 #include <string>
 
+class RCRegion;
+
 //! Represents a common interface for each process being run
 class Process {
 public:
@@ -16,6 +18,9 @@ public:
 
 	static const std::string& getName() { return name; }
 	static Process * getCurrent() { return current; }
+	
+	virtual void statusReport(std::ostream& os);
+	static bool statusReport(RCRegion* msg);
 
 protected:
 	static std::string name;
@@ -31,10 +36,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2005/06/15 18:54:43 $
+ * $Date: 2006/06/17 01:15:38 $
  */
 
 #endif
