@@ -1,4 +1,5 @@
 #include "SharedGlobals.h"
+#include "Simulator.h"
 
 const char * const SharedGlobals::runlevel_names[SharedGlobals::NUM_RUNLEVELS] = {
 	"CREATED",
@@ -14,6 +15,7 @@ ipc_setup_t * ipc_setup=NULL;
 SharedGlobals * globals=NULL;
 
 unsigned int SharedGlobals::get_time() {
+	float lastLastTimeScale=lastTimeScale; // used to avoid repeated "pause" commands if we're past autoPauseTime
 	if(timeScale<=0) {
 		//just need to update lastTimeScale in case it had been realtime mode
 		//adding an 'if' to test before the assignment is slower than just always doing the assignment
@@ -34,16 +36,31 @@ unsigned int SharedGlobals::get_time() {
 		}
 		//cout << timeOffset << ' ' << lastTimeScale << ' ' << timeScale << endl;
 	}
+	if(simulatorTime>autoPauseTime) {
+		simulatorTime=autoPauseTime;
+		if(ProcessID::getID()==ProcessID::SimulatorProcess) {
+			if(timeScale!=0) // don't reset it if it's already set -- triggers infinite recursion if/when the hook calls get_time
+				timeScale=0;
+		} else {
+			// can't set timeScale directly because Simulator process has hooks registered and we aren't in the Simulator process
+			if(lastLastTimeScale!=0) {
+				lastTimeScale=0;
+				Simulator::sendCommand("pause quiet"); // so do this instead
+			}
+		}
+	}
 	return simulatorTime;
 }
 
+float SharedGlobals::getTimeScale() const { return timeScale; }
+
 /*! @file
  * @brief A class to hold various simulator parameters which need to be accessed from multiple processes
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2005/07/27 17:37:53 $
+ * $Date: 2006/09/28 20:42:52 $
  */
