@@ -13,9 +13,9 @@ class SharedGlobals {
 public:
 	//! constructor
 	SharedGlobals()
-		: simulatorTime(0), timeScale(1), advanceOnAccess(true), lock(),
-		bootTime(), timeOffset(0), lastTimeScale(1), autoPauseTime(-1U),
-		semgr(), running(semgr.getSemaphore())
+		: simulatorTime(0), timeScale(1), motion(), lock(), 
+		nextTimer(-1U), nextMotion(-1U), nextSensorUpdate(-1U), bootTime(), timeOffset(0), lastTimeScale(0), autoPauseTime(-1U),
+			semgr(1), running(semgr.getSemaphore())
 	{
 		for(unsigned int i=0; i<NUM_RUNLEVELS; i++)
 			level_count[i]=0;
@@ -35,7 +35,7 @@ public:
 		semgr.setValue(running,0);
 	}
 	//! test to see if the shutdown flag has been set (non-blocking)
-	bool isShutdown() {
+	bool isShutdown() const {
 		return semgr.testZero(running,false);
 	}
 	//! blocks until shutdown flag has been set
@@ -61,7 +61,12 @@ public:
 	 *  so calls to ::get_time() will be forwarded here.  That wall all processes
 	 *  will share the same time */
 	unsigned int get_time();
-
+	
+	//! returns the current simulator #timeScale (speed factor), as a ratio of real time (e.g. '2' means simulation is running two times wall clock)
+	/*! the simulator should set project_get_time::get_timeScale_callback to call this,
+	 *  so calls to ::getTimeScale() will be forwarded here. */
+	float getTimeScale() const;
+	
 	//! the current time within the simulation, only applicable when #isRealTime is false
 	unsigned int simulatorTime;
 	
@@ -79,29 +84,10 @@ public:
 	 *  A value of zero halts time. */
 	plist::Primitive<double> timeScale;
 
-	//! If true, and #timeScale is negative, simulator will automatically advance simulatorTime after each data update is processed, allowing full-speed processing
-	/*! This functionality is actually achieved by having the receiver mark the
-	 *  message read when it is ready for another message.  If #advanceOnAccess is
-	 *  false, the receiver will not automatically mark the message read when it
-	 *  is accessed, and you will have to make a manual call within your code to
-	 *  signal completion.  For example, typically you will be doing this from
-	 *  Main process, which would look like this:
-	 *
-	 *  @code
-	 *  #include "local/sim/Main.h"
-	 *  
-	 *  Main::advanceVision(); //only legal if your code is
-	 *  Main::advanceSensor(); // actually running in Main!
-	 *  @endcode
-	 *
-	 *  This flag applies to both sensors and vision, but ignored when in realtime
-	 *  mode (0 or positive #timeScale, or loading from a realtime source, such as
-	 *  live telemetry)
-	 */
-	plist::Primitive<bool> advanceOnAccess;
-
 	//! sets #autoPauseTime
 	void setAutoPauseTime(unsigned int t) { autoPauseTime=t; }
+	//! returns #autoPauseTime
+	unsigned int getAutoPauseTime() const { return autoPauseTime; }
 	
 	//@}
 
@@ -130,6 +116,31 @@ public:
 
 	//@}
 
+
+	//       **********************
+	//!@name Configuration Parameters
+	//       **********************
+
+	//! holds configuration parameters for the motion process
+	class MotionSimConfig : public plist::Dictionary {
+	public:
+		MotionSimConfig() : Dictionary(), verbose(false), feedbackDelay(0), zeroPIDFeedback(false), /*speedLimit(0),*/ override(false), frameNumber(-1U) {
+			addEntry("Verbose",verbose,"Report whenever motion commands are being processed or joints are updated");
+			addEntry("FeedbackDelay",feedbackDelay,"Delay (in milliseconds) to apply to motion output before feeding back to sensor values (simulates (very roughly) inertia and system response time); 0 indicates instantaneous/perfect joint control, negative values indicate no feedback (only sensor data sets joint positions)");
+			addEntry("ZeroPIDFeedback",zeroPIDFeedback,"When set to false, if PIDs are set to zero, then sensor values are used to set joint positions; otherwise joint position sensors would only be used if FeedbackDelay is negative");
+			//addEntry("EnforceSpeedLimit",speedLimit,"The simulated motion of joints is limited to this factor of model's recommended speed limits.  0 (or negative) disables speed limit altogether.");
+			addEntry("OverrideSensors",override,"Allows motion feedback to override position values from sensor data loaded from disk.\nIf false, feedback is only provided when no other sensor data is being provided");
+		}
+		plist::Primitive<bool> verbose; //!< Report whenever motion commands are being processed or joints are updated
+		plist::Primitive<int> feedbackDelay; //!< Delay (in milliseconds) to apply to motion output before feeding back to sensor values (simulates (very roughly) inertia and system response time); 0 indicates instantaneous/perfect joint control, negative values indicate no feedback (only sensor data sets joint positions)
+		plist::Primitive<bool> zeroPIDFeedback; //!< When set to false, if PIDs are set to zero, then sensor values are used to set joint positions; otherwise joint position sensors would only be used if FeedbackDelay is negative
+		//plist::Primitive<float> speedLimit; //!< The simulated motion of joints is limited to this factor of model's recommended speed limits.  0 (or negative) disables speed limit altogether.
+		plist::Primitive<bool> override; //!< Allows motion feedback to override position values from sensor data loaded from disk; if false, feedback is only provided when no other sensor data is being provided
+		unsigned int frameNumber; //!< a monotonically increasing count of the number of sensor frames which have been "completed".  Needed to allow coordination between sensor loading from disk and feedback from motion.  Count is increased by the simulator process, which will send a heartbeat message over Simulator::sensorQueue when it does so.
+	} motion;
+	
+	//@}
+	
 	//! allows mutually exclusive access to the fields of SharedObject
 	MutexLock<ProcessID::NumProcesses> lock;
 
@@ -142,12 +153,30 @@ public:
 	//! each process should set a string version of its name for user feedback
 	char processNames[ProcessID::NumProcesses][MAX_PROCESS_NAME_LEN];
 	
+	bool setNextTimer(unsigned int t) { if(nextTimer==t) return false; nextTimer=t; return true; } //!< sets #nextTimer, returns true if the new value differs from previous value
+	unsigned int getNextTimer() { return nextTimer; } //!< gets #nextTimer
+	
+	void setNextMotion(unsigned int t) { nextMotion=t; } //!< sets #nextMotion
+	unsigned int getNextMotion() { return nextMotion; } //!< gets #nextMotion
+	
+	void setNextSensorUpdate(unsigned int t) { nextSensorUpdate=t; } //!< sets #nextSensorUpdate
+	unsigned int getNextSensorUpdate() { return nextSensorUpdate; } //!< gets #nextSensorUpdate
+	
 protected:
 	//! this returns time since boot (#bootTime), scaled by @a scale, relative to #timeOffset
 	unsigned int get_real_time(double scale) const {
 		return static_cast<unsigned int>(bootTime.Age().Value()*scale*1000-timeOffset);
 	}
 
+	//! set by setNextTimer, called with the current value of EventRouter::getNextTimer() after each user code section, indicates time of next timer event
+	unsigned int nextTimer;
+	
+	//! updated by Motion process after each motion update
+	unsigned int nextMotion;
+	
+	//! updated by Main process after each sensor update
+	unsigned int nextSensorUpdate;
+	
 	//! real time since simulator startup (or, at least, since SharedGlobals was constructed... close enough)
 	TimeET bootTime; 
 
@@ -174,16 +203,17 @@ typedef RegionRegistry<MAX_SUBJECTS,MAX_SUBJECT_NAME> ipc_setup_t;
 
 extern ipc_setup_t * ipc_setup; //!< a global pointer to the inter-process message queue registry (a RegionRegistry)
 extern SharedGlobals * globals; //!< a global pointer to the SharedGlobals instance
+extern float getTimeScale(); //!< a prototype for accessing current time scale without referencing ::globals directly
 
 /*! @file
  * @brief A class to hold various simulator parameters which need to be accessed from multiple processes
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.25 $
  * $State: Exp $
- * $Date: 2005/07/28 18:22:26 $
+ * $Date: 2006/09/28 20:42:52 $
  */
 
 #endif
