@@ -1,4 +1,5 @@
 #include "SoundPlay.h"
+#include "Simulator.h"
 #include "SharedGlobals.h"
 #include "Main.h"
 #include "IPC/RegionRegistry.h"
@@ -9,12 +10,16 @@ SoundPlay::SoundPlay()
 	: Process(getID(),getClassName()),
 		requests(ipc_setup->registerRegion(getSoundPlayID(),sizeof(sim::SoundPlayQueue_t))),
 		events(ipc_setup->registerRegion(Main::getEventsID(),sizeof(sim::EventQueue_t))),
+		statusRequest(ipc_setup->registerRegion(Simulator::getStatusRequestID(),sizeof(sim::StatusRequest_t))),
 		soundmanager(ipc_setup->registerRegion(getSoundManagerID(),sizeof(SoundManager))),
-		etrans(NULL), sndrecv(NULL)
+		soundProf(ipc_setup->registerRegion(getSoundProfilerID(),sizeof(soundProfiler_t))),
+		etrans(NULL), sndrecv(NULL), statusrecv(NULL)
 {
 	new (&(*requests)) sim::SoundPlayQueue_t;
-	new (&(*soundmanager)) SoundManager();
+	new (&(*soundmanager)) SoundManager;
+	new (&(*soundProfiler)) soundProfiler_t;
 	sndman=&(*soundmanager);
+	::soundProfiler=&(*soundProf);
 
 	//need to register any events which we might be sending
 	EventTranslator::registerPrototype<EventBase>(); //Sound only sends the basic event type
@@ -40,13 +45,19 @@ void SoundPlay::DoStart() {
 			erouter->addTrapper(etrans,static_cast<EventBase::EventGeneratorID_t>(i));
 	
 	sndrecv=new MessageReceiver(*requests,gotSnd);
+	statusrecv=new MessageReceiver(*statusRequest,statusReport);
 }
 
 void SoundPlay::DoStop() {
 	sndrecv->finish();
+	statusrecv->finish();
+
 	delete sndrecv;
 	sndrecv=NULL;
-	sndman->StopPlay();
+	delete statusrecv;
+	statusrecv=NULL;
+	
+	sndman->stopPlay();
 	erouter->removeTrapper(etrans);
 	Process::DoStop();
 }
@@ -57,9 +68,9 @@ void SoundPlay::DoStop() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2005/06/29 22:06:41 $
+ * $Date: 2006/09/18 18:07:58 $
  */
 
