@@ -8,6 +8,7 @@
 #include "IPC/SharedObject.h"
 #include "SharedGlobals.h"
 #include "Sound/SoundManager.h"
+#include "Shared/Profiler.h"
 
 class SoundPlay : public Process {
 public:
@@ -24,13 +25,18 @@ public:
 	
 	static const char * getSoundPlayID() { return "Sounds"; }
 	static const char * getSoundManagerID() { return "SoundManager"; }
+	static const char * getSoundProfilerID() { return "SoundProfiler"; }
 
 protected:
 	SharedObject<sim::SoundPlayQueue_t> requests;
 	SharedObject<sim::EventQueue_t> events;
+	SharedObject<sim::StatusRequest_t> statusRequest;
 	SharedObject<SoundManager> soundmanager;
+	SharedObject<soundProfiler_t> soundProf;
+	
 	IPCEventTranslator * etrans;
 	class MessageReceiver * sndrecv;
+	class MessageReceiver * statusrecv;
 	static bool gotSnd(RCRegion* msg) { sndman->ProcessMsg(msg); return true; }
 	
 private:
@@ -43,10 +49,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2005/06/29 22:06:41 $
+ * $Date: 2006/07/13 17:25:51 $
  */
 
 #endif
