@@ -8,6 +8,7 @@
 #include "IPC/SharedObject.h"
 #include "IPC/Thread.h"
 #include "Wireless/Wireless.h"
+#include "Shared/ProjectInterface.h"
 #include <vector>
 class SimConfig;
 
@@ -23,6 +24,10 @@ public:
 	typedef MessageQueue<50> SoundPlayQueue_t;
 	typedef MessageQueue<1> CameraQueue_t;
 	typedef MessageQueue<1> SensorQueue_t;
+	typedef MessageQueue<1> TimerWakeup_t;
+	typedef MessageQueue<1> MotionWakeup_t;
+	typedef MessageQueue<ProcessID::NumProcesses+1> StatusRequest_t;
+	typedef MessageQueue<1> MotionOutput_t;
 	
 	static SimConfig config;
 	static std::vector<std::string> assignments;
@@ -34,6 +39,7 @@ protected:
 	template<class T> bool fork_process();
 
 	static unsigned int sim_get_time() { return globals?globals->get_time():0; }
+	static float sim_getTimeScale() { return globals?globals->getTimeScale():0; }
 	
 	static void handle_signal(int sig);
 	static void handle_exit();
@@ -43,10 +49,20 @@ protected:
 	SharedObject<ipc_setup_t> subj;
 	static bool original;
 	static const char * const usage;
+	pid_t child;
 };
 
 class WirelessThread : public Thread {
 public:
+	//! constructor
+	WirelessThread() : Thread() {}
+	//! destructor -- stop thread
+	virtual ~WirelessThread() {
+		if(isRunning()) {
+			stop();
+			join();
+		}
+	}
 	virtual unsigned int runloop() {
 		// initial setup done by wireless's own constructor
 		wireless->pollTest(NULL); // by passing NULL, we wait indefinitely, so no need to usleep in the Thread code
@@ -54,6 +70,10 @@ public:
 		wireless->pollSetup(); // reinitialize for next test
 		return 0; //no sleep time because pollTest blocks
 	}
+	virtual void stop() {
+		Thread::stop();
+		wireless->wakeup();
+	}
 };
 
 
@@ -62,10 +82,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2005/08/01 23:18:00 $
+ * $Date: 2006/10/03 23:11:37 $
  */
 
 #endif
