@@ -81,7 +81,7 @@ void StartupBehavior::DoStart() {
 	wireless->setReceiver(sout, Controller::console_callback);
 	spawned.push_back(controller);
 	
-	sndman->PlayFile("roar.wav");
+	sndman->playFile("roar.wav");
 
 	//This will close the mouth so it doesn't look stupid or get in the
 	//way of head motions (ERS-210 or ERS-7 only)
@@ -105,6 +105,14 @@ void StartupBehavior::DoStart() {
 	for(unsigned int i=0; i<spawnedMC.size(); i++)
 		erouter->addListener(this,EventBase::motmanEGID,spawnedMC[i],EventBase::deactivateETID);
 	
+#ifdef PLATFORM_APERIOS
+	sout->printf("Remember, telnet to port 10001 for text entry (port 59000 is read only)\n");
+#else
+	sout->printf("All console output will be redirected to this terminal.\n");
+	sout->printf("Alternatively, telnet to port 10001 to isolate data from sout as a separate stream.\n");
+	sout->printf("If a prompt does not appear below, hit 'enter' or 'return' to refresh it.\n");
+#endif
+	
 	//if you didn't want to start off paused, you should throw an
 	//un-estop event.  This will make it clear to any background
 	//behaviors (namely WorldStateVelDaemon) that we're not in estop
@@ -196,7 +204,9 @@ StartupBehavior::SetupMenus() {
 		startSubMenu();
 		{ 
 			addItem(new ShutdownControl());
+#ifdef PLATFORM_APERIOS
 			addItem(new RebootControl());
+#endif
 		}
 		endSubMenu();
 		addItem(new HelpControl(root,2));
