@@ -22,7 +22,7 @@ StartupBehavior::SetupFileAccess() {
 		addItem(new PlaySoundControl("Play Sound"));
 		addItem(new WaypointWalkControl());
 		SetupWalkEdit();
-		addItem(new DumpFileControl("Files","/ms"));
+		addItem(new DumpFileControl("Files",config->portPath("")));
 	}
 	return endSubMenu();
 }
