@@ -32,7 +32,9 @@ StartupBehavior::SetupTekkotsuMon() {
 		addItem((new BehaviorSwitchControl<WMMonitorBehavior>("Watchable Memory Monitor",false))->start());
 		addItem((new BehaviorSwitchControl<StewartPlatformBehavior>("Stewart Platform",false)));
 		addItem((new BehaviorSwitchControl<Aibo3DControllerBehavior>("Aibo 3D",false)));
-		addItem((new BehaviorSwitchControl<WorldStateSerializerBehavior>("World State Serializer",false)));
+		BehaviorSwitchControlBase * wss=NULL;
+		addItem((wss=new BehaviorSwitchControl<WorldStateSerializerBehavior>("World State Serializer",false)));
+		Aibo3DControllerBehavior::setSerializerControl(wss);
 		addItem((new BehaviorSwitchControl<RawCamBehavior>("Raw Cam Server",false)));
 		addItem((new BehaviorSwitchControl<SegCamBehavior>("Seg Cam Server",false)));
 		addItem((new BehaviorSwitchControl<RegionCamBehavior>("Region Cam Server",false)));
