@@ -9,10 +9,10 @@
  * @author PA Gov. School for the Sciences 2003 Team Project - Motion group: Haoqian Chen, Yantian Martin, Jon Stahlman (creators)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_4_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-3_0 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/05/14 07:18:19 $
+ * $Date: 2005/09/22 21:54:17 $
  */
 
 #include "StartupBehavior.h"
@@ -32,8 +32,10 @@ StartupBehavior::SetupWalkEdit() {
 	addItem(new ControlBase("Walk Edit","Edit the walk parameters"));
 	startSubMenu();
 	{ 
+		//Use this instance of the GUI to try out changes you have made to parameters within this editor
+		//(the one in TekkotsuMon will load fresh parameters from walk.prm on disk and won't know about changes made here)
 		WalkControllerBehavior * walker = new WalkControllerBehavior();
-		addItem((new BehaviorSwitchControlBase(walker)));
+		addItem((new BehaviorSwitchControlBase("Walk GUI: test changes",walker)));
 
 		addItem(new ValueEditControl<float>("Slow Motion",walker->getWalkMC()->getSlowMo()));
 
