@@ -37,9 +37,9 @@ public:
 	{}
 
 protected:
-  //! constructor for subclasses (which would need to provide a different class name)
-  CLASSNAME(const std::string &class_name, const std::string &node_name)
-    : StateNode(class_name,node_name)
+	//! constructor for subclasses (which would need to provide a different class name)
+	CLASSNAME(const std::string &class_name, const std::string &node_name)
+		: StateNode(class_name,node_name)
 	{}
 	
 	
@@ -58,7 +58,7 @@ public:
 		// it when deemed appropriate
 	}
 
-	virtual void processEvent(const EventBase& /*e*/) {
+	virtual void processEvent(const EventBase& /*event*/) {
 		// <your event processing code here>
 		// you can delete this function if you don't use any events...
 	}
