@@ -54,7 +54,7 @@ public:
 		// StateNode do it when a transition (perhaps this one) fires
 	}
 
-	virtual void processEvent(const EventBase& /*e*/) {
+	virtual void processEvent(const EventBase& /*event*/) {
 		// <your event processing code here>
 		// Call fire() (a method of the Transition base class) whenever the
 		// environment satisifies whatever condition this Transition is supposed to
