@@ -174,7 +174,7 @@ int main(unsigned int argc, const char** argv) {
 			load_cmpack_mot(argv[i],ms);
 			if(compress)
 				ms.compress();
-			ms.SaveFile(path.c_str());
+			ms.saveFile(path.c_str());
 		}
 		used=argc;
 	} else if(argc-used==2) {
@@ -186,7 +186,7 @@ int main(unsigned int argc, const char** argv) {
 		load_cmpack_mot(argv[used],ms);
 		if(compress)
 			ms.compress();
-		ms.SaveFile(argv[used+1]);
+		ms.saveFile(argv[used+1]);
 		used=argc;
 	} else
 		return usage(argc,argv);
