@@ -12,9 +12,9 @@ int main(int argc, const char** argv) {
 	regex_t sysmsg, instbegin, inststat, ignorebegin, warnstat, inclbegin, inclstat;
 	
 	string OPENR="^";
-	if(argc>1)
+	if(argc>1) {
 		OPENR+=argv[1];
-	else {
+	} else {
 		char* OPENRSDK_ROOT=getenv("OPENRSDK_ROOT");
 		OPENR+=(OPENRSDK_ROOT!=NULL)?OPENRSDK_ROOT:"/usr/local/OPEN_R_SDK/";
 	}
@@ -32,8 +32,9 @@ int main(int argc, const char** argv) {
 	regcomp(&sysmsg,OPENR.c_str(),REG_EXTENDED|REG_NOSUB);
 	regcomp(&instbegin,instbeginstr.c_str(),REG_EXTENDED|REG_NOSUB);
 	regcomp(&inststat,inststatstr.c_str(),REG_EXTENDED|REG_NOSUB);
-	string pliststr_no_vdtor=".*plist.h:[0-9]*: warning: base class";
-	regcomp(&ignorebegin,(OPENR+".*: warning: |"+pliststr_no_vdtor).c_str(),REG_EXTENDED|REG_NOSUB);
+	string pliststr_no_vdtor=".*/plist[a-zA-Z]*\\.h:[0-9]*: warning: base ";
+	string dualcoding_no_vdtor=".*DualCoding/ShapeFuns\\.h:[0-9]*: warning: base ";
+	regcomp(&ignorebegin,(OPENR+".*: warning: |"+pliststr_no_vdtor+"|"+dualcoding_no_vdtor).c_str(),REG_EXTENDED|REG_NOSUB);
 	regcomp(&warnstat,"^   ",REG_EXTENDED|REG_NOSUB);
 
 	string file, instant;
