@@ -139,6 +139,10 @@ public class ControllerListener extends TCPListener {
 			sin=socket.getInputStream();
 			_out=new PrintStream(socket.getOutputStream());
 			fireConnected();
+			if(listener!=null) {
+				listener.gotConnection();
+				//listener.repaint();
+			}
 			_out.println("!hello");
 			_out.println("!dump_stack");
 			_out.println("!refresh");
@@ -201,7 +205,7 @@ public class ControllerListener extends TCPListener {
 							_titles.add(readLine(sin));
 						if(!_isConnected) break;
 					} else if(msgtype.equals("goodbye")) {
-						//removeDynObjs();
+						//closeDynObjs();
 						System.out.println("Remote is shutting down.");
 					} else if(msgtype.equals("reset")) {
 						_menus.clear();
@@ -244,20 +248,22 @@ public class ControllerListener extends TCPListener {
 							if(dynObjSrcs.get(name)==null) { //check the GUI didn't already assign a src (for VisionGUI)
 								//find out who launched this (not infallable - dynamic controls launching windows may not have stable launch points...)
 								int minsel=-1;
-								Vector menuitems=(Vector)_menus.get(_menus.size()-2);
-								for(int i=0; i<menuitems.size(); i++)
-									if(((ControllerListener.MenuEntry)menuitems.get(i)).selected) {
-										minsel=i;
-										break;
-									}
-								String title=((ControllerListener.MenuEntry)((Vector)_menus.get(_menus.size()-2)).get(minsel)).title;
-								Vector path=buildSelectionPath();
-								String cmd=new String();
-								for(int i=1; i<path.size()-1; i++)
-									cmd=cmd+"\""+path.get(i)+"\" ";
-								cmd=cmd+"\""+title+"\"";
-								System.out.println("Launched by: "+cmd);
-								dynObjSrcs.put(name,cmd);
+								if(_menus.size()>1) {
+									Vector menuitems=(Vector)_menus.get(_menus.size()-2);
+									for(int i=0; i<menuitems.size(); i++)
+										if(((ControllerListener.MenuEntry)menuitems.get(i)).selected) {
+											minsel=i;
+											break;
+										}
+											String title=((ControllerListener.MenuEntry)((Vector)_menus.get(_menus.size()-2)).get(minsel)).title;
+									Vector path=buildSelectionPath();
+									String cmd=new String();
+									for(int i=1; i<path.size()-1; i++)
+										cmd=cmd+"\""+path.get(i)+"\" ";
+									cmd=cmd+"\""+title+"\"";
+									System.out.println("Launched by: "+cmd);
+									dynObjSrcs.put(name,cmd);
+								}
 							}
 						}
 					} else if(msgtype.equals("close")) {
@@ -279,11 +285,13 @@ public class ControllerListener extends TCPListener {
 						System.err.println("ControllerListener - Invalid message type:"+msgtype);
 					}
 					_updatedFlag=true;
-					if(listener!=null)
-						listener.repaint();
-					else
-						System.out.println("null listener");
-				}
+				} //end of synchronized update section
+				if(listener!=null) {
+					//System.out.println("Listener repaint");
+					//listener.repaint();
+					listener.updated();
+				} else
+					System.out.println("null listener");
 			}
 		} catch (SocketException e) {
 		} catch (Exception e) {
@@ -302,7 +310,7 @@ public class ControllerListener extends TCPListener {
 		_status="Reconnecting.";
 		if(listener!=null) {
 			listener.lostConnection();
-			listener.repaint();
+			//listener.repaint();
 		}
 		//The sleep is to get around the socket still listening after being closed thing
 		//if(!destroy)
@@ -323,7 +331,20 @@ public class ControllerListener extends TCPListener {
 		dynObjPorts.clear();
 		dynObjSrcs.clear();
 	}
- 
+	
+	public void closeDynObjs() {
+		Iterator it=dynObjs.values().iterator();
+		while(it.hasNext()) {
+			Object obj=it.next();
+			try {
+				Method m=obj.getClass().getMethod("close",(java.lang.Class[])null);
+				m.invoke(obj,(java.lang.Object[])null);
+			} catch(Exception ex) {}
+		}
+		dynObjs.clear();
+		dynObjPorts.clear();
+	}
+	
 	public boolean hasData() {
 		return _updatedFlag;
 	}
