@@ -2,6 +2,7 @@ package org.tekkotsu.mon;
 
 import java.awt.event.*;
 import javax.swing.*;
+import javax.swing.filechooser.FileFilter;
 import java.lang.String;
 import java.util.LinkedList;
 import java.awt.*;
@@ -11,6 +12,7 @@ import java.awt.image.IndexColorModel;
 import java.util.Date;
 import java.io.PrintWriter;
 import java.io.FileOutputStream;
+import java.io.FileWriter;
 import java.util.prefs.Preferences;
 import java.io.File;
 
@@ -29,6 +31,7 @@ public class VisionGUI extends JFrame implements ActionListener, VisionUpdatedLi
 	boolean isRLE=false;
 	boolean connected=false;
 	boolean isFreezeFrame=false;
+	JRadioButton rgbMode,yuvMode;
 	final static ImageIcon carrows = new ImageIcon("images/chasingarrows.png");
 	ImageSequenceWriterThread imgWrite=null;
 	String state="Connecting...";
@@ -64,58 +67,130 @@ public class VisionGUI extends JFrame implements ActionListener, VisionUpdatedLi
 						ans+="Free="+imgWrite.imgBufs.size();
 				} else
 					ans="Writing";
-				ans+=" Queue="+imgWrite.q.size();
+				ans+=" Queue="+imgWrite.q.size()/4;
 				return ans;
 			} else
 				return "";
 		}
 		public String fpsReport() {
-				if(connected) {
+				if(connected && gui.mspf>.001) {
 					int rnd=(int)(10000/gui.mspf);
 					return rnd/10.0f+" fps";
 				} else
 					return "";
 		}
 	}
+
+	public class SaveSequenceDialog extends JDialog implements ActionListener {
+		JFileChooser dia;
+		boolean success;
+		JCheckBox positionsBut;
+		JButton saveBut;
+		JButton cancelBut;
+		VisionGUI gui;
+		SaveSequenceDialog(VisionGUI vg, File curpath) {
+			super(vg,"Save Image Sequence...");
+			gui=vg;
+			{
+				Box tmp=Box.createVerticalBox();
+				dia=new JFileChooser(curpath);
+				//dia.setControlButtonsAreShown(false);
+				dia.setApproveButtonText("Save Here");
+				dia.setDialogType(JFileChooser.SAVE_DIALOG);
+				dia.addActionListener(this);
+				tmp.add(dia);
+				{
+					Box tmp2=Box.createHorizontalBox();
+					tmp2.add(Box.createHorizontalStrut(10));
+					positionsBut=new JCheckBox("Save joint positions as well",!VisionGUI.prefs.get("save_positions","0").equals("0"));
+					positionsBut.addActionListener(this);
+					tmp2.add(positionsBut);
+					tmp2.add(Box.createHorizontalGlue());
+					tmp.add(tmp2);
+				}
+				/*
+				tmp.add(Box.createVerticalStrut(5));
+				{
+					Box tmp2=Box.createHorizontalBox();
+					tmp2.add(Box.createHorizontalGlue());
+					saveBut=new JButton("Save Here");
+					saveBut.addActionListener(this);
+					tmp2.add(saveBut);
+					tmp2.add(Box.createHorizontalStrut(5));
+					cancelBut=new JButton("Cancel");
+					cancelBut.addActionListener(this);
+					tmp2.add(cancelBut);
+					tmp2.add(Box.createHorizontalStrut(10));
+					tmp.add(tmp2);
+					}*/
+				tmp.add(Box.createVerticalStrut(10));
+				getContentPane().add(tmp,BorderLayout.CENTER);
+				getRootPane().setDefaultButton(saveBut);
+			}
+			pack();
+			success=false;
+		}
+		public void actionPerformed(ActionEvent e) {
+			/*if(e.getSource()==saveBut) {
+				success=true;
+				dia.approveSelection();
+				dispose();
+			} else if(e.getActionCommand().equals("Cancel")) {
+				dia.cancelSelection();
+				dispose();
+				} else */
+			if(e.getSource()==positionsBut) {
+				VisionGUI.prefs.put("save_positions",positionsBut.isSelected()?"1":"0");
+			} else if(e.getSource()==dia) {
+				if(e.getActionCommand().equals("ApproveSelection")) {
+					boolean isRGB=gui.vision.getConvertRGB(); 
+					boolean haveJPEGs=gui.vision.getListener().hasRawJPEG();
+					String name=dia.getSelectedFile().getName();
+					boolean hasExtension=name.lastIndexOf(".")!=-1;
+					boolean toJPEG=name.endsWith(".jpeg") || name.endsWith(".jpg");
+					if(!toJPEG && haveJPEGs) {
+						if(hasExtension) {
+							int n=JOptionPane.showConfirmDialog(this,"The original data stream consists of JPEG images, are you sure you\nwant to save in a different format?","Convert formats?",JOptionPane.OK_CANCEL_OPTION);
+							if(n!=JOptionPane.OK_OPTION)
+								return;
+						} else {
+							//silently default to JPEG if left unspecified
+							dia.setSelectedFile(new File(dia.getSelectedFile().getPath()+".jpg"));
+							hasExtension=toJPEG=true;
+						}
+					}
+					if(toJPEG) {
+						if(!isRGB) {
+							int n=JOptionPane.showConfirmDialog(this,"JPEGs store YUV data internally, so it is recommended to save JPEGs as\n\"RGB\" images so the YUV data can be extracted directly from the\ninternal storage, avoiding color space conversions.\n\nDo you want to switch to \"RGB\" mode? (recommended)\n","Save 'RGB' jpeg?",JOptionPane.YES_NO_CANCEL_OPTION);
+							if(n==JOptionPane.YES_OPTION)
+								gui.rgbMode.doClick();
+							if(n==JOptionPane.CANCEL_OPTION)
+								return;
+						}
+					}
+					success=true;
+					dispose();
+				} else if(e.getActionCommand().equals("CancelSelection")) {
+					dispose();
+				}
+			}
+		}
+		public File getCurrentDirectory() { return dia.getCurrentDirectory(); }
+		public File getSelectedFile() { return dia.getSelectedFile(); }
+	}
 	
 	public static void main(String s[]) {
 		int port=-1;
 		if(s.length<2)
-			usage();
-		String[] args=new String[1];
-		if(s[1].toUpperCase().compareTo("RLE")==0) {
-			args[0]=s[1];
-			port=VisionListener.defRLEPort;
-		} else if(s[1].toUpperCase().compareTo("RAW")==0) {
-			args[0]=s[1];
-			port=VisionListener.defRawPort;
-		} else {
-			port=Integer.parseInt(s[1]);
-		}
-		if(s.length>2) {
-			args[0]=s[2];
-			if(s[2].toUpperCase().compareTo("RLE")==0)
-				port=VisionListener.defRLEPort;
-			else if(s[2].toUpperCase().compareTo("RAW")==0)
-				port=VisionListener.defRawPort;
-		}
-		VisionGUI gui;
-		if(args[0].length()==0)
-			gui=new VisionGUI(s[0],port,new String[0]);
-		else
-			gui=new VisionGUI(s[0],port,args);
+			VisionPanel.usage();
+		String[] args=new String[s.length-1];
+		for(int i=0; i<args.length; i++)
+			args[i]=s[i+1];
+		VisionGUI gui=new VisionGUI(s[0],args);
 		gui.addWindowListener(new WindowAdapter() {
 				public void windowClosing(WindowEvent e) { System.exit(0); } });
 	}
-		
-	public static void usage() {
-		System.out.println("Usage: java VisionGUI host [port|raw|rle]");
-		System.out.println("       if port is not specified, it defaults to:");
-		System.out.println("       "+VisionListener.defRawPort+" for raw");
-		System.out.println("       "+VisionListener.defRLEPort+" for RLE.");
-		System.exit(2);
-	}
-			
+				
 	public void actionPerformed(ActionEvent e) {
 		if(e.getActionCommand().compareTo("YUV")==0) {
 			vision.setConvertRGB(false);
@@ -134,36 +209,17 @@ public class VisionGUI extends JFrame implements ActionListener, VisionUpdatedLi
 			vision.setLockAspectRatio(((JCheckBox)e.getSource()).isSelected());
 		} else if(e.getActionCommand().compareTo("seq")==0) {
 			File cursavepath = new File(prefs.get("cursavepath",""));
-			JFileChooser dia=new JFileChooser(cursavepath);
-			dia.setDialogTitle("Save Image Sequence...");
-			Component cur=this;
-			while(cur.getParent()!=null)
-				cur=cur.getParent();
-			if(dia.showSaveDialog(cur)==JFileChooser.APPROVE_OPTION) {
-				prefs.put("cursavepath",dia.getCurrentDirectory().getPath());
-				imgWrite=new ImageSequenceWriterThread(vision.getListener(), saveImageBut, !vision.getConvertRGB());
-				saveImageBut.setText("Stop Saving Sequence");
-				saveImageBut.setToolTipText("Click to stop buffering new frames - already captured frames will continue to be written (unless you close the window)");
-				saveImageBut.setActionCommand("stopseq");
-				String base=dia.getSelectedFile().getName();
-				String format;
-				if(base.lastIndexOf('.')==-1) {
-					format="png";
-				} else {
-					int i=base.lastIndexOf(".");
-					format=base.substring(i+1);
-					base=base.substring(0,i);
-				}
-				int first=base.indexOf('#');
-				int last=base.lastIndexOf('#');
-				boolean appendTime=(first==-1);
-				imgWrite.setDirectory(dia.getSelectedFile().getParent());
-				if(first!=-1)
-					imgWrite.setName(base.substring(0,first),last-first+1,base.substring(last+1),format);
-				else
-					imgWrite.setName(base,0,"",format);
-				imgWrite.start();
-			}
+			SaveSequenceDialog dia = new SaveSequenceDialog(this,cursavepath);
+			dia.setVisible(true);
+			dia.addWindowListener(new WindowAdapter() {
+					public void windowClosed(WindowEvent e) {
+						SaveSequenceDialog dia=(SaveSequenceDialog)e.getWindow();
+						dia.removeWindowListener(this);
+						prefs.put("cursavepath",dia.getCurrentDirectory().getPath());
+						if(dia.success)
+							dia.gui.startSaveSequence(dia.getSelectedFile(),dia.positionsBut.isSelected());
+					}
+				});
 		} else if(e.getActionCommand().compareTo("stopseq")==0) {
 			saveImageBut.setText("Save Image Sequence");
 			saveImageBut.setToolTipText("Saves to a series of files - use .jpg or .png extension to choose format; #'s will be replaced with index, otherwise timecode is appended");
@@ -172,39 +228,77 @@ public class VisionGUI extends JFrame implements ActionListener, VisionUpdatedLi
 				imgWrite.interrupt();
 		} else if(e.getActionCommand().compareTo("img")==0) {
 			File cursavepath = new File(prefs.get("cursavepath",""));
-			JFileChooser dia=new JFileChooser(cursavepath);
-			dia.setDialogTitle("Save Image...");
-			Component cur=this;
-			while(cur.getParent()!=null)
-				cur=cur.getParent();
-			if(dia.showSaveDialog(cur)==JFileChooser.APPROVE_OPTION) {
-				prefs.put("cursavepath",dia.getCurrentDirectory().getPath());
-				String base=dia.getSelectedFile().getName();
-				String format;
-				if(base.lastIndexOf('.')==-1) {
-					format="png";
-				} else {
-					int i=base.lastIndexOf(".");
-					format=base.substring(i+1);
-					base=base.substring(0,i);
-				}
-				try {
-					FileOutputStream fileout=new FileOutputStream(dia.getSelectedFile().getParent()+File.separator+base+"."+format);
-					if(vision.getConvertRGB() && vision.getListener().hasRawJPEG() && (format.equalsIgnoreCase("jpg") || format.equalsIgnoreCase("jpeg"))) {
-						byte[] jpeg=vision.getListener().getJPEG();
-						int len=vision.getListener().getJPEGLen();
-						fileout.write(jpeg,0,len);
-					} else {
-						ImageIO.write(vision.getListener().getImage(),format,fileout);
+			SaveSequenceDialog dia = new SaveSequenceDialog(this,cursavepath);
+			dia.setVisible(true);
+			dia.addWindowListener(new WindowAdapter() {
+					public void windowClosed(WindowEvent e) {
+						SaveSequenceDialog dia=(SaveSequenceDialog)e.getWindow();
+						dia.removeWindowListener(this);
+						prefs.put("cursavepath",dia.getCurrentDirectory().getPath());
+						if(dia.success)
+							dia.gui.saveImage(dia.getSelectedFile(),dia.positionsBut.isSelected());
 					}
-				} catch(Exception ex) {ex.printStackTrace();}
-			}
+				});
 		} else if(e.getSource()==reconnectBut) {
-			vision.close();
+			vision.kill();
 			vision.open();
 		}
 	}
 
+	void startSaveSequence(File file, boolean positions) {
+		imgWrite=new ImageSequenceWriterThread(vision.getListener(), saveImageBut, !vision.getConvertRGB(), positions);
+		saveImageBut.setText("Stop Saving Sequence");
+		saveImageBut.setToolTipText("Click to stop buffering new frames - already captured frames will continue to be written (unless you close the window)");
+		saveImageBut.setActionCommand("stopseq");
+		String base=file.getName();
+		String format;
+		if(base.lastIndexOf('.')==-1) {
+			format="png";
+		} else {
+			int i=base.lastIndexOf(".");
+			format=base.substring(i+1);
+			base=base.substring(0,i);
+		}
+		int first=base.indexOf('#');
+		int last=base.lastIndexOf('#');
+		boolean appendTime=(first==-1);
+		imgWrite.setDirectory(file.getParent());
+		if(first!=-1)
+			imgWrite.setName(base.substring(0,first),last-first+1,base.substring(last+1),format);
+		else
+			imgWrite.setName(base,0,"",format);
+		imgWrite.start();
+	}
+
+	void saveImage(File file, boolean savePose) {
+		String base=file.getName();
+		String format;
+		if(base.lastIndexOf('.')==-1) {
+			format="png";
+		} else {
+			int i=base.lastIndexOf(".");
+			format=base.substring(i+1);
+			base=base.substring(0,i);
+		}
+		try {
+			FileOutputStream fileout=new FileOutputStream(file.getParent()+File.separator+base+"."+format);
+			if(vision.getConvertRGB() && vision.getListener().hasRawJPEG() && (format.equalsIgnoreCase("jpg") || format.equalsIgnoreCase("jpeg"))) {
+				byte[] jpeg=vision.getListener().getJPEG();
+				int len=vision.getListener().getJPEGLen();
+				fileout.write(jpeg,0,len);
+			} else {
+				ImageIO.write(vision.getListener().getImage(),format,fileout);
+			}
+		} catch(Exception ex) {ex.printStackTrace();}
+		if(savePose) {
+			format="pos";
+			try {
+				FileOutputStream fileout=new FileOutputStream(file.getParent()+File.separator+base+"."+format);
+				fileout.write(vision.getListener().getSensors().getBytes());
+			} catch(Exception ex) {ex.printStackTrace();}
+		}
+	}
+
 	class CloseVisionAdapter extends WindowAdapter {
 		VisionGUI gui;
 		CloseVisionAdapter(VisionGUI gui) {this.gui=gui;}
@@ -220,7 +314,7 @@ public class VisionGUI extends JFrame implements ActionListener, VisionUpdatedLi
 		//I think I had needed to add getInsets() to keep the window from moving when reopening it, but now it *causes* it to move... weird.  what changed?
 		//prefs.putInt(name+".x",getLocation().x+getInsets().left);
 		//prefs.putInt(name+".y",getLocation().y+getInsets().top);
-		this.vision.close();
+		this.vision.kill();
 		if(this.imgWrite!=null && this.imgWrite.isAlive()) {
 			if(!this.imgWrite.isInterrupted() && !this.imgWrite.stopping)
 				this.imgWrite.interrupt();
@@ -280,66 +374,42 @@ public class VisionGUI extends JFrame implements ActionListener, VisionUpdatedLi
 			lastFrameTime=0;
 		}
 	}
+	public void sensorsUpdated(VisionListener l) {}
 	
 	public VisionGUI(String host, String[] args) {
 		super();
-		int port=-1;
-		for(int i=0; i<args.length; i++) {
-			if(args[i].toUpperCase().compareTo("RLE")==0) {
-				isRLE=true;
-				isRaw=false;
-			} else if(args[i].toUpperCase().compareTo("RAW")==0) {
-				isRaw=true;
-				isRLE=false;
-			} else
-				System.err.println("VisionGUI: Unrecognized argument: "+args[0]);
-		}
-		if(isRLE)
-			port=VisionListener.defRLEPort;
-		else if(isRaw)
-			port=VisionListener.defRawPort;
-		init(host,port,args);
+		init(host,args);
 	}
 	public VisionGUI(String host, int port, String[] args) {
 		super();
-		init(host,port,args);
+		String[] passargs=new String[args.length+1];
+		passargs[0]=String.valueOf(port);
+		for(int i=0; i<args.length; i++)
+			passargs[i+1]=args[i];
+		init(host,passargs);
 	}
-	public void init(String host, int port, String[] args) {
+	public void init(String host, String[] args) {
 		int strutsize=10;
 		int sepsize=5;
 		getContentPane().setLayout(new BorderLayout());
 		getContentPane().add(Box.createVerticalStrut(strutsize),BorderLayout.NORTH);
 		getContentPane().add(Box.createHorizontalStrut(strutsize),BorderLayout.WEST);
 		getContentPane().add(Box.createHorizontalStrut(strutsize),BorderLayout.EAST);
-		//always use RLE size for default - we'll assume it's full resolution
-		vision=null;
+		vision=new VisionPanel(host,args);
 		for(int i=0; i<args.length; i++) {
-			if(args[i].toUpperCase().compareTo("RLE")==0) {
-				setTitle("TekkotsuMon: Vision RLE");
-				vision=new VisionPanel(new VisionListener(host,port));
-				isRLE=true;
-				isRaw=false;
-				break;
-			} else if(args[i].toUpperCase().compareTo("RAW")==0) {
-				setTitle("TekkotsuMon: Vision Raw");
-				vision=new VisionPanel(new VisionListener(host,port));
-				isRaw=true;
-				isRLE=false;
-				break;
-			} else
-				System.err.println("VisionGUI: Unrecognized argument: "+args[i]);
-		}
-		if(vision==null) {
-			vision=new VisionPanel(new VisionListener(host,port));
-			if(port==VisionListener.defRLEPort) {
+			if(args[i].toUpperCase().compareTo("RLE")==0 || args[i]==String.valueOf(VisionListener.defRLEPort)) {
 				setTitle("TekkotsuMon: Vision RLE");
 				isRLE=true;
 				isRaw=false;
-			} else {
+			} else if(args[i].toUpperCase().compareTo("RAW")==0 || args[i]==String.valueOf(VisionListener.defRawPort)) {
 				setTitle("TekkotsuMon: Vision Raw");
-				isRLE=false;
 				isRaw=true;
-			}
+				isRLE=false;
+			} else if(args[i].toUpperCase().compareTo("REG")==0 || args[i]==String.valueOf(VisionListener.defRegionPort)) {
+				setTitle("TekkotsuMon: Vision Regions");
+				isRaw=false;
+				isRLE=true; //It's not really an RLE window, but the options are the same, so whatever
+			} 
 		}
 		vision.setMinimumSize(new Dimension(VisionListener.DEFAULT_WIDTH/2, VisionListener.DEFAULT_HEIGHT/2));
 		vision.setPreferredSize(new Dimension(VisionListener.DEFAULT_WIDTH*2, VisionListener.DEFAULT_HEIGHT*2));
@@ -350,21 +420,20 @@ public class VisionGUI extends JFrame implements ActionListener, VisionUpdatedLi
 			tmp2.add(Box.createHorizontalStrut(strutsize));
 			{
 				Box tmp3=Box.createVerticalBox();
-				if(isRaw) {
+				if(!isRLE) {
 					Box tmp4=Box.createHorizontalBox();
 					ButtonGroup group=new ButtonGroup();
-					JRadioButton tmpRad;
-					tmpRad=new JRadioButton("RGB");
-					tmpRad.setSelected(true);
-					tmpRad.addActionListener(this);
-					tmpRad.setToolTipText("Shows RGB colorspace");
-					group.add(tmpRad);
-					tmp4.add(tmpRad);
-					tmpRad=new JRadioButton("YUV");
-					tmpRad.addActionListener(this);
-					tmpRad.setToolTipText("Shows YUV colorspace");
-					group.add(tmpRad);
-					tmp4.add(tmpRad);
+					rgbMode=new JRadioButton("RGB");
+					rgbMode.setSelected(true);
+					rgbMode.addActionListener(this);
+					rgbMode.setToolTipText("Shows RGB colorspace");
+					group.add(rgbMode);
+					tmp4.add(rgbMode);
+					yuvMode=new JRadioButton("YUV");
+					yuvMode.addActionListener(this);
+					yuvMode.setToolTipText("Shows YUV colorspace");
+					group.add(yuvMode);
+					tmp4.add(yuvMode);
 					tmp3.add(tmp4);
 				}
 				aspectBut=new JCheckBox("Lock Aspect Ratio");
@@ -416,7 +485,7 @@ public class VisionGUI extends JFrame implements ActionListener, VisionUpdatedLi
 		String name="VisionGUI"+(isRaw?".raw":"")+(isRLE?".rle":"")+".location";
 		setLocation(prefs.getInt(name+".x",50),prefs.getInt(name+".y",50));
 
-		show();
+		setVisible(true);
 
 	}
 }
