@@ -91,11 +91,11 @@ int main(unsigned int argc, const char** argv) {
 				ms.setSaveRadians();
 			else
 				ms.setSaveDegrees();
-			ms.LoadFile(argv[i]);
+			ms.loadFile(argv[i]);
 			ms.makeSafe(MaxOutputSpeed,margin);
 			if(compress)
 				ms.compress();
-			ms.SaveFile(path.c_str());
+			ms.saveFile(path.c_str());
 		}
 		used=argc;
 	} else if(argc-used==2) {
@@ -104,11 +104,11 @@ int main(unsigned int argc, const char** argv) {
 			ms.setSaveRadians();
 		else
 			ms.setSaveDegrees();
-		ms.LoadFile(argv[used]);
+		ms.loadFile(argv[used]);
 		ms.makeSafe(MaxOutputSpeed,margin);
 		if(compress)
 			ms.compress();
-		ms.SaveFile(argv[used+1]);
+		ms.saveFile(argv[used+1]);
 		used=argc;
 	} else
 		return usage(argc,argv);
