@@ -57,8 +57,10 @@ int main(int argc, char** argv) {
     }
     unsigned int len=base64::decodeSize(enc);
     write(STDOUT_FILENO,dat,len);
+		delete [] dat;
   }
-  
+  delete [] buf;
+
   destruct();
   return 0;
 }
