@@ -1,7 +1,10 @@
+#define TK_ENABLE_CONFIG 
+#define TK_ENABLE_SOUTSERR
+#define TK_ENABLE_KINEMATICS
+#include "local/minisim.h"
+
 #include <iostream>
 #include <stdlib.h>
-#include "Motion/Kinematics.h"
-#include "Shared/Config.h"
 #include "Motion/PostureEngine.h"
 #include "Shared/newmat/newmatio.h"
 
@@ -13,15 +16,22 @@ void serrprintf(const char* msg, int x, int y, int z) {
 
 using namespace std;
 using namespace NEWMAT;
-
-unsigned int simulator_time=0;
+using namespace minisim;
 
 int main(int /*argc*/, char** /*argv*/) {
-	//Read config file
 	config=new Config("../../../project/ms/config/tekkotsu.cfg");
 	config->setValue(Config::sec_motion,"root","../../../project/ms/data/motion");
-	config->setValue(Config::sec_motion,"kinematics","../../config/ers7.kin");
-	kine = new Kinematics();
+#if defined( TGT_ERS7 )
+	config->setValue(Config::sec_motion,"kinematics","../../../project/ms/config/ers7.kin");
+#elif defined( TGT_ERS210 ) || defined( TGT_ERS2xx )
+	config->setValue(Config::sec_motion,"kinematics","../../../project/ms/config/ers210.kin");
+#elif defined( TGT_ERS220 )
+	config->setValue(Config::sec_motion,"kinematics","../../../project/ms/config/ers220.kin");
+#else
+#  error Unknown target model
+#endif
+	initialize();
+
 	
 	PostureEngine pose;
 	for(unsigned int i=0; i<NumOutputs; i++)
@@ -102,6 +112,7 @@ int main(int /*argc*/, char** /*argv*/) {
 	cout << pose.getTransformLinks(LFrLegOffset+KneeOffset,BaseFrameOffset) << endl;
 	cout << pose.getTransformLinks(PawFrameOffset+LFrLegOrder,BaseFrameOffset) << endl; */
 	
+	destruct();
 	return 0;
 }
 
