@@ -14,19 +14,21 @@ using namespace minisim;
 int main(int argc, char** argv) {
 	initialize(); //minisim function for global setup
 	
+	{//restricting scope so behavior is destructed before minisim::destruct is called
 
-	EchoBehavior eb;
-	eb.SetAutoDelete(false); //needed when using stack allocation
-	eb.DoStart();
-
-	for(string in; cin; getline(cin,in)) {
-		if(in.size()>0) {
-			erouter->postEvent(new TextMsgEvent(in));
+		EchoBehavior eb;
+		eb.SetAutoDelete(false); //needed when using stack allocation
+		eb.DoStart();
+		
+		for(string in; cin; getline(cin,in)) {
+			if(in.size()>0) {
+				erouter->postEvent(TextMsgEvent(in));
+			}
 		}
-	}
+		
+		eb.DoStop();
 
-	eb.DoStop();
-	
+	}//restricting scope so behavior is destructed before minisim::destruct is called
 	
 	destruct(); //minisim function for global teardown
 	return 0;
